@@ -1,7 +1,7 @@
 #!/bin/sh
 #set -x
 #=======================================================================
-# * Version: $Id: cron_daily.src,v 1.3 2015/06/03 14:03:23 nroche Exp $
+# * Version: $Id: cron_daily.src,v 1.6 2015/10/08 21:43:50 nroche Exp $
 # * Project: MediaTex
 # * Module : scripts
 # *
@@ -24,12 +24,7 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #=======================================================================
 
-CACHEDIR="/var/cache/mediatex"
-BINDIR=/usr/bin
-LOGFILE=$(mktemp)
+BINDIR=/usr/local/bin
 
-$BINDIR/mediatex -swarning -ffile make >/dev/null 2>$LOGFILE
-$BINDIR/mediatex -swarning -ffile motd >/etc/motd 2>>$LOGFILE
-
-cat $LOGFILE | sort | uniq
-rm -f $LOGFILE
+$BINDIR/mediatex -swarning -ffile make >/dev/null
+$BINDIR/mediatex -swarning -ffile motd >/usr/local/etc/motd
\ No newline at end of file
