@@ -1,7 +1,7 @@
 #!/bin/sh
 #set -x
 #=======================================================================
-# * Version: $Id: cron_hourly.src,v 1.3 2015/06/03 14:03:23 nroche Exp $
+# * Version: $Id: cron_hourly.src,v 1.5 2015/09/22 11:42:40 nroche Exp $
 # * Project: MediaTex
 # * Module : scripts
 # *
@@ -24,8 +24,7 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #=======================================================================
 
-CACHEDIR="/var/cache/mediatex"
-BINDIR=/usr/bin
+BINDIR=/usr/local/bin
 
 $BINDIR/mediatex -swarning -ffile srv extract    
 $BINDIR/mediatex -swarning -ffile srv notify
