@@ -2,7 +2,7 @@
 #set -x
 set -e
 #=======================================================================
-# * Version: $Id: init.sh,v 1.3 2015/06/03 14:03:24 nroche Exp $
+# * Version: $Id: init.sh,v 1.6 2015/10/11 21:11:13 nroche Exp $
 # * Project: MediaTex
 # * Module : scripts
 # *
@@ -50,18 +50,20 @@ HTDOCS_configure_mdtx_apache2
 
 # only needed once
 if [ $MDTX = mdtx ]; then
-    /usr/sbin/a2enmod auth_digest autoindex env include rewrite userdir ssl
+    /usr/sbin/a2enmod \
+	auth_digest authz_groupfile autoindex cgi env include rewrite \
+	userdir ssl
     /usr/sbin/a2ensite default-ssl
     /usr/sbin/invoke-rc.d rsyslog restart
     /sbin/ldconfig
 fi
 
-/usr/sbin/a2enconf mediatex ${MEDIATEX#/}-$MDTX.conf
+/usr/sbin/a2enconf mediatex ${MEDIATEX#/}-$MDTX.conf >/dev/null
 /usr/sbin/invoke-rc.d apache2 restart
 
 # script is not automatically installed for other instances than mdtx
 if [ $MDTX = mdtx ]; then
     /usr/sbin/update-rc.d ${MEDIATEX#/}d defaults
-    /usr/sbin/invoke-rc.d ${MEDIATEX#/}d start $MDTX
+    /usr/sbin/invoke-rc.d ${MEDIATEX#/}d restart $MDTX
 fi
 Info "done"
