@@ -1,9 +1,9 @@
 /*=======================================================================
- * Version: $Id: catalogHtml.c,v 1.3 2015/06/03 14:03:28 nroche Exp $
+ * Version: $Id: catalogHtml.c,v 1.10 2015/09/04 15:30:24 nroche Exp $
  * Project: MediaTeX
- * Module : Archive catalog's latex serializer
+ * Module : catalogHtml
  *
- * Archive catalog's latex serializer interface
+ * HTML catalog serializer
 
  MediaTex is an Electronic Records Management System
  Copyright (C) 2014 2015 Nicolas Roche
@@ -22,18 +22,8 @@
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  =======================================================================*/
 
-#include "../mediatex.h"
-#include "../misc/log.h"
-#include "../misc/html.h"
-#include "../memory/strdsm.h"
-#include "../memory/ardsm.h"
-#include "../memory/confTree.h"
-#include "../memory/serverTree.h"
-#include "../memory/catalogTree.h"
-#include "../memory/extractTree.h"
-#include "../common/openClose.h"
-#include "commonHtml.h"
-#include "catalogHtml.h"
+#include "mediatex-config.h"
+#include "client/mediatex-client.h"
 
 /*=======================================================================
  * Function   : getHumanUri
@@ -156,7 +146,7 @@ htmlIndexArchive(FILE* fd, Collection* coll, Archive* self)
   RGIT* curr = 0;
 
   checkArchive(self);
-  logEmit(LOG_DEBUG, "htmlIndexArchive: %s:%lli", 
+  logMain(LOG_DEBUG, "htmlIndexArchive: %s:%lli", 
 	  self->hash, (long long int)self->size);
 
   if (!sprintf(url, 
@@ -184,7 +174,7 @@ htmlIndexArchive(FILE* fd, Collection* coll, Archive* self)
     rgRewind(self->assoCaracs);
     htmlUlOpen(fd);
 
-    while ((assoCarac = rgNext(self->assoCaracs)) != 0) {
+    while ((assoCarac = rgNext(self->assoCaracs))) {
       if (!strcmp(assoCarac->carac->label, "icon")) continue;
       if (!htmlAssoCarac(fd, assoCarac)) goto error;
     }
@@ -196,7 +186,7 @@ htmlIndexArchive(FILE* fd, Collection* coll, Archive* self)
   rc = TRUE;
  error:
   if (!rc) {
-    logEmit(LOG_ERR, "%s", "htmlIndexArchive fails");
+    logMain(LOG_ERR, "htmlIndexArchive fails");
   }
   return rc;
 }
@@ -234,9 +224,9 @@ serializeHtmlRoleList(Collection* coll, RG* assoRoles, int i, int n)
   if (!(path = createString(coll->htmlIndexDir))) goto error;
   if (!(path = catString(path, url))) goto error;
 
-  logEmit(LOG_DEBUG, "serialize %s", path);
+  logMain(LOG_DEBUG, "serialize %s", path);
   if (!env.dryRun && (fd = fopen(path, "w")) == 0) {
-    logEmit(LOG_ERR, "fopen %s fails: %s", path, strerror(errno)); 
+    logMain(LOG_ERR, "fopen %s fails: %s", path, strerror(errno)); 
     goto error;
   }  
 
@@ -255,7 +245,7 @@ serializeHtmlRoleList(Collection* coll, RG* assoRoles, int i, int n)
     htmlLink(fd, 0, url, text);
     htmlLiClose(fd);
 
-    while ((asso = rgNext(assoRoles)) != 0 && humId == asso->human->id);
+    while ((asso = rgNext(assoRoles)) && humId == asso->human->id);
     if (asso) humId = asso->human->id;
   }
   htmlUlClose(fd);
@@ -274,7 +264,7 @@ serializeHtmlRoleList(Collection* coll, RG* assoRoles, int i, int n)
   }
  error:
   if (!rc) {
-    logEmit(LOG_ERR, "%s", "serializeHtmlRoleList fails");
+    logMain(LOG_ERR, "serializeHtmlRoleList fails");
   }
   path = destroyString(path);
   return rc;
@@ -302,7 +292,7 @@ serializeHtmlRole(Collection* coll, Role* self)
   int i = 0, n = 0;
 
   if(self == 0) goto error;
-  logEmit(LOG_DEBUG, "serializeHtmlRole %i: %s", self->id, self->label);
+  logMain(LOG_DEBUG, "serializeHtmlRole %i: %s", self->id, self->label);
 
   // serialize the role header (included by each list)
   if (!getRoleListUri(tmp, "/", self->id, 0)) goto error;
@@ -312,7 +302,7 @@ serializeHtmlRole(Collection* coll, Role* self)
   // build the directory for this role
   if (mkdir(path, 0755)) {
     if (errno != EEXIST) {
-      logEmit(LOG_ERR, "mkdir fails: %s", strerror(errno));
+      logMain(LOG_ERR, "mkdir fails: %s", strerror(errno));
       goto error;
     }
   }
@@ -322,7 +312,7 @@ serializeHtmlRole(Collection* coll, Role* self)
     if (!rgSort(self->assos, cmpAssoRole)) goto error; 
 
     rgRewind(self->assos);
-    while ((assoRole = rgNext(self->assos)) != 0) {
+    while ((assoRole = rgNext(self->assos))) {
       if (humId == assoRole->human->id) continue;
       humId = assoRole->human->id;
       ++nbHum;
@@ -332,9 +322,9 @@ serializeHtmlRole(Collection* coll, Role* self)
   // serialize header file for this role
   if (!(path2 = createString(path))) goto error;
   if (!(path2 = catString(path2, "/header.shtml"))) goto error;
-  logEmit(LOG_DEBUG, "Serialize %s", path2); 
+  logMain(LOG_DEBUG, "Serialize %s", path2); 
   if (!env.dryRun && (fd = fopen(path2, "w")) == 0) {
-    logEmit(LOG_ERR, "fopen %s fails: %s", path2, strerror(errno)); 
+    logMain(LOG_ERR, "fopen %s fails: %s", path2, strerror(errno)); 
     goto error;
   }  
   htmlSSIHeader2(fd, "../../..", "index");
@@ -356,7 +346,7 @@ serializeHtmlRole(Collection* coll, Role* self)
  
     // build lists sub-directories (group by MAX_FILES_PER_DIR)
     n = (nbHum - 1) / MAX_INDEX_PER_PAGE +1;
-    logEmit(LOG_DEBUG, "have %i human, so %i lists for role %s", 
+    logMain(LOG_DEBUG, "have %i human, so %i lists for role %s", 
 	    nbHum, n, self->label);
     if (!htmlMakeDirs(path, n)) goto error;
       
@@ -371,7 +361,7 @@ serializeHtmlRole(Collection* coll, Role* self)
   rc = TRUE;
  error:
   if (!rc) {
-    logEmit(LOG_ERR, "%s", "serializeHtmlRole fails");
+    logMain(LOG_ERR, "serializeHtmlRole fails");
   }
   path = destroyString(path);
   path2 = destroyString(path2);
@@ -401,16 +391,16 @@ serializeHtmlHuman(Collection* coll, Human* self)
   int nbCategory = -1;
 
   if(self == 0) goto error;
-  logEmit(LOG_DEBUG, "serializeHtmlHuman %i: %s %s", 
+  logMain(LOG_DEBUG, "serializeHtmlHuman %i: %s %s", 
 	  self->id, self->firstName, self->secondName);
 
   getHumanUri(url, "/", self->id);
   if (!(path = createString(coll->htmlIndexDir))) goto error;
   if (!(path = catString(path, url))) goto error;
 
-  logEmit(LOG_DEBUG, "serialize: %s", path); 
+  logMain(LOG_DEBUG, "serialize: %s", path); 
   if (!env.dryRun && (fd = fopen(path, "w")) == 0) {
-    logEmit(LOG_ERR, "fopen %s fails: %s", path, strerror(errno));
+    logMain(LOG_ERR, "fopen %s fails: %s", path, strerror(errno));
     goto error;
   }  
 
@@ -430,7 +420,7 @@ serializeHtmlHuman(Collection* coll, Human* self)
     htmlPOpen(fd);
     if (!fprintf(fd, "%s", "(")) goto error;
     rgRewind(self->categories);
-    while ((category = rgNext(self->categories)) != 0) {
+    while ((category = rgNext(self->categories))) {
       getCateListUri(url, "../..", category->id, 1);
       fprintf(fd, "%s", (++nbCategory)?", ":""); // may return 0
       htmlLink(fd, 0, url, category->label);
@@ -447,7 +437,7 @@ serializeHtmlHuman(Collection* coll, Human* self)
     if (!fprintf(fd, "%s", _("Characteristics:\n"))) goto error;
     htmlUlOpen(fd);
     rgRewind(self->assoCaracs);
-    while((assoCarac = rgNext(self->assoCaracs)) != 0) {
+    while ((assoCarac = rgNext(self->assoCaracs))) {
       if (!htmlAssoCarac(fd, assoCarac)) goto error;
     }
     htmlUlClose(fd);
@@ -461,7 +451,7 @@ serializeHtmlHuman(Collection* coll, Human* self)
     htmlUlOpen(fd);
     rgRewind(self->assoRoles);
     if (!rgSort(self->assoRoles, cmpAssoRole)) goto error;
-    while ((assoRole = rgNext(self->assoRoles)) != 0) {
+    while ((assoRole = rgNext(self->assoRoles))) {
 
       if (!role || assoRole->role != role) {
 	if (role) htmlUlClose(fd);
@@ -494,7 +484,7 @@ serializeHtmlHuman(Collection* coll, Human* self)
   rc = TRUE;
  error:
   if (!rc) {
-    logEmit(LOG_ERR, "%s", "serializeHtmlHuman fails");
+    logMain(LOG_ERR, "serializeHtmlHuman fails");
   }
   path = destroyString(path);
   return rc;
@@ -524,15 +514,15 @@ serializeHtmlDocument(Collection* coll, Document* self)
   int nbCategory = -1;
 
   if(self == 0) goto error;
-  logEmit(LOG_DEBUG, "serializeHtmlDocument %i: %s", self->id, self->label);
+  logMain(LOG_DEBUG, "serializeHtmlDocument %i: %s", self->id, self->label);
 
   getDocumentUri(url, "/", self->id);
   if (!(path = createString(coll->htmlIndexDir))) goto error;
   if (!(path = catString(path, url))) goto error;
 
-  logEmit(LOG_DEBUG, "serialize: %s", path);
+  logMain(LOG_DEBUG, "serialize: %s", path);
   if (!env.dryRun && (fd = fopen(path, "w")) == 0) {
-    logEmit(LOG_ERR, "fopen %s fails: %s", path, strerror(errno));
+    logMain(LOG_ERR, "fopen %s fails: %s", path, strerror(errno));
     goto error;
   }  
 
@@ -549,7 +539,7 @@ serializeHtmlDocument(Collection* coll, Document* self)
     htmlPOpen(fd);
     if (!fprintf(fd, "%s", "(")) goto error;
     rgRewind(self->categories);
-    while ((category = rgNext(self->categories)) != 0) {
+    while ((category = rgNext(self->categories))) {
       getCateListUri(url, "../..", category->id, 1);
       fprintf(fd, "%s", (++nbCategory)?", ":""); // may return 0
       htmlLink(fd, 0, url, category->label);
@@ -566,7 +556,7 @@ serializeHtmlDocument(Collection* coll, Document* self)
     if (!fprintf(fd, "%s", _("Characteristics:\n"))) goto error;
     htmlUlOpen(fd);
     rgRewind(self->assoCaracs);
-    while((assoCarac = rgNext(self->assoCaracs)) != 0) {
+    while ((assoCarac = rgNext(self->assoCaracs))) {
       if (!htmlAssoCarac(fd, assoCarac)) goto error;
     }
     htmlUlClose(fd);
@@ -579,7 +569,7 @@ serializeHtmlDocument(Collection* coll, Document* self)
     if (!fprintf(fd, "%s", _("\nParteners:\n"))) goto error;
     htmlUlOpen(fd);
     rgRewind(self->assoRoles);
-    while ((assoRole = rgNext(self->assoRoles)) != 0) {
+    while ((assoRole = rgNext(self->assoRoles))) {
       htmlLiOpen(fd);
 
       getRoleListUri(url, "../..", assoRole->role->id, 1);
@@ -603,7 +593,7 @@ serializeHtmlDocument(Collection* coll, Document* self)
   htmlUlOpen(fd);
   if (!isEmptyRing(self->archives)) {
     rgRewind(self->archives); 
-    while ((archive = rgNext(self->archives)) != 0) {
+    while ((archive = rgNext(self->archives))) {
       htmlIndexArchive(fd, coll, archive);
     }
   }
@@ -626,7 +616,7 @@ serializeHtmlDocument(Collection* coll, Document* self)
   }
  error:
   if (!rc) {
-    logEmit(LOG_ERR, "%s", "serializeHtmlDocument fails");
+    logMain(LOG_ERR, "serializeHtmlDocument fails");
   }
   path = destroyString(path);
   return rc;
@@ -663,9 +653,9 @@ serializeHtmlCateList(Collection* coll, Category* self, int i, int n)
   if (!(path = createString(coll->htmlIndexDir))) goto error;
   if (!(path = catString(path, url))) goto error;
 
-  logEmit(LOG_DEBUG, "serialize %s", path);
+  logMain(LOG_DEBUG, "serialize %s", path);
   if (!env.dryRun && (fd = fopen(path, "w")) == 0) {
-    logEmit(LOG_ERR, "fopen %s fails: %s", path, strerror(errno)); 
+    logMain(LOG_ERR, "fopen %s fails: %s", path, strerror(errno)); 
     goto error;
   }  
 
@@ -704,7 +694,7 @@ serializeHtmlCateList(Collection* coll, Category* self, int i, int n)
   }
  error:
   if (!rc) {
-    logEmit(LOG_ERR, "%s", "serializeHtmlRoleList fails");
+    logMain(LOG_ERR, "serializeHtmlRoleList fails");
   }
   path = destroyString(path);
   return rc;
@@ -734,7 +724,7 @@ serializeHtmlCategory(Collection* coll, Category* self)
   int nbDoc = 0, i = 0, n = 0;
 
   if(self == 0) goto error;
-  logEmit(LOG_DEBUG, "serializeHtmlCategory %i: %s",
+  logMain(LOG_DEBUG, "serializeHtmlCategory %i: %s",
   	  self->id, self->label);
 
   // serialize the category header (included by each list of doc)
@@ -745,7 +735,7 @@ serializeHtmlCategory(Collection* coll, Category* self)
   // build the directory for this category
   if (mkdir(path, 0755)) {
     if (errno != EEXIST) {
-      logEmit(LOG_ERR, "mkdir fails: %s", strerror(errno));
+      logMain(LOG_ERR, "mkdir fails: %s", strerror(errno));
       goto error;
     }
   }
@@ -753,9 +743,9 @@ serializeHtmlCategory(Collection* coll, Category* self)
   // serialize header file for this role
   if (!(path2 = createString(path))) goto error;
   if (!(path2 = catString(path2, "/header.shtml"))) goto error;
-  logEmit(LOG_DEBUG, "Serialize %s", path2);
+  logMain(LOG_DEBUG, "Serialize %s", path2);
   if (!env.dryRun && (fd = fopen(path2, "w")) == 0) {
-    logEmit(LOG_ERR, "fopen %s fails: %s", path2, strerror(errno));
+    logMain(LOG_ERR, "fopen %s fails: %s", path2, strerror(errno));
     goto error;
   }
   htmlSSIHeader2(fd, "../../..", "index");
@@ -773,7 +763,7 @@ serializeHtmlCategory(Collection* coll, Category* self)
     if (!fprintf(fd, "%s", _("\nParent classes: "))) goto error;
     htmlUlOpen(fd);
     rgRewind(self->fathers);
-    while ((cat = rgNext(self->fathers)) != 0) {
+    while ((cat = rgNext(self->fathers))) {
       getCateListUri(url, "../../..", cat->id, 1);
       htmlLiOpen(fd);
       htmlLink(fd, 0, url, cat->label);
@@ -789,7 +779,7 @@ serializeHtmlCategory(Collection* coll, Category* self)
     if (!fprintf(fd, "%s", _("\nSub-classes:\n"))) goto error;
     htmlUlOpen(fd);
     rgRewind(self->childs);
-    while ((cat = rgNext(self->childs)) != 0) {
+    while ((cat = rgNext(self->childs))) {
         getCateListUri(url, "../../..", cat->id, 1);
       htmlLiOpen(fd);
       htmlLink(fd, 0, url, cat->label);
@@ -805,7 +795,7 @@ serializeHtmlCategory(Collection* coll, Category* self)
     if (!fprintf(fd, "%s", _("\nCharacteristics:\n"))) goto error;
     htmlUlOpen(fd);
     rgRewind(self->assoCaracs);
-    while((assoCarac = rgNext(self->assoCaracs)) != 0) {
+    while ((assoCarac = rgNext(self->assoCaracs))) {
       if (!htmlAssoCarac(fd, assoCarac)) goto error;
     }
     htmlUlClose(fd);
@@ -818,7 +808,7 @@ serializeHtmlCategory(Collection* coll, Category* self)
     if (!fprintf(fd, _("\nParteners:\n"))) goto error;
     htmlUlOpen(fd);
     if (!rgSort(self->humans, cmpHuman)) goto error;
-    while ((human = rgNext(self->humans)) != 0) {
+    while ((human = rgNext(self->humans))) {
       getHumanUri(url, "../../..", human->id);
       if (!sprintf(tmp, "%s %s", human->firstName, human->secondName))
   	goto error;
@@ -848,7 +838,7 @@ serializeHtmlCategory(Collection* coll, Category* self)
 
     // compute the number of document into this category
     n = (nbDoc - 1) / MAX_INDEX_PER_PAGE +1;
-    logEmit(LOG_DEBUG, "have %i doc, so %i lists for category %s",
+    logMain(LOG_DEBUG, "have %i doc, so %i lists for category %s",
   	    nbDoc, n, self->label);
 
     // build lists sub-directories (group by MAX_FILES_PER_DIR)
@@ -870,7 +860,7 @@ serializeHtmlCategory(Collection* coll, Category* self)
   rc = TRUE;
  error:
   if (!rc) {
-    logEmit(LOG_ERR, "%s", "serializeHtmlCategory fails");
+    logMain(LOG_ERR, "serializeHtmlCategory fails");
   }
   path = destroyString(path);
   path2 = destroyString(path2);
@@ -903,9 +893,9 @@ serializeHtmlDocList(Collection* coll, AVLNode **node, int i, int n)
   if (!(path = createString(coll->htmlIndexDir))) goto error;
   if (!(path = catString(path, url))) goto error;
 
-  logEmit(LOG_DEBUG, "serialize %s", path);
+  logMain(LOG_DEBUG, "serialize %s", path);
   if (!env.dryRun && (fd = fopen(path, "w")) == 0) {
-    logEmit(LOG_ERR, "fopen %s fails: %s", path, strerror(errno)); 
+    logMain(LOG_ERR, "fopen %s fails: %s", path, strerror(errno)); 
     goto error;
   }  
 
@@ -942,7 +932,7 @@ serializeHtmlDocList(Collection* coll, AVLNode **node, int i, int n)
   }
  error:
   if (!rc) {
-    logEmit(LOG_ERR, "%s", "serializeHtmlDocList fails");
+    logMain(LOG_ERR, "serializeHtmlDocList fails");
   }
   path = destroyString(path);
   return rc;
@@ -970,7 +960,7 @@ serializeHtmlDocLists(Collection* coll, CatalogTree* self)
   int n = 0;
 
   if(self == 0) goto error;
-  logEmit(LOG_DEBUG, "%s", "serializeHtmlDocLists");
+  logMain(LOG_DEBUG, "serializeHtmlDocLists");
 
   nbDoc = avl_count(self->documents);
   if (!getDocListUri(tmp, "/", 0)) goto error;
@@ -980,16 +970,16 @@ serializeHtmlDocLists(Collection* coll, CatalogTree* self)
   // build the directory
   if (mkdir(path, 0755)) {
     if (errno != EEXIST) {
-      logEmit(LOG_ERR, "mkdir fails: %s", strerror(errno));
+      logMain(LOG_ERR, "mkdir fails: %s", strerror(errno));
       goto error;
     }
   }
   // serialize header file for the document list
   if (!(path2 = createString(path))) goto error;
   if (!(path2 = catString(path2, "/header.shtml"))) goto error;
-  logEmit(LOG_DEBUG, "Serialize %s", path2); 
+  logMain(LOG_DEBUG, "Serialize %s", path2); 
   if (!env.dryRun && (fd = fopen(path2, "w")) == 0) {
-    logEmit(LOG_ERR, "fopen %s fails: %s", path2, strerror(errno)); 
+    logMain(LOG_ERR, "fopen %s fails: %s", path2, strerror(errno)); 
     goto error;
   }  
   htmlSSIHeader2(fd, "../..", "index");
@@ -1007,7 +997,7 @@ serializeHtmlDocLists(Collection* coll, CatalogTree* self)
 
   // get the total number of lists of documents
   n = (nbDoc - 1) / MAX_INDEX_PER_PAGE +1;
-  logEmit(LOG_DEBUG, "have %i document lists", n);
+  logMain(LOG_DEBUG, "have %i document lists", n);
 
   // build lists sub-directories (group by MAX_FILES_PER_DIR)
   if (!htmlMakeDirs(path, n)) goto error;
@@ -1027,7 +1017,7 @@ serializeHtmlDocLists(Collection* coll, CatalogTree* self)
   rc = TRUE;
  error:
   if (!rc) {
-    logEmit(LOG_ERR, "%s", "serializeHtmlDocLists fails");
+    logMain(LOG_ERR, "serializeHtmlDocLists fails");
   }
   path2 = destroyString(path2);
   path = destroyString(path);
@@ -1063,9 +1053,9 @@ serializeHtmlHumList(Collection* coll, AVLNode **node, int i, int n)
   if (!(path = createString(coll->htmlIndexDir))) goto error;
   if (!(path = catString(path, url))) goto error;
 
-  logEmit(LOG_DEBUG, "serialize %s", path);
+  logMain(LOG_DEBUG, "serialize %s", path);
   if (!env.dryRun && (fd = fopen(path, "w")) == 0) {
-    logEmit(LOG_ERR, "fopen %s fails: %s", path, strerror(errno)); 
+    logMain(LOG_ERR, "fopen %s fails: %s", path, strerror(errno)); 
     goto error;
   }  
 
@@ -1103,7 +1093,7 @@ serializeHtmlHumList(Collection* coll, AVLNode **node, int i, int n)
   }
  error:
   if (!rc) {
-    logEmit(LOG_ERR, "%s", "serializeHtmlHumList fails");
+    logMain(LOG_ERR, "serializeHtmlHumList fails");
   }
   path = destroyString(path);
   return rc;
@@ -1132,7 +1122,7 @@ serializeHtmlHumLists(Collection* coll, CatalogTree* self)
   int n = 0;
 
   if(self == 0) goto error;
-  logEmit(LOG_DEBUG, "%s", "serializeHtmlDocLists");
+  logMain(LOG_DEBUG, "serializeHtmlDocLists");
 
   nbHum = avl_count(self->humans);
   if (!getHumListUri(tmp, "/", 0)) goto error;
@@ -1142,16 +1132,16 @@ serializeHtmlHumLists(Collection* coll, CatalogTree* self)
   // build the directory
   if (mkdir(path, 0755)) {
     if (errno != EEXIST) {
-      logEmit(LOG_ERR, "mkdir fails: %s", strerror(errno));
+      logMain(LOG_ERR, "mkdir fails: %s", strerror(errno));
       goto error;
     }
   }
   // serialize header file for this role
   if (!(path2 = createString(path))) goto error;
   if (!(path2 = catString(path2, "/header.shtml"))) goto error;
-  logEmit(LOG_DEBUG, "Serialize %s", path2); 
+  logMain(LOG_DEBUG, "Serialize %s", path2); 
   if (!env.dryRun && (fd = fopen(path2, "w")) == 0) {
-    logEmit(LOG_ERR, "fopen %s fails: %s", path2, strerror(errno)); 
+    logMain(LOG_ERR, "fopen %s fails: %s", path2, strerror(errno)); 
     goto error;
   }  
   htmlSSIHeader2(fd, "../..", "index");
@@ -1169,7 +1159,7 @@ serializeHtmlHumLists(Collection* coll, CatalogTree* self)
 
   // get the total number of lists of documents
   n = (nbHum - 1) / MAX_INDEX_PER_PAGE +1;
-  logEmit(LOG_DEBUG, "have %i human lists", n);
+  logMain(LOG_DEBUG, "have %i human lists", n);
   if (nbHum <= 0) goto end;
 
   // build lists sub-directories (group by MAX_FILES_PER_DIR)
@@ -1186,7 +1176,7 @@ serializeHtmlHumLists(Collection* coll, CatalogTree* self)
   rc = TRUE;
  error:
   if (!rc) {
-    logEmit(LOG_ERR, "%s", "serializeHtmlHumLists fails");
+    logMain(LOG_ERR, "serializeHtmlHumLists fails");
   }
   path2 = destroyString(path2);
   path = destroyString(path);
@@ -1213,9 +1203,9 @@ serializeHtmlMainIndex(Collection* coll)
 
   if (!(path = createString(coll->htmlIndexDir))) goto error;
   if (!(path = catString(path, "/index.shtml"))) goto error;
-  logEmit(LOG_DEBUG, "serialize: %s", path);
+  logMain(LOG_DEBUG, "serialize: %s", path);
   if (!env.dryRun && (fd = fopen(path, "w")) == 0) {
-    logEmit(LOG_ERR, "fopen %s fails: %s", path, strerror(errno));
+    logMain(LOG_ERR, "fopen %s fails: %s", path, strerror(errno));
     goto error;
   }  
 
@@ -1244,7 +1234,7 @@ serializeHtmlMainIndex(Collection* coll)
   }
  error:
   if (!rc) {
-    logEmit(LOG_ERR, "%s", "serializeHtmlMainIndex fails");
+    logMain(LOG_ERR, "serializeHtmlMainIndex fails");
   }
   path = destroyString(path);
   return rc;
@@ -1269,7 +1259,7 @@ htmlCategoryMenu(FILE* fd, Category* self, int depth)
   char url[128];
 
   if (self == 0) goto error;
-  logEmit(LOG_DEBUG, "htmlCategoryMenu %i", depth);
+  logMain(LOG_DEBUG, "htmlCategoryMenu %i", depth);
 
   getCateListUri(url, "<!--#echo var='HOME' -->/index", self->id, 1);
   if (depth>0) htmlLiOpen(fd);
@@ -1279,7 +1269,7 @@ htmlCategoryMenu(FILE* fd, Category* self, int depth)
   rgRewind(self->childs);
   if (!isEmptyRing(self->childs)) {
     htmlUlOpen(fd);
-    while((category = rgNext(self->childs)) != 0) {
+    while ((category = rgNext(self->childs))) {
       if (category->show && !htmlCategoryMenu(fd, category, depth+1)) 
 	goto error;
     }
@@ -1289,7 +1279,7 @@ htmlCategoryMenu(FILE* fd, Category* self, int depth)
   rc = TRUE;
  error:
   if (!rc) {
-    logEmit(LOG_ERR, "%s", "htmlCategoryMenu fails");
+    logMain(LOG_ERR, "htmlCategoryMenu fails");
   }
   return rc;
 }
@@ -1316,9 +1306,9 @@ serializeHtmlIndexHeader(Collection* coll)
 
   if (!(path = createString(coll->htmlDir))) goto error;
   if (!(path = catString(path, "/indexHeader.shtml"))) goto error;
-  logEmit(LOG_DEBUG, "serialize %s", path);
+  logMain(LOG_DEBUG, "serialize %s", path);
   if (!env.dryRun && (fd = fopen(path, "w")) == 0) {
-    logEmit(LOG_ERR, "fdopen %s fails: %s", path, strerror(errno)); 
+    logMain(LOG_ERR, "fdopen %s fails: %s", path, strerror(errno)); 
     goto error;
   }  
 
@@ -1336,7 +1326,7 @@ serializeHtmlIndexHeader(Collection* coll)
     if (!fprintf(fd, _("\nClasses:\n"))) goto error;
     htmlUlOpen(fd);
     rgRewind(self->categories);
-    while((category = rgNext(self->categories)) != 0) {
+    while ((category = rgNext(self->categories))) {
       if (category->show && isEmptyRing(category->fathers)) {
 	htmlLiOpen(fd);
 	if (!htmlCategoryMenu(fd, category, 0)) goto error;
@@ -1356,7 +1346,7 @@ serializeHtmlIndexHeader(Collection* coll)
 
     htmlUlOpen(fd);
     rgRewind(self->roles);
-    while ((role = rgNext(self->roles)) != 0) {
+    while ((role = rgNext(self->roles))) {
       getRoleListUri(url, "<!--#echo var='HOME' -->/index", role->id, 1);
       htmlLiOpen(fd);
       htmlLink(fd, 0, url, role->label);
@@ -1367,8 +1357,7 @@ serializeHtmlIndexHeader(Collection* coll)
   }
 
   // master url (other are relatives ones)
-  if (!sprintf(url, "https://%s/~%s", coll->masterHost, coll->masterUser)) 
-    goto error;
+  if (!getServerUrl(coll->serverTree->master, "", url)) goto error;
 
   if (!htmlLeftPageTail(fd)) goto error;
   if (!htmlRightHead(fd, url)) goto error;
@@ -1380,7 +1369,7 @@ serializeHtmlIndexHeader(Collection* coll)
   rc = TRUE;
  error:
   if (!rc) {
-    logEmit(LOG_ERR, "%s", "serializeHtmlIndexHeader fails");
+    logMain(LOG_ERR, "serializeHtmlIndexHeader fails");
   }
   path = destroyString(path);
   return rc;
@@ -1412,7 +1401,7 @@ serializeHtmlIndex(Collection* coll)
 
   checkCollection(coll);
   if (!(self = coll->catalogTree)) goto error;
-  logEmit(LOG_DEBUG, "serializeHtmlIndex: %s collection", coll->label);
+  logMain(LOG_DEBUG, "serializeHtmlIndex: %s collection", coll->label);
 
   nbDoc = avl_count(self->documents);
   nbHum = avl_count(self->humans);
@@ -1422,7 +1411,7 @@ serializeHtmlIndex(Collection* coll)
   if (!(path1 = catString(path1, "/roles"))) goto error;
   if (mkdir(path1, 0755)) {
     if (errno != EEXIST) {
-      logEmit(LOG_ERR, "mkdir fails: %s", strerror(errno));
+      logMain(LOG_ERR, "mkdir fails: %s", strerror(errno));
       goto error;
     }
   }
@@ -1431,7 +1420,7 @@ serializeHtmlIndex(Collection* coll)
   if (!(path1 = catString(path1, "/categories"))) goto error;
   if (mkdir(path1, 0755)) {
     if (errno != EEXIST) {
-      logEmit(LOG_ERR, "mkdir fails: %s", strerror(errno));
+      logMain(LOG_ERR, "mkdir fails: %s", strerror(errno));
       goto error;
     }
   }
@@ -1443,13 +1432,13 @@ serializeHtmlIndex(Collection* coll)
   if (!(path1 = catString(path1, tmp))) goto error;
   if (mkdir(path1, 0755)) {
     if (errno != EEXIST) {
-      logEmit(LOG_ERR, "mkdir fails: %s", strerror(errno));
+      logMain(LOG_ERR, "mkdir fails: %s", strerror(errno));
       goto error;
     }
   }
 
   if (nbDoc > 0) {
-    logEmit(LOG_DEBUG, "have %i documents", nbDoc);
+    logMain(LOG_DEBUG, "have %i documents", nbDoc);
     if (!htmlMakeDirs(path1, nbDoc)) goto error;
   }
 
@@ -1460,13 +1449,13 @@ serializeHtmlIndex(Collection* coll)
   if (!(path1 = catString(path1, tmp))) goto error;
   if (mkdir(path1, 0755)) {
     if (errno != EEXIST) {
-      logEmit(LOG_ERR, "mkdir fails: %s", strerror(errno));
+      logMain(LOG_ERR, "mkdir fails: %s", strerror(errno));
       goto error;
     }
   }
   
   if (nbHum > 0) {
-    logEmit(LOG_DEBUG, "have %i humans", nbHum);
+    logMain(LOG_DEBUG, "have %i humans", nbHum);
     if (!htmlMakeDirs(path1, nbHum)) goto error;
   }
 
@@ -1489,7 +1478,7 @@ serializeHtmlIndex(Collection* coll)
   // roles
   if (!isEmptyRing(self->roles)) {
     if (!rgSort(self->roles, cmpRole)) goto error;
-    while((role = rgNext(self->roles)) != 0) {
+    while ((role = rgNext(self->roles))) {
       if (!serializeHtmlRole(coll, role)) goto error;
     }
   }
@@ -1497,7 +1486,7 @@ serializeHtmlIndex(Collection* coll)
   // categories
   if (!isEmptyRing(self->categories)) {
     if (!rgSort(self->categories, cmpCategory)) goto error;
-    while((category = rgNext(self->categories)) != 0) {
+    while ((category = rgNext(self->categories))) {
       if (!serializeHtmlCategory(coll, category)) goto error;
     }
   }
@@ -1515,91 +1504,6 @@ serializeHtmlIndex(Collection* coll)
   return rc;
 }
 
-/************************************************************************/
-
-#ifdef utMAIN
-#include "../misc/command.h"
-#include "../parser/confFile.tab.h"
-#include "../parser/serverFile.tab.h"
-#include "../parser/catalogFile.tab.h"
-#include "../parser/extractFile.tab.h"
-#include "extractHtml.h"
-GLOBAL_STRUCT_DEF;
-
-/*=======================================================================
- * Function   : usage
- * Description: Print the usage.
- * Synopsis   : static void usage(char* programName)
- * Input      : programName = the name of the program; usually argv[0].
- * Output     : N/A
- =======================================================================*/
-static void 
-usage(char* programName)
-{
-  mdtxUsage(programName);
-
-  mdtxOptions();
-  //fprintf(stderr, "  ---\n");
-  return;
-}
-
-/*=======================================================================
- * Function   : main 
- * Author     : Nicolas ROCHE
- * modif      : 2012/05/01
- * Description: Unit test for confTree module.
- * Synopsis   : utconfTree
- * Input      : N/A
- * Output     : N/A
- =======================================================================*/
-int 
-main(int argc, char** argv)
-{
-  Collection* coll = 0;
-  // ---
-  int rc = 0;
-  int cOption = EOF;
-  char* programName = *argv;
-  char* options = MDTX_SHORT_OPTIONS;
-  struct option longOptions[] = {
-    MDTX_LONG_OPTIONS,
-    {0, 0, 0, 0}
-  };
-       
-  // import mdtx environment
-  getEnv(&env);
-
-  // parse the command line
-  while((cOption = getopt_long(argc, argv, options, longOptions, 0)) 
-	!= EOF) {
-    switch(cOption) {
-      
-      GET_MDTX_OPTIONS; // generic options
-    }
-    if (rc) goto optError;
-  }
-
-  // export mdtx environment
-  if (!setEnv(programName, &env)) goto optError;
-
-  /************************************************************************/
-  if (!(coll = mdtxGetCollection("coll1"))) goto error;
-  if (!loadCollection(coll, CTLG)) goto error;
-  if (!serializeHtmlIndex(coll)) goto error;
-  if (!releaseCollection(coll, CTLG)) goto error;
-  /************************************************************************/
-
-  freeConfiguration();
-  rc = TRUE;
- error:
-  ENDINGS;
-  rc=!rc;
- optError:
-  exit(rc);
-}
-
-#endif // utMAIN
-
 /* Local Variables: */
 /* mode: c */
 /* mode: font-lock */
