@@ -1,9 +1,9 @@
 /*=======================================================================
- * Version: $Id: commonHtml.c,v 1.3 2015/06/03 14:03:28 nroche Exp $
+ * Version: $Id: commonHtml.c,v 1.10 2015/08/13 21:14:32 nroche Exp $
  * Project: MediaTeX
- * Module : serverTree
+ * Module : commonHtml
 
-* Server producer interface
+* HTML serializer common fonctions
 
 MediaTex is an Electronic Records Management System
 Copyright (C) 2014 2015 Nicolas Roche
@@ -22,16 +22,8 @@ You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 =======================================================================*/
 
-#include "../mediatex.h"
-#include "../mediatex.h"
-#include "../misc/log.h"
-#include "../misc/html.h"
-#include "../memory/strdsm.h"
-#include "../memory/ardsm.h"
-#include "../memory/confTree.h"
-#include "../memory/serverTree.h"
-#include "../common/openClose.h"
-#include "commonHtml.h"
+#include "mediatex-config.h"
+#include "client/mediatex-client.h"
 
 /*=======================================================================
  * Function   : getItemUri
@@ -97,7 +89,7 @@ int htmlMakeDirs(char* path, int max)
     if (!sprintf(number, "/%0*i", MAX_NUM_DIR_SIZE+1, j)) goto error;
     if (mkdir(string, 0755)) {
       if (errno != EEXIST) {
-	logEmit(LOG_ERR, "mkdir fails: %s", strerror(errno));
+	logMain(LOG_ERR, "mkdir fails: %s", strerror(errno));
 	goto error;
       }
     }
@@ -266,7 +258,7 @@ serializeHtmlListBar(Collection* coll, FILE* fd, int n, int N)
   int x = 0;
   int c = 0;
 
-  logEmit(LOG_DEBUG, "serializeHtmlScoreListBar %i/%i", n, N);
+  logMain(LOG_DEBUG, "serializeHtmlScoreListBar %i/%i", n, N);
   if (n<1 || n>N) goto error;
   if (N == 1) goto end; // do not display the bar
 
@@ -389,7 +381,7 @@ serializeHtmlListBar(Collection* coll, FILE* fd, int n, int N)
   rc = TRUE;
  error:
   if (!rc) {
-    logEmit(LOG_ERR, "%s", "serializeHtmlListBar fails");
+    logMain(LOG_ERR, "serializeHtmlListBar fails");
   }
   return rc;
 }
@@ -408,7 +400,7 @@ htmlAssoCarac(FILE* fd, AssoCarac* self)
   int rc = FALSE;
 
   if(self == 0) goto error;
-  logEmit(LOG_DEBUG, "htmlAssoCarac: %s=%s", 
+  logMain(LOG_DEBUG, "htmlAssoCarac: %s=%s", 
 	  self->carac->label, self->value);
 
   htmlLiOpen(fd);
@@ -419,7 +411,45 @@ htmlAssoCarac(FILE* fd, AssoCarac* self)
   rc = TRUE;
  error:
   if (!rc) {
-    logEmit(LOG_ERR, "%s", "htmlAssoCarac fails");
+    logMain(LOG_ERR, "htmlAssoCarac fails");
+  }
+  return rc;
+}
+
+
+/*=======================================================================
+ * Function   : getServerUrl
+ * Description: get base url for a server
+ * Synopsis   : int serializeHtmlCacheTop(Collection* coll)
+ * Input      : Server* server
+ *              char* url: an allocated string
+ *              char* txt: text to cat at the end of the url
+ * Output     : TRUE on success
+ =======================================================================*/
+int getServerUrl(Server* server, char* txt, char* url)
+{
+  int rc = FALSE;
+
+  checkServer(server);
+  if (!server->wwwPort) {
+    logMain(LOG_WARNING, "no www port define for this server");
+    server->wwwPort = WWW_PORT;
+  }
+  
+  if (server->wwwPort == 443) {
+    if (sprintf(url, "https://%s/~%s%s", 
+		 server->host, server->user, txt) <= 0) goto error;
+  }
+  else {
+    if (sprintf(url, "https://%s:%i/~%s%s",
+  		 server->host, server->wwwPort, server->user, txt) <= 0)
+      goto error;
+  }
+  
+  rc = TRUE;
+ error:
+  if (!rc) {
+    logMain(LOG_ERR, "getServerUrl fails");
   }
   return rc;
 }
@@ -447,9 +477,9 @@ serializeHtmlCacheHeader(Collection* coll)
   if (!(self = coll->serverTree)) goto error;
   if (!(path = createString(coll->htmlDir))) goto error;
   if (!(path = catString(path, "/cacheHeader.shtml"))) goto error;
-  logEmit(LOG_DEBUG, "serialize %s", path);
+  logMain(LOG_DEBUG, "serialize %s", path);
   if (!env.dryRun && (fd = fopen(path, "w")) == 0) {
-    logEmit(LOG_ERR, "fdopen %s fails: %s", path, strerror(errno)); 
+    logMain(LOG_ERR, "fdopen %s fails: %s", path, strerror(errno)); 
     goto error;
   }  
 
@@ -461,10 +491,9 @@ serializeHtmlCacheHeader(Collection* coll)
     htmlUlOpen(fd);
 
     rgRewind(self->servers);
-    while ((server = rgNext_r(self->servers, &curr)) != 0) {
-      if (!sprintf(url, "https://%s/~%s/cache/", 
-		   server->host, server->user)) goto error;
-
+    while ((server = rgNext_r(self->servers, &curr))) {
+      if (!getServerUrl(server, "/cache", url)) goto error;
+      
       htmlLiOpen(fd);
       htmlLink(fd, 0, url, server->host);
       htmlLiClose(fd);      
@@ -473,9 +502,8 @@ serializeHtmlCacheHeader(Collection* coll)
   }
   
   // master url (other are relatives ones)
-  if (!sprintf(url, "https://%s/~%s", coll->masterHost, coll->masterUser)) 
-    goto error;
-
+  if (!getServerUrl(coll->serverTree->master, "", url)) goto error;
+  
   if (!htmlLeftPageTail(fd)) goto error;
   if (!htmlRightHead(fd, url)) goto error;
   
@@ -487,7 +515,7 @@ serializeHtmlCacheHeader(Collection* coll)
   rc = TRUE;
  error:
   if (!rc) {
-    logEmit(LOG_ERR, "%s", "serializeHtmlCacheHeader fails");
+    logMain(LOG_ERR, "serializeHtmlCacheHeader fails");
   }
   path = destroyString(path);
   return rc;
@@ -519,15 +547,13 @@ serializeHtmlCgiHeader(Collection* coll)
   if (!(self = coll->serverTree)) goto error;
   if (!(path = createString(coll->htmlDir))) goto error;
   if (!(path = catString(path, "/cgiHeader.shtml"))) goto error;
-  logEmit(LOG_DEBUG, "serialize %s", path);
+  logMain(LOG_DEBUG, "serialize %s", path);
   if (!env.dryRun && (fd = fopen(path, "w")) == 0) {
-    logEmit(LOG_ERR, "fdopen %s fails: %s", path, strerror(errno)); 
+    logMain(LOG_ERR, "fdopen %s fails: %s", path, strerror(errno)); 
     goto error;
   }  
 
-  if (!sprintf(url1, "https://%s/~%s", conf->host, coll->user))
-    goto error;
-
+  if (!getServerUrl(getLocalHost(coll), "", url1)) goto error;
   if (!htmlMainHeadBasic(fd, _("Cache"), url1)) goto error;
   if (!htmlLeftPageHeadBasic(fd, _("cache"), url1)) goto error;
 
@@ -536,10 +562,9 @@ serializeHtmlCgiHeader(Collection* coll)
     htmlUlOpen(fd);
 
     rgRewind(self->servers);
-    while ((server = rgNext_r(self->servers, &curr)) != 0) {
-      if (!sprintf(url2, "https://%s/~%s/cache/", 
-		   server->host, server->user)) goto error;
-
+    while ((server = rgNext_r(self->servers, &curr))) {
+      if (!getServerUrl(server, "/cache", url2)) goto error;
+      
       htmlLiOpen(fd);
       htmlLink(fd, 0, url2, server->host);
       htmlLiClose(fd);      
@@ -547,9 +572,7 @@ serializeHtmlCgiHeader(Collection* coll)
     htmlUlClose(fd);
   }
   
-  if (!sprintf(url2, "https://%s/~%s", coll->masterHost, coll->masterUser)) 
-    goto error;
-
+  if (!getServerUrl(coll->serverTree->master, "", url2)) goto error;
   if (!htmlLeftPageTail(fd)) goto error;
   if (!htmlRightHeadBasic(fd, url2, url1)) goto error;
   
@@ -561,7 +584,7 @@ serializeHtmlCgiHeader(Collection* coll)
   rc = TRUE;
  error:
   if (!rc) {
-    logEmit(LOG_ERR, "%s", "serializeHtmlCgiHeader fails");
+    logMain(LOG_ERR, "serializeHtmlCgiHeader fails");
   }
   path = destroyString(path);
   return rc;
@@ -587,16 +610,16 @@ serializeHtmlFooter(Collection* coll)
 
   if (!(path = createString(coll->htmlDir))) goto error;
   if (!(path = catString(path, "/footer.html"))) goto error;
-  logEmit(LOG_DEBUG, "serialize %s", path);
+  logMain(LOG_DEBUG, "serialize %s", path);
 
   if (!env.dryRun && (fd = fopen(path, "w")) == 0) {
-    logEmit(LOG_ERR, "fdopen %s fails: %s", path, strerror(errno)); 
+    logMain(LOG_ERR, "fdopen %s fails: %s", path, strerror(errno)); 
     goto error;
   }  
 
   if ((now = currentTime()) == -1) goto error;
   if (localtime_r(&now, &date) == (struct tm*)0) {
-    logEmit(LOG_ERR, "%s", "localtime_r returns on error");
+    logMain(LOG_ERR, "localtime_r returns on error");
     goto error;
   }
 
@@ -614,7 +637,7 @@ serializeHtmlFooter(Collection* coll)
   rc = TRUE;
  error:
   if (!rc) {
-    logEmit(LOG_ERR, "%s", "serializeHtmlAllBottom fails");
+    logMain(LOG_ERR, "serializeHtmlAllBottom fails");
   }
   path = destroyString(path);
   return rc;
@@ -634,7 +657,7 @@ serializeHtmlCache(Collection* coll)
   int rc = FALSE;
 
   checkCollection(coll);
-  logEmit(LOG_DEBUG, "serializeHtmlCache: %s collection", coll->label);
+  logMain(LOG_DEBUG, "serializeHtmlCache: %s collection", coll->label);
 
   if (!serializeHtmlCacheHeader(coll)) goto error;
   if (!serializeHtmlCgiHeader(coll)) goto error;
@@ -643,93 +666,11 @@ serializeHtmlCache(Collection* coll)
   rc = TRUE;
  error:
   if (!rc) {
-    logEmit(LOG_ERR, "%s", "serializeHtmlCache fails");
+    logMain(LOG_ERR, "serializeHtmlCache fails");
   }
   return rc;
 }
 
-/************************************************************************/
-
-#ifdef utMAIN
-#include "../misc/command.h"
-#include "../parser/confFile.tab.h"
-#include "../parser/serverFile.tab.h"
-GLOBAL_STRUCT_DEF;
-
-/*=======================================================================
- * Function   : usage
- * Description: Print the usage.
- * Synopsis   : static void usage(char* programName)
- * Input      : programName = the name of the program; usually argv[0].
- * Output     : N/A
- =======================================================================*/
-static void 
-usage(char* programName)
-{
-  mdtxUsage(programName);
-
-  mdtxOptions();
-  //fprintf(stderr, "  ---\n");
-  return;
-}
-
-/*=======================================================================
- * Function   : main 
- * Author     : Nicolas ROCHE
- * modif      : 2012/05/01
- * Description: Unit test for serverTree module.
- * Synopsis   : utconfTree
- * Input      : N/A
- * Output     : N/A
- =======================================================================*/
-int 
-main(int argc, char** argv)
-{
-  Collection* coll = 0;
-  // ---
-  int rc = 0;
-  int cOption = EOF;
-  char* programName = *argv;
-  char* options = MDTX_SHORT_OPTIONS;
-  struct option longOptions[] = {
-    MDTX_LONG_OPTIONS,
-    {0, 0, 0, 0}
-  };
-       
-  // import mdtx environment
-  getEnv(&env);
-
-  // parse the command line
-  while((cOption = getopt_long(argc, argv, options, longOptions, 0)) 
-	!= EOF) {
-    switch(cOption) {
-      
-      GET_MDTX_OPTIONS; // generic options
-    }
-    if (rc) goto optError;
-  }
-
-  // export mdtx environment
-  if (!setEnv(programName, &env)) goto optError;
-
-  /************************************************************************/
-  if (!(coll = mdtxGetCollection("coll1"))) goto error;
-  if (!loadCollection(coll, SERV)) goto error;
-  if (!serializeHtmlCache(coll)) goto error;
-  if (!releaseCollection(coll, SERV)) goto error;
-  /************************************************************************/
-
-  rc = TRUE;
- error:
-  freeConfiguration();
-  ENDINGS;
-  rc=!rc;
- optError:
-  exit(rc);
-}
-
-#endif // utMAIN
-
 /* Local Variables: */
 /* mode: c */
 /* mode: font-lock */
