@@ -1,9 +1,9 @@
 /*=======================================================================
- * Version: $Id: commonHtml.h,v 1.3 2015/06/03 14:03:29 nroche Exp $
+ * Version: $Id: commonHtml.h,v 1.5 2015/07/07 09:33:35 nroche Exp $
  * Project: MediaTeX
- * Module : server to LaTex
+ * Module : commonHtml
  *
- * Server to LaTex serializer
+ * HTML serializer common fonctions
 
  MediaTex is an Electronic Records Management System
  Copyright (C) 2014 2015 Nicolas Roche
@@ -22,11 +22,10 @@
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 =======================================================================*/
 
-#ifndef WRAPPER_ADMSERVER_H
-#define WRAPPER_ADMSERVER_H 1
+#ifndef MDTX_CLIENT_ADMSERVER_H
+#define MDTX_CLIENT_ADMSERVER_H 1
 
-#include "../memory/serverTree.h"
-#include <avl.h>
+#include "mediatex-types.h"
 
 int getItemUri(char* buf, int id, char* suffix);
 int getListUri(char* buf, int id);
@@ -39,10 +38,10 @@ int getArchiveUri(char* buf, char* path, Archive* archive);
 int getDocumentUri(char* buf, char* path, int id);
 int serializeHtmlListBar(Collection* coll, FILE* fd, int n, int N);
 int htmlAssoCarac(FILE* fd, AssoCarac* self);
-
+int getServerUrl(Server* server, char* txt, char* url);
 int serializeHtmlCache(Collection* coll);
 
-#endif /* WRAPPER_ADMSERVER_H */
+#endif /* MDTX_CLIENT_ADMSERVER_H */
 
 /* Local Variables: */
 /* mode: c */
