@@ -1,8 +1,8 @@
 
 /*=======================================================================
- * Version: $Id: conf.c,v 1.3 2015/06/03 14:03:29 nroche Exp $
+ * Version: $Id: conf.c,v 1.9 2015/09/22 11:42:40 nroche Exp $
  * Project: MediaTeX
- * Module : wrapper/conf
+ * Module : conf
  *
  * Manage mediatex.conf configuration file
 
@@ -23,18 +23,8 @@
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  =======================================================================*/
 
-#include "../mediatex.h"
-#include "../misc/log.h"
-#include "../misc/command.h"
-#include "../memory/confTree.h"
-#include "../parser/confFile.tab.h"
-#include "../common/openClose.h"
-#include "supp.h"
-#include "serv.h"
-#include "conf.h"
-
-#include <sys/stat.h>
-#include <time.h>
+#include "mediatex-config.h"
+#include "client/mediatex-client.h"
 
 
 /*=======================================================================
@@ -61,7 +51,7 @@ mdtxAddCollection(Collection* coll)
 
   checkCollection(coll);
   checkLabel(coll->label);
-  logEmit(LOG_DEBUG, "%s", "add a new collection (or re-add it)");
+  logMain(LOG_DEBUG, "add a new collection (or re-add it)");
   if (!(conf = getConfiguration())) goto error;
   
   // default value to mdtx if not provided
@@ -82,12 +72,11 @@ mdtxAddCollection(Collection* coll)
   argv[0] = catString(argv[0], "/new.sh");
   argv[1] = buf;
   
-#ifndef utMAIN
-  if (!execScript(argv, 0, 0, FALSE)) goto error;
-#endif
+  if (!env.noRegression) {
+    if (!execScript(argv, 0, 0, FALSE)) goto error;
+  }
 
   // check if script realy success
-  if (!loadConfiguration(CONF)) goto error;
   if (!(cvsFile = createString(conf->cvsDir)) 
       || !(cvsFile =  catString(cvsFile, "/"))
       || !(cvsFile =  catString(cvsFile, env.confLabel))
@@ -96,23 +85,25 @@ mdtxAddCollection(Collection* coll)
       || !(cvsFile =  catString(cvsFile, "/servers.txt")))
     goto error;
   if (stat(cvsFile, &sb) == -1) {
-    logEmit(LOG_INFO, "stat: %s", strerror(errno));
-    logEmit(LOG_DEBUG, "(stat was looking for %s)", cvsFile);
-    logEmit(LOG_NOTICE,
+    logMain(LOG_INFO, "stat: %s", strerror(errno));
+    logMain(LOG_DEBUG, "(stat was looking for %s)", cvsFile);
+    logMain(LOG_NOTICE,
 	    "Please send your collection key to %s server admin",
 	    coll->masterHost);
     goto end;
   }
 
   // register collection into configuration file
+  if (!loadConfiguration(CFG)) goto error;
   if (!(self = addCollection(coll->label))) goto error;
+  destroyString(self->masterLabel);
   self->masterLabel = coll->masterLabel;
   coll->masterLabel = 0; // consume it
   strncpy(self->masterHost, coll->masterHost, MAX_SIZE_HOST);
   self->masterPort = coll->masterPort;
   if (!expandCollection(self)) goto error;
   if (!populateCollection(self)) goto error;
-  conf->fileState[iCONF] = MODIFIED; // upgrade conf
+  conf->fileState[iCFG] = MODIFIED; // upgrade conf
 
   // register collection into servers.txt file
   if (!(self->serverTree->master = getLocalHost(self))) goto error;
@@ -123,12 +114,12 @@ mdtxAddCollection(Collection* coll)
   rc = TRUE;
  error:
   if (!rc) {
-    logEmit(LOG_ERR, "%s", "fails to add new collection");
+    logMain(LOG_ERR, "fails to add new collection");
     if (self) delCollection(self);
   }
   argv[0] = destroyString(argv[0]);
   cvsFile = destroyString(cvsFile);
-  // coll is freed by parser
+  // coll is free by parser
   return rc;
 }
 
@@ -150,7 +141,7 @@ mdtxDelCollection(char* label)
   Collection* coll = 0;
   char* argv[3] = {0, 0, 0};
 
-  logEmit(LOG_DEBUG, "%s", "del a collection");
+  logMain(LOG_DEBUG, "del a collection");
 
   //if (!allowedUser(env.confLabel)) goto error;
   if (!(conf = getConfiguration())) goto error;
@@ -160,25 +151,26 @@ mdtxDelCollection(char* label)
   argv[0] = createString(conf->scriptsDir);
   argv[0] = catString(argv[0], "/free.sh");
   argv[1] = label;
-#ifndef utMAIN
-  if (!execScript(argv, 0, 0, FALSE)) goto error;
-#endif
+
+  if (!env.noRegression) {
+    if (!execScript(argv, 0, 0, FALSE)) goto error;
+  }
 
   // upgrade configuration file
   // note: do not expand collection
-  if (!loadConfiguration(CONF)) goto error;
+  if (!loadConfiguration(CFG)) goto error;
   if (!(coll = getCollection(label))) {
-    logEmit(LOG_WARNING, "there was no collection named '%s'", label);
+    logMain(LOG_WARNING, "there was no collection named '%s'", label);
     goto end;
   }
   if (!delCollection(coll)) goto error;
-  conf->fileState[iCONF] = MODIFIED;
+  conf->fileState[iCFG] = MODIFIED;
   
  end:
   rc = TRUE;
  error:
   if (!rc) {
-    logEmit(LOG_ERR, "%s", "fails to del collection");
+    logMain(LOG_ERR, "fails to del collection");
   }
   if (argv[0]) free(argv[0]);
   return rc;
@@ -189,31 +181,35 @@ mdtxDelCollection(char* label)
  * Function   : listCollection
  * Description: print label of collections in configuration
  * Synopsis   : listCollection()
- * Input      : N/A
+ * Input      : int onlyMasterColl: only list locally hosted collections
  * Output     : number of matching collections
  =======================================================================*/
 int
-mdtxListCollection()
+mdtxListCollection(int onlyMasterColl)
 {
   int rc = FALSE; 
   Configuration* conf = 0;
-  Collection* collection = 0;
+  Collection* coll = 0;
   int nb = 0;
 
   // search into the configuration
-  if (!loadConfiguration(CONF)) goto error;
+  if (!loadConfiguration(CFG)) goto error;
   if (!(conf = getConfiguration())) goto error;
-  if (conf->collections != 0) {
+  if (conf->collections) {
 
-    if (conf->collections != 0) {
+    if (conf->collections) {
       if (!rgSort(conf->collections, cmpCollection)) {
-	logEmit(LOG_ERR, "%s", "fails to sort collections ring");
+	logMain(LOG_ERR, "fails to sort collections ring");
 	goto error;
       }
     }
     
-    while((collection = rgNext(conf->collections)) != 0) {
-      printf("%s%s", nb++?" ":"", collection->label);
+    while ((coll = rgNext(conf->collections))) {
+      if (onlyMasterColl) {
+	if (strcmp(coll->masterHost, conf->host)) continue;
+	if (strcmp(coll->masterLabel, env.confLabel)) continue;
+      }
+      printf("%s%s", nb++?" ":"", coll->label);
     }
   }
   printf("\n");
@@ -241,15 +237,15 @@ mdtxShareSupport(char* sLabel, char* cLabel)
   Collection* coll = 0;
 
   checkLabel(sLabel);
-  if (!loadConfiguration(CONF)) goto error;
+  if (!loadConfiguration(CFG)) goto error;
   if (!(conf = getConfiguration())) goto error;
   if (!(supp = mdtxGetSupport(sLabel))) goto error;
 
   // for all collections
   if (cLabel == 0) {
-    if (conf->collections != 0) {
+    if (conf->collections) {
       rgRewind(conf->collections);
-      while((coll = rgNext(conf->collections)) != 0) {
+      while ((coll = rgNext(conf->collections))) {
 	if (!addSupportToCollection(supp, coll)) goto error;
 	if (!wasModifiedCollection(coll, SERV)) goto error;
       }
@@ -263,11 +259,11 @@ mdtxShareSupport(char* sLabel, char* cLabel)
     if (!wasModifiedCollection(coll, SERV)) goto error;
   }
 
-  conf->fileState[iCONF] = MODIFIED;
+  conf->fileState[iCFG] = MODIFIED;
   rc = TRUE;
  error:
   if (!rc) {
-    logEmit(LOG_ERR, "fails to share \"%s\" support with %s collection%s", 
+    logMain(LOG_ERR, "fails to share \"%s\" support with %s collection%s", 
 	    supp?supp->name:"unknown", 
 	    cLabel?cLabel:"all", cLabel?"":"s");
   }
@@ -290,15 +286,15 @@ mdtxWithdrawSupport(char* sLabel, char* cLabel)
   Support* supp = 0;
   Collection* coll = 0;
 
-  if (!loadConfiguration(CONF)) goto error;
+  if (!loadConfiguration(CFG)) goto error;
   if (!(conf = getConfiguration())) goto error;
   if (!(supp = mdtxGetSupport(sLabel))) goto error;
 
   // for all collections
   if (cLabel == 0) {
-    if (conf->collections != 0) {
+    if (conf->collections) {
       rgRewind(conf->collections);
-      while((coll = rgNext(conf->collections)) != 0) {
+      while ((coll = rgNext(conf->collections))) {
 	if (!delSupportFromCollection(supp, coll)) goto error;
 	if (!wasModifiedCollection(coll, SERV)) goto error;
       }
@@ -313,11 +309,11 @@ mdtxWithdrawSupport(char* sLabel, char* cLabel)
     if (!wasModifiedCollection(coll, SERV)) goto error;
   }
 
-  conf->fileState[iCONF] = MODIFIED;
+  conf->fileState[iCFG] = MODIFIED;
   rc = TRUE;
  error:
   if (!rc) {
-    logEmit(LOG_ERR, 
+    logMain(LOG_ERR, 
 	    "fails to withdraw \"%s\" support from %s collection%s", 
 	    supp?supp->name:"unknown", 
 	    coll?coll->label:"all", coll?"":"s");
@@ -325,125 +321,6 @@ mdtxWithdrawSupport(char* sLabel, char* cLabel)
   return rc;
 }
 
-/************************************************************************/
-
-#ifdef utMAIN
-#include "../misc/command.h"
-GLOBAL_STRUCT_DEF;
-
-/*=======================================================================
- * Function   : usage
- * Description: Print the usage.
- * Synopsis   : static void usage(char* programName)
- * Input      : programName = the name of the program; usually argv[0].
- * Output     : N/A
- =======================================================================*/
-static void 
-usage(char* programName)
-{
-  mdtxUsage(programName);
-
-  mdtxOptions();
-  //fprintf(stderr, "  ---\n");
-  return;
-}
-
-
-/*=======================================================================
- * Function   : main 
- * Author     : Nicolas ROCHE
- * modif      : 2010/12/10
- * Description: entry point for conf module
- * Synopsis   : ./utconf
- * Input      : N/A
- * Output     : stdout
- =======================================================================*/
-int 
-main(int argc, char** argv)
-{
-  Collection* coll3 = 0;
-  Collection* coll4 = 0;
-  char* supp = "SUPP21_logo.part1";
-  // ---
-  int rc = 0;
-  int cOption = EOF;
-  char* programName = *argv;
-  char* options = MDTX_SHORT_OPTIONS;
-  struct option longOptions[] = {
-    MDTX_LONG_OPTIONS,
-    {0, 0, 0, 0}
-  };
-
-  // import mdtx environment
-  getEnv(&env);
-
-  // parse the command line
-  while((cOption = getopt_long(argc, argv, options, longOptions, 0)) 
-	!= EOF) {
-    switch(cOption) {
-      
-      GET_MDTX_OPTIONS; // generic options
-    }
-    if (rc) goto optError;
-  }
-
-  // export mdtx environment
-  if (!setEnv(programName, &env)) goto optError;
-
-  /************************************************************************/
-  if (!(coll3 = addCollection("coll3"))) goto error;
-
-  logEmit(LOG_NOTICE, "%s", "*** List collections: ");
-  if (!mdtxListCollection()) goto error;
-
-  logEmit(LOG_NOTICE, "%s", "*** Add a collection:");
-  if (!(coll4 = createCollection())) goto error;
-  strncpy(coll4->label, "coll4", MAX_SIZE_COLL);
-  strncpy(coll4->masterHost, "localhost", MAX_SIZE_HOST);
-  if (!mdtxAddCollection(coll4)) goto error;
-  coll4 = destroyCollection(coll4);
-
-  logEmit(LOG_NOTICE, "%s", "*** List collections:");
-  if (!mdtxListCollection()) goto error;
-
-  logEmit(LOG_NOTICE, "%s", "*** Del collection coll 4:");
-  if (!mdtxDelCollection("coll4")) goto error;
-  if (!saveConfiguration("topo")) goto error;
-
-  logEmit(LOG_NOTICE, "%s", "*** Share a support:");
-  if (!mdtxShareSupport(supp, "coll3")) goto error;
-  if (!saveConfiguration("topo")) goto error;
-
-  logEmit(LOG_NOTICE, "%s", "*** Share a support second time:");
-  if (!mdtxShareSupport(supp, "coll3")) goto error;
-  
-  logEmit(LOG_NOTICE, "%s", "*** Share support with all collections:");
-  if (!mdtxShareSupport(supp, 0)) goto error;
-  if (!saveConfiguration("topo")) goto error;
-
-  logEmit(LOG_NOTICE, "%s", "*** Withdraw a support:");
-  if (!mdtxWithdrawSupport(supp, "coll3")) goto error;
-  if (!saveConfiguration("topo")) goto error;
-
-  logEmit(LOG_NOTICE, "%s", "*** Withdraw second time:");
-  if (!mdtxWithdrawSupport(supp, "coll3")) goto error;
-
-  logEmit(LOG_NOTICE, "%s", "*** Withdraw support from all collections:");
-  if (!mdtxWithdrawSupport(supp, 0)) goto error;
-  if (!saveConfiguration("topo")) goto error;
-  /************************************************************************/
-  
-  rc = TRUE;
- error:
-  freeConfiguration();
-  ENDINGS;
-  rc=!rc;
- optError:
-  exit(rc);
-}
-
-#endif // utMAIN
-
 /* Local Variables: */
 /* mode: c */
 /* mode: font-lock */
