@@ -1,9 +1,9 @@
 /*=======================================================================
- * Version: $Id: extractHtml.c,v 1.3 2015/06/03 14:03:29 nroche Exp $
+ * Version: $Id: extractHtml.c,v 1.14 2015/09/23 19:10:19 nroche Exp $
  * Project: MediaTeX
- * Module : extraction tree latex serializer
+ * Module : extractHtml
  *
- * Extraction tree latex serializer interface
+ * HTML extraction catalog serializer
 
  MediaTex is an Electronic Records Management System
  Copyright (C) 2014 2015 Nicolas Roche
@@ -22,20 +22,8 @@
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  =======================================================================*/
 
-#include "../mediatex.h"
-#include "../mediatex.h"
-#include "../misc/log.h"
-#include "../misc/html.h"
-#include "../memory/strdsm.h"
-#include "../memory/ardsm.h"
-#include "../memory/confTree.h"
-#include "../memory/serverTree.h"
-#include "../memory/catalogTree.h"
-#include "../memory/extractTree.h"
-#include "../common/openClose.h"
-#include "../common/extractScore.h"
-#include "commonHtml.h"
-#include "extractHtml.h"
+#include "mediatex-config.h"
+#include "client/mediatex-client.h"
 
 /*=======================================================================
  * Function   : getArchiveListUri
@@ -99,7 +87,7 @@ htmlFromAsso(FromAsso* self, FILE* fd, int isHeader)
   int i = 0;
 
   if(self == 0) goto error;
-  logEmit(LOG_DEBUG, "%s", "htmlFromAsso");
+  logMain(LOG_DEBUG, "htmlFromAsso");
 
   container = self->container;
   many = (container->parents->nbItems > 1);
@@ -112,7 +100,7 @@ htmlFromAsso(FromAsso* self, FILE* fd, int isHeader)
   // do not sort !
   if (many) htmlUlOpen(fd);
   
-  while((archive = rgNext(container->parents)) != 0) {
+  while ((archive = rgNext(container->parents))) {
     if (isHeader) {
       getArchiveUri(url, "../../../..", archive);
     } else {
@@ -138,7 +126,7 @@ htmlFromAsso(FromAsso* self, FILE* fd, int isHeader)
   rc = TRUE;
  error:
   if (!rc) {
-    logEmit(LOG_ERR, "%s", "htmlFromAsso fails");
+    logMain(LOG_ERR, "htmlFromAsso fails");
   }
   return rc;
 }
@@ -163,7 +151,7 @@ htmlContainer(Container* self, FILE* fd)
   char score[8];
 
   if(self == 0) goto error;
-  logEmit(LOG_DEBUG, "%s", "htmlContainer");
+  logMain(LOG_DEBUG, "htmlContainer");
 
   //many = (self->childs->nbItems > 1);
   many = (avl_count(self->childs) > 1);
@@ -194,7 +182,7 @@ htmlContainer(Container* self, FILE* fd)
   rc = TRUE;
  error:
   if (!rc) {
-    logEmit(LOG_ERR, "%s", "htmlContainer fails");
+    logMain(LOG_ERR, "htmlContainer fails");
   }
   return rc;
 }
@@ -227,9 +215,9 @@ serializeHtmlContentList(Collection* coll, AVLNode **node,
   if (!(path = createString(coll->htmlScoreDir))) goto error;
   if (!(path = catString(path, url))) goto error;
 
-  logEmit(LOG_DEBUG, "serialize %s", path);
+  logMain(LOG_DEBUG, "serialize %s", path);
   if (!env.dryRun && (fd = fopen(path, "w")) == 0) {
-    logEmit(LOG_ERR, "fopen %s fails: %s", path, strerror(errno));
+    logMain(LOG_ERR, "fopen %s fails: %s", path, strerror(errno));
     goto error;
   }
 
@@ -271,7 +259,7 @@ serializeHtmlContentList(Collection* coll, AVLNode **node,
   }
  error:
   if (!rc) {
-    logEmit(LOG_ERR, "%s", "serializeHtmlContentList fails");
+    logMain(LOG_ERR, "serializeHtmlContentList fails");
   }
   path = destroyString(path);
   return rc;
@@ -305,6 +293,7 @@ serializeHtmlScoreArchive(Collection* coll, Archive* self)
   char headerHome[] = "../../../..";
   char* home = mainHome;
   int nb = 0, n = 0, i = 0;
+  struct tm date;
 
   checkArchive(self);
   if (!(conf = getConfiguration())) goto error;
@@ -327,7 +316,7 @@ serializeHtmlScoreArchive(Collection* coll, Archive* self)
     if (!(path = catString(path, url))) goto error;
     if (mkdir(path, 0755)) {
       if (errno != EEXIST) {
-    	logEmit(LOG_ERR, "mkdir fails: %s", strerror(errno));
+    	logMain(LOG_ERR, "mkdir fails: %s", strerror(errno));
     	goto error;
       }
     }
@@ -345,9 +334,9 @@ serializeHtmlScoreArchive(Collection* coll, Archive* self)
   }
   if (!(path = createString(coll->htmlScoreDir))) goto error;
   if (!(path = catString(path, url))) goto error;
-  logEmit(LOG_DEBUG, "serialize %s", path);
+  logMain(LOG_DEBUG, "serialize %s", path);
   if (!env.dryRun && (fd = fopen(path, "w")) == 0) {
-    logEmit(LOG_ERR, "fopen %s fails: %s", path, strerror(errno));
+    logMain(LOG_ERR, "fopen %s fails: %s", path, strerror(errno));
     goto error;
   }
   
@@ -377,7 +366,7 @@ serializeHtmlScoreArchive(Collection* coll, Archive* self)
     rgRewind(self->assoCaracs);
     htmlUlOpen(fd);
 
-    while ((assoCarac = rgNext(self->assoCaracs)) != 0) {
+    while ((assoCarac = rgNext(self->assoCaracs))) {
       if (!htmlAssoCarac(fd, assoCarac)) goto error;
     }
 
@@ -393,7 +382,7 @@ serializeHtmlScoreArchive(Collection* coll, Archive* self)
   htmlUlOpen(fd);
   if (!isEmptyRing(self->documents)) {
     if (!rgSort(self->documents, cmpDocument)) goto error;
-    while((document = rgNext(self->documents)) != 0) {
+    while ((document = rgNext(self->documents))) {
       if (!sprintf(text, "%s/../index", home)) goto error;
       getDocumentUri(url, text, document->id);
 
@@ -416,7 +405,7 @@ serializeHtmlScoreArchive(Collection* coll, Archive* self)
   htmlUlOpen(fd);
   if (!isEmptyRing(self->images)) {
     if (!rgSort(self->images, cmpImage)) goto error;
-    while((image = rgNext(self->images)) != 0) {
+    while ((image = rgNext(self->images))) {
       if (!sprintf(text, "%s/servers/srv_%s.shtml", home,
   		   image->server->fingerPrint)) goto error;
 
@@ -441,14 +430,29 @@ serializeHtmlScoreArchive(Collection* coll, Archive* self)
   if (!isEmptyRing(self->fromContainers)) {
     // already sorted
     rgRewind(self->fromContainers);
-    while((asso = rgNext(self->fromContainers)) != 0) {
+    while ((asso = rgNext(self->fromContainers))) {
       htmlFromAsso(asso, fd, isHeader);
     }
   }
   else {
-    htmlLiOpen(fd);
-    if (!fprintf(fd, _("External source"))) goto error;
-    htmlLiClose(fd);
+    if (self->uploadTime) {
+      if (localtime_r(&self->uploadTime, &date) == (struct tm*)0) {
+	logMemory(LOG_ERR, "localtime_r returns on error");
+	goto error;
+      }
+      
+      htmlLiOpen(fd);
+      if (!fprintf(fd, _("Cache: uploaded on "))) goto error;
+      if (!fprintf(fd, "%04i-%02i-%02i %02i:%02i:%02i",
+	  date.tm_year + 1900, date.tm_mon+1, date.tm_mday,
+		   date.tm_hour, date.tm_min, date.tm_sec)) goto error;
+      htmlLiClose(fd);
+    }
+    else {
+      htmlLiOpen(fd);
+      if (!fprintf(fd, _("External source"))) goto error;
+      htmlLiClose(fd);
+    }
   }
   htmlUlClose(fd);
   htmlPClose(fd);
@@ -503,7 +507,7 @@ serializeHtmlScoreArchive(Collection* coll, Archive* self)
   }
  error:
   if (!rc) {
-    logEmit(LOG_ERR, "%s", "serializeHtmlScoreArchive fails");
+    logMain(LOG_ERR, "serializeHtmlScoreArchive fails");
   }
   path = destroyString(path);
   return rc;
@@ -529,15 +533,21 @@ serializeHtmlServer(Collection* coll, Server* server)
   char url[128];
   char text[128];
   char score[8];
+  struct tm date;
 
   checkServer(server);
+  if (localtime_r(&server->lastCommit, &date) == (struct tm*)0) {
+    logMain(LOG_ERR, "localtime_r returns on error");
+    goto error;
+  }
+  
   if (!(path = createString(coll->htmlScoreDir))) goto error;
   if (!(path = catString(path, "/servers/srv_"))) goto error;
   if (!(path = catString(path, server->fingerPrint))) goto error;
   if (!(path = catString(path, ".shtml"))) goto error;
-  logEmit(LOG_DEBUG, "serialize %s", path);
+  logMain(LOG_DEBUG, "serialize %s", path);
   if (!env.dryRun && (fd = fopen(path, "w")) == 0) {
-    logEmit(LOG_ERR, "fopen %s fails: %s", path, strerror(errno)); 
+    logMain(LOG_ERR, "fopen %s fails: %s", path, strerror(errno)); 
     goto error;
   }  
 
@@ -565,6 +575,13 @@ serializeHtmlServer(Collection* coll, Server* server)
   htmlVerb(fd, server->fingerPrint);
   htmlLiClose(fd);
   htmlLiOpen(fd);
+  if (!fprintf(fd, _("last commit: "))) goto error;
+  if (!sprintf(text, "%04i-%02i-%02i,%02i:%02i:%02i",
+	       date.tm_year + 1900, date.tm_mon+1, date.tm_mday,
+	       date.tm_hour, date.tm_min, date.tm_sec)) goto error;
+  htmlVerb(fd, text);
+  htmlLiClose(fd);
+  htmlLiOpen(fd);
   if (!fprintf(fd, _("mdtx port: "))) goto error;
   if (!sprintf(text, "%i", server->mdtxPort)) goto error;
   htmlVerb(fd, text);
@@ -585,7 +602,7 @@ serializeHtmlServer(Collection* coll, Server* server)
     htmlUlOpen(fd);
 				    
     curr = 0;
-    while((string = rgNext_r(server->networks, &curr))) {    
+    while ((string = rgNext_r(server->networks, &curr))) {    
       htmlLiOpen(fd);
       if (!fprintf(fd, "%s\n", string)) goto error;
       htmlLiClose(fd);
@@ -602,7 +619,7 @@ serializeHtmlServer(Collection* coll, Server* server)
     htmlUlOpen(fd);
 				    
     curr = 0;
-    while((string = rgNext_r(server->gateways, &curr))) {    
+    while ((string = rgNext_r(server->gateways, &curr))) {    
       htmlLiOpen(fd);
       if (!fprintf(fd, "%s\n", string)) goto error;
       htmlLiClose(fd);
@@ -620,7 +637,7 @@ serializeHtmlServer(Collection* coll, Server* server)
     htmlUlOpen(fd);
 				    
     curr = 0;
-    while((image = rgNext_r(server->images, &curr))) {    
+    while ((image = rgNext_r(server->images, &curr))) {    
       getArchiveUri(url, "..", image->archive);
       if (!sprintf(text, "%s:%lli ", image->archive->hash, 
 		   (long long int)image->archive->size)) goto error;
@@ -645,7 +662,7 @@ serializeHtmlServer(Collection* coll, Server* server)
   }
  error:
   if (!rc) {
-    logEmit(LOG_ERR, "%s", "serializeHtmlServer fails");
+    logMain(LOG_ERR, "serializeHtmlServer fails");
   }
   path = destroyString(path);
   return rc;
@@ -677,9 +694,9 @@ serializeHtmlArchiveList(Collection* coll, AVLNode **node, int i, int n)
   getArchiveListUri(url, "/", i);
   if (!(path = createString(coll->htmlScoreDir))) goto error;
   if (!(path = catString(path, url))) goto error;
-  logEmit(LOG_DEBUG, "serialize %s", path);
+  logMain(LOG_DEBUG, "serialize %s", path);
   if (!env.dryRun && (fd = fopen(path, "w")) == 0) {
-    logEmit(LOG_ERR, "fopen %s fails: %s", path, strerror(errno)); 
+    logMain(LOG_ERR, "fopen %s fails: %s", path, strerror(errno)); 
     goto error;
   }  
 
@@ -721,7 +738,7 @@ serializeHtmlArchiveList(Collection* coll, AVLNode **node, int i, int n)
   }
  error:
   if (!rc) {
-    logEmit(LOG_ERR, "%s", "serializeHtmlArchiveList fails");
+    logMain(LOG_ERR, "serializeHtmlArchiveList fails");
   }
   path = destroyString(path);
   return rc;
@@ -748,7 +765,7 @@ serializeHtmlArchiveLists(Collection* coll)
   int i = 0;
   int n = 0;
 
-  logEmit(LOG_DEBUG, "%s", "serializeHtmsScoreLists");
+  logMain(LOG_DEBUG, "serializeHtmsScoreLists");
 
   nb = avl_count(coll->archives);
   if (!getArchiveListUri(tmp, "/", 0)) goto error;
@@ -758,16 +775,16 @@ serializeHtmlArchiveLists(Collection* coll)
   // build the directory
   if (mkdir(path, 0755)) {
     if (errno != EEXIST) {
-      logEmit(LOG_ERR, "mkdir fails: %s", strerror(errno));
+      logMain(LOG_ERR, "mkdir fails: %s", strerror(errno));
       goto error;
     }
   }
   // serialize header file for the document list
   if (!(path2 = createString(path))) goto error;
   if (!(path2 = catString(path2, "/header.shtml"))) goto error;
-  logEmit(LOG_DEBUG, "Serialize %s", path2); 
+  logMain(LOG_DEBUG, "Serialize %s", path2); 
   if (!env.dryRun && (fd = fopen(path2, "w")) == 0) {
-    logEmit(LOG_ERR, "fopen %s fails: %s", path2, strerror(errno)); 
+    logMain(LOG_ERR, "fopen %s fails: %s", path2, strerror(errno)); 
     goto error;
   }  
 
@@ -786,7 +803,7 @@ serializeHtmlArchiveLists(Collection* coll)
 
   // get the total number of lists of archives
   n = (nb - 1) / MAX_INDEX_PER_PAGE +1;
-  logEmit(LOG_DEBUG, "have %i archive, so %i lists", nb, n);
+  logMain(LOG_DEBUG, "have %i archive, so %i lists", nb, n);
 
   // build lists sub-directories (group by MAX_FILES_PER_DIR)
   if (!htmlMakeDirs(path, n)) goto error;
@@ -806,7 +823,7 @@ serializeHtmlArchiveLists(Collection* coll)
   rc = TRUE;
  error:
   if (!rc) {
-    logEmit(LOG_ERR, "%s", "serializeHtmlScoreScoreLists fails");
+    logMain(LOG_ERR, "serializeHtmlScoreScoreLists fails");
   }
   path = destroyString(path);
   path2 = destroyString(path2);
@@ -841,9 +858,9 @@ serializeHtmlBadList(Collection* coll, RG* ring, int i, int n)
   if (!(path = createString(coll->htmlScoreDir))) goto error;
   if (!(path = catString(path, url))) goto error;
 
-  logEmit(LOG_DEBUG, "serialize %s", path);
+  logMain(LOG_DEBUG, "serialize %s", path);
   if (!env.dryRun && (fd = fopen(path, "w")) == 0) {
-    logEmit(LOG_ERR, "fopen %s fails: %s", path, strerror(errno)); 
+    logMain(LOG_ERR, "fopen %s fails: %s", path, strerror(errno)); 
     goto error;
   }  
 
@@ -885,7 +902,7 @@ serializeHtmlBadList(Collection* coll, RG* ring, int i, int n)
   }
  error:
   if (!rc) {
-    logEmit(LOG_ERR, "%s", "serializeHtmlBadList fails");
+    logMain(LOG_ERR, "serializeHtmlBadList fails");
   }
   path = destroyString(path);
   return rc;
@@ -913,8 +930,9 @@ serializeHtmlBadLists(Collection* coll)
   int nb = 0;
   int i = 0;
   int n = 0;
+  char buf[30];
 
-  logEmit(LOG_DEBUG, "%s", "serializeHtmsBadLists");
+  logMain(LOG_DEBUG, "serializeHtmsBadLists");
 
   // put bad archives into a new ring  
   if (!(badArchives = createRing())) goto error;
@@ -928,16 +946,16 @@ serializeHtmlBadLists(Collection* coll)
   // build the directory
   if (mkdir(path, 0755)) {
     if (errno != EEXIST) {
-      logEmit(LOG_ERR, "mkdir fails: %s", strerror(errno));
+      logMain(LOG_ERR, "mkdir fails: %s", strerror(errno));
       goto error;
     }
   }
   // serialize header file for the document list
   if (!(path2 = createString(path))) goto error;
   if (!(path2 = catString(path2, "/header.shtml"))) goto error;
-  logEmit(LOG_DEBUG, "Serialize %s", path2); 
+  logMain(LOG_DEBUG, "Serialize %s", path2); 
   if (!env.dryRun && (fd = fopen(path2, "w")) == 0) {
-    logEmit(LOG_ERR, "fopen %s fails: %s", path2, strerror(errno)); 
+    logMain(LOG_ERR, "fopen %s fails: %s", path2, strerror(errno)); 
     goto error;
   }
   
@@ -951,20 +969,8 @@ serializeHtmlBadLists(Collection* coll)
   htmlPClose(fd);
   
   if (badSize > 0) {
-    if (badSize >= GIGA) {
-      if (!fprintf(fd, "%lli Go\n", badSize / GIGA)) goto error;
-      goto next;
-    }
-    if (badSize >= MEGA) {
-      if (!fprintf(fd, "%lli Mo\n", badSize / MEGA)) goto error;
-      goto next;
-    }
-    if (badSize >= KILO) {
-      if (!fprintf(fd, "%lli Ko\n", badSize / KILO)) goto error;
-      goto next;
-    }
-    if (!fprintf(fd, "%lli o\n", badSize)) goto error;
-  next:
+    sprintSize(buf, badSize);
+    if (!fprintf(fd, "%s\n", buf)) goto error;
     if (!fprintf(fd, "%s", _("should be burned into supports:")))
       goto error;
   }
@@ -980,7 +986,7 @@ serializeHtmlBadLists(Collection* coll)
 
   // get the total number of lists of documents
   n = (nb - 1) / MAX_INDEX_PER_PAGE +1;
-  logEmit(LOG_DEBUG, "have %i bad archives, so %i lists", nb, n);
+  logMain(LOG_DEBUG, "have %i bad archives, so %i lists", nb, n);
 
   // build lists sub-directories (group by MAX_FILES_PER_DIR)
   if (!htmlMakeDirs(path, n)) goto error;
@@ -1000,7 +1006,7 @@ serializeHtmlBadLists(Collection* coll)
   rc = TRUE;
  error:
   if (!rc) {
-    logEmit(LOG_ERR, "%s", "serializeHtmlBadLists fails");
+    logMain(LOG_ERR, "serializeHtmlBadLists fails");
   }
   path = destroyString(path);
   path2 = destroyString(path2);
@@ -1033,9 +1039,9 @@ serializeHtmsScoreIndex(Collection* coll)
 
   if (!(path = createString(coll->htmlScoreDir))) goto error;
   if (!(path = catString(path, "/index.shtml"))) goto error;
-  logEmit(LOG_DEBUG, "serialize %s", path);
+  logMain(LOG_DEBUG, "serialize %s", path);
   if (!env.dryRun && (fd = fopen(path, "w")) == 0) {
-    logEmit(LOG_ERR, "fdopen %s fails: %s", path, strerror(errno)); 
+    logMain(LOG_ERR, "fdopen %s fails: %s", path, strerror(errno)); 
     goto error;
   }  
 
@@ -1046,6 +1052,12 @@ serializeHtmsScoreIndex(Collection* coll)
   if (!fprintf(fd, _("\nScore parameters:\n"))) goto error;
   htmlUlOpen(fd);
   htmlLiOpen(fd);
+  printLapsTime(fd, "%-10s:", "serverTTL",  serverTree->serverTTL);
+  htmlLiClose(fd);
+  htmlLiOpen(fd);
+  printLapsTime(fd, "%-10s:", "uploadTTL",  serverTree->uploadTTL);
+  htmlLiClose(fd);
+  htmlLiOpen(fd);
   printLapsTime(fd, "%-10s:", "suppTTL",  serverTree->scoreParam.suppTTL);
   htmlLiClose(fd);
   htmlLiOpen(fd);
@@ -1061,6 +1073,9 @@ serializeHtmsScoreIndex(Collection* coll)
   fprintf(fd, "%-10s: %.2f\n", "factSupp", serverTree->scoreParam.factSupp);
   htmlLiClose(fd);
   htmlLiOpen(fd);
+  fprintf(fd, "%-10s: %.2f\n", "fileScore", serverTree->scoreParam.fileScore);
+  htmlLiClose(fd);
+  htmlLiOpen(fd);
   fprintf(fd,  "%-10s: %i", "minGeoDup", serverTree->minGeoDup);
   htmlLiClose(fd);
   htmlUlClose(fd);
@@ -1073,7 +1088,7 @@ serializeHtmsScoreIndex(Collection* coll)
   htmlUlOpen(fd);
   if (!isEmptyRing(serverTree->archives)) {
     if (!rgSort(serverTree->archives, cmpArchive)) goto error;
-    while((archive = rgNext(serverTree->archives)) != 0) {
+    while ((archive = rgNext(serverTree->archives))) {
       getArchiveUri(url, "", archive);
       if (!sprintf(text, "%s:%lli ", archive->hash, 
 		   (long long int)archive->size)) goto error;
@@ -1104,7 +1119,7 @@ serializeHtmsScoreIndex(Collection* coll)
   rc = TRUE;
  error:
   if (!rc) {
-    logEmit(LOG_ERR, "%s", "serializeHtmsScoreIndex fails");
+    logMain(LOG_ERR, "serializeHtmsScoreIndex fails");
   }
   path = destroyString(path);
   return rc;
@@ -1133,9 +1148,9 @@ serializeHtmlScoreHeader(Collection* coll)
 
   if (!(path = createString(coll->htmlDir))) goto error;
   if (!(path = catString(path, "/scoreHeader.shtml"))) goto error;
-  logEmit(LOG_DEBUG, "serialize %s", path);
+  logMain(LOG_DEBUG, "serialize %s", path);
   if (!env.dryRun && (fd = fopen(path, "w")) == 0) {
-    logEmit(LOG_ERR, "fdopen %s fails: %s", path, strerror(errno)); 
+    logMain(LOG_ERR, "fdopen %s fails: %s", path, strerror(errno)); 
     goto error;
   }  
 
@@ -1162,7 +1177,7 @@ serializeHtmlScoreHeader(Collection* coll)
     htmlUlOpen(fd);
 
     rgRewind(self->servers);
-    while ((server = rgNext(self->servers)) != 0) {
+    while ((server = rgNext(self->servers))) {
       if (!sprintf(url, 
 		   "<!--#echo var='HOME' -->/score/servers/srv_%s.shtml", 
 		   server->fingerPrint)) goto error;
@@ -1175,8 +1190,7 @@ serializeHtmlScoreHeader(Collection* coll)
   }
 
   // master url (other are relatives ones)
-  if (!sprintf(url, "https://%s/~%s", coll->masterHost, coll->masterUser)) 
-    goto error;
+  if (!getServerUrl(coll->serverTree->master, "", url)) goto error;
 
   if (!htmlLeftPageTail(fd)) goto error;
   if (!htmlRightHead(fd, url)) goto error;
@@ -1189,7 +1203,7 @@ serializeHtmlScoreHeader(Collection* coll)
   rc = TRUE;
  error:
   if (!rc) {
-    logEmit(LOG_ERR, "%s", "serializeHtmlScoreHeader fails");
+    logMain(LOG_ERR, "serializeHtmlScoreHeader fails");
   }
   path = destroyString(path);
   return rc;
@@ -1218,14 +1232,14 @@ serializeHtmlScore(Collection* coll)
 
   checkCollection(coll);
   if (!(self = coll->serverTree)) goto error;
-  logEmit(LOG_DEBUG, "serializeHtmlScore: %s collection", coll->label);
+  logMain(LOG_DEBUG, "serializeHtmlScore: %s collection", coll->label);
  
   // servers directories
   if (!(path1 = createString(coll->htmlScoreDir))) goto error;
   if (!(path1 = catString(path1, "/servers"))) goto error;
   if (mkdir(path1, 0755)) {
     if (errno != EEXIST) {
-      logEmit(LOG_ERR, "mkdir fails: %s", strerror(errno));
+      logMain(LOG_ERR, "mkdir fails: %s", strerror(errno));
       goto error;
     }
   }
@@ -1233,7 +1247,7 @@ serializeHtmlScore(Collection* coll)
   // servers
   if (!isEmptyRing(self->servers)) {
     if (!rgSort(self->servers, cmpServer)) goto error;
-    while((server = rgNext(self->servers)) != 0) {
+    while ((server = rgNext(self->servers))) {
       if (!serializeHtmlServer(coll, server)) goto error;
     }
   }
@@ -1245,13 +1259,13 @@ serializeHtmlScore(Collection* coll)
   if (!(path1 = catString(path1, tmp))) goto error;
   if (mkdir(path1, 0755)) {
     if (errno != EEXIST) {
-      logEmit(LOG_ERR, "mkdir %s fails: %s", path1, strerror(errno));
+      logMain(LOG_ERR, "mkdir %s fails: %s", path1, strerror(errno));
       goto error;
     }
   }
 
   if ((nb = avl_count(coll->archives))) {
-    logEmit(LOG_DEBUG, "have %i archives", nb);
+    logMain(LOG_DEBUG, "have %i archives", nb);
     if (!htmlMakeDirs(path1, nb)) goto error;
   }
 
@@ -1272,99 +1286,13 @@ serializeHtmlScore(Collection* coll)
   rc = TRUE;
  error:
   if (!rc) {
-    logEmit(LOG_ERR, "%s", "serializeHtmlScore fails");
+    logMain(LOG_ERR, "serializeHtmlScore fails");
   }
   path1 = destroyString(path1);
   path2 = destroyString(path2);
   return rc;
 }
 
-/************************************************************************/
-
-#ifdef utMAIN
-#include "../misc/command.h"
-#include "../parser/confFile.tab.h"
-#include "../parser/serverFile.tab.h"
-#include "../parser/catalogFile.tab.h"
-#include "../parser/extractFile.tab.h"
-GLOBAL_STRUCT_DEF;
-
-
-/*=======================================================================
- * Function   : usage
- * Description: Print the usage.
- * Synopsis   : static void usage(char* programName)
- * Input      : programName = the name of the program; usually argv[0].
- * Output     : N/A
- =======================================================================*/
-static void 
-usage(char* programName)
-{
-  mdtxUsage(programName);
-
-  mdtxOptions();
-  //fprintf(stderr, "  ---\n");
-  return;
-}
-
-/*=======================================================================
- * Function   : main 
- * Author     : Nicolas ROCHE
- * modif      : 2012/05/01
- * Description: Unit test for confTree module.
- * Synopsis   : utconfTree
- * Input      : N/A
- * Output     : N/A
- =======================================================================*/
-int 
-main(int argc, char** argv)
-{
-  Collection* coll = 0;
-  // ---
-  int rc = 0;
-  int cOption = EOF;
-  char* programName = *argv;
-  char* options = MDTX_SHORT_OPTIONS;
-  struct option longOptions[] = {
-    MDTX_LONG_OPTIONS,
-    {0, 0, 0, 0}
-  };
-
-  // import mdtx environment
-  getEnv(&env);
-
-  // parse the command line
-  while((cOption = getopt_long(argc, argv, options, longOptions, 0)) 
-	!= EOF) {
-    switch(cOption) {
-      
-      GET_MDTX_OPTIONS; // generic options
-    }
-    if (rc) goto optError;
-  }
-
-  // export mdtx environment
-  if (!setEnv(programName, &env)) goto optError;
-
-  /************************************************************************/
-  if (!(coll = mdtxGetCollection("coll1"))) goto error;
-  if (!computeExtractScore(coll)) goto error; 
-  if (!loadCollection(coll, CTLG|SERV|EXTR)) goto error;
-  if (!serializeHtmlScore(coll)) goto error;
-  if (!releaseCollection(coll, CTLG|SERV|EXTR)) goto error;
-  /************************************************************************/
-
-  rc = TRUE;
- error:
-  freeConfiguration();
-  ENDINGS;
-  rc=!rc;
- optError:
-  exit(rc);
-}
-
-#endif // utMAIN
-
 /* Local Variables: */
 /* mode: c */
 /* mode: font-lock */
