@@ -1,9 +1,9 @@
- /*=======================================================================
- * Version: $Id: misc.c,v 1.3 2015/06/03 14:03:29 nroche Exp $
+/*=======================================================================
+ * Version: $Id: misc.c,v 1.14 2015/10/13 08:20:59 nroche Exp $
  * Project: MediaTeX
- * Module : wrapper/make
+ * Module : misc
  *
- * Front-end for the html sub modules
+ * Miscelanous client queries
 
  MediaTex is an Electronic Records Management System
  Copyright (C) 2014 2015 Nicolas Roche
@@ -20,29 +20,17 @@
  
  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
-=======================================================================*/
+ =======================================================================*/
 
-#include "../mediatex.h"
-#include "../misc/log.h"
-#include "../misc/command.h"
-#include "../misc/device.h"
-#include "../misc/progbar.h"
-#include "../misc/md5sum.h"
-#include "../misc/tcp.h"
-#include "../common/connect.h"
-#include "../common/openClose.h"
-#include "../common/extractScore.h"
-#include "commonHtml.h"
-#include "catalogHtml.h"
-#include "extractHtml.h"
-#include "misc.h"
+#include "mediatex-config.h"
+#include "client/mediatex-client.h"
 
 /*=======================================================================
  * Function   : mdtxMake
  * Author     : Nicolas ROCHE
  * modif      : 2013/10/23
  * Description: Serialize collections into LaTex files
- * Synopsis   : int mdtxPp(char* label)
+ * Synopsis   : int mdtxMake(char* label)
  * Input      : char* label = collection to pre-process
  * Output     : TRUE on success
  =======================================================================*/
@@ -58,29 +46,29 @@ int mdtxMake(char* label)
   if (!loadCollection(coll, SERV|CTLG|EXTR)) goto error;
   if (!computeExtractScore(coll)) goto error2;
 
-  logEmit(LOG_INFO, "Make HTML for %s", label);
+  logMain(LOG_INFO, "Make HTML for %s", label);
 
   // roughtly estimate the number of steps
   env.progBar.cur = 0;
   env.progBar.max = 0;
   n = avl_count(coll->archives);
   env.progBar.max += n + 2*n / MAX_INDEX_PER_PAGE;
-  logEmit(LOG_INFO, "estimate %i steps for archives", env.progBar.max);
+  logMain(LOG_INFO, "estimate %i steps for archives", env.progBar.max);
   n = avl_count(coll->catalogTree->documents);
   env.progBar.max += n + 2*n / MAX_INDEX_PER_PAGE;
   n = avl_count(coll->catalogTree->humans);
   env.progBar.max += n + 2*n / MAX_INDEX_PER_PAGE;
-  logEmit(LOG_INFO, "estimate %i steps for all", env.progBar.max);
+  logMain(LOG_INFO, "estimate %i steps for all", env.progBar.max);
 
-  logEmit(LOG_INFO, "%s", "html");
+  logMain(LOG_INFO, "html");
   if (!becomeUser(env.confLabel, TRUE)) goto error2;
   startProgBar("make");
   if (!serializeHtmlCache(coll)) goto error3;
   if (!serializeHtmlIndex(coll)) goto error3;
   if (!serializeHtmlScore(coll)) goto error3;
   stopProgBar();
-  logEmit(LOG_INFO, "steps: %lli / %lli", env.progBar.cur, env.progBar.max);
-  logEmit(LOG_INFO, "%s", "ending");
+  logMain(LOG_INFO, "steps: %lli / %lli", env.progBar.cur, env.progBar.max);
+  logMain(LOG_INFO, "ending");
 
   rc = TRUE;
  error3:
@@ -89,7 +77,94 @@ int mdtxMake(char* label)
   if (!releaseCollection(coll, SERV|CTLG|EXTR)) rc = FALSE;
  error:
   if (!rc) {
-    logEmit(LOG_ERR, "%s", "mdtxMake fails");
+    logMain(LOG_ERR, "mdtxMake fails");
+  }
+  return rc;
+}
+
+/*=======================================================================
+ * Function   : mdtxUpgradePlus
+ * Author     : Nicolas ROCHE
+ * modif      : 2013/10/23
+ * Description: Upgrade and make (order as no inpact)
+ * Synopsis   : int mdtxUpgradePlus(char* label)
+ * Input      : char* label = collection to pre-process
+ * Output     : TRUE on success
+ =======================================================================*/
+int mdtxUpgradePlus(char* label)
+{
+  int rc = FALSE;
+
+  checkLabel(label);
+  if (!mdtxUpgrade(label)) goto error;
+  if (!mdtxMake(label)) goto error;
+
+  rc = TRUE;
+ error:
+  if (!rc) {
+    logMain(LOG_ERR, "mdtxUpgradePlus fails");
+  }
+  return rc;
+}
+
+/*=======================================================================
+ * Function   : mdtxUploadPlus
+ * Author     : Nicolas ROCHE
+ * modif      : 2013/10/23
+ * Description: Upload + upgrade
+ * Synopsis   : int mdtxUploadPlus(char* label, char* path)
+ * Input      : char* label = collection to pre-process
+ *              char* catalog: catalog metadata file to upload
+ *              char* extract: extract metadata file to upload
+ *              char* file: data to upload
+ *              char* targetPath: where to copy data into the cache
+ * Output     : TRUE on success
+ =======================================================================*/
+int mdtxUploadPlus(char* label, char* catalog, char* extract, 
+		   char* file, char* targetPath)
+{
+  int rc = FALSE;
+
+  checkLabel(label);
+  if (!mdtxUpload(label, catalog, extract, file, targetPath)) 
+    goto error;
+
+  if (!mdtxUpgrade(label)) goto error;
+  rc = TRUE;
+ error:
+  if (!rc) {
+    logMain(LOG_ERR, "mdtxUploadPlus fails");
+  }
+  return rc;
+}
+
+/*=======================================================================
+ * Function   : mdtxUploadPlusPlus
+ * Author     : Nicolas ROCHE
+ * modif      : 2013/10/23
+ * Description: Upload + upgrade + make
+ * Synopsis   : int mdtxUploadPlusPlus(char* label, char* path)
+ * Input      : char* label = collection to pre-process
+ *              char* catalog: catalog metadata file to upload
+ *              char* extract: extract metadata file to upload
+ *              char* file: data to upload
+ *              char* targetPath: where to copy data into the cache
+ * Output     : TRUE on success
+ =======================================================================*/
+int mdtxUploadPlusPlus(char* label, char* catalog, char* extract, 
+		   char* file, char* targetPath)
+{
+  int rc = FALSE;
+
+  checkLabel(label);
+  if (!mdtxUploadPlus(label, catalog, extract, file, targetPath))
+    goto error;
+
+  if (!mdtxMake(label)) goto error;
+  rc = TRUE;
+ error:
+  if (!rc) {
+    logMain(LOG_ERR, "mdtxUploadPlusPlus fails");
   }
   return rc;
 }
@@ -110,7 +185,7 @@ mdtxClean(char* label)
   //Collection* coll = 0;
   char* argv[3] = {0, 0, 0};
 
-  logEmit(LOG_DEBUG, "%s", "del a collection");
+  logMain(LOG_DEBUG, "del a collection");
 
   if (!allowedUser(env.confLabel)) goto error;
   if (!(conf = getConfiguration())) goto error;
@@ -118,14 +193,15 @@ mdtxClean(char* label)
   argv[0] = createString(conf->scriptsDir);
   argv[0] = catString(argv[0], "/clean.sh");
   argv[1] = label;
-#ifndef utMAIN
-  if (!execScript(argv, "root", 0, FALSE)) goto error;
-#endif
+
+  if (!env.noRegression) {
+    if (!execScript(argv, "root", 0, FALSE)) goto error;
+  }
 
   rc = TRUE;
  error:
   if (!rc) {
-    logEmit(LOG_ERR, "%s", "fails to clean collection");
+    logMain(LOG_ERR, "fails to clean collection");
   }
   if (argv[0]) free(argv[0]);
   return rc;
@@ -145,7 +221,7 @@ mdtxInit()
   int rc = FALSE;
   char *argv[] = {0, 0, 0};
 
-  logEmit(LOG_DEBUG, "%s", "initializing mdtx software");
+  logMain(LOG_DEBUG, "initializing mdtx software");
 
   if (!(argv[0] = createString(getConfiguration()->scriptsDir)))
     goto error;
@@ -158,7 +234,7 @@ mdtxInit()
   rc = TRUE;
  error:  
   if (!rc) {
-    logEmit(LOG_ERR, "%s", "mtdx software initialization fails");
+    logMain(LOG_ERR, "mtdx software initialization fails");
   }
   if (argv[0]) destroyString(argv[0]);
   return rc;
@@ -178,7 +254,7 @@ mdtxRemove()
   int rc = FALSE;
   char *argv[] = {0, 0, 0};
 
-  logEmit(LOG_DEBUG, "%s", "removing mdtx software");
+  logMain(LOG_DEBUG, "removing mdtx software");
 
   if (!(argv[0] = createString(getConfiguration()->scriptsDir)))
     goto error;
@@ -191,7 +267,7 @@ mdtxRemove()
   rc = TRUE;
  error:  
   if (!rc) {
-    logEmit(LOG_ERR, "%s", "mtdx software removal fails");
+    logMain(LOG_ERR, "mtdx software removal fails");
   }
   if (argv[0]) destroyString(argv[0]);
   return rc;
@@ -203,7 +279,7 @@ mdtxRemove()
  * Synopsis   : int mdtxPurge()
  * Input      : N/A
  * Output     : TRUE on success
-* Note       : must be call by root
+ * Note       : must be call by root
  =======================================================================*/
 int 
 mdtxPurge()
@@ -211,7 +287,7 @@ mdtxPurge()
   int rc = FALSE;
   char *argv[] = {0, 0, 0};
 
-  logEmit(LOG_DEBUG, "%s", "purging mdtx software");
+  logMain(LOG_DEBUG, "purging mdtx software");
 
   if (!(argv[0] = createString(getConfiguration()->scriptsDir)))
     goto error;
@@ -224,7 +300,7 @@ mdtxPurge()
   rc = TRUE;
  error:  
   if (!rc) {
-    logEmit(LOG_ERR, "%s", "mdtx software purge fails");
+    logMain(LOG_ERR, "mdtx software purge fails");
   }
   if (argv[0]) destroyString(argv[0]);
   return rc;
@@ -245,21 +321,21 @@ mdtxAddUser(char* user)
   char *argv[] = {0, 0, 0};
 
   checkLabel(user);
-  logEmit(LOG_DEBUG, "mdtxAddUser %s:", user);
+  logMain(LOG_DEBUG, "mdtxAddUser %s:", user);
 
   if (!(conf = getConfiguration())) goto error;
   if (!(argv[0] = createString(conf->scriptsDir))) goto error;
   if (!(argv[0] = catString(argv[0], "/addUser.sh"))) goto error;
   argv[1] = user;
   
-#ifndef utMAIN
-  if (!execScript(argv, 0, 0, FALSE)) goto error;
-#endif
+  if (!env.noRegression) {
+    if (!execScript(argv, 0, 0, FALSE)) goto error;
+  }
 
   rc = TRUE;
  error:  
   if (!rc) {
-    logEmit(LOG_ERR, "%s", "mdtxAddUser fails");
+    logMain(LOG_ERR, "mdtxAddUser fails");
   }
   argv[0] = destroyString(argv[0]);
   return(rc);
@@ -280,21 +356,21 @@ mdtxDelUser(char* user)
   char *argv[] = {0, 0, 0};
 
   checkLabel(user);
-  logEmit(LOG_DEBUG, "mdtxDelUser %s:", user);
+  logMain(LOG_DEBUG, "mdtxDelUser %s:", user);
 
   if (!(conf = getConfiguration())) goto error;
   if (!(argv[0] = createString(conf->scriptsDir))) goto error;
   if (!(argv[0] = catString(argv[0], "/delUser.sh"))) goto error;
   argv[1] = user;
   
-#ifndef utMAIN
-  if (!execScript(argv, 0, 0, FALSE)) goto error;
-#endif
+  if (!env.noRegression) {
+    if (!execScript(argv, 0, 0, FALSE)) goto error;
+  }
 
   rc = TRUE;
  error:  
   if (!rc) {
-    logEmit(LOG_ERR, "%s", "mdtxDelUser fails");
+    logMain(LOG_ERR, "mdtxDelUser fails");
   }
   argv[0] = destroyString(argv[0]);
   return(rc);
@@ -306,7 +382,7 @@ mdtxDelUser(char* user)
  * Synopsis   : int mdtxBind()
  * Input      : N/A
  * Output     : TRUE on success
-* Note       : must be call by root
+ * Note       : must be call by root
  =======================================================================*/
 int 
 mdtxBind()
@@ -314,7 +390,7 @@ mdtxBind()
   int rc = FALSE;
   char *argv[] = {0, 0};
 
-  logEmit(LOG_DEBUG, "%s", "bind mdtx directories");
+  logMain(LOG_DEBUG, "bind mdtx directories");
 
   if (!(argv[0] = createString(getConfiguration()->scriptsDir))
       || !(argv[0] = catString(argv[0], "/bind.sh"))) 
@@ -327,7 +403,7 @@ mdtxBind()
   rc = TRUE;
  error:  
   if (!rc) {
-    logEmit(LOG_ERR, "%s", "mdtx bind fails");
+    logMain(LOG_ERR, "mdtx bind fails");
   }
   if (argv[0]) destroyString(argv[0]);
   return rc;
@@ -339,7 +415,7 @@ mdtxBind()
  * Synopsis   : int mdtxUnind()
  * Input      : N/A
  * Output     : TRUE on success
-* Note       : must be call by root
+ * Note       : must be call by root
  =======================================================================*/
 int 
 mdtxUnbind()
@@ -347,7 +423,7 @@ mdtxUnbind()
   int rc = FALSE;
   char *argv[] = {0, 0};
 
-  logEmit(LOG_DEBUG, "%s", "unbind mdtx directories");
+  logMain(LOG_DEBUG, "unbind mdtx directories");
 
   if (!(argv[0] = createString(getConfiguration()->scriptsDir))
       || !(argv[0] = catString(argv[0], "/unbind.sh"))) 
@@ -360,7 +436,7 @@ mdtxUnbind()
   rc = TRUE;
  error:  
   if (!rc) {
-    logEmit(LOG_ERR, "%s", "mdtx unbind fails");
+    logMain(LOG_ERR, "mdtx unbind fails");
   }
   if (argv[0]) destroyString(argv[0]);
   return rc;
@@ -384,7 +460,7 @@ mdtxSu(char* label)
   char* home = 0;
   char* user = 0;
 
-  logEmit(LOG_DEBUG, "mdtxSu %s", label?label:"");
+  logMain(LOG_DEBUG, "mdtxSu %s", label?label:"");
 
   // set the HOME directory environment variable
   if (label == 0) {
@@ -417,7 +493,7 @@ mdtxSu(char* label)
   rc = TRUE;
  error:  
   if (!rc) {
-    logEmit(LOG_ERR, "%s", "mdtx su has failed");
+    logMain(LOG_ERR, "mdtx su has failed");
   }
   return(rc);
 }
@@ -425,13 +501,15 @@ mdtxSu(char* label)
 /*=======================================================================
  * Function   : mdtxScp
  * Description: call scp so as to not need setuid bit on daemon
- * Synopsis   : 
- * Input      : 
- *              
+ * Synopsis   : int mdtxScp(char* label, char* fingerPrint, char* target)
+ * Input      : char* label: collection label
+ *              char* fingerPrint: source server's fingerprint
+ *              char* source: relative path to remote source
+ *              char* target: relative path to local destination
  * Output     : TRUE on success
  =======================================================================*/
 int 
-mdtxScp(char* label, char* fingerPrint, char* target)
+mdtxScp(char* label, char* fingerPrint, char* source, char* target)
 {
   int rc = FALSE;
   Collection* coll = 0;
@@ -440,8 +518,9 @@ mdtxScp(char* label, char* fingerPrint, char* target)
 
   checkLabel(label);
   checkLabel(fingerPrint);
+  checkLabel(source);
   checkLabel(target);
-  logEmit(LOG_DEBUG, "mdtxScp %s", target);
+  logMain(LOG_DEBUG, "mdtxScp %s@%s on %s", source, fingerPrint, target);
 
   if (!(coll = mdtxGetCollection(label))) goto error;
   if (!loadCollection(coll, SERV)) goto error;
@@ -453,245 +532,173 @@ mdtxScp(char* label, char* fingerPrint, char* target)
       || !(argv[1] = catString(argv[1], ":/var/cache/"))
       || !(argv[1] = catString(argv[1], server->user))
       || !(argv[1] = catString(argv[1], "/"))
-      || !(argv[1] = catString(argv[1], target)))
+      || !(argv[1] = catString(argv[1], source)))
     goto error2;
 
-  if (!(argv[2] = createString(coll->extractDir))
-      || !(argv[2] = catString(argv[2], "/")) 
-      || !(argv[2] = catString(argv[2], target)))
-    goto error2;
+  argv[2] = target;
 
   if (!env.dryRun && !execScript(argv, coll->user, 0, FALSE)) 
     goto error2;
   rc = TRUE;
  error2:
-   if (!releaseCollection(coll, SERV)) goto error;
+  if (!releaseCollection(coll, SERV)) goto error;
  error:
   if (!rc) {
-    logEmit(LOG_ERR, "%s", "mdtxScp fails");
+    logMain(LOG_ERR, "mdtxScp fails");
   } 
   argv[1] = destroyString(argv[1]);
-  argv[2] = destroyString(argv[2]);
   return rc;
 }
 
 /*=======================================================================
- * Function   : mdtxUploadFile 
- * Description: upload a file and add its extraction metadata
- * Synopsis   : int mdtxUploadFile(char* label, char* path)
- * Input      : char* label = related collection
- *            : char* path = path to the file to upload
+ * Function   : mdtxAudit
+ * Description: simulate extraction on all archive of a collection
+ * Synopsis   : int mdtxAudit(char* label, char* mail)
+ * Input      : char* label: collection label
+ *              char* mail: mail to use to return the audit
  * Output     : TRUE on success
  =======================================================================*/
-int
-mdtxUploadFile(char* label, char* path)
-{
+int 
+mdtxAudit(char* label, char* mail)
+{ 
   int rc = FALSE;
-  int socket = -1;
+  Configuration* conf = 0;
   Collection* coll = 0;
-  Container* container = 0;
-  Archive* archive = 0;
   RecordTree* tree = 0;
+  Archive* archive = 0;
   Record* record = 0;
-  struct stat statBuffer;
-  Md5Data md5; 
-  char* extra = 0;
-#ifndef utMAIN
-  char* message = 0;
-  char reply[256];
-  int status = 0;
+  AVLNode *node = 0;
+  FILE* fd = stdout; 
+  char path[MAX_SIZE_STRING];
+  char extra[MAX_SIZE_STRING];
+  char* ptrMail = 0;
+  char* tmp = 0;
+  time_t now = 0;
+  struct tm date;
+  int socket = -1;
   int n = 0;
-#endif
+  char reply[255] = "100 nobody";
+  int status = 0;
 
-  if (isEmptyString(path)) goto error;
+  logMain(LOG_DEBUG, "audit %s collection for %s", label, mail);
+  checkLabel(label);
+  checkLabel(mail);
+
+  if (!(conf = getConfiguration())) goto error;
+  if (!env.noRegression) {
+    // check if daemon is awake
+    if (access(conf->pidFile, R_OK) == -1) {
+      logMain(LOG_INFO, "cannot read daemon's pid file: %s", 
+	      strerror(errno));
+      goto end;
+    }
+  }
+
+  if (!becomeUser(env.confLabel, TRUE)) goto error;
   if (!(coll = mdtxGetCollection(label))) goto error;
+  if (!(tree = createRecordTree())) goto error;
+  if (!getLocalHost(coll)) goto error;
+  tree->collection = coll;
+  tree->messageType = CGI;
+
+  // open audit file
+  if ((now = currentTime()) == -1) goto error;
+  if (localtime_r(&now, &date) == (struct tm*)0) {
+    logMemory(LOG_ERR, "localtime_r returns on error");
+    goto error;
+  }
+ 
+  sprintf(path, "%s/%s%04i%02i%02i-%02i%02i%02i_%s.txt",
+	  coll->extractDir, CONF_AUDIT,
+	  date.tm_year + 1900, date.tm_mon+1, date.tm_mday,
+	  date.tm_hour, date.tm_min, date.tm_sec,
+	  coll->userFingerPrint);
+  strcpy(extra, path + strlen(coll->extractDir) + 1);
+  ptrMail = extra + strlen(extra) - 3;
+  *(ptrMail - 1) = ':';
+
+  if (!env.dryRun) {
+    if ((fd = fopen(path, "w")) == 0) {
+      logMemory(LOG_ERR, "fopen %s fails: %s", path, strerror(errno));
+      fd = stdout;
+      goto error;
+    }
+    if (!lock(fileno(fd), F_WRLCK)) goto error;
+  }
+
+  logMemory(LOG_INFO, "Serializing audit into: %s", 
+	    env.dryRun?"stdout":path);
+
   if (!loadCollection(coll, EXTR)) goto error;
 
-/* #ifndef utMAIN */
-/*   // check if daemon is awake */
-/*   if (access(conf->pidFile, R_OK) == -1) { */
-/*     logEmit(LOG_INFO, "cannot read daemon's pid file: %s",  */
-/* 	    strerror(errno)); */
-/*     goto end; */
-/*   } */
-/* #endif */
+  fprintf(fd, "Audit on %s collection\n", coll->label);
+  fprintf(fd, " requested on %04i-%02i-%02i %02i:%02i:%02i\n",
+	  date.tm_year + 1900, date.tm_mon+1, date.tm_mday,
+	  date.tm_hour, date.tm_min, date.tm_sec); 
+  fprintf(fd, " requested by %s\n", mail);
+  fprintf(fd, " %i archives to check\n", avl_count(coll->archives));
+  fprintf(fd, " %i archives checked:\n", 0);
+  fprintf(fd, "  %i archives ok\n", 0);
+  fprintf(fd, "  %i archives ko\n", 0);
 
-  if (!(tree = createRecordTree())) goto error2; 
-  tree->collection = coll;
-  tree->messageType = UPLOAD; 
-  if (!getLocalHost(coll)) goto error2;
-
-  // get file attributes (size)
-  if (stat(path, &statBuffer)) {
-    logEmit(LOG_ERR, "status error on %s: %s", path, strerror(errno));
-    goto error2;
+  fprintf(fd, "\nArchive to check:\n");
+  if (avl_count(coll->archives)) {
+    for(node = coll->archives->head; node; node = node->next) {
+      archive = (Archive*)node->item;
+      fprintf(fd, " %s:%lli\n", archive->hash,
+	      (long long int)archive->size);
+      
+      // add a final demand
+      strcpy(ptrMail, mail);
+      if (!(tmp = createString(extra))) goto error2; 
+      if (!(record = newRecord(coll->localhost, archive, DEMAND, tmp))) 
+	goto error;
+      tmp = 0;
+      if (!rgInsert(tree->records, record)) goto error2;
+      record = 0;
+    }
   }
+  fflush(fd);
 
-  // compute hash
-  memset(&md5, 0, sizeof(Md5Data));
-  md5.path = path;
-  md5.size = statBuffer.st_size;
-  md5.opp = MD5_CACHE_ID;
-  if (!doMd5sum(&md5)) goto error2;
-
-  // archive to upload
-  if (!(archive = addArchive(coll, md5.fullMd5sum, statBuffer.st_size)))
-    goto error2;
-
-  /* // add the file to the UPLOAD message */
-  if (!(extra = absolutePath(path))) goto error2;
-  if (!(record = addRecord(coll, coll->localhost, archive, SUPPLY, extra)))
-    goto error2;
-  extra = 0;
-  if (!rgInsert(tree->records, record)) goto error2;
-  record = 0;
-  
-#ifdef utMAIN
-  logEmit(LOG_INFO, "upload file to %s collection", label);
-#else
+  // connect server and write query
+  if (env.noRegression) goto end;
   if ((socket = connectServer(coll->localhost)) == -1) goto error2;
   if (!upgradeServer(socket, tree, 0)) goto error2;
-
+  
   // read reply
+  if (env.dryRun) goto end;
   n = tcpRead(socket, reply, 255);
-  tcpRead(socket, reply, 1);
-
   // erase the \n send by server
   if (n<=0) n = 1;
-  reply[n-1] = (char)0;
-
-  if (sscanf(reply, "%i %s", &status, message) < 1) {
-    logEmit(LOG_ERR, "error reading reply: %s", reply);
-    goto error2;
+  reply[n-1] = (char)0; 
+  if (sscanf(reply, "%i", &status) < 1) {
+    logMain(LOG_ERR, "error reading server reply: %s", reply);
+    goto error;
   }
-    
-  logEmit(LOG_INFO, "local server tels (%i) %s", status, message);
-  if (status != 200) goto error2;
-#endif
-
-  // add extraction rule
-  if (!(container = addContainer(coll, REC, archive))) goto error;
-  if (!wasModifiedCollection(coll, EXTR)) goto error2;
-
-  rc = TRUE;
+  
+  logMain(LOG_INFO, "receive: %s", reply);
+  logMain(LOG_NOTICE, "please check motd and performe extraction", reply);
+ end:
+  rc = (env.noRegression || env.dryRun || status == 221);
  error2:
-  extra = destroyString(extra);
-  if (record) delRecord(coll, record);
-  tree = destroyRecordTree(tree);
-  if (socket) close(socket);
   if (!releaseCollection(coll, EXTR)) goto error;
  error:
-  if (!rc) {
-    logEmit(LOG_ERR, "%s", "upload query failed");
-    if (record) delRecord(coll, record);
+  if (fd != stdout) {
+    if (!unLock(fileno(fd))) rc = FALSE;
+    if (fclose(fd)) {
+      logMemory(LOG_ERR, "fclose fails: %s", strerror(errno));
+      rc = FALSE;
+    }
   }
+  if (!rc) {
+    logMain(LOG_ERR, "mdtx audit fails");
+  }
+  destroyString(tmp);
+  destroyRecord(record);
+  destroyRecordTree(tree);
   return rc;
 }
 
-/************************************************************************/
-
-#ifdef utMAIN
-#include "../misc/command.h"
-GLOBAL_STRUCT_DEF;
-
-/*=======================================================================
- * Function   : usage
- * Description: Print the usage.
- * Synopsis   : static void usage(char* programName)
- * Input      : programName = the name of the program; usually argv[0].
- * Output     : N/A
- =======================================================================*/
-static void 
-usage(char* programName)
-{
-  mdtxUsage(programName);
-  fprintf(stderr, " [ -d repository ]");
-
-  mdtxOptions();
-  fprintf(stderr, "  ---\n"
-	  "  -d, --input-rep\trepository with logo files\n");
-  return;
-}
-
-
-/*=======================================================================
- * Function   : main 
- * Author     : Nicolas ROCHE
- * modif      : 2010/12/10
- * Description: entry point for make module
- * Synopsis   : ./utmake
- * Input      : N/A
- * Output     : N/A
- =======================================================================*/
-int 
-main(int argc, char** argv)
-{
-  char inputRep[255] = ".";
-  char* path = 0;
-  Collection* coll = 0;
-  // ---
-  int rc = 0;
-  int cOption = EOF;
-  char* programName = *argv;
-  char* options = MDTX_SHORT_OPTIONS"d:";
-  struct option longOptions[] = {
-    MDTX_LONG_OPTIONS,
-    {"input-rep", required_argument, 0, 'd'},
-    {0, 0, 0, 0}
-  };
-
-  // import mdtx environment
-  //env.dryRun = FALSE;
-  getEnv(&env);
-
-  // parse the command line
-  while((cOption = getopt_long(argc, argv, options, longOptions, 0)) 
-	!= EOF) {
-    switch(cOption) {
-      
-    case 'd':
-      if(optarg == 0 || *optarg == (char)0) {
-	fprintf(stderr, 
-		"%s: nil or empty argument for the input repository\n",
-		programName);
-	rc = EINVAL;
-	break;
-      }
-      strncpy(inputRep, optarg, strlen(optarg)+1);
-      break; 
-
-      GET_MDTX_OPTIONS; // generic options
-    }
-    if (rc) goto optError;
-  }
-
-  // export mdtx environment
-  if (!setEnv(programName, &env)) goto optError;
-  
-  /************************************************************************/
-  // build the HTML catalog
-  if (!mdtxMake("coll1")) goto error;
-
-  // upload a file
-  if (!(path = createString(inputRep))) goto error;
-  if (!(path = catString(path, "/../../examples/logo.png"))) goto error;
-  if (!mdtxUploadFile("coll1", path)) goto error;
-  if (!(coll = addCollection("coll1"))) goto error;
-  if (!saveCollection(coll, EXTR)) goto error;
-  /************************************************************************/
-
-  rc = TRUE;
- error:
-  path = destroyString(path);
-  freeConfiguration();
-  ENDINGS;
-  rc=!rc;
- optError:
-  exit(rc);
-}
-
-#endif // utMAIN
-
 /* Local Variables: */
 /* mode: c */
 /* mode: font-lock */
