@@ -1,7 +1,7 @@
 /*=======================================================================
- * Version: $Id: motd.h,v 1.3 2015/06/03 14:03:30 nroche Exp $
+ * Version: $Id: motd.h,v 1.5 2015/09/04 15:30:25 nroche Exp $
  * Project: MediaTeX
- * Module : wrapper/motd
+ * Module : motd
  *
  * Manage message of the day
 
@@ -22,21 +22,15 @@
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 =======================================================================*/
 
-#ifndef MDTX_WRAPPER_MOTD_H
-#define MDTX_WRAPPER_MOTD_H 1
+#ifndef MDTX_CLIENT_MOTD_H
+#define MDTX_CLIENT_MOTD_H 1
 
-typedef struct MotdData {
-
-  Collection* coll;
-  RG* outArchives;
-  int found;
-
-} MotdData;
+#include "mediatex-types.h"
 
 /* API */
 int updateMotd();
 
-#endif /* MDTX_WRAPPER_MOTD_H */
+#endif /* MDTX_CLIENT_MOTD_H */
 
 /* Local Variables: */
 /* mode: c */
