@@ -1,7 +1,7 @@
 /*=======================================================================
- * Version: $Id: serv.c,v 1.3 2015/06/03 14:03:30 nroche Exp $
+ * Version: $Id: serv.c,v 1.8 2015/09/17 18:53:46 nroche Exp $
  * Project: MediaTeX
- * Module : wrapper/serv
+ * Module : serv
  *
  * Manage servers.txt modifications
 
@@ -22,14 +22,8 @@
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  =======================================================================*/
 
-#include "../mediatex.h"
-#include "../misc/log.h"
-#include "../memory/confTree.h"
-#include "../common/ssh.h"
-#include "../common/openClose.h"
-
-#include <sys/types.h>
-#include <sys/ipc.h>
+#include "mediatex-config.h"
+#include "client/mediatex-client.h"
 #include <sys/sem.h>
 
 typedef union semun {
@@ -55,10 +49,10 @@ static int setConcurentAccessLock()
   unsigned short table[1];
   int uid = getuid();
 
-  logEmit(LOG_DEBUG, "%s", "initialise the concurrent access"); 
+  logMain(LOG_DEBUG, "initialise the concurrent access"); 
 
   if (!(conf = getConfiguration())) goto error;
-  if (conf->sem != 0) goto end;
+  if (conf->sem) goto end;
   
   // force becoming mdtx user 
   if (!becomeUser(env.confLabel, FALSE)) goto error;
@@ -66,25 +60,23 @@ static int setConcurentAccessLock()
   // Create a new IPC key base on an i-node + minor peripherical
   // number and a project number
   if ((key = ftok(conf->confFile, COMMON_OPEN_CLOSE_PROJECT_ID)) == -1) {
-    logEmit(LOG_ERR, "ftok fails to create IPC key: %s", strerror(errno)); 
-    logEmit(LOG_NOTICE, "ftok using path: %s", conf->confFile); 
+    logMain(LOG_ERR, "ftok fails to create IPC key: %s", strerror(errno)); 
+    logMain(LOG_NOTICE, "ftok using path: %s", conf->confFile); 
     goto error;
   }
 
-  logEmit(LOG_INFO, "client ipc key: {%s, %i}", 
+  logMain(LOG_INFO, "client ipc key: {%s, %i}", 
 	  conf->confFile, COMMON_OPEN_CLOSE_PROJECT_ID); 
-#ifndef utMAIN
-  logEmit(LOG_INFO, "client ipc key: 0x%x", key); 
-#endif
+  logMain(LOG_DEBUG, "client ipc key: 0x%x", key); 
 
   // Try to match an existing semaphore with the key
   if (( conf->sem = semget(key, 1, 0)) == -1) {
 
     // Create a new semaphore matched with the key
     if ((conf->sem = semget(key, 1, IPC_CREAT | IPC_EXCL | 0600)) == -1) {
-      logEmit(LOG_ERR, "semget fails matching 0x%x IPC key: %s", 
+      logMain(LOG_ERR, "semget fails matching 0x%x IPC key: %s", 
 	      strerror(errno)); 
-      logEmit(LOG_NOTICE, "%s", "(semaphore as gone)");
+      logMain(LOG_NOTICE, "(semaphore as gone)");
       goto error;
     }
   
@@ -92,7 +84,7 @@ static int setConcurentAccessLock()
     table[0] = 1;
     u_semun.table = table;
     if (semctl(conf->sem, 0, SETALL, u_semun) <0) {
-      logEmit(LOG_ERR, "semctl fails to initialize semaphore value: %s", 
+      logMain(LOG_ERR, "semctl fails to initialize semaphore value: %s", 
 	      strerror(errno)); 
       goto error;
     }
@@ -103,7 +95,7 @@ static int setConcurentAccessLock()
  error:
   if (!logoutUser(uid)) rc = FALSE;
   if (!rc) {
-    logEmit(LOG_ERR, "%s", "fails to set concurrent access lock"); 
+    logMain(LOG_ERR, "fails to set concurrent access lock"); 
   }
   return rc;
 }
@@ -122,12 +114,12 @@ int clientWriteLock()
   struct sembuf sembuf;
   int uid = getuid();
 
-  logEmit(LOG_DEBUG, "%s", "get the concurrent access"); 
+  logMain(LOG_DEBUG, "get the concurrent access"); 
 
   if (!(conf = getConfiguration())) goto error;
   if (!setConcurentAccessLock()) goto error;
   if (conf->sem == 0) {
-    logEmit(LOG_ERR, "%s", "concurrent access lock is not initialized"); 
+    logMain(LOG_ERR, "concurrent access lock is not initialized"); 
     goto error;
   }
 
@@ -135,18 +127,18 @@ int clientWriteLock()
   if (!becomeUser(env.confLabel, FALSE)) goto error;
 
   // P (may I ?)
-  logEmit(LOG_DEBUG, "%s", "get writter lock");
+  logMain(LOG_DEBUG, "get writter lock");
   sembuf.sem_num = 0;
   sembuf.sem_op = -1;
   sembuf.sem_flg = SEM_UNDO | IPC_NOWAIT; // for crash recovery...
   //... + do not asleep process if not available but exit with EAGAIN
   if (semop(conf->sem, &sembuf, 1) < 0) {
     if (errno == EAGAIN) {
-      logEmit(LOG_ERR, "%s", 
+      logMain(LOG_ERR, 
 	      "cannot take concurent access as it is already locked");
     }
     else {
-      logEmit(LOG_ERR, "semop fails asking for semaphore: %s", 
+      logMain(LOG_ERR, "semop fails asking for semaphore: %s", 
 	      strerror(errno)); 
     }
     goto error;
@@ -158,7 +150,7 @@ int clientWriteLock()
  error:
   if (!logoutUser(uid)) rc = FALSE;
   if (!rc) {
-    logEmit(LOG_ERR, "%s", "fails to get writter lock"); 
+    logMain(LOG_ERR, "fails to get writter lock"); 
   }
   return rc;
 }
@@ -177,11 +169,11 @@ int clientWriteUnlock()
   union semun arg;
   int uid = getuid();
 
-  logEmit(LOG_DEBUG, "%s", "release the concurrent access"); 
+  logMain(LOG_DEBUG, "release the concurrent access"); 
 
   if (!(conf = getConfiguration())) goto error;
   if (conf->sem == 0) {
-    logEmit(LOG_ERR, "%s", "concurrent access lock already unlock"); 
+    logMain(LOG_ERR, "concurrent access lock already unlock"); 
     goto error;
   }
 
@@ -196,7 +188,7 @@ int clientWriteUnlock()
   // Free semaphore IPC ressource
   arg.val = 0;
   if (semctl(conf->sem, 0, IPC_RMID, arg) == -1) {
-    logEmit(LOG_ERR, "semctl fails: %s", strerror(errno)); 
+    logMain(LOG_ERR, "semctl fails: %s", strerror(errno)); 
     goto error;
   }
 
@@ -205,7 +197,7 @@ int clientWriteUnlock()
  error:
   if (!logoutUser(uid)) rc = FALSE;
   if (!rc) {
-    logEmit(LOG_ERR, "%s", "fails to release the writter lock"); 
+    logMain(LOG_ERR, "fails to release the writter lock"); 
   }
   return rc;
 }
@@ -227,7 +219,7 @@ mdtxUpdate(char* label)
   Collection* coll = 0;
 
   checkLabel(label);
-  logEmit(LOG_DEBUG, "%s", "update collection");
+  logMain(LOG_DEBUG, "update collection");
 
   if (!(coll = mdtxGetCollection(label))) goto error;
   if (!callUpdate(coll->user)) goto error;
@@ -235,7 +227,7 @@ mdtxUpdate(char* label)
   rc = TRUE;
  error:
   if (!rc) {
-    logEmit(LOG_ERR, "%s", "fails to update collection");
+    logMain(LOG_ERR, "fails to update collection");
   }
   return(rc);
 }
@@ -258,7 +250,7 @@ mdtxCommit(char* label)
   Collection* coll = 0;
 
   checkLabel(label);
-  logEmit(LOG_DEBUG, "%s", "commit collection");
+  logMain(LOG_DEBUG, "commit collection");
 
   if (!(conf = getConfiguration())) goto error;
   if (!(coll = mdtxGetCollection(label))) goto error;
@@ -269,7 +261,7 @@ mdtxCommit(char* label)
   rc = TRUE;
  error:
   if (!rc) {
-    logEmit(LOG_ERR, "%s", "fails to commit collection");
+    logMain(LOG_ERR, "fails to commit collection");
   }
   return(rc);
 }
@@ -296,7 +288,7 @@ mdtxUpgrade(char* label)
   Collection* coll = 0;
 
   checkLabel(label);
-  logEmit(LOG_DEBUG, "plan to upgrade %s collection", label);
+  logMain(LOG_DEBUG, "plan to upgrade %s collection", label);
 
   if (!(conf = getConfiguration())) goto error;
   if (!(coll = mdtxGetCollection(label))) goto error;
@@ -310,7 +302,7 @@ mdtxUpgrade(char* label)
   if (!releaseCollection(coll, CTLG|EXTR|SERV)) goto error;
  error:
   if (!rc) {
-    logEmit(LOG_ERR, "%s", "mdtxUpgrade fails");
+    logMain(LOG_ERR, "mdtxUpgrade fails");
   }
   return rc;
 }
@@ -332,13 +324,13 @@ addKey(char* label, char* path)
   int rc = FALSE;
   Collection* coll = 0;
   char* key = 0;
-  char hash[MAX_SIZE_HASH+1];
+  char hash[MAX_SIZE_MD5+1];
   ServerTree* servers = 0;
   Server* server = 0;
 
   if (label == 0) goto error;
   if (path == 0) goto error;
-  logEmit(LOG_INFO, "add %s key to %s collection", path, label);
+  logMain(LOG_INFO, "add %s key to %s collection", path, label);
 
   // parse server DB for merge
   if (!(coll = mdtxGetCollection(label))) goto error;
@@ -347,8 +339,8 @@ addKey(char* label, char* path)
   // look if key is ouself
   if (!(key = readPublicKey(path))) goto error;
   if (!getFingerPrint(key, hash)) goto error;
-  if (!strncmp(coll->userFingerPrint, hash, MAX_SIZE_HASH)) {
-    logEmit(LOG_WARNING, "key \"%s\" is our %s collection key", 
+  if (!strncmp(coll->userFingerPrint, hash, MAX_SIZE_MD5)) {
+    logMain(LOG_WARNING, "key \"%s\" is our %s collection key", 
 	    hash, coll->label);
     goto error;
   }
@@ -356,12 +348,12 @@ addKey(char* label, char* path)
   // look if key is already shared by the collection
   if (!loadCollection(coll, SERV)) goto error;
   rgRewind(servers->servers);
-  while ((server = rgNext(servers->servers)) != 0) {
-    if (!strncmp(server->fingerPrint, hash, MAX_SIZE_HASH)) break;
+  while ((server = rgNext(servers->servers))) {
+    if (!strncmp(server->fingerPrint, hash, MAX_SIZE_MD5)) break;
   }
 
-  if (server != 0) {
-    logEmit(LOG_WARNING, "key \"%s\" is already added to %s collection", 
+  if (server) {
+    logMain(LOG_WARNING, "key \"%s\" is already added to %s collection", 
 	    hash, coll->label);
     goto error2;
   }
@@ -381,7 +373,7 @@ addKey(char* label, char* path)
   if (!releaseCollection(coll, SERV)) rc = FALSE;
  error:
   if (!rc) {
-    logEmit(LOG_ERR, "cannot add %s key to %s collection", path, label);
+    logMain(LOG_ERR, "cannot add %s key to %s collection", path, label);
   }
   if (key) free(key);
   return rc;
@@ -403,24 +395,24 @@ delKey(char* label, char* key)
 {
   int rc = FALSE;
   Collection* coll = 0;
-  char hash[MAX_SIZE_HASH+1];
+  char hash[MAX_SIZE_MD5+1];
   ServerTree* servers = 0;
   Server* server = 0;
 
   if (label == 0) goto error;
   if (key == 0) goto error;
-  logEmit(LOG_INFO, "del %s key from %s collection", key, label);
+  logMain(LOG_INFO, "del %s key from %s collection", key, label);
 
   // we are expecting a fingerprint
-  strncpy(hash, key, MAX_SIZE_HASH+1);
+  strncpy(hash, key, MAX_SIZE_MD5+1);
 
   // parse server DB for merge
   if (!(coll = mdtxGetCollection(label))) goto error;
   servers = coll->serverTree;
 
   // look if key is ouself
-  if (!strncmp(coll->userFingerPrint, hash, MAX_SIZE_HASH)) {
-    logEmit(LOG_WARNING, "key \"%s\" is our %s collection key", 
+  if (!strncmp(coll->userFingerPrint, hash, MAX_SIZE_MD5)) {
+    logMain(LOG_WARNING, "key \"%s\" is our %s collection key", 
 	    hash, coll->label);
     goto error;
   }
@@ -428,12 +420,12 @@ delKey(char* label, char* key)
   // look if key is shared by the collection
   if (!loadCollection(coll, SERV)) goto error;
   rgRewind(servers->servers);
-  while ((server = rgNext(servers->servers)) != 0) {
-    if (!strncmp(server->fingerPrint, hash, MAX_SIZE_HASH)) break;
+  while ((server = rgNext(servers->servers))) {
+    if (!strncmp(server->fingerPrint, hash, MAX_SIZE_MD5)) break;
   }
 
   if (server == 0) {
-    logEmit(LOG_WARNING, 
+    logMain(LOG_WARNING, 
 	    "key \"%s\" not share with %s collection", 
 	    hash, coll->label);
     goto error2;
@@ -452,159 +444,11 @@ delKey(char* label, char* key)
   if (!releaseCollection(coll, SERV)) rc = FALSE;
  error:
   if (!rc) {
-    logEmit(LOG_ERR, "cannot del %s key to %s collection", key, coll);
+    logMain(LOG_ERR, "cannot del %s key to %s collection", key, coll);
   }
   return rc;
 }
 
-/************************************************************************/
-
-#ifdef utMAIN
-#include "../misc/command.h"
-#include "../misc/signals.h"
-
-GLOBAL_STRUCT_DEF;
-int running = TRUE;
-
-void* 
-sigManager(void* arg)
-{
-  int sigNumber = 0;
-
-  (void) arg;
-  logEmit(LOG_NOTICE, "%s", "please send me HUP, USR1 or TERM signals:");
-  logEmit(LOG_NOTICE, "- kill -SIGHUP %i", getpid());
-  logEmit(LOG_NOTICE, "- kill -SIGUSR1 %i", getpid());
-  logEmit(LOG_NOTICE, "- kill -SIGTERM %i", getpid());
-
-  if ((sigNumber = sigwaitinfo(&signalsToManage, 0)) == -1) {
-    logEmit(LOG_ERR, "sigwait fails: %s", strerror(errno));
-    goto error;
-  }
- 
-  running = FALSE;
-  return (void*)TRUE;
- error:
-  return (void*)FALSE;
-}
-
-/*=======================================================================
- * Function   : usage
- * Description: Print the usage.
- * Synopsis   : static void usage(char* programName)
- * Input      : programName = the name of the program; usually argv[0].
- * Output     : N/A
- =======================================================================*/
-static void 
-usage(char* programName)
-{
-  mdtxUsage(programName);
-  fprintf(stderr, " [ -k ]");
-  mdtxOptions();
-  fprintf(stderr, 
-	  "  -k, --lock\t\ttest the concurrent lock\n");
-  return;
-}
-
-  
-/*=======================================================================
- * Function   : main 
- * Author     : Nicolas ROCHE
- * modif      : 2012/05/01
- * Description: Unit test for cache module.
- * Synopsis   : ./utupgrade
- * Input      : -i mediatex.conf
- * Output     : stdout
- =======================================================================*/
-int 
-main(int argc, char** argv)
-{
-  Collection* coll = 0;
-  pthread_t thread;
-  int doLock = FALSE;
-  int err = 0;
-  // ---
-  int rc = 0;
-  int cOption = EOF;
-  char* programName = *argv;
-  char* options = MDTX_SHORT_OPTIONS"k";
-  struct option longOptions[] = {
-    {"lock", no_argument, 0, 'k'},
-    MDTX_LONG_OPTIONS,
-    {0, 0, 0, 0}
-  };
-
-  // import mdtx environment
-  getEnv(&env);
-
-  // parse the command line
-  while((cOption = getopt_long(argc, argv, options, longOptions, 0)) 
-	!= EOF) {
-    switch(cOption) {
-      
-    case 'k':
-      doLock = TRUE;
-      break;			
-
-      GET_MDTX_OPTIONS; // generic options
-    }
-    if (rc) goto optError;
-  }
-
-  // export mdtx environment
-  if (!setEnv(programName, &env)) goto optError;
-
-  /************************************************************************/
-  // test writter lock
-  if (doLock) {
-    if (!clientWriteLock()) goto error;
-
-    // infinite loop (file descriptor should not be available)
-    if (!manageSignals(sigManager, &thread)) goto error;
-    while (running) usleep(200000);
-    
-    if (!clientWriteUnlock()) goto error;
-    if ((err = pthread_join(thread, 0))) {
-      logEmit(LOG_ERR, "pthread_join fails: %s", strerror(err));
-      goto error;
-    }
-  }
-
-  // others tests
-  if (!(coll = addCollection("coll1"))) goto error;
-
-  logEmit(LOG_NOTICE, "%s", "*** upgrade:");
-  env.noCollCvs = FALSE;
-  if (!mdtxUpgrade("coll1")) goto error;
-
-  logEmit(LOG_NOTICE, "%s", "*** refuse to del localhost key: ");
-  if (delKey("coll1", "746d6ceeb76e05cfa2dea92a1c5753cd")) goto error;
-    
-  logEmit(LOG_NOTICE, "%s", "*** del a key: ");
-  if (!delKey("coll1", "bedac32422739d7eced624ba20f5912e")) goto error;
-  
-  logEmit(LOG_NOTICE, "%s", "*** refuse to add localhost key: ");
-  if (addKey("coll1", "user1Key_rsa.pub")) goto error;
-
-  logEmit(LOG_NOTICE, "%s", "*** add a key: ");
-  if (!addKey("coll1", "user3Key_dsa.pub")) goto error;
-
-  logEmit(LOG_NOTICE, "%s", "*** save and disease test: ");
-  if (!saveCollection(coll, SERV)) goto error;
-  if (!diseaseCollection(coll, SERV)) goto error;
-  /************************************************************************/
-  
-  rc = TRUE;
- error:
-  freeConfiguration();
-  ENDINGS;
-  rc=!rc;
- optError:
-  exit(rc);
-}
-
-#endif // utMAIN
-
 /* Local Variables: */
 /* mode: c */
 /* mode: font-lock */
