@@ -1,9 +1,9 @@
 /*=======================================================================
- * Version: $Id: extractScore.c,v 1.3 2015/06/03 14:03:34 nroche Exp $
+ * Version: $Id: extractScore.c,v 1.17 2015/09/23 19:10:20 nroche Exp $
  * Project: MediaTeX
- * Module : common/extractScore
+ * Module : extractScore
  *
- * Manage extraction scores
+ * Compute scores based on extraction rules
 
  MediaTex is an Electronic Records Management System
  Copyright (C) 2014 2015 Nicolas Roche
@@ -22,14 +22,9 @@
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 =======================================================================*/
 
-#include "../mediatex.h"
-#include "../misc/log.h"
-#include "../common/openClose.h"
-#include "../common/extractScore.h"
+#include "mediatex-config.h"
 
-#include <avl.h> 
-
-int computeArchive(Archive* self, int depth);
+int computeArchive(Collection* coll, Archive* self, int depth);
 
 
 /*=======================================================================
@@ -52,13 +47,14 @@ populateExtractTree(Collection* coll)
   Archive* archive = 0;
   Image* image = 0;
   int i = 0;
+  time_t now = 0;
 
   checkCollection(coll);
   logCommon(LOG_DEBUG, "populateExtractTree: %s", coll->label);
 
   self = coll->extractTree;
   if(self == 0) {
-    logCommon(LOG_DEBUG, "%s", "cannot populate empty ExtractTree");
+    logCommon(LOG_DEBUG, "cannot populate empty ExtractTree");
     goto error;
   }
   
@@ -68,16 +64,19 @@ populateExtractTree(Collection* coll)
  	    "cannot populate tree with an empty ServerTree");
     goto error;
   }
+  
+  // date
+  if ((now = currentTime()) == -1) goto error;
 
   // for each server
   rgRewind(serverTree->servers);
-  while ((server = rgNext(serverTree->servers)) != 0) {
+  while ((server = rgNext(serverTree->servers))) {
     
     // server->score = min (image's scores)
     server->score = -1;
-    if (server->images != 0) {
+    if (server->images) {
       rgRewind(server->images);
-      while((image = rgNext(server->images)) != 0) {
+      while ((image = rgNext(server->images))) {
 	if (server->score == -1 || image->score < server->score) {
 	  server->score = image->score;
 	}
@@ -87,45 +86,51 @@ populateExtractTree(Collection* coll)
 
   // for each archive related to images
   rgRewind(serverTree->archives);
-  while ((archive = rgNext(serverTree->archives)) != 0) {
+  while ((archive = rgNext(serverTree->archives))) {
 
     // archive->imageScore = sum (image's scores)
     archive->imageScore = -1;
-    if (archive->images != 0) {
+    if (archive->images) {
       archive->imageScore = 0;
       rgRewind(archive->images);
 
-      logCommon(LOG_DEBUG, "local image score for %s:%lli",
+      logCommon(LOG_INFO, "local image score for %s:%lli",
 	      archive->hash, archive->size);
 
       i=0;
-      while((image = rgNext(archive->images)) != 0) {
+      while ((image = rgNext(archive->images))) {
+
+	// ignore image from a mute server
+	if (image->server->lastCommit + serverTree->serverTTL < now) 
+	  continue;
+	
 	archive->imageScore += image->score;
-	logCommon(LOG_DEBUG, "%c %5.2f", (i > 1)?'+':' ', image->score);
+	logCommon(LOG_INFO, "%c %5.2f", (i > 1)?'+':' ', image->score);
 	++i;
       }
     }
     
-    logCommon(LOG_DEBUG, "= %5.2f", archive->imageScore);
+    logCommon(LOG_INFO, "= %5.2f", archive->imageScore);
 
     // archive->imageScore /= minGeoDup
     archive->imageScore /= serverTree->minGeoDup;
-    logCommon(LOG_DEBUG, "/ %i", serverTree->minGeoDup);
+    logCommon(LOG_INFO, "/ %i", serverTree->minGeoDup);
 
     // truncate it if more than maxScore
     if (archive->imageScore > coll->serverTree->scoreParam.maxScore) {
       archive->imageScore = coll->serverTree->scoreParam.maxScore;
-      logCommon(LOG_DEBUG, "> %5.2f", coll->serverTree->scoreParam.maxScore);
+      logCommon(LOG_INFO, "> %5.2f", 
+		coll->serverTree->scoreParam.maxScore);
     }
 
-    logCommon(LOG_DEBUG, "-------", archive->imageScore);
-    logCommon(LOG_DEBUG, "= %5.2f", archive->imageScore);
+    logCommon(LOG_INFO, "-------", archive->imageScore);
+    logCommon(LOG_INFO, "= %5.2f", archive->imageScore);
   }    
 
   rc = TRUE;
  error:
   if (!rc) {
-    logCommon(LOG_ERR, "%s", "fails to populateExtractTree");
+    logCommon(LOG_ERR, "fails to populateExtractTree");
   }  
   return rc;
 }
@@ -134,83 +139,127 @@ populateExtractTree(Collection* coll)
 /*=======================================================================
  * Function   : computeContainer
  * Description: Compute container's scores (from its parents files)
- * Synopsis   : int computeContainer(Container* self)
- * Input      : ExtractTree* self
+ * Synopsis   : int computeContainer(Collection coll, Container* self, 
+ *                                   int depth)
+ * Input      : Collection* coll
+ *              Container* self
+ *              int depth: use to indent logs
  * Output     : TRUE on success
  =======================================================================*/
 int 
-computeContainer(Container* self, int depth)
+computeContainer(Collection* coll, Container* self, int depth)
 {
   int rc = FALSE;
   Archive* archive = 0;
 
   checkContainer(self);
   if (self->score != -1) goto quit; // already computed
-  logCommon(LOG_DEBUG, "%*s computeContainer %s/%s:%lli", 
+  if (self->type == INC) {
+    logCommon(LOG_ERR, "internal error: INC container not expected");
+    goto error;
+  }
+
+  logCommon(LOG_DEBUG, "%*scomputeContainer %s/%s:%lli", 
 	  depth, "", strEType(self->type),
 	  self->parent->hash, (long long int)self->parent->size);
 
   // score = min ( content's scores )
+  self->incInherency = FALSE;
   rgRewind(self->parents);
-  while ((archive = rgNext(self->parents)) != 0) {
-    if (!computeArchive(archive, depth+1)) goto error;
+  while ((archive = rgNext(self->parents))) {
+    if (!computeArchive(coll, archive, depth+1)) goto error;
+    self->incInherency |= archive->incInherency;
     if (self->score == -1 || self->score > archive->extractScore) {
       self->score = archive->extractScore;
     }
   }
   
  quit:
-  logCommon(LOG_DEBUG, " %*s container %s/%s:%lli = %.2f", depth, "",
+  logCommon(LOG_INFO, "%*s container %s/%s:%lli = %.2f", depth, "",
 	  strEType(self->type), self->parent->hash, 
 	  (long long int)self->parent->size, self->score);
   rc = TRUE;
  error:
  if (!rc) {
-    logCommon(LOG_ERR, "%s", "fails to computeContainer");
+    logCommon(LOG_ERR, "fails to computeContainer");
   }
   return rc;
 }
 
+/*=======================================================================
+ * Function   : isNewIncoming
+ * Description: state if an archive was newly upload
+ * Synopsis   : static int isNewIncoming(Collection* coll, 
+ *                                                    Archive* archive)
+ * Input      : Collection* coll: to get uploadTTL parameter
+ *              Archive* archive
+ * Output     : TRUE on success
+ =======================================================================*/
+static int 
+isNewIncoming(Collection* coll, Archive* archive)
+{
+  int rc = FALSE;
+
+  if (!isIncoming(coll, archive)) goto end;
+  if (currentTime() > archive->uploadTime + coll->serverTree->uploadTTL) {
+    logCommon(LOG_INFO, "obsolete incoming archive: %s:%lli", 
+	      archive->hash, (long long int)archive->size); 
+    goto end;
+  }
+  
+  rc = TRUE;
+ end:
+  return rc;
+}
+
 
 /*=======================================================================
  * Function   : computeArchive
  * Description: Compute content score (from container's scores)
- * Synopsis   : int computeArchive(Archive* self)
- * Input      : ExtractTree* self
- * Output     : ??
+ * Synopsis   : int computeArchive(Collection* coll, Archive* self, 
+ *                                 int depth)
+ * Input      : Collection* coll
+ *              Archive* self
+ *              int depth: use to indent logs
+ * Output     : TRUE on success
  =======================================================================*/
 int 
-computeArchive(Archive* self, int depth)
+computeArchive(Collection* coll, Archive* self, int depth)
 {
   int rc = FALSE;
   FromAsso* asso = 0;
 
   checkArchive(self);
   if (self->extractScore != -1) goto quit; // already computed
-  logCommon(LOG_DEBUG, "%*s computeArchive: %s:%lli", 
+  logCommon(LOG_DEBUG, "%*scomputeArchive: %s:%lli", 
 	  depth, "", self->hash, self->size);
 
   // score = max (image's scores)
   self->extractScore = (self->imageScore > 0)?self->imageScore:0;
 
+  if (isEmptyRing(self->fromContainers)) {
+    self->incInherency = isNewIncoming(coll, self);
+    goto quit;
+  }
+
   // score = max (from container's scores)
-  if (self->fromContainers != 0) {
-    rgRewind(self->fromContainers);
-    while((asso = rgNext(self->fromContainers)) != 0) {
-      if (!computeContainer(asso->container, depth+1)) goto error;
-      if (self->extractScore < asso->container->score) {
-	self->extractScore = asso->container->score;
-      }
+  self->incInherency = TRUE;
+  rgRewind(self->fromContainers);
+  while ((asso = rgNext(self->fromContainers))) {
+    if (!computeContainer(coll, asso->container, depth+1)) goto error;
+    self->incInherency &= asso->container->incInherency;
+    if (self->extractScore < asso->container->score) {
+      self->extractScore = asso->container->score;
     }
   }
 
  quit:
-  logCommon(LOG_DEBUG, " %*s archive %s:%lli = %.2f", depth, "",
+  logCommon(LOG_INFO, "%*s archive %s:%lli = %.2f", depth, "",
 	  self->hash, self->size, self->extractScore);
   rc = TRUE;
  error:
   if (!rc) {
-    logCommon(LOG_ERR, "%s", "fails to computeArchive");
+    logCommon(LOG_ERR, "fails to computeArchive");
   }
   return rc;
 }
@@ -233,7 +282,7 @@ computeExtractScore(Collection* coll)
   checkCollection(coll);
   self = coll->extractTree;
   if(self == 0) {
-    logCommon(LOG_DEBUG, "%s", "cannot compute empty ExtractTree");
+    logCommon(LOG_DEBUG, "cannot compute empty ExtractTree");
     rc = -1;
     goto error;
   }
@@ -251,34 +300,18 @@ computeExtractScore(Collection* coll)
   if (!populateExtractTree(coll)) goto error2;
 
   // compute archives score recursively
-  self->score = 20.00;
+  self->score = coll->serverTree->scoreParam.maxScore;
   if (coll->archives) {
     for (node = coll->archives->head; node; node = node->next) {
       archive = (Archive*)node->item;
-      if (!computeArchive(archive, 0)) goto error2;
+      if (!computeArchive(coll, archive, 0)) goto error2;
 
-      // do not dumb score with outdated rules, only looks for
-      // final contents and images
-      //       imageScore  toContainer  toContainer->type
-      // IMG       x          x            x      <--
-      // REC      -1          x            REC
-      // CONT     -1          x            x
-      // content  -1          0         -      <--
-      if (archive->imageScore == -1 && archive->toContainer) continue;
-
-      /*
-      // do not consider archives that do not figure into the
-      // extraction rule meta-data file (from md5sums file for instance)
-      //                                         fromContainer
-      // IMG       x          x            x      *       <--
-      // content  -1          0         -      +       <--
-      // record   -1          0         -      0
-      if (archive->imageScore == -1 && !archive->fromContainers->nbItems)
-	continue;
-      */
+      // new incomings are ignored into score computation
+      if (archive->incInherency) continue;
 
+      // global score = min ( archive's score )
       if (archive->extractScore > -1) {
-	if (self->score > archive->extractScore) 
+	if (self->score > archive->extractScore)
 	  self->score = archive->extractScore;
       }
     }
@@ -290,7 +323,7 @@ computeExtractScore(Collection* coll)
  quit:
  error:
  if (!rc || self->score == -1) {
-    logCommon(LOG_ERR, "%s", "fails to computeExtractScore");
+    logCommon(LOG_ERR, "fails to computeExtractScore");
   }
   return rc;
 }
@@ -320,44 +353,30 @@ getExtractStatus(Collection* coll, off_t* badSize, RG** badArchives)
   if (!(self = coll->extractTree)) goto error;
   logCommon(LOG_DEBUG, "getExtractStatus: %s", coll->label);
 
-  // already computed (and not diseased since)
   if (self->score == -1) {
-    logCommon(LOG_ERR, "%s", "please call computeExtractScore first");
-    goto error;
+    // if scores are not already computed (not used yet)
+    if (!computeExtractScore(coll)) goto error;
   }
 
   // put bad archives into a new ring
   *badSize = 0;
   for(node = coll->archives->head; node; node = node->next) {
     archive = (Archive*) node->item;
-    
-    // only look for content files and REC containers (uploaded files)
-    //       imageScore  toContainer  toContainer->type
-    // IMG       x          x            x     
-    // REC      -1          x            REC    <--
-    // CONT     -1          x            x
-    // content  -1          0         -      <--
-    if (archive->toContainer && archive->toContainer->type != REC) 
-      continue;
 
-    /*
-    // do not consider archives that do not figure into the
-    // extraction rule meta-data file (from md5sums file for instance)
-    //                                         fromContainer
-    // REC      -1          x            REC    0       <--
-    // content  -1          0         -      +       <--
-    // record   -1          0         -      0
-    if (!archive->toContainer && !archive->fromContainers->nbItems)
-      continue;
-    */
+    // looking for top containers as content cannot have worse score
+    if (!isEmptyRing(archive->fromContainers)) continue;
 
-    if (archive->extractScore < 5) {
+    // do not display a global bad score due to incomings
+    if (archive->incInherency) continue;
+
+    if (archive->extractScore <= 
+	coll->serverTree->scoreParam.maxScore /2) {
       if (badArchives && !rgInsert(*badArchives, archive)) goto error;
       *badSize += archive->size;
     }
   }
 
-  logCommon(LOG_DEBUG, "extraction score = %.2f", self->score);
+  logCommon(LOG_INFO, "extraction score = %.2f", self->score);
 
   if (self->score < 0) {
     // should never be reached
@@ -368,15 +387,15 @@ getExtractStatus(Collection* coll, off_t* badSize, RG** badArchives)
     rc = createString(_("Perenniality lost"));
     goto next;
   }
-  if (self->score < coll->serverTree->scoreParam.badScore) {
+  if (self->score <= coll->serverTree->scoreParam.badScore) {
     rc = createString(_("Serious risk to loose perenniality"));
     goto next;
   }
-  if (self->score < 5) {
+  if (self->score <= coll->serverTree->scoreParam.maxScore/2) {
     rc = createString(_("Bad perenniality"));
     goto next;
   }
-  if (self->score < 7.5) {
+  if (self->score <= coll->serverTree->scoreParam.maxScore*3/4) {
     rc = createString(_("Good perenniality"));
     goto next;
   }
@@ -400,95 +419,11 @@ getExtractStatus(Collection* coll, off_t* badSize, RG** badArchives)
   
  error:
   if (!rc) {
-    logCommon(LOG_ERR, "%s", "getExtractStatus fails");
+    logCommon(LOG_ERR, "getExtractStatus fails");
   }
   return rc;
 }
 
-/************************************************************************/
-
-#ifdef utMAIN
-#include "../misc/command.h"
-GLOBAL_STRUCT_DEF;
-
-/*=======================================================================
- * Function   : usage
- * Description: Print the usage.
- * Synopsis   : static void usage(char* programName)
- * Input      : programName = the name of the program; usually argv[0].
- * Output     : N/A
- =======================================================================*/
-static void 
-usage(char* programName)
-{
-  mdtxUsage(programName);
-
-  mdtxOptions();
-  //fprintf(stderr, "  ---\n");
-  return;
-}
-
-  
-/*=======================================================================
- * Function   : main 
- * Author     : Nicolas ROCHE
- * modif      : 2012/05/01
- * Description: Unit test for cache module.
- * Synopsis   : ./utupgrade
- * Input      : -i mediatex.conf
- * Output     : stdout
- =======================================================================*/
-int 
-main(int argc, char** argv)
-{
-  Collection* coll = 0;
-  char* mess = 0;
-  off_t badSize = 0;
-  // ---
-  int rc = 0;
-  int cOption = EOF;
-  char* programName = *argv;
-  char* options = MDTX_SHORT_OPTIONS;
-  struct option longOptions[] = {
-    MDTX_LONG_OPTIONS,
-    {0, 0, 0, 0}
-  };
-
-  // import mdtx environment
-  env.debugCommon = TRUE;
-  getEnv(&env);
-
-  // parse the command line
-  while((cOption = getopt_long(argc, argv, options, longOptions, 0)) 
-	!= EOF) {
-    switch(cOption) {
-      
-      GET_MDTX_OPTIONS; // generic options
-    }
-    if (rc) goto optError;
-  }
-
-  // export mdtx environment
-  if (!setEnv(programName, &env)) goto optError;
-
-  /************************************************************************/
-  if (!(coll = mdtxGetCollection("coll1"))) goto error;
-  if (!computeExtractScore(coll)) goto error; 
-  if (!(mess = getExtractStatus(coll, &badSize, 0))) goto error;
-  /************************************************************************/
-  
-  mess = destroyString(mess);
-  freeConfiguration();
-  rc = TRUE;
- error:
-  ENDINGS;
-  rc=!rc;
- optError:
-  exit(rc);
-}
-
-#endif // utMAIN
-
 /* Local Variables: */
 /* mode: c */
 /* mode: font-lock */
