@@ -1,9 +1,9 @@
 /*=======================================================================
- * Version: $Id: openClose.c,v 1.3 2015/06/03 14:03:34 nroche Exp $
+ * Version: $Id: openClose.c,v 1.18 2015/10/12 23:28:51 nroche Exp $
  * Project: MediaTeX
- * Module : bus/openClose
+ * Module : openClose
  
- * Manage data files
+ * Manage meta-data files
 
  MediaTex is an Electronic Records Management System
  Copyright (C) 2014 2015 Nicolas Roche
@@ -22,23 +22,7 @@
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  =======================================================================*/
 
-#include "../misc/log.h"
-#include "../misc/setuid.h"
-#include "../misc/command.h"
-#include "../misc/md5sum.h"
-#include "../memory/confTree.h"
-#include "../parser/confFile.tab.h"
-#include "../parser/supportFile.tab.h"
-#include "../parser/catalogFile.tab.h"
-#include "../parser/extractFile.tab.h"
-#include "../parser/serverFile.tab.h"
-#include "../parser/recordList.tab.h"
-#include "register.h"
-#include "ssh.h"
-#include "upgrade.h"
-#include "openClose.h"
-
-#include <avl.h>
+#include "mediatex-config.h"
 
 static char* CollFiles[] = {
   "    ", "   C", "  X ", "  XC", " S  ", " S C", " SX ", " SXC",
@@ -74,7 +58,7 @@ callUpdate(char* user)
   rc = TRUE;
  error:  
   if (!rc) {
-    logCommon(LOG_WARNING, "%s", "callUpdate fails");
+    logCommon(LOG_WARNING, "callUpdate fails");
   }
   argv[0] = destroyString(argv[0]);
   return(rc);
@@ -114,7 +98,7 @@ callCommit(char* user, char* signature1, char* signature2)
   rc = TRUE;
  error:  
   if (!rc) {
-    logCommon(LOG_WARNING, "%s", "callCommit fails");
+    logCommon(LOG_WARNING, "callCommit fails");
   }
   argv[0] = destroyString(argv[0]);
   return(rc);
@@ -124,7 +108,7 @@ callCommit(char* user, char* signature1, char* signature2)
  * Function   : loadConfiguration
  * Description: Call the parser on private files
  * Synopsis   : int loadConfiguration(int confFiles)
- * Input      : int confFiles: OR from ConfFile (CONF,SUPP)
+ * Input      : int confFiles: OR from ConfFile (CFG,SUPP)
  * Output     : TRUE on success
  =======================================================================*/
 int loadConfiguration(int confFiles)
@@ -132,16 +116,16 @@ int loadConfiguration(int confFiles)
   int rc = FALSE;
   Configuration* conf = 0;
 
-  logCommon(LOG_DEBUG, "%s", "load configuration");
+  logCommon(LOG_DEBUG, "load configuration");
   if (!confFiles) {
-    logCommon(LOG_ERR, "%s", "please provide files to load");
+    logCommon(LOG_ERR, "please provide files to load");
     goto error;
   }
   if (!(conf = getConfiguration())) goto error;
 
-  if ((confFiles & CONF) && conf->fileState[iCONF] == DISEASED) {
+  if ((confFiles & CFG) && conf->fileState[iCFG] == DISEASED) {
     if (!parseConfiguration(conf->confFile)) goto error;
-    conf->fileState[iCONF] = LOADED;
+    conf->fileState[iCFG] = LOADED;
   }
 
   if ((confFiles & SUPP) && conf->fileState[iSUPP] == DISEASED) {
@@ -152,7 +136,7 @@ int loadConfiguration(int confFiles)
   rc = TRUE;
  error:
   if (!rc) {
-    logCommon(LOG_ERR, "%s", "fails to load configuration");   
+    logCommon(LOG_ERR, "fails to load configuration");   
   }
   return rc;
 }
@@ -174,13 +158,15 @@ int loadRecords(Collection* coll)
   Record* record = 0;
   
   checkCollection(coll);
-  logCommon(LOG_INFO, "load %s records", coll->label);
-  logCommon(LOG_DEBUG, "records file is: %s", coll->md5sumsDB);
+  logCommon(LOG_DEBUG, "load %s records", coll->label);
+  logCommon(LOG_INFO, "parse records file: %s", coll->md5sumsDB);
+
+  // compute scores (only once), as score will be used by addCacheEntry
+  if (!computeExtractScore(coll)) goto error;
 
   if (access(coll->md5sumsDB, R_OK) == -1) {
     logCommon(LOG_NOTICE, "no md5sums file: %s", coll->md5sumsDB);
-    rc = TRUE;
-    goto error;
+    goto end;
   }
 
   // open md5sumsDB file
@@ -192,7 +178,7 @@ int loadRecords(Collection* coll)
   if (!lock(fd, F_RDLCK)) goto error;
 
   // parse md5sumsDB file into the main recordTree
-  if ((tree = parseRecordList(fd)) == 0) goto error;
+  if ((tree = parseRecords(fd)) == 0) goto error;
 
   if (!unLock(fd)) goto error;
   if (close(fd) == -1) {
@@ -208,15 +194,16 @@ int loadRecords(Collection* coll)
   coll->cacheTree->recordTree->messageType = DISK;
   curr = 0;
 
-  while((record = rgNext_r(coll->cacheTree->recordTree->records, &curr)) 
+  while ((record = rgNext_r(coll->cacheTree->recordTree->records, &curr)) 
 	!= 0) {
     if (!addCacheEntry(coll, record)) goto error;
   }
    
+ end:
   rc = TRUE;
  error:
   if (!rc) {
-    logCommon(LOG_ERR, "%s", "fails to load records");   
+    logCommon(LOG_ERR, "fails to load records");   
   }
   return rc;
 }
@@ -253,7 +240,8 @@ collectionLoop(Collection* coll, int collFiles,
   logCommon(LOG_DEBUG, "file loop on %s collection (%s)", 
 	  coll->label, strCF(collFiles));
 
-  for (i=iCTLG; i<=iCACH; ++i) {
+  // cache need computeExtractScore so cache must be disease first
+  for (i=iCACH; i>=iCTLG; --i) {
     if (collFiles & (1<<i)) {
       if (!callback(coll, i)) goto error;
     }
@@ -262,7 +250,7 @@ collectionLoop(Collection* coll, int collFiles,
   rc = TRUE;
  error:
   if (!rc) {
-    logCommon(LOG_ERR, "%s", "file loop fails");   
+    logCommon(LOG_ERR, "file loop fails");   
   }
   return rc;
 }
@@ -296,39 +284,42 @@ loadCvsFiles(Collection* coll, int fileIdx)
     parser = parseExtractFile;
     break;
   default:
-    logCommon(LOG_ERR, "%s", "metadata file not handle"); 
+    logCommon(LOG_ERR, "metadata file not handle"); 
     goto error;
   }
 
   l = strlen(path);
-  if (!(path = catString(path, "00.txt"))) goto error;
+  if (!(path = catString(path, "000.txt"))) goto error;
 
   // load from part files
   do {
-    if (!sprintf(path+l, "%02i.txt", i)) goto error;
-    if (access(path, R_OK) != 0) break;
+    if (!sprintf(path+l, "%03i.txt", i)) goto error;
+    if (access(path, R_OK)) break;
     if (!parser(coll, path)) goto error;
   }
   while (++i < 100);
   coll->fileState[fileIdx] = LOADED;
 
   // load last addon
-  if (!sprintf(path+l, "%s", "NN.txt")) goto error;
+  if (!sprintf(path+l, "%s", "NNN.txt")) goto error;
   if (access(path, R_OK) == 0) {
     if (!parser(coll, path)) goto error;
     i=1;
 
     // cgi and server only read the meta-data
     if (!env.noCollCvs) {
-      // force to re-serialize and commit it
+      // force re-serialize and commit to eat NNN.txt
       coll->fileState[fileIdx] = MODIFIED;
     }
   }  
   
-  rc = i>0;
+  if (!i) {
+    logCommon(LOG_INFO, "no metadata file founded");
+  }
+  rc = (i >= 0);
  error:
   if (!rc) {
-    logCommon(LOG_ERR, "%s", "loadCvsFiles fails");
+    logCommon(LOG_ERR, "loadCvsFiles fails");
   }
   path = destroyString(path);
   return rc;
@@ -353,7 +344,7 @@ loadColl(Collection* coll, int fileIdx)
   logCommon(LOG_DEBUG, "do load %s collection (%s)", 
 	  coll->label, strCF(1<<fileIdx));
 
-  if ((err = pthread_mutex_lock(&coll->mutex[fileIdx])) != 0) {
+  if ((err = pthread_mutex_lock(&coll->mutex[fileIdx]))) {
     logCommon(LOG_ERR, "pthread_mutex_lock fails: %s", strerror(err));
     goto error;
   }
@@ -392,13 +383,13 @@ loadColl(Collection* coll, int fileIdx)
 
   rc = TRUE;
  error2:
-  if ((err = pthread_mutex_unlock(&coll->mutex[fileIdx])) != 0) {
+  if ((err = pthread_mutex_unlock(&coll->mutex[fileIdx]))) {
     logCommon(LOG_ERR, "pthread_mutex_unlock fails: %s", strerror(err));
     rc = FALSE;
   }
  error:
   if (!rc) {
-    logCommon(LOG_ERR, "%s", "loadColl fails");   
+    logCommon(LOG_ERR, "loadColl fails");   
   }
   return rc;
 }
@@ -420,7 +411,7 @@ loadCollectionNbSteps(Collection* coll, int collFiles)
   int fileIdx = 0, i = 0, l = 0;
 
   checkCollection(coll);
-  logCommon(LOG_DEBUG, "%s", "loadCollectionNbSteps");
+  logCommon(LOG_DEBUG, "loadCollectionNbSteps");
 
   env.progBar.cur = env.progBar.max = 0;
   for (fileIdx=iCTLG; fileIdx<=iCACH; ++fileIdx) {
@@ -439,12 +430,12 @@ loadCollectionNbSteps(Collection* coll, int collFiles)
       
       i = 0;
       l = strlen(path);
-      if (!(path = catString(path, "00.txt"))) goto error;
+      if (!(path = catString(path, "000.txt"))) goto error;
       
       // part files
       do {
-	if (!sprintf(path+l, "%02i.txt", i)) goto error;
-	if (access(path, R_OK) != 0) break;
+	if (!sprintf(path+l, "%03i.txt", i)) goto error;
+	if (access(path, R_OK)) break;
 	
 	// roughtly estimate the number of steps (number of lines)
 	fd = fopen(path, "r");
@@ -452,10 +443,10 @@ loadCollectionNbSteps(Collection* coll, int collFiles)
 	  ++env.progBar.max;
 	fclose(fd);
       }
-      while (++i < 100);
+      while (++i < 1000);
       
       // load last addon
-      if (!sprintf(path+l, "%s", "NN.txt")) goto error;
+      if (!sprintf(path+l, "%s", "NNN.txt")) goto error;
       if (access(path, R_OK) == 0) {
 	fd = fopen(path, "r");
 	while (EOF != (fscanf(fd, "%*[^\n]"), fscanf(fd, "%*c")))
@@ -472,7 +463,7 @@ loadCollectionNbSteps(Collection* coll, int collFiles)
   rc = TRUE;
  error:
   if (!rc) {
-    logCommon(LOG_ERR, "%s", "loadCollectionNbSteps fails");   
+    logCommon(LOG_ERR, "loadCollectionNbSteps fails");   
   }
   path = destroyString(path);
   return rc;
@@ -495,6 +486,9 @@ loadCollection(Collection* coll, int collFiles)
   logCommon(LOG_DEBUG, "load %s collection (%s)", 
 	  coll->label, strCF(collFiles));
 
+  // force catalog to use archives from extract (assert no ophanes)
+  if (collFiles & CTLG) collFiles |= EXTR;
+
   if (!expandCollection(coll)) goto error;
 
   if (!env.noCollCvs) {
@@ -512,21 +506,24 @@ loadCollection(Collection* coll, int collFiles)
   startProgBar("load");
   if (!collectionLoop(coll, collFiles, loadColl)) goto error;
   stopProgBar();
-  logCommon(LOG_INFO, "steps: %lli / %lli", 
-	    env.progBar.cur, env.progBar.max);
+
+  if (env.progBar.max) {
+    logCommon(LOG_INFO, "steps: %lli / %lli", 
+	      env.progBar.cur, env.progBar.max);
+  }
 
   rc = TRUE;
  error:
   if (!rc) {
-    logCommon(LOG_ERR, "%s", "fails to load collection");   
+    logCommon(LOG_ERR, "fails to load collection");   
   }
   return rc;
 }
 
 /*=======================================================================
- * Function   : wasModifiedCollection
+ * Function   : wasModifiedColl
  * Description: Call serializer on private files
- * Synopsis   : int wasModifiedCollection()
+ * Synopsis   : int wasModifiedColl()
  * Input      : N/A
  * Output     : TRUE on success
  =======================================================================*/
@@ -540,14 +537,14 @@ wasModifiedColl(Collection* coll, int i)
   logCommon(LOG_DEBUG, "do set %s collection as modified (%s)", 
 	  coll->label, strCF(1<<i));
 
-  if ((err = pthread_mutex_lock(&coll->mutex[i])) != 0) {
+  if ((err = pthread_mutex_lock(&coll->mutex[i]))) {
     logCommon(LOG_ERR, "pthread_mutex_lock fails: %s", strerror(err));
     goto error;
   }
   
   coll->fileState[i] = MODIFIED;
   
-  if ((err = pthread_mutex_unlock(&coll->mutex[i])) != 0) {
+  if ((err = pthread_mutex_unlock(&coll->mutex[i]))) {
     logCommon(LOG_ERR, "pthread_mutex_unlock fails: %s", strerror(err));
     goto error;
   }
@@ -555,7 +552,7 @@ wasModifiedColl(Collection* coll, int i)
   rc = TRUE;
  error:
   if (!rc) {
-    logCommon(LOG_ERR, "%s", "fails to set collection as modified");
+    logCommon(LOG_ERR, "fails to set collection as modified");
   }
   return rc;
 }
@@ -584,7 +581,7 @@ wasModifiedCollection(Collection* coll, int collFiles)
   releaseCollection(coll, collFiles);
  error:
   if (!rc) {
-    logCommon(LOG_ERR, "%s", "fails to set collection as modified");
+    logCommon(LOG_ERR, "fails to set collection as modified");
   }
   return rc;
 }
@@ -606,7 +603,7 @@ releaseColl(Collection* coll, int i)
   logCommon(LOG_DEBUG, "do release %s collection (%s)", 
 	  coll->label, strCF(1<<i));
 
-  if ((err = pthread_mutex_lock(&coll->mutex[i])) != 0) {
+  if ((err = pthread_mutex_lock(&coll->mutex[i]))) {
     logCommon(LOG_ERR, "pthread_mutex_lock fails: %s", strerror(err));
     goto error;
   }
@@ -620,7 +617,7 @@ releaseColl(Collection* coll, int i)
 	    strCF(1<<i), coll->cptInUse[i]);
   }
 
-  if ((err = pthread_mutex_unlock(&coll->mutex[i])) != 0) {
+  if ((err = pthread_mutex_unlock(&coll->mutex[i]))) {
     logCommon(LOG_ERR, "pthread_mutex_unlock fails: %s", strerror(err));
     goto error;
   }
@@ -628,7 +625,7 @@ releaseColl(Collection* coll, int i)
   rc = TRUE;
  error:
   if (!rc) {
-    logCommon(LOG_ERR, "%s", "fails to do release collection");
+    logCommon(LOG_ERR, "fails to do release collection");
   }
   return rc;
 }
@@ -649,12 +646,15 @@ releaseCollection(Collection* coll, int collFiles)
   logCommon(LOG_DEBUG, "release %s collection (%s)", 
 	  coll->label, strCF(collFiles));
 
- if (!collectionLoop(coll, collFiles, releaseColl)) goto error;
+  // force catalog to use archives from extract (assert no ophanes)
+  if (collFiles & CTLG) collFiles |= EXTR;
+
+  if (!collectionLoop(coll, collFiles, releaseColl)) goto error;
 
   rc = TRUE;
  error:
   if (!rc) {
-    logCommon(LOG_ERR, "%s", "fails to release collection");
+    logCommon(LOG_ERR, "fails to release collection");
   }
   return rc;
 }
@@ -673,14 +673,14 @@ saveConfiguration()
   Configuration* conf = 0;
   int change = FALSE;
 
-  logCommon(LOG_DEBUG, "%s", "save configuration");
+  logCommon(LOG_DEBUG, "save configuration");
   if (!(conf = getConfiguration())) goto error;
 
-  if (conf->fileState[iCONF] == MODIFIED) {
+  if (conf->fileState[iCFG] == MODIFIED) {
     if (!expandConfiguration()) goto error;
     if (!populateConfiguration()) goto error;
     if (!serializeConfiguration(conf)) goto error;
-    conf->fileState[iCONF] = LOADED;
+    conf->fileState[iCFG] = LOADED;
     change = TRUE;
     conf->toHup = TRUE;
   }
@@ -699,7 +699,7 @@ saveConfiguration()
   rc = TRUE;
  error:
   if (!rc) {
-    logCommon(LOG_ERR, "%s", "fails to save configuration");   
+    logCommon(LOG_ERR, "fails to save configuration");   
   }
   return rc;
 }
@@ -716,12 +716,13 @@ saveColl(Collection* coll, int i)
 {
   int rc = FALSE;
   int err = 0;
+  CvsFile fd = {0, 0, 0, FALSE, 0, cvsCutOpen, cvsCutPrint};
 
   checkCollection(coll);
   logCommon(LOG_DEBUG, "do save %s collection (%s)", 
 	  coll->label, strCF(1<<i));
 
-  if ((err = pthread_mutex_lock(&coll->mutex[i])) != 0) {
+  if ((err = pthread_mutex_lock(&coll->mutex[i]))) {
     logCommon(LOG_ERR, "pthread_mutex_lock fails: %s", strerror(err));
     goto error;
   }
@@ -730,11 +731,11 @@ saveColl(Collection* coll, int i)
   if (coll->fileState[i] == MODIFIED && coll->cptInUse[i] == 0) {
     switch (i) {
     case iCTLG:
-      if (!serializeCatalogTree(coll)) goto error2;
+      if (!serializeCatalogTree(coll, &fd)) goto error2;
       coll->toCommit = TRUE;
       break;
     case iEXTR:
-      if (!serializeExtractTree(coll)) goto error2;
+      if (!serializeExtractTree(coll, &fd)) goto error2;
       coll->toCommit = TRUE;
       break;
     case iSERV:
@@ -756,9 +757,9 @@ saveColl(Collection* coll, int i)
     coll->fileState[i] = LOADED;
   }
   else {
-    logCommon(LOG_DEBUG, "%s", "do not save collection as...");
+    logCommon(LOG_DEBUG, "do not save collection as...");
     if (coll->fileState[i] != MODIFIED) {
-      logCommon(LOG_DEBUG, "%s", "... not modified");
+      logCommon(LOG_DEBUG, "... not modified");
     }
     if (coll->cptInUse[i]) {
       logCommon(LOG_DEBUG, "... still used by %i functions", 
@@ -768,13 +769,13 @@ saveColl(Collection* coll, int i)
 
   rc = TRUE;
  error2:
-  if ((err = pthread_mutex_unlock(&coll->mutex[i])) != 0) {
+  if ((err = pthread_mutex_unlock(&coll->mutex[i]))) {
     logCommon(LOG_ERR, "pthread_mutex_unlock fails: %s", strerror(err));
     rc = FALSE;
   }
  error:
   if (!rc) {
-    logCommon(LOG_ERR, "%s", "fails to save collection");
+    logCommon(LOG_ERR, "fails to save collection");
   }
   return rc;
 }
@@ -794,7 +795,7 @@ saveCollectionNbSteps(Collection* coll, int collFiles)
   int fileIdx = 0, i = 0;
 
   checkCollection(coll);
-  logCommon(LOG_DEBUG, "%s", "saveCollectionNbSteps");
+  logCommon(LOG_DEBUG, "saveCollectionNbSteps");
 
   env.progBar.cur = env.progBar.max = 0;
   for (fileIdx=iCTLG; fileIdx<=iCACH; ++fileIdx) {
@@ -819,7 +820,7 @@ saveCollectionNbSteps(Collection* coll, int collFiles)
   rc = TRUE;
  error:
   if (!rc) {
-    logCommon(LOG_ERR, "%s", "saveCollectionNbSteps fails");   
+    logCommon(LOG_ERR, "saveCollectionNbSteps fails");   
   }
   return rc;
 }
@@ -867,7 +868,7 @@ saveCollection(Collection* coll, int collFiles)
   rc = TRUE;
  error:
   if (!rc) {
-    logCommon(LOG_ERR, "%s", "fails to save collection");
+    logCommon(LOG_ERR, "fails to save collection");
   }
   return rc;
 }
@@ -878,7 +879,6 @@ saveCollection(Collection* coll, int collFiles)
  * Synopsis   : int clientSaveAll(char* cmdLine)
  * Input      : N/A
  * Output     : TRUE on success
- * TODO       : save collection before configuration (as a stack) ?
  =======================================================================*/
 int 
 clientSaveAll()
@@ -888,10 +888,10 @@ clientSaveAll()
   Collection* coll = 0;
   RGIT* curr = 0;
   
-  logCommon(LOG_DEBUG, "%s", "clientSaveAll");
+  logCommon(LOG_DEBUG, "clientSaveAll");
   if (!(conf = env.confTree)) goto end; // nothing was loaded
 
-  while ((coll = rgNext_r(conf->collections, &curr)) != 0) {
+  while ((coll = rgNext_r(conf->collections, &curr))) {
     if (!saveCollection(coll, CTLG|EXTR|SERV)) goto error;
   }
 
@@ -907,7 +907,7 @@ clientSaveAll()
   rc = TRUE;
  error:
   if (!rc) {
-    logCommon(LOG_ERR, "%s", "clientSaveAll fails");
+    logCommon(LOG_ERR, "clientSaveAll fails");
   }
   return rc;
 }
@@ -926,10 +926,10 @@ int serverSaveAll()
   Collection* coll = 0;
   RGIT* curr = 0;
   
-  logCommon(LOG_DEBUG, "%s", "server save all");
+  logCommon(LOG_DEBUG, "server save all");
   if (!(conf = env.confTree)) goto end; // nothing was loaded
 
-  while ((coll = rgNext_r(conf->collections, &curr)) != 0) {
+  while ((coll = rgNext_r(conf->collections, &curr))) {
     if (!saveCollection(coll, CACH)) goto error;
   }
 
@@ -937,14 +937,14 @@ int serverSaveAll()
   rc = TRUE;
  error:
   if (!rc) {
-    logCommon(LOG_ERR, "%s", "server fails to save all");
+    logCommon(LOG_ERR, "server fails to save all");
   }
   return rc;
 }
 
 /*=======================================================================
  * Function   : diseaseCollection
- * Description: Call serializer on private files
+ * Description: Release memory used to parse metadata files
  * Synopsis   : int diseaseCollection()
  * Input      : N/A
  * Output     : TRUE on success
@@ -959,7 +959,7 @@ diseaseColl(Collection* coll, int i)
   logCommon(LOG_DEBUG, "disease %s collection (%s)", 
 	  coll->label, strCF(1<<i));
 
-  if ((err = pthread_mutex_lock(&coll->mutex[i])) != 0) {
+  if ((err = pthread_mutex_lock(&coll->mutex[i]))) {
     logCommon(LOG_ERR, "pthread_mutex_lock fails: %s", strerror(err));
     goto error;
   } 
@@ -987,13 +987,13 @@ diseaseColl(Collection* coll, int i)
 
   rc = TRUE; 
  error2:
-  if ((err = pthread_mutex_unlock(&coll->mutex[i])) != 0) {
+  if ((err = pthread_mutex_unlock(&coll->mutex[i]))) {
     logCommon(LOG_ERR, "pthread_mutex_unlock fails: %s", strerror(err));
     rc = FALSE;
   }
  error:
   if (!rc) {
-    logCommon(LOG_ERR, "%s", "fails to disease collection");
+    logCommon(LOG_ERR, "fails to disease collection");
   }
   return rc;
 }
@@ -1014,14 +1014,14 @@ diseaseCollection(Collection* coll, int collFiles)
   logCommon(LOG_DEBUG, "disease %s collection (%s)", 
 	  coll->label, strCF(collFiles));
 
-  if (!env.noRegression) memoryStatus(LOG_NOTICE);
+  if (!env.noRegression) memoryStatus(LOG_INFO, __FILE__, __LINE__);
   if (!collectionLoop(coll, collFiles, diseaseColl)) goto error;
-  if (!env.noRegression) memoryStatus(LOG_NOTICE);
+  if (!env.noRegression) memoryStatus(LOG_INFO, __FILE__, __LINE__);
 
   rc = TRUE;
  error:
   if (!rc) {
-    logCommon(LOG_ERR, "%s", "fails to disease collection");
+    logCommon(LOG_ERR, "fails to disease collection");
   }
   return rc;
 }
@@ -1042,10 +1042,10 @@ clientDiseaseAll()
   Collection* coll = 0;
   RGIT* curr = 0;
   
-  logCommon(LOG_DEBUG, "%s", "clientDiseaseAll");
+  logCommon(LOG_DEBUG, "clientDiseaseAll");
   if (!(conf = env.confTree)) goto error; // do not malloc
 
-  if ((coll = rgNext_r(conf->collections, &curr)) != 0) {
+  if ((coll = rgNext_r(conf->collections, &curr))) {
     if (!saveCollection(coll, CTLG|EXTR|SERV)) goto error;
     if (!diseaseCollection(coll, CTLG|EXTR|SERV|CACH)) goto error;
   }
@@ -1053,7 +1053,7 @@ clientDiseaseAll()
   rc = TRUE;
  error:
   if (!rc) {
-    logCommon(LOG_ERR, "%s", "clientDiseaseAll fails");
+    logCommon(LOG_ERR, "clientDiseaseAll fails");
   }
   return rc;
 }
@@ -1072,10 +1072,10 @@ int serverDiseaseAll()
   Collection* coll = 0;
   RGIT* curr = 0;
   
-  logCommon(LOG_DEBUG, "%s", "serverDiseaseAll");
+  logCommon(LOG_DEBUG, "serverDiseaseAll");
   if (!(conf = env.confTree)) goto error; // do not malloc
 
-  if ((coll = rgNext_r(conf->collections, &curr)) != 0) {
+  if ((coll = rgNext_r(conf->collections, &curr))) {
     if (!saveCollection(coll, CACH)) goto error;
     if (!diseaseCollection(coll, CTLG|EXTR|SERV|CACH)) goto error;
   }
@@ -1083,14 +1083,14 @@ int serverDiseaseAll()
   rc = TRUE;
  error:
   if (!rc) {
-    logCommon(LOG_ERR, "%s", "serverDiseaseAll fails");
+    logCommon(LOG_ERR, "serverDiseaseAll fails");
   }
   return rc;
 }
 
 /*=======================================================================
  * Function   : mdtxGetCollection
- * Description: Call serializer on all modified files
+ * Description: load a collection
  * Synopsis   : Collection* mdtxGetCollection(char* label)
  * Input      : char* label: collection label to search for
  * Output     : Collection*: the matching collection ; 0 if not found
@@ -1103,21 +1103,21 @@ Collection* mdtxGetCollection(char* label)
   checkLabel(label);  
   logCommon(LOG_DEBUG, "get %s collection", label);
 
-  if (!loadConfiguration(CONF)) goto error;
+  if (!loadConfiguration(CFG)) goto error;
   if (!(coll = getCollection(label))) goto error;
   if (!expandCollection(coll)) goto error;
 
   rc = coll;
  error:
   if (!rc) {
-    logCommon(LOG_ERR, "%s", "fails to get collection");
+    logCommon(LOG_ERR, "fails to get collection");
   }
   return rc;
 }
 
 /*=======================================================================
  * Function   : mdtxGetSupport
- * Description: Call serializer on all modified files
+ * Description: load a support
  * Synopsis   : Support* mdtxGetSupport(char* label)
  * Input      : char* label: support label to search for
  * Output     : Support*: the matching support ; 0 if not found
@@ -1137,7 +1137,7 @@ Support* mdtxGetSupport(char* label)
   rc = supp;
  error:
   if (!rc) {
-    logCommon(LOG_ERR, "%s", "fails to get support");
+    logCommon(LOG_ERR, "fails to get support");
   }
   return rc;
 }
@@ -1157,15 +1157,15 @@ clientLoop(int (*callback)(char*))
   Collection* coll = 0;
   RGIT* curr = 0;
 
-  logCommon(LOG_DEBUG, "%s", "loop on all collections");
+  logCommon(LOG_DEBUG, "loop on all collections");
 
   if (!allowedUser(env.confLabel)) goto error;
 
   // for all collection
-  if (!loadConfiguration(CONF)) goto error;
+  if (!loadConfiguration(CFG)) goto error;
   conf = getConfiguration();
-  if (conf->collections != 0) {
-    while((coll = rgNext_r(conf->collections, &curr)) != 0) {
+  if (conf->collections) {
+    while ((coll = rgNext_r(conf->collections, &curr))) {
       if (!callback(coll->label)) goto error;
       
       // free memory as soon as possible
@@ -1177,7 +1177,7 @@ clientLoop(int (*callback)(char*))
   rc = TRUE;
  error:
   if (!rc) {
-    logCommon(LOG_ERR, "%s", "clientLoop fails");
+    logCommon(LOG_ERR, "clientLoop fails");
   } 
   return rc;
 }
@@ -1197,15 +1197,15 @@ serverLoop(int (*callback)(Collection*))
   Collection* coll = 0;
   RGIT* curr = 0;
 
-  logCommon(LOG_DEBUG, "%s", "loop on all collections (2)");
+  logCommon(LOG_DEBUG, "loop on all collections (2)");
 
   if (!allowedUser(env.confLabel)) goto error;
 
   // for all collection
-  if (!loadConfiguration(CONF)) goto error;
+  if (!loadConfiguration(CFG)) goto error;
   conf = getConfiguration();
-  if (conf->collections != 0) {
-    while((coll = rgNext_r(conf->collections, &curr)) != 0) {
+  if (conf->collections) {
+    while ((coll = rgNext_r(conf->collections, &curr))) {
       if (!callback(coll)) goto error;
     }
   }
@@ -1213,95 +1213,11 @@ serverLoop(int (*callback)(Collection*))
   rc = TRUE;
  error:
   if (!rc) {
-    logCommon(LOG_ERR, "%s", "serverLoop fails");
+    logCommon(LOG_ERR, "serverLoop fails");
   } 
   return rc;
 }
 
-/************************************************************************/
-
-#ifdef utMAIN
-#include "../misc/command.h"
-GLOBAL_STRUCT_DEF;
-
-/*=======================================================================
- * Function   : usage
- * Description: Print the usage.
- * Synopsis   : static void usage(char* programName)
- * Input      : programName = the name of the program; usually argv[0].
- * Output     : N/A
- =======================================================================*/
-static void 
-usage(char* programName)
-{
-  mdtxUsage(programName);
-  //fprintf(stderr, "\n\t\t");
-
-  mdtxOptions();
-  //fprintf(stderr, "  ---\n");
-  return;
-}
-
-
-/*=======================================================================
- * Function   : main 
- * Author     : Nicolas ROCHE
- * modif      : 2012/05/01
- * Description: Unit test for open/close module.
- * Synopsis   : ./openClose
- * Input      : 
- * Output     : stdout
- =======================================================================*/
-int 
-main(int argc, char** argv)
-{
-  Collection* coll = 0;
-  // ---
-  int rc = 0;
-  int cOption = EOF;
-  char* programName = *argv;
-  char* options = MDTX_SHORT_OPTIONS"";
-  struct option longOptions[] = {
-    MDTX_LONG_OPTIONS,
-    {0, 0, 0, 0}
-  };
-
-  // import mdtx environment
-  env.debugCommon = TRUE;
-  getEnv(&env);
-
-  // parse the command line
-  while((cOption = getopt_long(argc, argv, options, longOptions, 0)) 
-	!= EOF) {
-    switch(cOption) {
-      
-      GET_MDTX_OPTIONS; // generic options
-    }
-    if (rc) goto optError;
-  }
-
-  // export mdtx environment
-  if (!setEnv(programName, &env)) goto optError;
-
-  /************************************************************************/
-  if (!mdtxGetSupport("SUPP11_logo.png")) goto error;
-  if (!(coll = mdtxGetCollection("coll1"))) goto error;
-  if (!loadCollection(coll, CTLG|EXTR|SERV|CACH)) goto error;
-  if (!releaseCollection(coll, CTLG|EXTR|SERV|CACH)) goto error;
-  if (!diseaseCollection(coll, CTLG|EXTR|SERV|CACH)) goto error;
-  /************************************************************************/
-
-  rc = TRUE;
- error:
-  freeConfiguration();
-  ENDINGS;
-  rc=!rc;
- optError:
-  exit(rc);
-}
-
-#endif // utMAIN
-
 /* Local Variables: */
 /* mode: c */
 /* mode: font-lock */
