@@ -1,9 +1,9 @@
 /*=======================================================================
- * Version: $Id: register.c,v 1.3 2015/06/03 14:03:34 nroche Exp $
+ * Version: $Id: register.c,v 1.6 2015/08/13 21:14:33 nroche Exp $
  * Project: MediaTeX
  * Module : bus/register
  
- * Manage simple interaction between wrapper and server
+ * Manage signals from client to server using registers
 
  MediaTex is an Electronic Records Management System
  Copyright (C) 2014 2015 Nicolas Roche
@@ -22,13 +22,7 @@
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 =======================================================================*/
 
-#include "../misc/log.h"
-#include "../misc/shm.h"
-#include "../memory/strdsm.h"
-#include "../memory/confTree.h"
-#include "register.h"
-
-#include <signal.h>
+#include "mediatex-config.h"
 
 /*=======================================================================
  * Function   : mdtxShmCopy
@@ -187,7 +181,7 @@ mdtxAsyncSignal(int signal)
     logCommon(LOG_INFO, "cannot retrieve pid from %s", conf->pidFile);
     goto error;
   }
-  if (fclose(fd) != 0) {
+  if (fclose(fd)) {
     logCommon(LOG_ERR, "fclose fails: %s", strerror(errno));
     goto error;
   }
@@ -197,14 +191,13 @@ mdtxAsyncSignal(int signal)
 
   if (kill(pid, signal) == -1) {
     logCommon(LOG_ERR, "kill signal to daemon fails: %s", strerror(errno));
-    //logCommon(LOG_DEBUG, "%s", "(you need to be logged as mdtx user)");
     goto error;
   }
 
   rc = TRUE;
  error:
   if (!rc) {
-    logCommon(LOG_WARNING, "%s", "mdtxAsyncSignal fails");
+    logCommon(LOG_WARNING, "mdtxAsyncSignal fails");
   }
 return rc;
 }
@@ -266,184 +259,15 @@ int mdtxSyncSignal(int flag)
 
   rc = TRUE;
   if (param.buf[flag] != MDTX_DONE) {
-    logCommon(LOG_WARNING, "%s", "server fails to perform your query");
+    logCommon(LOG_WARNING, "server fails to perform your query");
   }
  error:
   if (!rc) {
-    logCommon(LOG_ERR, "%s", "mdtxSyncSignal fails");
+    logCommon(LOG_ERR, "mdtxSyncSignal fails");
   }
   return rc;
 }
 
-/************************************************************************/
-
-#ifdef utMAIN
-#include "../misc/command.h"
-
-#define UNDEF -1
-#define INIT  10
-#define GET   11
-#define FREE  12
-#define ERROR 13
-GLOBAL_STRUCT_DEF;
-
-/*=======================================================================
- * Function   : usage
- * Description: Print the usage.
- * Synopsis   : static void usage(char* programName)
- * Input      : programName = the name of the program; usually argv[0].
- * Output     : N/A
- =======================================================================*/
-static void 
-usage(char* programName)
-{
-  mdtxUsage(programName);
-  fprintf(stderr, "\n\t\t{ -I | -G | -F | -S | -E | -N | -D | -e }");
-
-  mdtxOptions();
-  fprintf(stderr, "  ---\n"
-	  "  -I, --initialize\tinitialize share memory\n"
-	  "  -G, --read-shm\tread share memory\n"
-	  "  -F, --free-shm\tfree share memory\n"
-	  "  -W, --do-save\t\tsave md5sums.txt file\n"
-	  "  -E, --do-extract\tperform extracton\n"
-	  "  -N, --do-notify\tperform notification\n"
-	  "  -D, --do-deliver\tperform deliver\n"
-	  "  -e, --do-errorx\terror test\n");
-  return;
-}
-
-
-/*=======================================================================
- * Function   : main 
- * Author     : Nicolas ROCHE
- * modif      : 2012/05/01
- * Description: Unit test for register module.
- * Synopsis   : ./utregister
- * Input      : { -I | -G | -F | -5 | -X | -N | -S }
- * Output     : stdout
- =======================================================================*/
-int 
-main(int argc, char** argv)
-{
-  int signal = UNDEF;
-  ShmParam param;
-  int doError = FALSE;
-  // ---
-  int rc = 0;
-  int cOption = EOF;
-  char* programName = *argv;
-  char* options = MDTX_SHORT_OPTIONS"IGFWENDe";
-  struct option longOptions[] = {
-    MDTX_LONG_OPTIONS,
-    {"initialize", required_argument, 0, 'I'},
-    {"read-shm", required_argument, 0, 'G'},
-    {"free-shm", required_argument, 0, 'F'},
-    {"do-save", required_argument, 0, 'W'},
-    {"do-extract", required_argument, 0, 'E'},
-    {"do-notify", required_argument, 0, 'N'},
-    {"do-deliver", required_argument, 0, 'D'},
-    {"do-error", required_argument, 0, 'e'},
-    {0, 0, 0, 0}
-  };
-
-  // import mdtx environment
-  env.debugCommon = TRUE;
-  getEnv(&env);
-
-  // parse the command line
-  while((cOption = getopt_long(argc, argv, options, longOptions, 0)) 
-	!= EOF) {
-    switch(cOption) {
-
-    case 'I':
-      if (signal != UNDEF) rc=1;
-      signal = INIT;
-      break;
-
-    case 'G':
-      if (signal != UNDEF) rc=2;
-      signal = GET;
-      break;
-
-    case 'F':
-      if (signal != UNDEF) rc=3;
-      signal = FREE;
-      break;
-
-    case 'W':
-      if (signal != UNDEF) rc=4;
-      signal = MDTX_SAVEMD5;
-      break;
-
-    case 'E':
-      if (signal != UNDEF) rc=5;
-      signal = MDTX_EXTRACT;
-      break;
-
-    case 'N':
-      if (signal != UNDEF) rc=6;
-      signal = MDTX_NOTIFY;
-      break;
-
-    case 'D':
-      if (signal != UNDEF) rc=7;
-      signal = MDTX_DELIVER;
-      break;
-
-    case 'e':
-      doError = TRUE;
-      break;
-
-      GET_MDTX_OPTIONS; // generic options
-    }
-    if (rc) goto optError;
-  }
-
-  // export mdtx environment
-  usleep(50000);
-  if (!setEnv(programName, &env)) goto optError;
-
-  /************************************************************************/
-  switch (signal) {
-  case INIT:
-    rc = mdtxShmInitialize();
-    break;
-  case GET:
-    if (!(rc = shmRead(getConfiguration()->confFile, MDTX_SHM_BUFF_SIZE,
-		       mdtxShmRead, (void*)&param)))
-      goto error;
-    printf("=> %s\n", param.buf);
-    break;
-  case FREE:
-    rc = mdtxShmFree();
-    break;
-  case UNDEF:
-    usage(programName);
-    break;
-  default:
-    if (doError) {
-      param.flag = signal;
-      if (!(rc = shmWrite(getConfiguration()->confFile, MDTX_SHM_BUFF_SIZE,
-			  mdtxShmError, (void*)&param)))
-	goto error;
-    }
-    else {
-      rc = mdtxSyncSignal(signal);
-    }
-  }
-  /************************************************************************/
-
-  freeConfiguration();
- error:
-  ENDINGS;
-  rc=!rc;
- optError:
-  exit(rc);
-}
-
-#endif // utMAIN
-
 /* Local Variables: */
 /* mode: c */
 /* mode: font-lock */
