@@ -1,9 +1,9 @@
 /*=======================================================================
- * Version: $Id: ssh.c,v 1.3 2015/06/03 14:03:34 nroche Exp $
+ * Version: $Id: ssh.c,v 1.8 2015/09/04 15:30:26 nroche Exp $
  * Project: MediaTeX
- * Module : serverTree
+ * Module : ssh
 
-* SSH producer interface
+ * update ssh user's configuration
 
 MediaTex is an Electronic Records Management System
 Copyright (C) 2014 2015 Nicolas Roche
@@ -22,16 +22,7 @@ You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 =======================================================================*/
 
-#include "../mediatex.h"
-#include "../misc/log.h"
-#include "../misc/command.h"
-#include "../memory/strdsm.h"
-#include "../memory/serverTree.h"
-#include "../parser/confFile.tab.h"
-#include "../parser/serverFile.tab.h"
-
-#include <sys/types.h> // umask
-#include <sys/stat.h>
+#include "mediatex-config.h"
 
 /*=======================================================================
  * Function   : serializeAuthKeys
@@ -51,16 +42,16 @@ serializeAuthKeys(Collection* coll)
   RGIT* curr = 0;
   mode_t mask;
 
+  mask = umask(0177);
   checkCollection(coll);
   if (!(self = coll->serverTree)) goto error;
-  logCommon(LOG_DEBUG, "%s", "serialize authorized_keys file");
+  logCommon(LOG_DEBUG, "serialize authorized_keys file");
 
   path = coll->sshAuthKeys;
   logCommon(LOG_INFO, "Serializing the authorized_keys file: %s", 
 	  path?path:"stdout");
       
   // output file
-  mask = umask(0177);
   if (!env.dryRun) {
     if ((fd = fopen(path, "w")) == 0) {
       logCommon(LOG_ERR, "fdopen %s fails: %s", path, strerror(errno)); 
@@ -70,8 +61,8 @@ serializeAuthKeys(Collection* coll)
       
   fprintf(fd, "# This file is managed by MediaTeX software.\n");
 
-  if (self->servers != 0) {
-    while((server = rgNext_r(self->servers, &curr)) != 0) {
+  if (self->servers) {
+    while ((server = rgNext_r(self->servers, &curr))) {
       fprintf(fd, "%s\n", server->userKey);
     }
   }
@@ -84,7 +75,7 @@ serializeAuthKeys(Collection* coll)
     rc = FALSE;
   }
   if (!rc) {
-    logCommon(LOG_ERR, "%s", "fail to serialize authorized_keys file");
+    logCommon(LOG_ERR, "fail to serialize authorized_keys file");
   }
   umask(mask);
   return(rc);
@@ -111,7 +102,7 @@ serializeSshConfig(Collection* coll)
 
   checkCollection(coll);
   if (!(self = coll->serverTree)) goto error;
-  logCommon(LOG_DEBUG, "%s", "serialize ssh's config file");
+  logCommon(LOG_DEBUG, "serialize ssh's config file");
 
   path = coll->sshConfig;
   logCommon(LOG_INFO, "Serializing the ssh's config file: %s", 
@@ -135,7 +126,7 @@ serializeSshConfig(Collection* coll)
 
   if (!isEmptyRing(self->servers)) {
     if (!rgSort(self->servers, cmpServer)) goto error;
-    while((server = rgNext_r(self->servers, &curr)) != 0) {
+    while ((server = rgNext_r(self->servers, &curr))) {
       if (isEmptyString(server->host) ||
 	  (previous && !strcmp(server->host, previous->host))) 
 	continue;
@@ -152,7 +143,7 @@ serializeSshConfig(Collection* coll)
     rc = FALSE;
   }
   if (!rc) {
-    logCommon(LOG_ERR, "%s", "fail to serialize ssh's config file");
+    logCommon(LOG_ERR, "fail to serialize ssh's config file");
   }
   umask(mask);
   return(rc);
@@ -183,7 +174,7 @@ serializeKnownHosts(Collection* coll)
   if (!(conf = getConfiguration())) goto error;
   if (!(populateConfiguration())) goto error;
   if (!(self = coll->serverTree)) goto error;
-  logCommon(LOG_DEBUG, "%s", "serialize known_hosts file");
+  logCommon(LOG_DEBUG, "serialize known_hosts file");
 
   path = coll->sshKnownHosts;
   logCommon(LOG_INFO, "Serializing the known_host file: %s", 
@@ -193,7 +184,8 @@ serializeKnownHosts(Collection* coll)
   mask = umask(0177);
   if (!env.dryRun) {
     if ((fd = fopen(path, "w")) == 0) {
-      logCommon(LOG_ERR, "Cannot open known_host file for write: %s", path);
+      logCommon(LOG_ERR, "Cannot open known_host file for write: %s", 
+		path);
       goto error;
     }
   }
@@ -204,14 +196,14 @@ serializeKnownHosts(Collection* coll)
   // here using "localhost" name for local connexions
   fprintf(fd, "localhost %s\n", conf->hostKey);
   if (!strcmp(conf->host, "localhost")) {
-    logCommon(LOG_WARNING, "%s", 
+    logCommon(LOG_WARNING, 
 	    "Please avoid using localhost in the configuration");
   }
 
   // add all keys using the host name provided by servers.txt
-  if (self->servers != 0) {
-    while((server = rgNext_r(self->servers, &curr)) != 0) {
-      if (server->hostKey != 0) {
+  if (self->servers) {
+    while ((server = rgNext_r(self->servers, &curr))) {
+      if (server->hostKey) {
 
 	// must add port != 22 given by .ssh/config file
 	if (server->sshPort == 22) {
@@ -224,7 +216,7 @@ serializeKnownHosts(Collection* coll)
 
 	// warning message as you cannot be reach from the outside
 	if (!strcmp(server->host, "localhost")) {
-	  logCommon(LOG_WARNING, "%s", 
+	  logCommon(LOG_WARNING, 
 		  "Please avoid having localhost in the servers list");
 	}
       }
@@ -243,7 +235,7 @@ serializeKnownHosts(Collection* coll)
   rc = TRUE;  
  error:  
   if (!rc) {
-    logCommon(LOG_ERR, "%s", "fail to serialize known_host file");
+    logCommon(LOG_ERR, "fail to serialize known_host file");
   }
   umask(mask);
   return(rc);
@@ -264,7 +256,7 @@ sshKeygen(Collection* coll)
   char* argv[] = {"/usr/bin/ssh-keygen", "-Hf", 0, 0};
   char *path = 0;
 
-  logCommon(LOG_DEBUG, "%s", "do ssh-keygen -H");
+  logCommon(LOG_DEBUG, "do ssh-keygen -H");
   argv[2] = coll->sshKnownHosts;
 
 
@@ -277,7 +269,8 @@ sshKeygen(Collection* coll)
     
     // do $ rm -f $CACHEDIR/home/$LABEL/.ssh/known_hosts.old
     if (unlink(path) == -1) {
-      logCommon(LOG_ERR, "error with unlink %s: %s", path, strerror(errno));
+      logCommon(LOG_ERR, "error with unlink %s: %s", path, 
+		strerror(errno));
       goto error;
     }
   }
@@ -285,7 +278,7 @@ sshKeygen(Collection* coll)
   rc = TRUE;
  error:  
   if (!rc) {
-    logCommon(LOG_ERR, "%s", "fails to do ssh-keygen -H");
+    logCommon(LOG_ERR, "fails to do ssh-keygen -H");
   }
   path = destroyString(path);
   return(rc);
@@ -321,101 +314,11 @@ upgradeSshConfiguration(Collection* coll)
  error:  
   if (!logoutUser(uid)) rc = FALSE;
   if (!rc) {
-    logCommon(LOG_ERR, "%s", "fail to upgrade ssh configuration");
+    logCommon(LOG_ERR, "fail to upgrade ssh configuration");
   }
   return(rc);
 }
 
-/************************************************************************/
-
-#ifdef utMAIN
-#include "../misc/command.h"
-#include "../memory/confTree.h"
-GLOBAL_STRUCT_DEF;
-
-/*=======================================================================
- * Function   : usage
- * Description: Print the usage.
- * Synopsis   : static void usage(char* programName)
- * Input      : programName = the name of the program; usually argv[0].
- * Output     : N/A
- =======================================================================*/
-static void 
-usage(char* programName)
-{
-  mdtxUsage(programName);
-
-  mdtxOptions();
-  //fprintf(stderr, "  ---\n");
-  return;
-}
-
-
-/*=======================================================================
- * Function   : main 
- * Author     : Nicolas ROCHE
- * modif      : 2010/12/10
- * Description: entry point for conf module
- * Synopsis   : ./utconf
- * Input      : N/A
- * Output     : stdout
- =======================================================================*/
-int 
-main(int argc, char** argv)
-{
-  Configuration* conf = 0;
-  Collection* coll = 0;
-  // ---
-  int rc = 0;
-  int cOption = EOF;
-  char* programName = *argv;
-  char* options = MDTX_SHORT_OPTIONS;
-  struct option longOptions[] = {
-    MDTX_LONG_OPTIONS,
-    {0, 0, 0, 0}
-  };
-
-  // import mdtx environment
-  env.debugCommon = TRUE;
-  getEnv(&env);
-
-  // parse the command line
-  while((cOption = getopt_long(argc, argv, options, longOptions, 0)) 
-	!= EOF) {
-    switch(cOption) {
-      
-      GET_MDTX_OPTIONS; // generic options
-    }
-    if (rc) goto optError;
-  }
-
-  // export mdtx environment
-  if (!setEnv(programName, &env)) goto optError;
-
-  /************************************************************************/
-  if (!(conf = getConfiguration())) goto error;
-  if (!parseConfiguration(conf->confFile)) goto error;
-  if (!(coll = getCollection("coll1"))) goto error;
-  if (!expandCollection(coll)) goto error;
-
-  // parse server DB for merge
-  if (!parseServerFile(coll, coll->serversDB)) goto error;
-
-  env.dryRun = FALSE;
-  if (!upgradeSshConfiguration(coll)) goto error;
-  /************************************************************************/
-  
-  freeConfiguration();
-  rc = TRUE;
- error:
-  ENDINGS;
-  rc=!rc;
- optError:
-  exit(rc);
-}
-
-#endif // utMAIN
-
 /* Local Variables: */
 /* mode: c */
 /* mode: font-lock */
