@@ -1,7 +1,7 @@
 /*=======================================================================
- * Version: $Id: upgrade.c,v 1.3 2015/06/03 14:03:35 nroche Exp $
+ * Version: $Id: upgrade.c,v 1.15 2015/10/11 21:11:13 nroche Exp $
  * Project: MediaTeX
- * Module : wrapper/upgrade
+ * Module : upgrade
  *
  * Manage servers.txt upgrade from mediatex.conf and supports.txt
 
@@ -22,24 +22,137 @@
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  =======================================================================*/
 
-#include "../mediatex.h"
-#include "../misc/log.h"
-#include "../misc/address.h"
-#include "../misc/setuid.h"
-#include "../misc/perm.h"
-#include "../memory/ardsm.h"
-#include "../memory/strdsm.h"
-#include "../parser/confFile.tab.h"
-#include "../parser/supportFile.tab.h"
-#include "../parser/serverFile.tab.h"
-#include "../common/openClose.h"
-#include "ssh.h"
-#include "upgrade.h"
+#include "mediatex-config.h"
+#include <math.h>      // pow
+#include <dirent.h>    // scandir
 
-#include <math.h>
-#include <sys/types.h> // umask
-#include <sys/stat.h>
-#include <dirent.h>
+/*=======================================================================
+ * Function   : checkSupport 
+ * Description: Do checksums on an available support
+ * Synopsis   : int checkSupport(Support *supp, char* path)
+ * Input      : Support *supp = the support object
+ *              char* path = the device that host the support
+ * Output     : TRUE on success
+ *
+ * Note       : supp->lastCheck: (O will force check)
+ *              also call by supp module
+ =======================================================================*/
+int 
+doCheckSupport(Support *supp, char* path)
+{
+  int rc = FALSE;
+  Configuration* conf = 0;
+  time_t now = 0;
+  time_t laps = 0;
+  time_t ttl = 0;
+  CheckData data;
+
+  logMain(LOG_DEBUG, "doCheckSupport");
+  if (!(conf = getConfiguration())) goto error;
+  checkSupport(supp);
+  memset(&data, 0, sizeof(CheckData));
+  
+  if ((data.path = createString(path)) == 0) {
+    logMain(LOG_ERR, "cannot dupplicate path string");
+    goto error;
+  }
+  
+  // current date
+  if ((now = currentTime()) == -1) goto error;
+ 
+  // by default do not exists: full computation (no check)
+  data.opp = CHECK_SUPP_ADD;
+
+  // check if support need to be full checked or not
+  if (supp->lastCheck > 0) {
+
+    // exists: quick check
+    data.opp = CHECK_SUPP_ID;
+
+    // but maybe need to be re-checked fully
+    ttl = (isSupportFile(supp))?conf->fileTTL:conf->checkTTL;
+    laps = now - supp->lastCheck;
+    if (laps > ttl/2) {
+
+      // soon obsolete: full check
+      data.opp = CHECK_SUPP_CHECK;
+      logMain(LOG_NOTICE, "support no checked since %d days: checking...", 
+	      laps/60/60/24);
+    }
+  }
+  
+  // copy size and current checksums to compare them
+  switch (data.opp) {
+  case CHECK_SUPP_CHECK:
+    strncpy(data.fullMd5sum, supp->fullMd5sum, MAX_SIZE_MD5);
+    strncpy(data.fullShasum, supp->fullShasum, MAX_SIZE_SHA);
+  case CHECK_SUPP_ID:
+    data.size = supp->size;
+    strncpy(data.quickMd5sum, supp->quickMd5sum, MAX_SIZE_MD5);
+    strncpy(data.quickShasum, supp->quickShasum, MAX_SIZE_SHA);
+  default:
+    break;
+  }
+
+  // checksum computation
+  rc = TRUE;
+  if (!doChecksum(&data)) {
+      logMain(LOG_DEBUG, 
+	      "internal error on md5sum computation for \"%s\" support", 
+	      supp->name);
+      rc = FALSE;
+      goto error;
+  }
+
+  if (data.rc == CHECK_FALSE_SIZE) {
+    logMain(LOG_WARNING, "wrong size on \"%s\" support", supp->name);
+    rc = FALSE;
+  }
+  if (data.rc == CHECK_FALSE_QUICK) {
+    logMain(LOG_WARNING, "wrong quick hash on \"%s\" support", supp->name);
+    rc = FALSE;
+  }
+  if (data.rc == CHECK_FALSE_FULL) {
+    logMain(LOG_WARNING, "wrong full hash on \"%s\" support", supp->name);
+    rc = FALSE;
+  }
+
+  if (!rc && !isSupportFile(supp)) {
+    logMain(LOG_WARNING, "please manualy check \"%s\" support", supp->name);
+    logMain(LOG_WARNING, "either this is not \"%s\" support at %s", 
+	    supp->name, path);
+    logMain(LOG_WARNING, "or maybe the \"%s\" support is obsolete", 
+	    supp->name);
+    goto error;
+  }
+
+  // store results
+  switch (data.opp) {
+  case  CHECK_SUPP_ADD:
+    supp->size = data.size;
+    strncpy(supp->quickMd5sum, data.quickMd5sum, MAX_SIZE_MD5);
+    strncpy(supp->fullMd5sum, data.fullMd5sum, MAX_SIZE_MD5);
+    strncpy(supp->quickShasum, data.quickShasum, MAX_SIZE_SHA);
+    strncpy(supp->fullShasum, data.fullShasum, MAX_SIZE_SHA);
+  case CHECK_SUPP_CHECK:
+    if (env.noRegression)
+      supp->lastCheck = currentTime() + 1*DAY;
+    else
+      supp->lastCheck = now;
+  case CHECK_SUPP_ID:
+    if (env.noRegression)
+      supp->lastSeen = currentTime() + 1*DAY;
+    else
+      supp->lastSeen = now;
+  default:
+    break;
+  }
+
+  conf->fileState[iSUPP] = MODIFIED;
+ error:
+  free(data.path);
+  return rc;
+}
 
 /*=======================================================================
  * Function   : scoreSupport
@@ -55,45 +168,60 @@ scoreSupport(Support* supp, ScoreParam *p)
   Configuration* conf = 0;
   time_t now = 0;
   time_t laps = 0;
+  time_t ttl = 0;
   int rc = FALSE;
 
   checkSupport(supp);
   logCommon(LOG_INFO, "compute support score for %s:%lli (%s)", 
-	  supp->fullHash, supp->size, supp->name);
+	  supp->fullMd5sum, supp->size, supp->name);
 
   if (!(conf = getConfiguration())) goto error;
-
-  // date
-  if ((now = currentTime()) == -1) goto error;
+  if ((now = currentTime()) == -1) goto error;  
   supp->score = 0; // obsolete: need to be checked
 
   // check data consistancy
   if (supp->firstSeen > now) {
-    logCommon(LOG_ERR, "%s", "support firstSeen date is in the futur");
+    logCommon(LOG_ERR, "support firstSeen date is in the futur");
     goto error;
   }
 
   if (supp->firstSeen > supp->lastCheck) {
-    logCommon(LOG_ERR, "%s", "support lastCheck > firstSeen");
+    logCommon(LOG_ERR, "support lastCheck > firstSeen");
     goto error;
   }
 
   if (supp->lastCheck > supp->lastSeen) {
-    logCommon(LOG_ERR, "%s", "support lastCheck > lastSeen");
+    logCommon(LOG_ERR, "support lastCheck > lastSeen");
     goto error;
   }
 
   // check support validity
+  ttl = (isSupportFile(supp))?conf->fileTTL:conf->checkTTL;
   laps = now - supp->lastCheck;
-  if (conf->checkTTL < 0 ||
-      (conf->checkTTL >= 0 &&
-       laps > conf->checkTTL)) {
+  if (laps > ttl) {
     logCommon(LOG_WARNING, "\"%s\" support have expired since %d days",
-    	    supp->name, laps/(60*60*24));
+	      supp->name, laps/(60*60*24));
     // score = 0: unchecked support for too many time (may be broken)
     goto end;
   }
 
+  // static score for support file
+  if (isSupportFile(supp)) {
+
+    // check support file before they become obsolete
+    if (laps > ttl/2) {
+      if (!doCheckSupport(supp, supp->name)) {
+	logMain(LOG_WARNING, "\"%s\" support file seems lost", supp->name);
+	// score = 0: fails to check support file on disk
+	goto end;
+      }
+    }
+      
+    supp->score = p->fileScore;
+    logCommon(LOG_INFO, "file: = %.2f", supp->score);
+    goto end;
+  }
+  
   // compute a support score base on its age
   laps = now - supp->firstSeen;
 
@@ -125,7 +253,7 @@ scoreSupport(Support* supp, ScoreParam *p)
   rc = TRUE;
  error:
   if (!rc && supp) {
-    logCommon(LOG_ERR, "%s", "scoreSupport fails");
+    logCommon(LOG_ERR, "scoreSupport fails");
   }
   return rc;
 }
@@ -150,28 +278,24 @@ scoreLocalImages(Collection* coll)
   Image* image1 = 0;
   Image* image2 = 0;
   Image* image3 = 0;
-  //char* label = 0;
   int nbSupp = 0;
 
   checkCollection(coll);
   logCommon(LOG_DEBUG, "scores for %s collection", coll->label);
 
-#ifndef utMAIN
   if (!loadConfiguration(SUPP)) goto error;
-#endif
-
   if ((images = createRing()) == 0)  goto error;
   serverTree = coll->serverTree;
 
   // for each support names:
   rgRewind(coll->supports);
-  while((supp = rgNext(coll->supports)) != 0) {
+  while ((supp = rgNext(coll->supports))) {
  
     // compute score on support (using collection's parameters)
     if (!scoreSupport(supp, &serverTree->scoreParam)) goto error;
 
     // add supports to temporary ring
-    if (!(archive = addArchive(coll, supp->fullHash, supp->size)))
+    if (!(archive = addArchive(coll, supp->fullMd5sum, supp->size)))
       goto error;
     if ((image1 = createImage()) == 0) goto error;
     image1->archive = archive;
@@ -182,16 +306,16 @@ scoreLocalImages(Collection* coll)
   // sort supports on the ring by scores and grouped by images
   if (!rgSort(images, cmpImageScore)) goto error;
 
-   // for each group of support names:
+  // for each group of support names:
   rgRewind(images);
   image1 = image2 = rgNext(images);
-  while (image1 != 0) {
+  while (image1) {
     logCommon(LOG_INFO, "compute image score for %s:%lli", 
 	    image1->archive->hash, image1->archive->size);
     nbSupp = 0;
 
     // while supports match the same image
-    while (image2 != 0 && 
+    while (image2 && 
 	   image1->archive == image2->archive) {
       
       // if not the first image, incremment the final score
@@ -224,7 +348,7 @@ scoreLocalImages(Collection* coll)
  error:
   images = destroyRing(images, (void*(*)(void*)) destroyImage);
   if (!rc) {
-    logCommon(LOG_ERR, "%s", "scoreLocalImages fails");
+    logCommon(LOG_ERR, "scoreLocalImages fails");
   }
   return rc;
 }
@@ -247,17 +371,17 @@ serializeCvsRootClientFile(Collection* coll, char* dirpath)
   ServerTree* self = 0;
   mode_t mask;
 
+  mask = umask(0117);
   checkCollection(coll);
   if (!(self = coll->serverTree)) goto error;
   checkServer(self->master);
-  logCommon(LOG_DEBUG, "%s", "serialize CVS/Root files");
+  logCommon(LOG_DEBUG, "serialize CVS/Root files");
 
   if (!(path = createString(dirpath)) ||
       !(path = catString(path, "/")) ||
       !(path = catString(path, "Root"))) goto error;
       
   // output file
-  mask = umask(0117);
   if (!env.dryRun) {
     if ((fd = fopen(path, "w")) == 0) {
       logCommon(LOG_ERR, "fdopen %s fails: %s", path, strerror(errno)); 
@@ -277,7 +401,7 @@ serializeCvsRootClientFile(Collection* coll, char* dirpath)
     rc = FALSE;
   }
   if (!rc) {
-    logCommon(LOG_ERR, "%s", "serializeCvsRootClientFile fails");
+    logCommon(LOG_ERR, "serializeCvsRootClientFile fails");
   }
   umask(mask);
   path = destroyString(path);
@@ -345,9 +469,9 @@ scanCvsClientDirectory(Collection* coll, char* path)
   rc = TRUE;
  error:
   if (!rc) {
-    logCommon(LOG_ERR, "%s", "scanCvsClientDirectory fails");
+    logCommon(LOG_ERR, "scanCvsClientDirectory fails");
   }
-  if (entries != 0) {
+  if (entries) {
     for (n=0; n<nbEntries; ++n) {
       remind(entries[n]);
       free(entries[n]);
@@ -358,7 +482,6 @@ scanCvsClientDirectory(Collection* coll, char* path)
   return rc;
 }
 
-
 /*=======================================================================
  * Function   : upgradeCollection
  * Description: Upgrade servers.txt
@@ -366,9 +489,9 @@ scanCvsClientDirectory(Collection* coll, char* path)
  * Input      : Collection* coll = collection to upgrade              
  * Output     : TRUE on success 
 
- * Note       : Should not be called by the server (to save memory).
+ * Note       : Must only be call by client (nor server or cgi).
  *              This function do almost all the consistency job:
- *              - re-compute the locale image's score
+ *              - re-compute the local image's score
  *              - update own configuration values into servers.txt
  *              - update ssh configuration files (config, key and auth)
  *              - update master collection host values into:
@@ -403,6 +526,7 @@ upgradeCollection(Collection* coll)
   strncpy(localhost->host, conf->host, MAX_SIZE_HOST);
   localhost->mdtxPort = conf->mdtxPort;
   localhost->sshPort = conf->sshPort;
+  localhost->wwwPort = conf->wwwPort;
   if (!(localhost->comment = createString(conf->comment))) goto error;
   if (!(localhost->userKey = createString(coll->userKey))) goto error;
   if (!(localhost->hostKey = createString(conf->hostKey))) goto error;
@@ -415,6 +539,9 @@ upgradeCollection(Collection* coll)
       || !(localhost->user = catString(localhost->user, coll->label)))
     goto error;
 
+  // update lastCommit
+  if (!(localhost->lastCommit = currentTime())) goto error;
+
   // get networks and gateway from configuration
   ring = coll->networks;
   if (isEmptyRing(ring)) ring = conf->networks;
@@ -460,21 +587,21 @@ upgradeCollection(Collection* coll)
   if (strncmp(coll->masterHost, master->host, MAX_SIZE_HOST)) {
     strncpy(coll->masterHost, master->host, MAX_SIZE_HOST);
     coll->masterHost[MAX_SIZE_HOST] = 0;
-    conf->fileState[iCONF] = MODIFIED;
+    conf->fileState[iCFG] = MODIFIED;
   }
   if (strcmp(coll->masterLabel, master->label)) {
     destroyString(coll->masterLabel);
     if (!(coll->masterLabel = createString(master->label))) goto error;
-    conf->fileState[iCONF] = MODIFIED;
+    conf->fileState[iCFG] = MODIFIED;
   }
   if (strcmp(coll->masterUser, master->user)) {
     destroyString(coll->masterUser);
     if (!(coll->masterUser = createString(master->user))) goto error;
-    conf->fileState[iCONF] = MODIFIED;
+    conf->fileState[iCFG] = MODIFIED;
   }
   if (coll->masterPort != master->sshPort) {
     coll->masterPort = master->sshPort;
-    conf->fileState[iCONF] = MODIFIED;
+    conf->fileState[iCFG] = MODIFIED;
   } 
 
   // upgrade SSH settings (using servers)
@@ -487,105 +614,13 @@ upgradeCollection(Collection* coll)
   rc = TRUE;
 error:
   if (!rc) {
-    logCommon(LOG_ERR, "%s", "upgradeCollection fails");
+    logCommon(LOG_ERR, "upgradeCollection fails");
     // note: not a good idea to destroy localhost server on error,
     // as it may be used later
   }
   return rc;
 }
 
-/************************************************************************/
-
-#ifdef utMAIN
-#include "../misc/command.h"
-GLOBAL_STRUCT_DEF;
-
-/*=======================================================================
- * Function   : usage
- * Description: Print the usage.
- * Synopsis   : static void usage(char* programName)
- * Input      : programName = the name of the program; usually argv[0].
- * Output     : N/A
- =======================================================================*/
-static void 
-usage(char* programName)
-{
-  mdtxUsage(programName);
-
-  mdtxOptions();
-  //fprintf(stderr, "  ---\n");
-  return;
-}
-
-  
-/*=======================================================================
- * Function   : main 
- * Author     : Nicolas ROCHE
- * modif      : 2012/05/01
- * Description: Unit test for cache module.
- * Synopsis   : ./utupgrade
- * Input      : -i mediatex.conf
- * Output     : stdout
- =======================================================================*/
-int 
-main(int argc, char** argv)
-{
-  Configuration* conf = 0;
-  Collection* coll = 0;
-  // ---
-  int rc = 0;
-  int cOption = EOF;
-  char* programName = *argv;
-  char* options = MDTX_SHORT_OPTIONS;
-  struct option longOptions[] = {
-    MDTX_LONG_OPTIONS,
-    {0, 0, 0, 0}
-  };
-
-  // import mdtx environment
-  env.debugCommon = TRUE;
-  getEnv(&env);
-
-  // parse the command line
-  while((cOption = getopt_long(argc, argv, options, longOptions, 0)) 
-	!= EOF) {
-    switch(cOption) {
-      
-      GET_MDTX_OPTIONS; // generic options
-    }
-    if (rc) goto optError;
-  }
-
-  // export mdtx environment
-  if (!setEnv(programName, &env)) goto optError;
-
-  /************************************************************************/
-   env.dryRun = TRUE;
-
-  if (!(conf = getConfiguration())) goto error;
-  if (!parseConfiguration(conf->confFile)) goto error;
-  if (!parseSupports(conf->supportDB)) goto error;
-  if (!(coll = getCollection("coll1"))) goto error;
-  if (!expandCollection(coll)) goto error;
-  if (!parseServerFile(coll, coll->serversDB)) goto error;
-
-  logCommon(LOG_DEBUG, "%s", "*** upgrade: ");
-  if (!(populateConfiguration())) goto error;
-  if (!upgradeCollection(coll)) goto error;
-  if (!serializeServer(coll->localhost, stdout)) goto error;
-  /************************************************************************/
-  
-  freeConfiguration();
-  rc = TRUE;
- error:
-  ENDINGS;
-  rc=!rc;
- optError:
-  exit(rc);
-}
-
-#endif // utMAIN
-
 /* Local Variables: */
 /* mode: c */
 /* mode: font-lock */
