@@ -1,5 +1,5 @@
 /*=======================================================================
- * Version: $Id: archive.c,v 1.4 2015/06/03 14:03:37 nroche Exp $
+ * Version: $Id: archive.c,v 1.14 2015/09/23 19:10:20 nroche Exp $
  * Project: MediaTeX
  * Module : archive
  *
@@ -22,12 +22,7 @@
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  =======================================================================*/
 
-#include "../mediatex.h"
-#include "../misc/log.h"
-#include "archive.h"
-
-#include <string.h> // memset
-#include <avl.h>
+#include "mediatex-config.h"
 
 /*=======================================================================
  * Function   : createArchive
@@ -53,14 +48,14 @@ createArchive(void)
   if ((rc->records = createRing()) == 0) goto error;
   if ((rc->demands = createRing()) == 0) goto error;
   if ((rc->remoteSupplies = createRing()) == 0) goto error;
-  if ((rc->finaleSupplies = createRing()) == 0) goto error;
-  rc->extractScore = -1; // still not computed
+  if ((rc->finalSupplies = createRing()) == 0) goto error;
   rc->imageScore = -1;   // still not computed
+  rc->extractScore = -1; // still not computed
   rc->state = UNUSED;
 
   return rc;
  error:
-  logMemory(LOG_ERR, "%s", "malloc: cannot create Archive");
+  logMemory(LOG_ERR, "malloc: cannot create Archive");
   return destroyArchive(rc);
 }
 
@@ -81,11 +76,12 @@ destroyArchive(Archive* self)
 
 #if 0 // developpement mode
   strncpy(self->hash, "................................", 
-	  MAX_SIZE_HASH);
+	  MAX_SIZE_MD5);
   self->size = 0;
   self->imageScore = -1;
   self->extractScore = -1;
   self->state = UNUSED;
+  self->incInherency = FALSE;
 #endif
 
   // delete assoCarac associations
@@ -100,7 +96,7 @@ destroyArchive(Archive* self)
   self->records = destroyOnlyRing(self->records);
   self->demands = destroyOnlyRing(self->demands);
   self->remoteSupplies = destroyOnlyRing(self->remoteSupplies);
-  self->finaleSupplies = destroyOnlyRing(self->finaleSupplies);
+  self->finalSupplies = destroyOnlyRing(self->finalSupplies);
   free(self);
   
 error:
@@ -127,7 +123,7 @@ cmpArchive(const void *p1, const void *p2)
   Archive* a1 = *((Archive**)p1);
   Archive* a2 = *((Archive**)p2);
 
-  rc = strncmp(a1->hash, a2->hash, MAX_SIZE_HASH);
+  rc = strncmp(a1->hash, a2->hash, MAX_SIZE_MD5);
   if (!rc) rc = a1->size - a2->size; // growing sizes
  
   return rc;
@@ -145,7 +141,7 @@ cmpArchive2(const void *p1, const void *p2)
   Archive* a1 = (Archive*)p1;
   Archive* a2 = (Archive*)p2;
 
-  rc = strncmp(a1->hash, a2->hash, MAX_SIZE_HASH);
+  rc = strncmp(a1->hash, a2->hash, MAX_SIZE_MD5);
   if (!rc) rc = a1->size - a2->size; // growing sizes
  
   return rc;
@@ -171,7 +167,7 @@ cmpArchiveSize(const void *p1, const void *p2)
   Archive* a2 = *((Archive**)p2);
 
   rc = a1->size - a2->size; // growing sizes
-  if (!rc) rc = strncmp(a1->hash, a2->hash, MAX_SIZE_HASH);
+  if (!rc) rc = strncmp(a1->hash, a2->hash, MAX_SIZE_MD5);
  
   return rc;
 }
@@ -196,7 +192,7 @@ cmpArchiveScore(const void *p1, const void *p2)
   Archive* a2 = *((Archive**)p2);
 
   rc = a1->extractScore - a2->extractScore; // growing scores
-  if (!rc) rc = strncmp(a1->hash, a2->hash, MAX_SIZE_HASH);
+  if (!rc) rc = strncmp(a1->hash, a2->hash, MAX_SIZE_MD5);
   if (!rc) rc = a1->size - a2->size; // growing sizes
  
   return rc;
@@ -246,7 +242,7 @@ getArchive(Collection* coll, char* hash, off_t size)
   logMemory(LOG_DEBUG, "getArchive %s:%lli", hash, (long long int) size);
 
   // look for archive
-  strncpy(archive.hash, hash, MAX_SIZE_HASH);
+  strncpy(archive.hash, hash, MAX_SIZE_MD5);
   archive.size = size;
   if ((node = avl_search(coll->archives, &archive))) {
     rc = (Archive*)node->item;
@@ -281,9 +277,9 @@ addArchive(Collection* coll, char* hash, off_t size)
 
   // add new one if not already there
   if (!(archive = createArchive())) goto error;
-  strncpy(archive->hash, hash, MAX_SIZE_HASH);
+  strncpy(archive->hash, hash, MAX_SIZE_MD5);
 #if 1
-  archive->hash[MAX_SIZE_HASH] = (char)0; // developpement code
+  archive->hash[MAX_SIZE_MD5] = (char)0; // developpement code
 #endif
   archive->size = size;
   archive->id = coll->maxId++;
@@ -294,7 +290,7 @@ addArchive(Collection* coll, char* hash, off_t size)
   rc = archive;
  error:
   if (!rc) {
-    logMemory(LOG_ERR, "%s", "addArchive fails");
+    logMemory(LOG_ERR, "addArchive fails");
     archive = destroyArchive(archive);
   }
   return rc;
@@ -326,31 +322,30 @@ delArchive(Collection* coll, Archive* self)
 
   // delete archive from record ring
   curr = 0;
-  while((rec = rgNext_r(self->records, &curr)) != 0)
+  while ((rec = rgNext_r(self->records, &curr)))
     if (!delRecord(coll, rec)) goto error;
 
   // delete archive from image ring
   curr = 0;
-  while((img = rgNext_r(self->images, &curr)) != 0)
+  while ((img = rgNext_r(self->images, &curr)))
     if (!delImage(coll, img)) goto error;
 
   // delete archive from container ring
   if (!delContainer(coll, self->toContainer)) goto error;
 
   // delete archive from content association
-  // (should be already done by above call)
   curr = 0;
-  while((af = rgNext_r(self->fromContainers, &curr)) != 0)
-    if (!delFromAsso(coll, af, TRUE)) goto error;
+  while ((af = rgNext_r(self->fromContainers, &curr)))
+    if (!delFromAsso(coll, af)) goto error;
   
   // delete archive from document ring
   curr = 0;
-  while((doc = rgNext_r(self->documents, &curr)) != 0)
+  while ((doc = rgNext_r(self->documents, &curr)))
     if (!delArchiveFromDocument(coll, self, doc)) goto error;
   
   // delete archive from assoCarac ring
   curr = 0;
-  while((ac = rgNext_r(self->assoCaracs, &curr)) != 0) {
+  while ((ac = rgNext_r(self->assoCaracs, &curr))) {
     rgRemove(self->assoCaracs);
     destroyAssoCarac(ac);
   }
@@ -402,8 +397,8 @@ diseaseArchive(Collection* coll, Archive* self)
   // check cache's rings
   if (self->demands->nbItems >0) goto next;
   if (self->remoteSupplies->nbItems >0) goto next;
-  if (self->finaleSupplies->nbItems >0) goto next;
-  if (self->localSupply != 0) goto next;
+  if (self->finalSupplies->nbItems >0) goto next;
+  if (self->localSupply) goto next;
   
   // delete archive from collection ring and free it
   avl_delete(coll->archives, self);
@@ -412,7 +407,7 @@ diseaseArchive(Collection* coll, Archive* self)
   rc = TRUE;
  error:
   if (!rc) {
-    logMemory(LOG_ERR, "%s", "diseaseArchive fails");
+    logMemory(LOG_ERR, "diseaseArchive fails");
   }
   return rc;
 }
@@ -447,129 +442,48 @@ diseaseArchives(Collection* coll)
   rc = TRUE;
  error:
   if (!rc) {
-    logMemory(LOG_ERR, "%s", "diseaseArchives fails");
+    logMemory(LOG_ERR, "diseaseArchives fails");
   }
   return rc;
 }
 
-/************************************************************************/
-
-#ifdef utMAIN
-#include "../misc/command.h"
-#include "utFunc.h"
-GLOBAL_STRUCT_DEF;
-
 /*=======================================================================
- * Function   : usage
- * Description: Print the usage.
- * Synopsis   : static void usage(char* programName)
- * Input      : programName = the name of the program; usually argv[0].
- * Output     : N/A
+ * Function   : isIncoming
+ * Description: state if an archive belongs to INC container
+ * Synopsis   : int isIncoming(Collection* coll, Archive* self)
+ *              Collection* coll
+ * Input      : Archive* self
+ * Output     : TRUE on success
+ * Requirement: loadCollection(coll, EXTR)
+ * Note       : archive is no more an incoming when having a good score
  =======================================================================*/
-static void 
-usage(char* programName)
+int isIncoming(Collection* coll, Archive* self)
 {
-  mdtxUsage(programName);
-  fprintf(stderr, " [ -d repository ]");
-
-  memoryOptions();
-  //fprintf(stderr, "\t\t---\n");
-  return;
+  return self->uploadTime && 
+    (self->extractScore ==-1 || 
+     self->extractScore <
+     coll->serverTree->scoreParam.maxScore /2);
 }
 
 /*=======================================================================
- * Function   : main
- * Author     : Nicolas Roche
- * modif      : 2012/02/11
- * Description: Unit test for md5sumTree module.
- * Synopsis   : utmd5sumTree
- * Input      : N/A
- * Output     : /tmp/mdtx/var/local/cache/mdtx/md5sums.txt
+ * Function   : hasExtractRule
+ * Description: state if an archive belongs extract metadata
+ * Synopsis   : int hasExtractRule(Archive* self)
+ * Input      : Archive* self
+ * Output     : TRUE on success
+*  Requirement: loadCollection(coll, EXTR)
  =======================================================================*/
-int 
-main(int argc, char** argv)
+int hasExtractRule(Archive* self)
 {
-  Collection* coll = 0;
-  Archive* arch1 = 0;
-  Archive* arch2 = 0;
-  // ---
-  int rc = 0;
-  int cOption = EOF;
-  char* programName = *argv;
-  char* options = MEMORY_SHORT_OPTIONS;
-  struct option longOptions[] = {
-    MEMORY_LONG_OPTIONS,
-    {0, 0, 0, 0}
-  };
-       
-  // import mdtx environment
-  env.dryRun = FALSE;
-  env.debugMemory = TRUE;
-  getEnv(&env);
-
-  // parse the command line
-  while((cOption = getopt_long(argc, argv, options, longOptions, 0)) 
-	!= EOF) {
-    switch(cOption) {
-      
-      GET_MEMORY_OPTIONS; // generic options
-    }
-    if (rc) goto optError;
-  }
-
-  // export mdtx environment
-  if (!setEnv(programName, &env)) goto optError;
-
-  /************************************************************************/
-  // test types on this architecture:
-  off_t offset = 0xFFFFFFFFFFFFFFFFULL; // 2^64
-  time_t timer = 0x7FFFFFFF; // 2^32
-  logMemory(LOG_DEBUG, "type off_t is store into %u bytes", 
-	  (unsigned int)sizeof(off_t));
-  logMemory(LOG_DEBUG, "type time_t is store into %u bytes", 
-	  (unsigned int) sizeof(time_t));
-  logMemory(LOG_DEBUG,  "off_t max value is: %llu", 
-	  (unsigned long long int)offset);
-  logMemory(LOG_DEBUG, "time_t max value is: %lu", 
-	  (unsigned long int)timer);
-
-  if (!createExempleConfiguration()) goto error;
-  if (!(coll = getCollection("coll1"))) goto error;
-
-  // creating an archive 2 times return the same object
-  if (!(arch1 =
-  	addArchive(coll, "780968014038afcbae5c6feca2e630de", 81)))
-    goto error;
-  if (!(arch2 =
-  	addArchive(coll, "780968014038afcbae5c6feca2e630de", 81)))
-    goto error;
-  if (arch1 != arch2) goto error;
-  
-  // search an archive
-  if (getArchive(coll, "aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa", 22222))
-    goto error;
-  if (!(arch1 =
-  	addArchive(coll, "aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa", 22222)))
-    goto error;
-  if (getArchive(coll, "aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa", 22222) != arch1)
-    goto error;
-
-  if (avl_count(coll->archives) != 2) goto error;
-  if (!(diseaseArchives(coll))) goto error;
-  if (avl_count(coll->archives) != 0) goto error;
-  /************************************************************************/
-
-  freeConfiguration();
-  rc = TRUE;
- error:
-  ENDINGS;
-  rc=!rc;
- optError:
-  exit(rc);
+  // archive may appears in 3 location into extract metadata:
+  // - only as a container for images
+  // - only as a content for final contents
+  // - only as an incoming content for incoming content having no rules
+  return (self->toContainer ||
+	  !isEmptyRing(self->fromContainers) ||
+	  self->uploadTime); // ~isIncoming()
 }
 
-#endif // utMAIN
-
 /* Local Variables: */
 /* mode: c */
 /* mode: font-lock */
