@@ -1,5 +1,5 @@
 /*=======================================================================
- * Version: $Id: archive.h,v 1.3 2015/06/03 14:03:37 nroche Exp $
+ * Version: $Id: archive.h,v 1.13 2015/09/23 19:10:20 nroche Exp $
  * Project: MediaTeX
  * Module : archive tree
  *
@@ -25,7 +25,7 @@
 #ifndef MDTX_MEMORY_ARCHIVE_H
 #define MDTX_MEMORY_ARCHIVE_H 1
 
-#include "confTree.h"
+#include "mediatex-types.h"
 
 // type write into Record struct
 typedef enum {UNUSED = 0, USED, WANTED, ALLOCATED, AVAILABLE, TOKEEP,
@@ -34,7 +34,7 @@ typedef enum {UNUSED = 0, USED, WANTED, ALLOCATED, AVAILABLE, TOKEEP,
 struct Archive
 {
   // not easy to parse into uchar[16]
-  char  hash[MAX_SIZE_HASH+1]; 
+  char  hash[MAX_SIZE_MD5+1]; 
   int   id;  // id used to serialize html pages
   int   tag; // dedicated for external use
 
@@ -49,7 +49,9 @@ struct Archive
   // extractTree related data
   RG*        fromContainers; // (FromAsso*)
   Container* toContainer;    // only one: (choose a rule TGZ or TAR+GZ)
-  float      extractScore;   // computed value
+  time_t     uploadTime;     // uploaded archive (from INC container)
+  float      extractScore;   // computed value used by cache
+  int        incInherency;   // is a new incoming (even by inherency)
 
   // documentTree related data
   RG* documents;
@@ -62,16 +64,12 @@ struct Archive
   AState  state;
   RG*     demands;        // Record*
   RG*     remoteSupplies; // Record*
-  RG*     finaleSupplies; // Record*
+  RG*     finalSupplies;  // Record*
   Record* localSupply;
   int     nbKeep;
   time_t  backupDate;     // date to set after last unkeep
 };
 
-/* private */
-Archive* createArchive(void);
-Archive* destroyArchive(Archive* self);
-
 /* API */
 char* strAState(AState state);
 int cmpArchive(const void *p1, const void *p2);
@@ -82,8 +80,13 @@ Archive* getArchive(Collection* coll, char* hash, off_t size);
 Archive* addArchive(Collection* coll, char* hash, off_t size);
 int delArchive(Collection* coll, Archive* archive);
 
+/* Private */
+Archive* createArchive(void);
+Archive* destroyArchive(Archive* self);
 int diseaseArchive(Collection* coll, Archive* arch);
 int diseaseArchives(Collection* coll);
+int isIncoming(Collection* coll, Archive* self);
+int hasExtractRule(Archive* self);
 
 #endif /* MDTX_MEMORY_ARCHIVE_H */
 
