@@ -1,5 +1,5 @@
 /*=======================================================================
- * Version: $Id: ardsm.c,v 1.3 2015/06/03 14:03:37 nroche Exp $
+ * Version: $Id: ardsm.c,v 1.8 2015/09/04 15:30:26 nroche Exp $
  * Project: MediaTeX
  * Module : ardsm
  *
@@ -23,9 +23,7 @@
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  =======================================================================*/
 
-#include "ardsm.h"
-#include "../misc/alloc.h"
-#include "../misc/log.h"
+#include "mediatex-config.h"
 
 
 /* Item related : */
@@ -44,7 +42,7 @@ rgCreate(void)
   RGIT *item = 0;
   
   if((item = (RGIT*)malloc(sizeof(RGIT))) == 0) {
-    logMemory(LOG_ERR, "%s", "malloc: cannot allocate a ring item");
+    logMemory(LOG_ERR, "malloc: cannot allocate a ring item");
     goto error;
   }
 
@@ -65,7 +63,7 @@ rgCreate(void)
 void 
 rgDestroy(RGIT* item)
 {
-  if(item != 0) {
+  if(item) {
     free(item);
     item = 0;
   }
@@ -87,7 +85,7 @@ void
 rgInit(RG* ring)
 {
   if(ring == (RG *)0) {	
-    logMemory(LOG_ERR, "%s", "please do not provide an empty ring");
+    logMemory(LOG_ERR, "please do not provide an empty ring");
     goto error;
   }
 
@@ -115,14 +113,12 @@ rgDelete(RG* ring)
 
   if(ring == (RG *)0) goto error;
 
-  //not empty ring
   while (ring->head != (RGIT *)0) {
     temp = ring->head->next;
     rgDestroy(ring->head);
     ring->head = temp;
   }
 	
-  // empty ring
   ring->curr = ring->tail = (RGIT *)0;
   ring->nbItems = 0;
  error:
@@ -144,7 +140,7 @@ rgInsert(RG* ring, void* it)
   RGIT *item = 0;
 
   if(ring == (RG *)0) {	
-    logMemory(LOG_ERR, "%s", "please do not provide an empty ring");
+    logMemory(LOG_ERR, "please do not provide an empty ring");
     goto error;
   }
 
@@ -203,7 +199,7 @@ rgHeadInsert(RG* ring, void* it)
   RGIT *item = 0;
 
   if(ring == (RG *)0) {	
-    logMemory(LOG_ERR, "%s", "please do not provide an empty ring");
+    logMemory(LOG_ERR, "please do not provide an empty ring");
     goto error;
   }
 
@@ -241,7 +237,7 @@ rgRemove(RG* ring)
   RGIT *temp = (RGIT *)0;
 
   if(ring == (RG *)0) {	
-    logMemory(LOG_ERR, "%s", "please do not provide an empty ring");
+    logMemory(LOG_ERR, "please do not provide an empty ring");
     goto error;
   }
 
@@ -299,7 +295,7 @@ void rgRemove_r(RG* ring, RGIT** curr)
   RGIT *temp = (RGIT *)0;
 
   if(ring == (RG *)0) {	
-    logMemory(LOG_ERR, "%s", "please do not provide an empty ring");
+    logMemory(LOG_ERR, "please do not provide an empty ring");
     goto error;
   }
 
@@ -359,7 +355,7 @@ rgCurrent(RG* ring)
   void *rc = (void *)0;
 
   if(ring == (RG *)0) {	
-    logMemory(LOG_ERR, "%s", "please do not provide an empty ring");
+    logMemory(LOG_ERR, "please do not provide an empty ring");
     goto error;
   }
 
@@ -385,7 +381,7 @@ rgPrevious(RG* ring)
   void *rc = (void *)0;
 
   if(ring == (RG *)0) {	
-    logMemory(LOG_ERR, "%s", "please do not provide an empty ring");
+    logMemory(LOG_ERR, "please do not provide an empty ring");
     goto error;
   }
 
@@ -422,7 +418,7 @@ rgNext(RG* ring)
   void *rc = (void *)0;
 
   if(ring == (RG *)0) {	
-    logMemory(LOG_ERR, "%s", "please do not provide an empty ring");
+    logMemory(LOG_ERR, "please do not provide an empty ring");
     goto error;
   }
 
@@ -459,7 +455,7 @@ rgNext(RG* ring)
 /*   void *rc = (void *)0; */
   
 /*   if(ring == (RG *)0) { */
-/*     logMemory(LOG_ERR, "%s", "please do not provide an empty ring"); */
+/*     logMemory(LOG_ERR, "please do not provide an empty ring"); */
 /*     goto error; */
 /*   } */
 
@@ -502,7 +498,7 @@ rgHead(RG* ring)
   void *rc = (void *)0;
   
   if(ring == (RG *)0) {	
-    logMemory(LOG_ERR, "%s", "please do not provide an empty ring");
+    logMemory(LOG_ERR, "please do not provide an empty ring");
     goto error;
   }
 
@@ -527,7 +523,7 @@ void
 rgRewind(RG* ring)
 {
   if(ring == (RG *)0) {	
-    logMemory(LOG_ERR, "%s", "please do not provide an empty ring");
+    logMemory(LOG_ERR, "please do not provide an empty ring");
     goto error;
   }
 
@@ -556,21 +552,21 @@ rgSort(RG* ring, int(*compar)(const void *, const void *))
   RGIT* curr = 0;
 
   if(ring == (RG *)0) {	
-    logMemory(LOG_ERR, "%s", "please do not provide an empty ring");
+    logMemory(LOG_ERR, "please do not provide an empty ring");
     goto error;
   }
 
   if(ring->nbItems > 1) {
     if ((pItemArray = (void**)malloc(ring->nbItems * sizeof(void*))) 
 	== (void**)0) {
-      logMemory(LOG_ERR, "%s", 
+      logMemory(LOG_ERR, 
 	      "malloc: cannot allocate an array to sort the ring");
       goto error;
     }
 
     nbItem = 0;
     curr = 0;
-    while((pItem = (void*)rgNext_r(ring, &curr)) != 0) {	
+    while ((pItem = (void*)rgNext_r(ring, &curr))) {	
       pItemArray[nbItem++] = pItem;
     }
 	  
@@ -578,7 +574,7 @@ rgSort(RG* ring, int(*compar)(const void *, const void *))
 	  
     nbItem = 0;
     curr = 0;
-    while((pItem = (void*)rgNext_r(ring, &curr)) != 0) {	
+    while ((pItem = (void*)rgNext_r(ring, &curr))) {	
       curr->it = pItemArray[nbItem++];
     }
 	    
@@ -589,7 +585,7 @@ rgSort(RG* ring, int(*compar)(const void *, const void *))
   rc = TRUE;
  error:
   if (!rc) {
-    logMemory(LOG_ERR, "%s", "rgSort fails");
+    logMemory(LOG_ERR, "rgSort fails");
   }
   return rc;
 }
@@ -612,7 +608,7 @@ rgMatchItem(RG* ring, void* pItem,
   void* pIt = 0;
   RGIT* rc = 0;
 
-  while((pIt = rgNext_r(ring, &rc)) != 0) {
+  while ((pIt = rgNext_r(ring, &rc))) {
     if (!compar(&pIt, &pItem)) break;
   }
 
@@ -633,7 +629,7 @@ rgHaveItem(RG* ring, void* pItem)
   RGIT* rc = 0;
   void* pIt = 0;
 
-  while((pIt = rgNext_r(ring, &rc)) != 0) {
+  while ((pIt = rgNext_r(ring, &rc))) {
     if (pIt == pItem) break;
   }
 
@@ -655,11 +651,11 @@ rgDelItem(RG* ring, void* pItem)
   RGIT* curr = 0;
   void* pIt = 0;
 
-  while((pIt = rgNext_r(ring, &curr)) != 0) {
+  while ((pIt = rgNext_r(ring, &curr))) {
     if (pIt == pItem) break;
   }
 
-  if (pIt != 0) {
+  if (pIt) {
     rgRemove_r(ring, &curr);
     rc = 1;
   }
@@ -688,9 +684,9 @@ rgShareItems(RG* ring1, RG* ring2)
   if (isEmptyRing(ring2)) goto end;
   
   // O(n2) but rings should usaly only have 1 or 2 items
-  while((pIt1 = rgNext_r(ring1, &curr1)) != 0) {
+  while ((pIt1 = rgNext_r(ring1, &curr1))) {
     pIt2 = 0;
-    while((pIt2 = rgNext_r(ring2, &curr2)) != 0) {
+    while ((pIt2 = rgNext_r(ring2, &curr2))) {
       if (pIt1 == pIt2) {
 	rc = TRUE;
 	goto end;
@@ -884,7 +880,7 @@ createRing()
   RG* rc = 0;
 
   if ((rc = (RG*)malloc(sizeof(RG))) == 0) {
-    logMemory(LOG_ERR, "%s", "malloc: cannot allocate a ring");
+    logMemory(LOG_ERR, "malloc: cannot allocate a ring");
     goto error;
   }
 							  
@@ -904,7 +900,7 @@ createRing()
 RG* 
 destroyOnlyRing(RG* self)
 {
-  if (self != 0) {
+  if (self) {
     rgDelete(self);
     free(self);
   } 
@@ -926,10 +922,10 @@ destroyRing(RG* self, void* (*destroyItem)(void *))
   void* item = 0;
   RGIT* curr = 0;
 	
-  if(self != 0) {
+  if(self) {
     //rgRewind(self);
-    while((item = (RG*)rgNext_r(self, &curr)) != 0) {
-      if (destroyItem != 0) {
+    while ((item = (RG*)rgNext_r(self, &curr))) {
+      if (destroyItem) {
 	item = destroyItem(item);
       }
     }
@@ -963,7 +959,7 @@ copyRing(RG* destination, RG* source,
   RGIT* curr = 0;
 
   if(source == 0) {
-    logMemory(LOG_ERR, "%s", "please do not provide an empty source ring");
+    logMemory(LOG_ERR, "please do not provide an empty source ring");
     goto error;
   }
 
@@ -972,9 +968,9 @@ copyRing(RG* destination, RG* source,
     goto error;
   }
   
-  if(source != 0) {
+  if(source) {
     //rgRewind(source);
-    while((sourceItem = (void*)rgNext_r(source, &curr)) != 0) {
+    while ((sourceItem = (void*)rgNext_r(source, &curr))) {
       if ((destinationItem = copyItem(destinationItem, sourceItem)) == 0) {
 	goto error;
       }
@@ -992,7 +988,7 @@ copyRing(RG* destination, RG* source,
   
   return destination;
  error:
-  logMemory(LOG_ERR, "%s", "fails to copy a ring");
+  logMemory(LOG_ERR, "fails to copy a ring");
   destination = destroyRing(destination, destroyItem);
   return destination;
 }
@@ -1011,230 +1007,6 @@ inline int isEmptyRing(RG* self)
   return (self == 0 || self->head == 0)?TRUE:FALSE;
 }
 
-/************************************************************************/
-
-#ifdef utMAIN
-#include "../misc/command.h"
-#include "strdsm.h"
-GLOBAL_STRUCT_DEF;
-
-/*=======================================================================
- * Function   : usage
- * Description: Print the usage.
- * Synopsis   : static void usage(char* programName)
- * Input      : programName = the name of the program; usually argv[0].
- * Output     : N/A
- =======================================================================*/
-static void 
-usage(char* programName)
-{
-  memoryUsage(programName);
-  fprintf(stderr, " [ -i input ] [ -o output ]");
-
-  memoryOptions();
-  fprintf(stderr, "  ---\n");
-  fprintf(stderr, "  -i, --input\t\tinput stream\n");
-  fprintf(stderr, "  -o, --output\t\toutput stream\n");
-  return;
-}
-
-/*=======================================================================
- * Function   : main
- * Author     : Peter FELECAN, Nicolas ROCHE
- * modif      : 2012/05/01
- * Description: Unit test for ardsm module. Tests RG generic
- *              implementation by acquiring string content from the
- *              stdandard input.
- * Synopsis   : utardsm
- * Input      : stdin
- * Output     : stdout
- =======================================================================*/
-int 
-main(int argc, char** argv)
-{
-  char E[] = "ABCDE";
-  char* E1[] = {&E[0], &E[1],        &E[3], &E[4]};
-  char* E2[] = {       &E[1], &E[2], &E[3]};
-  int i = 0;
-  char *it = (char *)0;
-  RG* cont = 0;
-  RG* ring = 0;
-  RG* ring2 = 0;
-  FILE* hin = (FILE*)stdin;
-  FILE* hout = (FILE*)stdout;
-  char buffer[BUFSIZ];
-  // ---
-  int rc = 0;
-  int cOption = EOF;
-  char* programName = *argv;
-  char* options = MEMORY_SHORT_OPTIONS"i:o:";
-  struct option longOptions[] = {
-    MEMORY_LONG_OPTIONS,
-    {"input", required_argument, 0, 'i'},
-    {"output", required_argument, 0, 'o'},
-    {0, 0, 0, 0}
-  };
-
-  // import mdtx environment
-  env.debugMemory = TRUE;
-  getEnv(&env);
-
-  // parse the command line
-  while((cOption = getopt_long(argc, argv, options, longOptions, 0)) 
-	!= EOF) {
-    switch(cOption) {
-
-    case 'i':
-      if(isEmptyString(optarg)) {
-	fprintf(stderr, 
-		"%s: nil or empty argument for the input stream\n",
-		programName);
-	rc = 2;
-      }
-      else {
-	if ((hin = fopen(optarg, "r")) == 0) {
-	  fprintf(stderr, 
-		  "cannot open '%s' for input, "
-		  "will try to revert to the standard input\n", optarg);
-	  rc = 3;
-	}
-      }
-      break;
-		
-    case 'o':
-      if(isEmptyString(optarg)) {
-	fprintf(stderr, 
-		"%s: nil or empty argument for the output stream\n",
-		programName);
-	rc = 2;
-      }
-      else {
-	if ((hin = fopen(optarg, "r")) == 0) {
-	  fprintf(stderr, 
-		  "cannot open '%s' for input, "
-		  "will try to revert to the standard output\n", optarg);
-	  rc = 3;
-	}
-      }
-      break;
-
-      GET_MEMORY_OPTIONS; // generic options
-    }
-    if (rc) goto optError;
-  }
-  
-  // export mdtx environment
-  if (!setEnv(programName, &env)) goto optError;
-  
-  /************************************************************************/
-  // working with pointers (don't care about item's content)
-  if (!(ring = createRing())) goto error;
-  if (!(ring2 = createRing())) goto error;
-  for (i=0; i<4; ++i) rgInsert(ring, E1[i]);
-  for (i=0; i<3; ++i) rgInsert(ring2, E2[i]);
-
-  if (!rgSort(ring, cmpPtr)) goto error;  
-  fprintf(hout, "E1: ");
-  while((it = rgNext(ring))) fprintf(hout, "%c", *it);
-  fprintf(hout, "\n");
-
-  if (!rgSort(ring2, cmpPtr)) goto error;
-  fprintf(hout, "E2: ");
-  while((it = rgNext(ring2))) fprintf(hout, "%c", *it);
-  fprintf(hout, "\n");
-  
-  if (!(cont = rgInter(ring, ring2))) goto error;
-  fprintf(hout, "E1 /\\ E2: ");
-  while((it = rgNext(cont))) fprintf(hout, "%c", *it);
-  fprintf(hout, "\n");
-  cont = destroyOnlyRing(cont);
-
-  if (!(cont = rgUnion(ring, ring2))) goto error;
-  fprintf(hout, "E1 \\/ E2: ");
-  while((it = rgNext(cont))) fprintf(hout, "%c", *it);
-  fprintf(hout, "\n");
-  cont = destroyOnlyRing(cont);
-
-  if (!(cont = rgMinus(ring, ring2))) goto error;
-  fprintf(hout, "E1 - E2: ");
-  while((it = rgNext(cont))) fprintf(hout, "%c", *it);
-  fprintf(hout, "\n");
-  cont = destroyOnlyRing(cont);
-
-  ring = destroyOnlyRing(ring);
-  ring2 = destroyOnlyRing(ring2);
-  /*------------------------------------------------------------------*/
-  if ((cont = createRing()) == 0) goto error;
-  if ((ring2 = createRing()) == 0) goto error;
-  rgInit(cont);	/*	: ring initialisation (not needed) */
-  fprintf(hout, 
-	  "Enter items, one per line.\nEnd the list by EOF (ctl-d)\n");
-		
-  while(fgets(buffer, BUFSIZ, hin) != 0) {
-    if (!strcmp(buffer, "quit\n")) break;
-
-    /*	content acquisition :	*/
-    it = (char *)malloc(sizeof(char) * (strlen(buffer) + 1));
-    strcpy(it, buffer);
-    rgInsert(cont, (void *)it);
-    rgHeadInsert(ring2, (void *)it);
-  }
-  
-  rgRewind(cont);
-  if ((ring = copyRing(ring, cont,
-		       (void*(*)(void*)) destroyString, 
-		       (void*(*)(void*, const void*)) copyString))
-      == 0) goto error;
-
-  while((it = (char *)rgNext(ring)) != (char *)0) {
-    /*	forward :	*/
-    fprintf(hout, "fw : %s", it);
-  }
-  
-  while((it = (char *)rgPrevious(ring)) != (char *)0) {
-    /*	backward :	*/
-    fprintf(hout, "bk : %s", it);
-  }
-
-  while((it = (char *)rgNext(ring2)) != (char *)0) {
-    /*	forward :	*/
-    fprintf(hout, "bk2 : %s", it);
-  }
-  
-  /* sort */
-  fprintf(hout, "sorting ring ...\n");
-  if (rgSort(ring, cmpString) == FALSE) goto error;
-
-  fprintf(hout, "first ring (your inputs)\n");
-  rgRewind(cont);
-  while((it = (char *)rgNext(cont)) != (char *)0) {
-    /*	forward :	*/
-    fprintf(hout, "fw : %s", it);
-  }
-
-  fprintf(hout, "ring sorted\n");
-  rgRewind(ring);
-  while((it = (char *)rgNext(ring)) != (char *)0) {
-    /*	forward :	*/
-    fprintf(hout, "fw : %s", it);
-  }
-
-  ring = destroyRing(ring, (void*(*)(void*)) destroyString);
-  cont = destroyRing(cont, (void*(*)(void*)) destroyString);
-  ring2 = destroyOnlyRing(ring2);	
-  fflush(hout);
-  rc = TRUE;
-  /************************************************************************/
-
- error:
-  ENDINGS;
-  rc=!rc;
- optError:
-  exit(rc);
-}
- 
-#endif // utMAIN
-
 /* Local Variables: */
 /* mode: c */
 /* mode: font-lock */
