@@ -1,5 +1,5 @@
 /*=======================================================================
- * Version: $Id: cacheTree.c,v 1.3 2015/06/03 14:03:38 nroche Exp $
+ * Version: $Id: cacheTree.c,v 1.15 2015/09/13 23:47:35 nroche Exp $
  * Project: MediaTeX
  * Module : cache
  *
@@ -22,18 +22,18 @@
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  =======================================================================*/
 
-#include "../mediatex.h"
-#include "../misc/log.h"
-#include "strdsm.h"
-#include "confTree.h"
+#include "mediatex-config.h"
 
 
 /*=======================================================================
  * Function   : lockCacheRead
- * Description: lock cache for read
+ * Description: lock cache for read (use and insert records)
  * Synopsis   : int lockCacheRead(CacheTree* self)
  * Input      : CacheTree* self
  * Output     : TRUE on success
+ *
+ * Note       : Server's threads use the cache for reading
+ *              simultaneously (using 3 mutexes)
  =======================================================================*/
 int lockCacheRead(Collection* coll)
 {
@@ -41,7 +41,7 @@ int lockCacheRead(Collection* coll)
   int err = 0;
  
   checkCollection(coll);
-  logMemory(LOG_DEBUG, "%s", "lock cache for read");
+  logMemory(LOG_DEBUG, "lock cache for read");
  
   // lock R
   if ((err = pthread_rwlock_rdlock(coll->cacheTree->rwlock))) {
@@ -52,14 +52,14 @@ int lockCacheRead(Collection* coll)
   rc = TRUE;
  error:
   if (!rc) {
-    logMemory(LOG_ERR, "%s", "lockCacheRead fails");
+    logMemory(LOG_ERR, "lockCacheRead fails");
   }
   return rc;
 }
 
 /*=======================================================================
  * Function   : lockCacheWrite
- * Description: lock cache for write
+ * Description: lock cache for write (remove records marked 'removed')
  * Synopsis   : int lockCacheWrite(CacheTree* self)
  * Input      : CacheTree* self
  * Output     : TRUE on success
@@ -70,7 +70,7 @@ int lockCacheWrite(Collection* coll)
   int err = 0;
  
   checkCollection(coll);
-  logMemory(LOG_DEBUG, "%s", "lock cache for write");
+  logMemory(LOG_DEBUG, "lock cache for write");
  
   // lock W
   if ((err = pthread_rwlock_wrlock(coll->cacheTree->rwlock))) {
@@ -81,7 +81,7 @@ int lockCacheWrite(Collection* coll)
   rc = TRUE;
  error:
   if (!rc) {
-    logMemory(LOG_ERR, "%s", "lockCacheWrite fails");
+    logMemory(LOG_ERR, "lockCacheWrite fails");
   }
   return rc;
 }
@@ -100,7 +100,7 @@ int unLockCache(Collection* coll)
   int err = 0;
  
   checkCollection(coll);
-  logMemory(LOG_DEBUG, "%s", "unlock Cache");
+  logMemory(LOG_DEBUG, "unlock Cache");
  
   // lock W
   if ((err = pthread_rwlock_unlock(coll->cacheTree->rwlock))) {
@@ -111,7 +111,7 @@ int unLockCache(Collection* coll)
   rc = TRUE;
  error:
   if (!rc) {
-    logMemory(LOG_ERR, "%s", "unLockCache fails");
+    logMemory(LOG_ERR, "unLockCache fails");
   }
   return rc;
 }
@@ -143,12 +143,12 @@ createCacheTree(void)
   // init the locks
 
   if ((rc->attr = malloc(sizeof(pthread_rwlockattr_t))) == 0) {
-    logMemory(LOG_ERR, "%s", "cannot allocate pthread_rwlockattr_t");
+    logMemory(LOG_ERR, "cannot allocate pthread_rwlockattr_t");
     goto error;
   }
 
   if ((rc->rwlock = malloc(sizeof(pthread_rwlock_t))) == 0) {
-    logMemory(LOG_ERR, "%s", "cannot allocate pthread_rwlock_t");
+    logMemory(LOG_ERR, "cannot allocate pthread_rwlock_t");
     goto error;
   }
   
@@ -173,17 +173,17 @@ createCacheTree(void)
 
   return rc;
  error:
-  logMemory(LOG_ERR, "%s", "malloc: cannot create Record");
+  logMemory(LOG_ERR, "malloc: cannot create Record");
   rc = destroyCacheTree(rc);
   return rc;
 }
 
 /*=======================================================================
- * Function   : destroyRecord
- * Description: Destroy a merger by freeing all the allocate memory.
+ * Function   : destroyCacheTree
+ * Description: Destroy a cacheTree
  * Synopsis   : CacheTree* destroyCacheTree(CacheTree* self)
- * Input      : CacheTree* self = the address of the merger to destroy.
- * Output     : Nil address of a merger.
+ * Input      : CacheTree* self = what to destry
+ * Output     : NULL
  =======================================================================*/
 CacheTree* 
 destroyCacheTree(CacheTree* self)
@@ -204,7 +204,7 @@ destroyCacheTree(CacheTree* self)
   free(self->attr);
   
   for (i=0; i<MUTEX_MAX; ++i) {
-    if ((err = pthread_mutex_destroy(&self->mutex[i]) != 0)) {
+    if ((err = pthread_mutex_destroy(&self->mutex[i]))) {
       logMemory(LOG_INFO, "pthread_mutex_init: %s", strerror(err));
       goto error;
     }
@@ -216,11 +216,11 @@ destroyCacheTree(CacheTree* self)
 }
 
 /*=======================================================================
- * Function   : 
- * Description: 
- * Synopsis   : 
- * Input      : 
- * Output     : 
+ * Function   : haveRecords
+ * Description: int haveRecords(RG* ring)
+ * Synopsis   : check if there is record into the input ring
+ * Input      : RG* ring
+ * Output     : TRUE if there is at less one record
  =======================================================================*/
 int 
 haveRecords(RG* ring) 
@@ -245,8 +245,11 @@ haveRecords(RG* ring)
  * Synopsis   : int computeArchiveStatus(Archive* self)
  * Input      : Archive* self = the archive
  * Output     : TRUE on success
+ *
+ * Note       : This function and only this one use the
+ *              MUTEX_COMPUTE mutex so as to be threads-safe
  =======================================================================*/
-static int 
+int 
 computeArchiveStatus(Collection* coll, Archive* archive)
 {
   int rc = FALSE;
@@ -273,7 +276,7 @@ computeArchiveStatus(Collection* coll, Archive* archive)
   archive->state = UNUSED;
 
   // state1: used
-  if (haveRecords(archive->finaleSupplies) ||
+  if (haveRecords(archive->finalSupplies) ||
       haveRecords(archive->remoteSupplies))
     archive->state = USED;
 
@@ -282,14 +285,14 @@ computeArchiveStatus(Collection* coll, Archive* archive)
   if (archive->localSupply == 0 ||
       (archive->localSupply->type & REMOVE)) goto end;
 
-  // state 3: allocated (archive->localSupply != 0)
+  // state 3: allocated (archive->localSupply)
   switch (getRecordType(archive->localSupply)) {
   case MALLOC_SUPPLY:
     archive->state = ALLOCATED;
     goto end;
     break;
 
-  case LOCALE_SUPPLY:
+  case LOCAL_SUPPLY:
     // state 4: available
     archive->state = AVAILABLE;
     break;
@@ -300,14 +303,18 @@ computeArchiveStatus(Collection* coll, Archive* archive)
     goto error2;
   }
 
-  // state 5: to keep
-  if (archive->localSupply->date > date) {
+  // state 5: to keep archive having a bad score or 
+  // still in use for extraction
+  if (archive->extractScore <= coll->serverTree->scoreParam.maxScore /2
+      || archive->localSupply->date > date) {
     archive->state = TOKEEP;
   }
     
  end:
-  logMemory(LOG_INFO, "state: %s -> %s", 
-	  strAState(previousState), strAState(archive->state));
+  logMemory(LOG_INFO, "%s:%lli (score=%5.2f) : %s -> %s", 
+	    archive->hash, (long long int)archive->size,
+	    archive->extractScore,
+	    strAState(previousState), strAState(archive->state));
 
   // become allocated
   if (previousState < ALLOCATED && archive->state >= ALLOCATED)
@@ -318,11 +325,11 @@ computeArchiveStatus(Collection* coll, Archive* archive)
     coll->cacheTree->useSize -= archive->size;
 
   // become to be keept
-  if (previousState < TOKEEP && archive->state == TOKEEP)
+  if (previousState < TOKEEP && archive->state >= TOKEEP)
      coll->cacheTree->frozenSize += archive->size;
 
   // become not to keept anymore
-  if (previousState == TOKEEP && archive->state <= TOKEEP)
+  if (previousState >= TOKEEP && archive->state < TOKEEP)
     coll->cacheTree->frozenSize -= archive->size;
 
   rc = TRUE;
@@ -333,7 +340,7 @@ computeArchiveStatus(Collection* coll, Archive* archive)
   }
  error:
   if (!rc) {
-     logMemory(LOG_ERR, "%s", "computeArchiveStatus fails");
+     logMemory(LOG_ERR, "computeArchiveStatus fails");
   }
   return rc;
 }
@@ -378,7 +385,7 @@ int addCacheEntry(Collection* coll, Record* record)
   }
 
   if (record->type & REMOVE) {
-    logMemory(LOG_ERR, "%s", "cannot add a record marked as removed");
+    logMemory(LOG_ERR, "cannot add a record marked 'removed'");
     goto error;
   }
 
@@ -386,27 +393,27 @@ int addCacheEntry(Collection* coll, Record* record)
   switch (getRecordType(record)) {
 
   case MALLOC_SUPPLY:
-  case LOCALE_SUPPLY:
+  case LOCAL_SUPPLY:
     if (archive->localSupply == 0 ||
 	(archive->localSupply->type & REMOVE)) {
       archive->localSupply = record;
     }
     else {
-      logMemory(LOG_NOTICE, "%s", 
+      logMemory(LOG_NOTICE, 
 	      "we only record one local supply by archive");
     }
     break;
       
-  case FINALE_SUPPLY:
-     if (!rgInsert(archive->finaleSupplies, record)) goto error;
+  case FINAL_SUPPLY:
+     if (!rgInsert(archive->finalSupplies, record)) goto error;
      break;
 
   case REMOTE_SUPPLY:
      if (!rgInsert(archive->remoteSupplies, record)) goto error;
      break;
 
-  case FINALE_DEMAND:
-  case LOCALE_DEMAND:
+  case FINAL_DEMAND:
+  case LOCAL_DEMAND:
   case REMOTE_DEMAND:
      if (!rgInsert(archive->demands, record)) goto error;
      break;
@@ -421,7 +428,7 @@ int addCacheEntry(Collection* coll, Record* record)
 
   /*
   // openClose mutex
-  if ((err = pthread_mutex_lock(&coll->mutex[iCACH])) != 0) {
+  if ((err = pthread_mutex_lock(&coll->mutex[iCACH]))) {
     logMemory(LOG_ERR, "pthread_mutex_lock fails: %s", strerror(err));
     goto error;
   }
@@ -430,7 +437,7 @@ int addCacheEntry(Collection* coll, Record* record)
   coll->fileState[iCACH] = MODIFIED;
 
   /*
-  if ((err = pthread_mutex_unlock(&coll->mutex[iCACH])) != 0) {
+  if ((err = pthread_mutex_unlock(&coll->mutex[iCACH]))) {
     logMemory(LOG_ERR, "pthread_mutex_unlock fails: %s", strerror(err));
     goto error;
   }
@@ -439,7 +446,7 @@ int addCacheEntry(Collection* coll, Record* record)
   rc = TRUE;
  error:
   if (!rc) {
-     logMemory(LOG_DEBUG, "%s", "fails to add a cache entry");
+     logMemory(LOG_DEBUG, "fails to add a cache entry");
      delCacheEntry(coll, record);
   }
   return rc;
@@ -452,7 +459,9 @@ int addCacheEntry(Collection* coll, Record* record)
  * Input      : Collection* coll: the collection we use
  *              Record* record: record to del
  * Output     : TRUE on success
- * Note       : Server's records are not managed here
+ * Note       : Record may be referenced elsewhere so we just mark
+ *              it as removed (but do not destroy it)
+ *              ex: servers add a back reference to records
  =======================================================================*/
 int delCacheEntry(Collection* coll, Record* record)
 {
@@ -474,7 +483,7 @@ int delCacheEntry(Collection* coll, Record* record)
   if (!computeArchiveStatus(coll, record->archive)) goto error;
 
   /*
-  if ((err = pthread_mutex_lock(&coll->mutex[iCACH])) != 0) {
+  if ((err = pthread_mutex_lock(&coll->mutex[iCACH]))) {
     logMemory(LOG_ERR, "pthread_mutex_lock fails: %s", strerror(err));
     goto error;
   }
@@ -483,7 +492,7 @@ int delCacheEntry(Collection* coll, Record* record)
   coll->fileState[iCACH] = MODIFIED;
 
   /*
-  if ((err = pthread_mutex_unlock(&coll->mutex[iCACH])) != 0) {
+  if ((err = pthread_mutex_unlock(&coll->mutex[iCACH]))) {
     logMemory(LOG_ERR, "pthread_mutex_unlock fails: %s", strerror(err));
     goto error;
   }
@@ -492,7 +501,7 @@ int delCacheEntry(Collection* coll, Record* record)
   rc = TRUE;
  error:
   if (!rc) {
-     logMemory(LOG_ERR, "%s", "fails to del a cache entry");
+     logMemory(LOG_ERR, "fails to del a cache entry");
   }
   return rc;
 }
@@ -506,12 +515,16 @@ int delCacheEntry(Collection* coll, Record* record)
  *              Archive* archive = archive to keep
  *              RecordType type = use to compute time to keep
  * Output     : TRUE on success
+ *
+ * Note       : keepArchive and unKeepArchive are using MUTEX_KEEP
+ *              manage the concurents calls.
+ *              Keeping archive is only related to extraction delay, 
+ *              but it is not related with scores 
  =======================================================================*/
 int
-keepArchive(Collection* coll, Archive* archive, RecordType type)
+keepArchive(Collection* coll, Archive* archive)
 {
   int rc = FALSE;
-  Configuration* conf = 0;
   CacheTree* cache = 0;
   Record* record = 0;
   time_t date = -1;
@@ -522,12 +535,11 @@ keepArchive(Collection* coll, Archive* archive, RecordType type)
   record = archive->localSupply;
   checkRecord(record);
   cache = coll->cacheTree;
-  logMemory(LOG_DEBUG, "keep %s %s:%lli",
-	  type?strRecordType2(type):"TMP", archive->hash, archive->size); 
+  logMemory(LOG_DEBUG, "keep %s:%lli", archive->hash, archive->size); 
 
   if (record->type & REMOVE) {
-      logMemory(LOG_ERR, "%s", 
-	      "cannot keep as local supply is already removedkeep");
+      logMemory(LOG_ERR, 
+	      "cannot keep as local supply is already removed");
       goto error;
   }
   
@@ -535,45 +547,28 @@ keepArchive(Collection* coll, Archive* archive, RecordType type)
     logMemory(LOG_ERR, "pthread_mutex_lock fails: %s", strerror(err));
     goto error;
   }
-
-  if ((date = currentTime()) == -1) goto error2; 
-  if (!(conf = getConfiguration())) goto error2;
   
-  // note: only the temporary record use during extraction 
-  // should be unkeep
-  switch (type) {
-  case FINALE_DEMAND:
-    // mail + download http
-    date += coll->cacheTTL;
-    break;
-  case LOCALE_DEMAND:
-    // cgi
-    date += archive->size / (conf->uploadRate >> 5);
-    break;
-  case REMOTE_DEMAND:
-    // scp (time between 2 extraction on local server)
-    date += 1*DAY;
-    break;
-  default:
-    if ((err = pthread_mutex_lock(&cache->mutex[MUTEX_KEEP]))) {
-      logMemory(LOG_ERR, "pthread_mutex_lock fails: %s", strerror(err));
-      goto error2;
-    }
-
-    if (archive->nbKeep == 0) archive->backupDate = record->date;
-    ++archive->nbKeep;
-
-    if ((err = pthread_mutex_unlock(&cache->mutex[MUTEX_KEEP]))) {
-      logMemory(LOG_ERR, "pthread_mutex_lock fails: %s", strerror(err));
-      goto error2;
-    }
-
-    // temporary record during extraction
-    date += 5*MINUTE;
+  if ((err = pthread_mutex_lock(&cache->mutex[MUTEX_KEEP]))) {
+    logMemory(LOG_ERR, "pthread_mutex_lock fails: %s", strerror(err));
+    goto error2;
   }
 
-  if (record->date < date) record->date = date;
-  if (!computeArchiveStatus(coll, archive)) goto error2;
+  if (archive->nbKeep == 0) archive->backupDate = record->date;
+  ++archive->nbKeep;
+  
+  if ((err = pthread_mutex_unlock(&cache->mutex[MUTEX_KEEP]))) {
+    logMemory(LOG_ERR, "pthread_mutex_lock fails: %s", strerror(err));
+    goto error2;
+  }
+  
+  // temporary record during extraction
+  if ((date = currentTime()) == -1) goto error; 
+  date += 5*MINUTE;
+
+  if (record->date < date) {
+    record->date = date;
+    if (!computeArchiveStatus(coll, archive)) goto error2;
+  }
 
   rc = TRUE;
  error2:
@@ -583,7 +578,7 @@ keepArchive(Collection* coll, Archive* archive, RecordType type)
   }
  error:
     if (!rc) {
-    logMemory(LOG_ERR, "%s", "keepArchive fails");
+    logMemory(LOG_ERR, "keepArchive fails");
   }
   return rc;
 }
@@ -597,7 +592,8 @@ keepArchive(Collection* coll, Archive* archive, RecordType type)
  *              Archive* archive = archive to un-keep
  *              time_t prevDate = date to set
  * Output     : TRUE on success
- * Note       : only the temporary record use during extraction 
+ *
+ * Note       : only the temporary records used during extraction 
  *              should be unkeep
  =======================================================================*/
 int
@@ -617,7 +613,7 @@ unKeepArchive(Collection* coll, Archive* archive)
 	  archive->hash, archive->size); 
   
   if (record->type & REMOVE) {
-    logMemory(LOG_ERR, "%s", 
+    logMemory(LOG_ERR, 
 	    "cannot unkeep as local supply is already removedkeep");
     goto error;
   }
@@ -641,7 +637,7 @@ unKeepArchive(Collection* coll, Archive* archive)
   rc = TRUE;
  error:
     if (!rc) {
-    logMemory(LOG_ERR, "%s", "unKeepArchive fails");
+    logMemory(LOG_ERR, "unKeepArchive fails");
   }
   return rc;
 }
@@ -679,22 +675,22 @@ int cleanCacheTree(Collection* coll)
     switch (getRecordType(record)) {
 
     case MALLOC_SUPPLY:
-    case LOCALE_SUPPLY:
+    case LOCAL_SUPPLY:
       if (archive->localSupply == record) {
 	archive->localSupply = 0; 
       }
       break;
       
-    case FINALE_SUPPLY:
-      rgDelItem(archive->finaleSupplies, record);
+    case FINAL_SUPPLY:
+      rgDelItem(archive->finalSupplies, record);
       break;
       
     case REMOTE_SUPPLY:
       rgDelItem(archive->remoteSupplies, record);
       break;
       
-    case FINALE_DEMAND:
-    case LOCALE_DEMAND:
+    case FINAL_DEMAND:
+    case LOCAL_DEMAND:
     case REMOTE_DEMAND:
       rgDelItem(archive->demands, record);
       break;
@@ -706,7 +702,7 @@ int cleanCacheTree(Collection* coll)
 
     // del record if there
     if (!rgDelItem(records, record)) {
-      logMemory(LOG_WARNING, "%s", "record not found into cache");
+      logMemory(LOG_WARNING, "record not found into cache");
       goto error2;
     }
 
@@ -720,7 +716,7 @@ int cleanCacheTree(Collection* coll)
     if (!diseaseArchive(coll, record->archive)) goto error2;  
 
     // remove the record as owned by cache->recordTree->records
-    if (!delRecord(coll, record)) goto error;;
+    if (!delRecord(coll, record)) goto error;
   }
 
   rc = TRUE;
@@ -728,7 +724,7 @@ int cleanCacheTree(Collection* coll)
   if (!unLockCache(coll)) rc = FALSE;
  error:
   if (!rc) {
-    logMemory(LOG_ERR, "%s", "cleanCacheTree fails");
+    logMemory(LOG_ERR, "cleanCacheTree fails");
   }
   return rc;
 }
@@ -740,6 +736,7 @@ int cleanCacheTree(Collection* coll)
  * Input      : Collection* coll: the collection to use
  * Output     : TRUE on success
  * Note       : Do not disease the recordTree !?
+#warning seems no more needed (try to replace directely by cleanCacheTree)
  =======================================================================*/
 int diseaseCacheTree(Collection* coll)
 {
@@ -754,7 +751,7 @@ int diseaseCacheTree(Collection* coll)
   // for all records
   if (!expandCollection(coll)) goto error;
   ring = coll->cacheTree->recordTree->records;
-  while((record = rgNext_r(ring, &curr))) {
+  while ((record = rgNext_r(ring, &curr))) {
     if (!(record->type & REMOVE) &&
 	!delCacheEntry(coll, record)) goto error;
   }
@@ -763,139 +760,127 @@ int diseaseCacheTree(Collection* coll)
 
   rc = TRUE;
  error:
-  if (!rc) logMemory(LOG_ERR, "%s", "diseaseCacheTree fails");
+  if (!rc) logMemory(LOG_ERR, "diseaseCacheTree fails");
   return rc;
 }
 
-/************************************************************************/
-
-#ifdef utMAIN
-#include "../misc/command.h"
-#include "utFunc.h"
-GLOBAL_STRUCT_DEF;
-
-
 /*=======================================================================
- * Function   : testThread
- * Description: Testing the concurent access
- * Synopsis   : void* testThread(void* arg)
- * Input      : void* arg: CacheTree* mergeMd5
- * Output     : N/A
+ * Function   : buildTargetFile
+ * Description: create a new empty file and return its absolute path
+ * Synopsis   : int 
+ *              buildTargetFile(Collection* coll, char** newAbsolutePath, 
+ *              char* prefix, char* postfix)
+ * Input      : Collection* coll
+ *              char* prefix: directory path we know it is accessible 
+ *              (without the leading '/')
+ *              char* postfix: path to work on (directory without the 
+ *              heading '/') + filename
+ * Output     : char** newAbsolutePath: allocated new path
+ *              TRUE on success
  =======================================================================*/
-void* 
-testThread(void* arg)
+int
+buildTargetFile(Collection* coll, char** newAbsolutePath, 
+		char* prefix, char* postfix)
 {
-  //env.recordTree = copyCurrentRecordTree(mergeMd5);
-  return 0;
-}
+  int rc = FALSE;
+  int err = 0;
+  CacheTree* cache = 0;
+  FILE* fd = 0;
+  mode_t mask;
 
-/*=======================================================================
- * Function   : usage
- * Description: Print the usage.
- * Synopsis   : static void usage(char* programName)
- * Input      : programName = the name of the program; usually argv[0].
- * Output     : N/A
- =======================================================================*/
-static void 
-usage(char* programName)
-{
-  mdtxUsage(programName);
-  fprintf(stderr, " [ -d repository ]");
+  logMain(LOG_DEBUG, "buildTargetFile %s / %s", prefix, postfix);
+  checkCollection(coll);
+  cache = coll->cacheTree;
 
-  memoryOptions();
-  //fprintf(stderr, "\t\t---\n");
-  return;
-}
-
-
-/*=======================================================================
- * Function   : main 
- * Author     : Nicolas ROCHE
- * modif      : 2012/05/01
- * Description: Unit test for cache module.
- * Synopsis   : ./utcache
- * Input      : N/A
- * Output     : N/A
- =======================================================================*/
-int 
-main(int argc, char** argv)
-{
-  Collection* coll = 0;
-  Record* record = 0;
-  //pthread_t thread;
-  // ---
-  int rc = 0;
-  int cOption = EOF;
-  char* programName = *argv;
-  char* options = MEMORY_SHORT_OPTIONS;
-  struct option longOptions[] = {
-    MEMORY_LONG_OPTIONS,
-    {0, 0, 0, 0}
-  };
-
-  // import mdtx environment
-  env.dryRun = FALSE;
-  env.debugMemory = TRUE;
-  getEnv(&env);
-
-  // parse the command line
-  while((cOption = getopt_long(argc, argv, options, longOptions, 0)) 
-	!= EOF) {
-    switch(cOption) {
- 
-      GET_MEMORY_OPTIONS; // generic options
-    }
-    if (rc) goto optError;
+  if ((err = pthread_mutex_lock(&cache->mutex[MUTEX_TARGET]))) {
+    logMemory(LOG_ERR, "pthread_mutex_lock fails: %s", strerror(err));
+    goto error;
   }
 
-  // export mdtx environment
-  if (!setEnv(programName, &env)) goto optError;
+  if (!buildAbsoluteTargetPath(newAbsolutePath, prefix, postfix)) 
+    goto error2;
 
-  /************************************************************************/
-  if (!createExempleConfiguration()) goto error;
-  if (!(coll = getCollection("coll1"))) goto error;
-
-  if (!lockCacheRead(coll)) goto error;
-  if (!unLockCache(coll)) goto error;
-  if (!lockCacheWrite(coll)) goto error;
-  if (!unLockCache(coll)) goto error;
-  if (!lockCacheRead(coll)) goto error;
-  if (!lockCacheRead(coll)) goto error;
-  if (!unLockCache(coll)) goto error;
-  if (!unLockCache(coll)) goto error;
-
-  if (!createExempleRecordTree(coll)) goto error;
-
-  // index the record tree
-  logMemory(LOG_DEBUG, "%s", "___ test indexation ___");
-  coll->cacheTree->recordTree->aes.fd = STDERR_FILENO;
-
-  while ((record = rgHead(coll->cacheTree->recordTree->records))) {
-    if (!serializeRecord(coll->cacheTree->recordTree, record)) goto error;
-    aesFlush(&coll->cacheTree->recordTree->aes);
-    fprintf(stderr, "\n");
-
-    if (!addCacheEntry(coll, record)) goto error;
-    if (record->archive->state >= AVAILABLE) {
-      if (!keepArchive(coll, record->archive, 0)) goto error;
-      if (!unKeepArchive(coll, record->archive)) goto error;
-    }
-    if (!delCacheEntry(coll, record)) goto error;
-    if (!cleanCacheTree(coll)) goto error;
+  if (!makeDir(prefix, *newAbsolutePath, 0770)) goto error2;
+  
+  mask = umask(0117);
+  if (!(fd = fopen(*newAbsolutePath, "w"))) {
+    logMemory(LOG_ERR, "fdopen %s fails: %s", 
+	      *newAbsolutePath, strerror(errno));
+    mask = umask(mask);
+    goto error2;
+  }
+  mask = umask(mask);
+
+  if ((fclose(fd))) {
+    logMemory(LOG_ERR, "fclose fails: %s", strerror(errno));
+    goto error2;
   }
-  if (!diseaseCacheTree(coll)) goto error;
-  /************************************************************************/
 
-  freeConfiguration();
   rc = TRUE;
+ error2:
+  if ((err = pthread_mutex_unlock(&cache->mutex[MUTEX_TARGET]))) {
+    logMemory(LOG_ERR, "pthread_mutex_lock fails: %s", strerror(err));
+    rc = FALSE;
+  }
  error:
-  ENDINGS;
-  rc=!rc;
- optError:
-  exit(rc);
+  if (!rc) {
+    logMain(LOG_ERR, "buildTargetFile fails");
+    *newAbsolutePath = 0;
+  }
+  return rc;
 }
 
-#endif // utMAIN
+/*=======================================================================
+ * Function   : buildTargetDir
+ * Description: create a new directory and return its absolute path
+ * Synopsis   : int 
+ *              buildTargetDir(Collection* coll, char** newAbsolutePath, 
+ *                             char* prefix, char* postfix)
+ * Input      : Collection* coll
+ *              char* prefix: directory path we know it is accessible 
+ *              (without the leading '/')
+ *              char* postfix: path to work on (directory without the 
+ *              heading and leading '/')
+ * Output     : char** newAbsolutePath: allocated new path with
+ *                                      leading '/'
+ *              TRUE on success
+ =======================================================================*/
+int
+buildTargetDir(Collection* coll, char** newAbsolutePath, 
+	       char* prefix, char* postfix)
+{
+  int rc = FALSE;
+  int err = 0;
+  CacheTree* cache = 0;
+
+  logMain(LOG_DEBUG, "buildTargetDir %s / %s", prefix, postfix);
+  checkCollection(coll);
+  cache = coll->cacheTree;
+
+  if ((err = pthread_mutex_lock(&cache->mutex[MUTEX_TARGET]))) {
+    logMemory(LOG_ERR, "pthread_mutex_lock fails: %s", strerror(err));
+    goto error;
+  }
+
+  if (!buildAbsoluteTargetPath(newAbsolutePath, prefix, postfix)) 
+    goto error2;
+
+  if (!(*newAbsolutePath = catString(*newAbsolutePath, "/"))) goto error2;
+  if (!makeDir(prefix, *newAbsolutePath, 0700)) goto error2;
+
+  rc = TRUE;
+ error2:
+  if ((err = pthread_mutex_unlock(&cache->mutex[MUTEX_TARGET]))) {
+    logMemory(LOG_ERR, "pthread_mutex_lock fails: %s", strerror(err));
+    rc = FALSE;
+  }
+ error:
+  if (!rc) {
+    logMain(LOG_ERR, "buildTargetDir fails");
+    *newAbsolutePath = 0;
+  }
+  return rc;
+}
 
 /* Local Variables: */
 /* mode: c */
