@@ -1,9 +1,9 @@
 /*=======================================================================
- * Version: $Id: cacheTree.h,v 1.3 2015/06/03 14:03:38 nroche Exp $
+ * Version: $Id: cacheTree.h,v 1.10 2015/10/04 22:15:50 nroche Exp $
  * Project: MediaTeX
- * Module : cache
+ * Module : cache memory
  *
- * Manage local cache directory and DB
+ * Manage local cache directory
 
  MediaTex is an Electronic Records Management System
  Copyright (C) 2014 2015 Nicolas Roche
@@ -22,12 +22,10 @@
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 =======================================================================*/
 
-#ifndef MDTX_MEMORY_CACHE_TREE_H
-#define MDTX_MEMORY_CACHE_TREE_H 1
+#ifndef MDTX_MEMORY_CACHE_H
+#define MDTX_MEMORY_CACHE_H 1
 
-#include "../mediatex.h"
-#include "confTree.h"
-#include <pthread.h>
+#include "mediatex-types.h"
 
 /* API */
 
@@ -35,9 +33,25 @@ typedef enum {
   MUTEX_ALLOC=0, 
   MUTEX_KEEP=1, 
   MUTEX_COMPUTE=2,
-  MUTEX_MAX=3
+  MUTEX_TARGET=3,
+  MUTEX_MAX=4
 } CacheMutex;
 
+// hight level type computed from type, host and path
+typedef enum {
+  UNDEF_RECORD = 0,
+  FINAL_SUPPLY = 1, 
+  LOCAL_SUPPLY = 2,
+  REMOTE_SUPPLY = 4,
+  MALLOC_SUPPLY = 8,   // use by merger to reserve space
+  FINAL_DEMAND = 16, 
+  LOCAL_DEMAND = 32,
+  REMOTE_DEMAND = 64,
+  ALL_SUPPLY    = 1|2|4,
+  ALL_DEMAND    = 16|32|64,
+  ALL_RECORD    = 1|2|4|16|32|64,
+} RecordType;
+
 // cache content
 struct CacheTree
 {
@@ -71,11 +85,13 @@ int lockCacheRead(Collection* coll);
 int lockCacheWrite(Collection* coll);
 int unLockCache(Collection* coll);
 
+int computeArchiveStatus(Collection* coll, Archive* archive);
+
 int addCacheEntry(Collection* coll, Record* record);
 int delCacheEntry(Collection* coll, Record* record);
 int cleanCacheTree(Collection* coll);
 
-int keepArchive(Collection* coll, Archive* archive, RecordType type);
+int keepArchive(Collection* coll, Archive* archive);
 int unKeepArchive(Collection* coll, Archive* archive);
 
 int getCacheSizes(Collection* coll, 
@@ -83,7 +99,15 @@ int getCacheSizes(Collection* coll,
 
 int diseaseCacheTree(Collection* coll);
 
-#endif /* MDTX_MEMORY_CACHE_TREE_H */
+int haveRecords(RG* ring);
+
+// call by extract.c
+int buildTargetFile(Collection* coll, char** newAbsolutePath, 
+		    char* prefix, char* postfix);
+int buildTargetDir(Collection* coll, char** newAbsolutePath, 
+		   char* prefix, char* postfix);
+
+#endif /* MDTX_MEMORY_CACHE_H */
 
 /* Local Variables: */
 /* mode: c */
