@@ -1,5 +1,5 @@
 /*=======================================================================
- * Version: $Id: catalogTree.c,v 1.3 2015/06/03 14:03:38 nroche Exp $
+ * Version: $Id: catalogTree.c,v 1.10 2015/09/04 15:30:26 nroche Exp $
  * Project: MediaTeX
  * Module : admCatalogTree
  *
@@ -22,11 +22,7 @@
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  =======================================================================*/
 
-#include "../mediatex.h"
-#include "../misc/log.h"
-#include "catalogTree.h"
-
-#include <avl.h>
+#include "mediatex-config.h"
 
 
 /*=======================================================================
@@ -64,7 +60,7 @@ createCarac()
   Carac* rc = 0;
 
   if ((rc = (Carac*)malloc(sizeof(Carac))) == 0) {
-    logMemory(LOG_ERR, "%s", "malloc: cannot create a Carac");
+    logMemory(LOG_ERR, "malloc: cannot create a Carac");
     goto error;
   }
 
@@ -88,7 +84,7 @@ destroyCarac(Carac* self)
 {
   Carac* rc = 0;
 
-  if(self != 0) {
+  if(self) {
     self->label = destroyString(self->label);
     free(self);
   }
@@ -127,7 +123,7 @@ createAssoCarac()
   AssoCarac* rc = 0;
 
   if ((rc = (AssoCarac*)malloc(sizeof(AssoCarac))) == 0) {
-    logMemory(LOG_ERR, "%s", "malloc: cannot create AssoCarac");
+    logMemory(LOG_ERR, "malloc: cannot create AssoCarac");
     goto error;
   }
 
@@ -151,7 +147,7 @@ destroyAssoCarac(AssoCarac* self)
 {
   AssoCarac* rc = 0;
 
-  if(self != 0) {
+  if(self) {
     self->value = destroyString(self->value);
     free(self);
   }
@@ -197,12 +193,12 @@ serializeAssoCarac(AssoCarac* self, CvsFile* fd)
   logMemory(LOG_DEBUG, "serialize AssoCarac: %s/%s", 
 	  self->carac->label, self->value);
 
-  cvsPrint(fd, "  \"%s\" = \"%s\"\n", self->carac->label, self->value);
+  fd->print(fd, "  \"%s\" = \"%s\"\n", self->carac->label, self->value);
 
   rc = TRUE;
  error:
   if (!rc) {
-    logMemory(LOG_ERR, "%s", "cannot serialize empty AssoCarac");
+    logMemory(LOG_ERR, "cannot serialize empty AssoCarac");
   }
   return(rc);
 }
@@ -243,7 +239,7 @@ createRole(void)
   Role* rc = 0;
 
   if ((rc = (Role*)malloc(sizeof(Role))) == 0) {
-    logMemory(LOG_ERR, "%s", "malloc: cannot create a Role");
+    logMemory(LOG_ERR, "malloc: cannot create a Role");
     goto error;
   }
 
@@ -268,7 +264,7 @@ destroyRole(Role* self)
 {
   Role* rc = 0;
 
-  if(self != 0) {
+  if(self) {
     self->label = destroyString(self->label);
     
     // we destroy the assoRole too
@@ -312,7 +308,7 @@ createAssoRole()
   AssoRole* rc = 0;
 
   if ((rc = (AssoRole*)malloc(sizeof(AssoRole))) == 0) {
-    logMemory(LOG_ERR, "%s", "malloc: cannot create AssoRole");
+    logMemory(LOG_ERR, "malloc: cannot create AssoRole");
     goto error;
   }
 
@@ -336,7 +332,7 @@ destroyAssoRole(AssoRole* self)
 {
   AssoRole* rc = 0;
 
-  if(self != 0) {
+  if(self) {
     free(self);
   }
 
@@ -359,14 +355,14 @@ serializeAssoRole(AssoRole* self, CvsFile* fd)
   logMemory(LOG_DEBUG, "serialize AssoRole: %s", self->role->label);
   if(self == 0) goto error;
 
-  cvsPrint(fd, "  With \"%s\" = \"%s\" \"%s\"\n", 
+  fd->print(fd, "  With \"%s\" = \"%s\" \"%s\"\n", 
 	  self->role->label, 
 	  self->human->firstName, self->human->secondName);
 
   rc = TRUE;
  error:
   if (!rc) {
-    logMemory(LOG_ERR, "%s", "cannot serialize empty AssoRole");
+    logMemory(LOG_ERR, "cannot serialize empty AssoRole");
   }
   return(rc);
 }
@@ -386,25 +382,28 @@ serializeCatalogArchive(Archive* self, CvsFile* fd)
   AssoCarac *assoCarac = 0;
 
   checkArchive(self);
-  logMemory(LOG_DEBUG, "serialize archive: %s:%lli", self->hash, self->size);
+  logMemory(LOG_DEBUG, "serialize archive: %s:%lli", 
+	    self->hash, self->size);
 
-  cvsPrint(fd, "Archive\t %s:%lli\n", self->hash, self->size);
+  fd->print(fd, "Archive\t %s:%lli\n", self->hash, self->size);
   fd->doCut = FALSE;
 
   // serialize assoCaracs
   if (!isEmptyRing(self->assoCaracs)) {
     rgSort(self->assoCaracs, cmpAssoCarac);
     rgRewind(self->assoCaracs);
-    while ((assoCarac = rgNext(self->assoCaracs)) != 0) {
+    while ((assoCarac = rgNext(self->assoCaracs))) {
       if (!serializeAssoCarac(assoCarac, fd)) goto error;
     }
   }
 
+  fd->print(fd, "\n");
+  
   fd->doCut = TRUE;
   rc = TRUE;
  error:
   if (!rc) {
-    logMemory(LOG_ERR, "%s", "cannot serialize empty CRecord");
+    logMemory(LOG_ERR, "cannot serialize empty CRecord");
   }
   return(rc);
 }
@@ -432,7 +431,7 @@ createHuman(void)
 
   return rc;
  error:
-  logMemory(LOG_ERR, "%s", "malloc: cannot create Human");
+  logMemory(LOG_ERR, "malloc: cannot create Human");
   return destroyHuman(rc);
 }
 
@@ -449,7 +448,7 @@ destroyHuman(Human* self)
 {
   Human* rc = 0;
 
-  if(self != 0) {
+  if(self) {
     self->firstName  = destroyString(self->firstName);
     self->secondName = destroyString(self->secondName);
 
@@ -522,34 +521,35 @@ serializeHuman(Human* self, CvsFile* fd)
   logMemory(LOG_DEBUG, "serialize Human %i: %s %s",
 	  self->id, self->firstName, self->secondName);
 
-  cvsPrint(fd, "Human\t \"%s\" \"%s\"", self->firstName, self->secondName);
+  fd->print(fd, "Human\t \"%s\" \"%s\"", self->firstName, self->secondName);
   fd->doCut = FALSE;
   
   // serialize categories
   if (!isEmptyRing(self->categories)) {
     rgSort(self->categories, cmpCategory);
     rgRewind(self->categories);
-    while ((cathegory = rgNext(self->categories)) != 0) {
-      cvsPrint(fd, "%s\"%s\"", (++i)?", ":": ", cathegory->label);
+    while ((cathegory = rgNext(self->categories))) {
+      fd->print(fd, "%s\"%s\"", (++i)?", ":": ", cathegory->label);
     }
   }
-  cvsPrint(fd, "\n");
+  fd->print(fd, "\n");
 
   // serialize assoCaracs
   if (!isEmptyRing(self->assoCaracs)) {
     rgSort(self->assoCaracs, cmpAssoCarac);
     rgRewind(self->assoCaracs);
-    while ((assoCarac = rgNext(self->assoCaracs)) != 0) {
+    while ((assoCarac = rgNext(self->assoCaracs))) {
       serializeAssoCarac(assoCarac, fd);
     }
   }
+  fd->print(fd, "\n");
 
   ++env.progBar.cur;
   fd->doCut = TRUE;
   rc = TRUE;
  error:
   if (!rc) {
-    logMemory(LOG_ERR, "%s", "cannot serialize empty Human");
+    logMemory(LOG_ERR, "cannot serialize empty Human");
   }
   return(rc);
 }
@@ -578,7 +578,7 @@ createDocument(void)
 
   return rc;
  error:
-  logMemory(LOG_ERR, "%s", "malloc: cannot create Document");
+  logMemory(LOG_ERR, "malloc: cannot create Document");
   return destroyDocument(rc);
 }
 
@@ -595,7 +595,7 @@ destroyDocument(Document* self)
 {
   Document* rc = 0;
 
-  if(self != 0) {
+  if(self) {
     self->label = destroyString(self->label);
  
     // delete assoCarac associations
@@ -667,24 +667,24 @@ serializeDocument(Document* self, CvsFile* fd)
   if(self == 0) goto error;
   logMemory(LOG_DEBUG, "serialize Document %s", self->label);
 
-  cvsPrint(fd, "Document \"%s\"", self->label);
+  fd->print(fd, "Document \"%s\"", self->label);
   fd->doCut = FALSE;
 
   // serialize categories
   if (!isEmptyRing(self->categories)) {
     rgSort(self->categories, cmpCategory);
     rgRewind(self->categories);
-    while ((cathegory = rgNext(self->categories)) != 0) {
-      cvsPrint(fd, "%s\"%s\"", (++i)?", ":": ", cathegory->label);
+    while ((cathegory = rgNext(self->categories))) {
+      fd->print(fd, "%s\"%s\"", (++i)?", ":": ", cathegory->label);
     }
   }
-  cvsPrint(fd, "\n");
+  fd->print(fd, "\n");
   
   // serialize assoRoles
   if (!isEmptyRing(self->assoRoles)) {
     rgSort(self->assoRoles, cmpAssoRole);
     rgRewind(self->assoRoles);
-    while ((assoRole = rgNext(self->assoRoles)) != 0) {
+    while ((assoRole = rgNext(self->assoRoles))) {
       if (!serializeAssoRole(assoRole, fd)) goto error;
     }
   }
@@ -693,7 +693,7 @@ serializeDocument(Document* self, CvsFile* fd)
   if (!isEmptyRing(self->assoCaracs)) {
     rgSort(self->assoCaracs, cmpAssoCarac);
     rgRewind(self->assoCaracs);
-    while ((assoCarac = rgNext(self->assoCaracs)) != 0) {
+    while ((assoCarac = rgNext(self->assoCaracs))) {
       if (!serializeAssoCarac(assoCarac, fd)) goto error;
     }
   }
@@ -702,17 +702,19 @@ serializeDocument(Document* self, CvsFile* fd)
   if (!isEmptyRing(self->archives)) {
     rgSort(self->archives, cmpArchive);
     rgRewind(self->archives);
-    while ((archive = rgNext(self->archives)) != 0) {
-      cvsPrint(fd, "  %s:%lli\n", archive->hash, archive->size);
+    while ((archive = rgNext(self->archives))) {
+      fd->print(fd, "  %s:%lli\n", archive->hash, archive->size);
     }
   }
 
+  fd->print(fd, "\n");
+
   ++env.progBar.cur;
   fd->doCut = TRUE;
   rc = TRUE;
  error:
   if (!rc) {
-    logMemory(LOG_ERR, "%s", "serializeDocument fails");
+    logMemory(LOG_ERR, "serializeDocument fails");
   }
   return(rc);
 }
@@ -742,7 +744,7 @@ createCategory(void)
 
   return rc;
  error:
-  logMemory(LOG_ERR, "%s", "malloc: cannot create Category");
+  logMemory(LOG_ERR, "malloc: cannot create Category");
   return destroyCategory(rc);
 }
 
@@ -759,7 +761,7 @@ destroyCategory(Category* self)
 {
   Category* rc = 0;
 
-  if(self != 0) {
+  if(self) {
     self->label = destroyString(self->label);
     
     // delete assoCarac associations
@@ -817,33 +819,34 @@ serializeCategory(Category* self, CvsFile* fd)
   if(self == 0) goto error;
   logMemory(LOG_DEBUG, "serialize Category %s", self->label);
 
-  cvsPrint(fd, "%sCategory \"%s\"", self->show?"Top ":"", self->label);
+  fd->print(fd, "%sCategory \"%s\"", self->show?"Top ":"", self->label);
   fd->doCut = FALSE;
 
   // serialize father's
   if (!isEmptyRing(self->fathers)) {
     //rgSort(self->fathers, cmpCategory);
     rgRewind(self->fathers);
-    while ((category = rgNext(self->fathers)) != 0) {
-      cvsPrint(fd, "%s\"%s\"", (++i)?", ":": ", category->label);
+    while ((category = rgNext(self->fathers))) {
+      fd->print(fd, "%s\"%s\"", (++i)?", ":": ", category->label);
     }
   }
-  cvsPrint(fd, "\n");
+  fd->print(fd, "\n");
 
   // serialize assoCaracs
   if (!isEmptyRing(self->assoCaracs)) {
     rgSort(self->assoCaracs, cmpAssoCarac);
     rgRewind(self->assoCaracs);
-    while ((assoCarac = rgNext(self->assoCaracs)) != 0) {
+    while ((assoCarac = rgNext(self->assoCaracs))) {
       if (!serializeAssoCarac(assoCarac, fd)) goto error;
     }
   }
+  fd->print(fd, "\n");
 
   fd->doCut = TRUE;
   rc = TRUE;
  error:
   if (!rc) {
-    logMemory(LOG_ERR, "%s", "serializeCategory fails");
+    logMemory(LOG_ERR, "serializeCategory fails");
   }
   return(rc);
 }
@@ -881,7 +884,7 @@ createCatalogTree(void)
 
   return rc;
  error:
-  logMemory(LOG_ERR, "%s", "malloc: cannot create CatalogTree");
+  logMemory(LOG_ERR, "malloc: cannot create CatalogTree");
   return destroyCatalogTree(rc);
 }
 
@@ -900,7 +903,7 @@ destroyCatalogTree(CatalogTree* self)
   CatalogTree* rc = 0;
   //int i = 0;
 
-  if(self != 0) {
+  if(self) {
 
     /* entities */
     /* do not destroy archives (owned by the collection) */
@@ -929,15 +932,17 @@ destroyCatalogTree(CatalogTree* self)
 /*=======================================================================
  * Function   : serializeCatalogTree
  * Description: Serialize the catalog metadata
- * Synopsis   : int serializeCatalogTree(Collection* coll)
+ * Synopsis   : int serializeCatalogTree(Collection* coll, CvsFile* fd)
  * Input      : Collection* coll = what to serialize
+ *              CvsFile* fd = serializer object:
+ *              - fd = {0, 0, 0, FALSE, 0, cvsCutOpen, cvsCutPrint};
+ *              - fd = {0, 0, 0, FALSE, 0, cvsCatOpen, cvsCatPrint};
  * Output     : TRUE on success
  =======================================================================*/
 int
-serializeCatalogTree(Collection* coll)
+serializeCatalogTree(Collection* coll, CvsFile* fd)
 {
   int rc = FALSE;
-  CvsFile fd = {0, 0, 0, FALSE, 0};
   Human* human = 0;
   Archive* archive = 0;
   Document* document = 0;
@@ -950,67 +955,69 @@ serializeCatalogTree(Collection* coll)
   if (!(self = coll->catalogTree)) goto error;
   logMemory(LOG_DEBUG, "serialize %s document tree", coll->label);
 
+  if (!fd) goto error;
+  fd->nb = 0;
+  fd->fd = 0;
+  fd->doCut = FALSE;
+  fd->offset = 0;
+
   // we neeed to use the cvs collection directory
   if (!coll->memoryState & EXPANDED) {
-    logMemory(LOG_ERR, "%s", "collection must be expanded first");
+    logMemory(LOG_ERR, "collection must be expanded first");
     goto error;
   }
   
   if (!becomeUser(coll->user, TRUE)) goto error;
 
   // output file
-  if (env.dryRun) fd.fd = stdout;
-  fd.path = coll->catalogDB;
-  if (!cvsOpenFile(&fd)) goto error;
+  if (env.dryRun) fd->fd = stdout;
+  fd->path = coll->catalogDB;  
+  if (!fd->open(fd)) goto error;
 
-  cvsPrint(&fd, "# MediaTeX collection catalog: %s\n", coll->label);
-  //cvsPrint(&fd, "# Version: $" "Id" "$\n");
+  fd->print(fd, "# MediaTeX collection catalog: %s\n", coll->label);
+  //fd->print(fd, "# Version: $" "Id" "$\n");
 
-  cvsPrint(&fd, "\n# Categories:\n\n");
+  fd->print(fd, "\n# Categories:\n\n");
   if (!isEmptyRing(self->categories)) {
     //rgSort(self->categories, cmpCategory);
     rgRewind(self->categories);
-    while((category = rgNext(self->categories)) != 0) {
-      if (!serializeCategory(category, &fd)) goto error;
+    while ((category = rgNext(self->categories))) {
+      if (!serializeCategory(category, fd)) goto error;
     }
-    cvsPrint(&fd, "\n");
   }
 
-  cvsPrint(&fd, "# Humans:\n\n");
+  fd->print(fd, "# Humans:\n\n");
   if (avl_count(self->humans)) {
     for(node = self->humans->head; node; node = node->next) {
       human = (Human*)node->item;
-      if (!serializeHuman(human, &fd)) goto error;
+      if (!serializeHuman(human, fd)) goto error;
     }
-    cvsPrint(&fd, "\n");
   }
 
-  cvsPrint(&fd, "# Archives:\n\n");
+  fd->print(fd, "# Archives:\n\n");
   if (avl_count(coll->archives)) {
     for(node = coll->archives->head; node; node = node->next) {
       archive = (Archive*)node->item;
       if (!isEmptyRing(archive->assoCaracs)) {
-	if (!serializeCatalogArchive(archive, &fd)) goto error;
+	if (!serializeCatalogArchive(archive, fd)) goto error;
       }
     }
-    cvsPrint(&fd, "\n");
   }
 
-  cvsPrint(&fd, "# Documents:\n\n");
+  fd->print(fd, "# Documents:\n\n");
   if (avl_count(self->documents)) {
     for(node = self->documents->head; node; node = node->next) {
       document = (Document*)node->item;
-      if (!serializeDocument(document, &fd)) goto error;
+      if (!serializeDocument(document, fd)) goto error;
     }
-    cvsPrint(&fd, "\n");
   }
 
   rc = TRUE;
  error:
-  if (!cvsCloseFile(&fd)) rc = FALSE;
+  if (!cvsClose(fd)) rc = FALSE;
   if (!logoutUser(uid)) rc = FALSE;
   if (!rc) {
-    logMemory(LOG_ERR, "%s", "serializeCatalogTree fails");
+    logMemory(LOG_ERR, "serializeCatalogTree fails");
   }
   return rc;
 }
@@ -1072,7 +1079,7 @@ addCarac(Collection* coll, char* label)
   rc = carac;
  error:
   if (!rc) {
-    logMemory(LOG_ERR, "%s", "addCarac fails");
+    logMemory(LOG_ERR, "addCarac fails");
     carac = destroyCarac(carac);
   }
   return rc;
@@ -1106,7 +1113,7 @@ delCarac(Collection* coll, Carac* self)
   rc = TRUE;
  error:
   if (!rc) {
-    logMemory(LOG_ERR, "%s", "delCarac fails");
+    logMemory(LOG_ERR, "delCarac fails");
   }
   return rc;
 }
@@ -1154,7 +1161,7 @@ getAssoCarac(Collection* coll, Carac* carac, CType type,
   }
 
   // look for assoCarac
-  while((rc = rgNext_r(ring, &curr)) != 0) {
+  while ((rc = rgNext_r(ring, &curr))) {
     if (carac == rc->carac && !strcmp(rc->value, value)) break;
   }
   
@@ -1218,7 +1225,7 @@ addAssoCarac(Collection* coll, Carac* carac, CType type,
   rc = asso;
  error:
   if (!rc) {
-    logMemory(LOG_ERR, "%s", "addAssoCarac fails");
+    logMemory(LOG_ERR, "addAssoCarac fails");
     asso = destroyAssoCarac(asso);
   }
   return rc;
@@ -1283,7 +1290,7 @@ addRole(Collection* coll, char* label)
   rc = role;
  error:
   if (!rc) {
-    logMemory(LOG_ERR, "%s", "addRole fails");
+    logMemory(LOG_ERR, "addRole fails");
     role = destroyRole(role);
   }
   return rc;
@@ -1308,7 +1315,7 @@ delRole(Collection* coll, Role* self)
   logMemory(LOG_DEBUG, "delRole %s", self->label);
 
   // delete related assossiations
-  while((aR = rgHead(self->assos)) != 0) {
+  while ((aR = rgHead(self->assos))) {
     if (!delAssoRole(coll, aR)) goto error;
   }
 
@@ -1323,7 +1330,7 @@ delRole(Collection* coll, Role* self)
   rc = TRUE;
  error:
   if (!rc) {
-    logMemory(LOG_ERR, "%s", "delRole fails");
+    logMemory(LOG_ERR, "delRole fails");
   }
   return rc;
 }
@@ -1352,7 +1359,7 @@ getAssoRole(Collection* coll,
 	  human->firstName, human->secondName, document->label);
 
   // look for assoRole
-  while((rc = rgNext_r(document->assoRoles, &curr)) != 0) {
+  while ((rc = rgNext_r(document->assoRoles, &curr))) {
     if (rc->human == human && rc->role == role) break;
   }
   
@@ -1405,7 +1412,7 @@ addAssoRole(Collection* coll,
   rc = asso;
  error:
   if (!rc) {
-    logMemory(LOG_ERR, "%s", "cannot add an assoRole");
+    logMemory(LOG_ERR, "cannot add an assoRole");
     if (asso) delAssoRole(coll, asso);
   }
   return rc;
@@ -1451,7 +1458,7 @@ delAssoRole(Collection* coll, AssoRole* self)
   rc = TRUE;
  error:
   if (!rc) {
-    logMemory(LOG_ERR, "%s", "delAssoRole fails");
+    logMemory(LOG_ERR, "delAssoRole fails");
   }
   return rc;
 }
@@ -1486,7 +1493,7 @@ int addHumanToCategory(Collection* coll, Human* human, Category* category)
   rc = TRUE;
  error:
   if (!rc) {
-    logMemory(LOG_ERR, "%s", "addHumanToCategory fails");
+    logMemory(LOG_ERR, "addHumanToCategory fails");
   }
   return rc;
 }
@@ -1524,7 +1531,7 @@ int delHumanToCategory(Collection* coll, Human* human, Category* category)
   rc = TRUE;
  error:
   if (!rc) {
-    logMemory(LOG_ERR, "%s", "delHumanToCategory fails");
+    logMemory(LOG_ERR, "delHumanToCategory fails");
   }
   return rc;
 }
@@ -1596,7 +1603,7 @@ addHuman(Collection* coll, char* firstName, char* secondName)
   rc = human;
  error:
   if (!rc) {
-    logMemory(LOG_ERR, "%s", "addHuman fails");
+    logMemory(LOG_ERR, "addHuman fails");
     human = destroyHuman(human);
   }	    
   return rc;
@@ -1624,12 +1631,12 @@ delHuman(Collection* coll, Human* self)
   logMemory(LOG_DEBUG, "delHuman %s-%s", self->firstName, self->secondName);
 
   // delete assoRole associations
-  while((aR = rgHead(self->assoRoles)) != 0)
+  while ((aR = rgHead(self->assoRoles)))
     if (!delAssoRole(coll, aR)) goto error;
 
   // delete human from categories rings
   curr = 0;
-  while((cat = rgNext_r(self->categories, &curr)) != 0) {
+  while ((cat = rgNext_r(self->categories, &curr))) {
     if ((curr2 = rgHaveItem(cat->humans, self))) {
       rgRemove_r(cat->humans, &curr2);
     }
@@ -1641,7 +1648,7 @@ delHuman(Collection* coll, Human* self)
   rc = TRUE;
  error:
   if (!rc) {
-    logMemory(LOG_ERR, "%s", "delHuman fails");
+    logMemory(LOG_ERR, "delHuman fails");
   }
   return rc;
 }
@@ -1678,7 +1685,7 @@ int addArchiveToDocument(Collection* coll,
   rc = TRUE;
  error:
   if (!rc) {
-    logMemory(LOG_ERR, "%s", "addArchiveToDocument fails");
+    logMemory(LOG_ERR, "addArchiveToDocument fails");
   }
   return rc;
 }
@@ -1718,7 +1725,7 @@ int delArchiveFromDocument(Collection* coll,
   rc = TRUE;
  error:
   if (!rc) {
-    logMemory(LOG_ERR, "%s", "delArchiveFromDocument fails");
+    logMemory(LOG_ERR, "delArchiveFromDocument fails");
   }
   return rc;
 }
@@ -1754,7 +1761,7 @@ int addDocumentToCategory(Collection* coll, Document* document,
   rc = TRUE;
  error:
   if (!rc) {
-    logMemory(LOG_ERR, "%s", "addDocumentToCategory fails");
+    logMemory(LOG_ERR, "addDocumentToCategory fails");
   }
   return rc;
 }
@@ -1793,7 +1800,7 @@ int delDocumentToCategory(Collection* coll, Document* document,
   rc = TRUE;
  error:
   if (!rc) {
-    logMemory(LOG_ERR, "%s", "delDocumentToCategory fails");
+    logMemory(LOG_ERR, "delDocumentToCategory fails");
   }
   return rc;
 }
@@ -1859,7 +1866,7 @@ addDocument(Collection* coll, char* label)
   rc = document;
  error:
   if (!rc) {
-    logMemory(LOG_ERR, "%s", "addDocument fails");
+    logMemory(LOG_ERR, "addDocument fails");
     document = destroyDocument(document);
   }
   return rc;
@@ -1889,13 +1896,13 @@ delDocument(Collection* coll, Document* self)
 
   // delete assoRole associations
   curr = 0;
-  while((aR = rgNext_r(self->assoRoles, &curr)) != 0) {
+  while ((aR = rgNext_r(self->assoRoles, &curr))) {
     if (!delAssoRole(coll, aR)) goto error;
   }
 
   // delete document from categories rings
   curr = curr2 = 0;
-  while((cat = rgNext_r(self->categories, &curr)) != 0) {
+  while ((cat = rgNext_r(self->categories, &curr))) {
     if ((curr2 = rgHaveItem(cat->documents, self))) {
       rgRemove_r(cat->documents, &curr2);
     }
@@ -1903,7 +1910,7 @@ delDocument(Collection* coll, Document* self)
 
   // delete document from archive rings
   curr = curr2 = 0;
-  while((arch = rgNext_r(self->archives, &curr)) != 0) {
+  while ((arch = rgNext_r(self->archives, &curr))) {
     if ((curr2 = rgHaveItem(arch->documents, self))) {
       rgRemove_r(arch->documents, &curr2);
     }
@@ -1915,7 +1922,7 @@ delDocument(Collection* coll, Document* self)
   rc = TRUE;
  error:
   if (!rc) {
-    logMemory(LOG_ERR, "%s", "delDocument fails");
+    logMemory(LOG_ERR, "delDocument fails");
   }
   return rc;
 }
@@ -1942,20 +1949,20 @@ delArchiveCatalog(Collection* coll, Archive* self)
 	  self->hash, (long long int)self->size);
 
   // delete assoCarac associations
-  while((aC = rgHead(self->assoCaracs)) != 0) {
+  while ((aC = rgHead(self->assoCaracs))) {
     rgRemove(self->assoCaracs);
     destroyAssoCarac(aC);
   }
 
   // delete from document rings
-  while((doc = rgHead(self->documents)) != 0) {
+  while ((doc = rgHead(self->documents))) {
     if (!delArchiveFromDocument(coll, self, doc)) goto error;
   }
 
   rc = TRUE;
  error:
   if (!rc) {
-    logMemory(LOG_ERR, "%s", "delArchiveCatalog fails");
+    logMemory(LOG_ERR, "delArchiveCatalog fails");
   }
   return rc;
 }
@@ -1991,7 +1998,7 @@ addCategoryLink(Collection* coll, Category* father, Category* child)
   rc = TRUE;
  error:
   if (!rc) {
-    logMemory(LOG_ERR, "%s", "addCategoryLink fails");
+    logMemory(LOG_ERR, "addCategoryLink fails");
   }
   return rc;
 }
@@ -2030,7 +2037,7 @@ delCategoryLink(Collection* coll, Category* father, Category* child)
   rc = TRUE;
  error:
   if (!rc) {
-    logMemory(LOG_ERR, "%s", "delCategoryLink fails");
+    logMemory(LOG_ERR, "delCategoryLink fails");
   }
   return rc;
 }
@@ -2054,7 +2061,7 @@ getCategory(Collection* coll, char* label)
   logMemory(LOG_DEBUG, "getCategory %s", label);
   
   // look for category
-  while((rc = rgNext_r(coll->catalogTree->categories, &curr)) 
+  while ((rc = rgNext_r(coll->catalogTree->categories, &curr)) 
 	!= 0)
     if (!strcmp(rc->label, label)) break;
   
@@ -2123,17 +2130,17 @@ delCategory(Collection* coll, Category* self)
   logMemory(LOG_DEBUG, "delCategory %s", self->label);
 
   // delete category from fathers ring
-  while((cat = rgHead(self->fathers)) != 0)
+  while ((cat = rgHead(self->fathers)))
     if (!delCategoryLink(coll, cat, self)) goto error;
 
   // delete category from childs ring  curr = 0;
-  while((cat = rgHead(self->childs)) != 0)
+  while ((cat = rgHead(self->childs)))
     if (!delCategoryLink(coll, self, cat)) goto error;
 
   // delete category from humans rings
   curr = 0;
   curr2 = 0;
-  while((hum = rgNext_r(self->humans, &curr)) != 0) {
+  while ((hum = rgNext_r(self->humans, &curr))) {
     if ((curr2 = rgHaveItem(hum->categories, self))) {
       rgRemove_r(hum->categories, &curr2);
     }
@@ -2142,7 +2149,7 @@ delCategory(Collection* coll, Category* self)
   // delete category from documents rings
   curr = 0;
   curr2 = 0;
-  while((doc = rgNext_r(self->documents, &curr)) != 0) {
+  while ((doc = rgNext_r(self->documents, &curr))) {
     if ((curr2 = rgHaveItem(doc->categories, self))) {
       rgRemove_r(doc->categories, &curr2);
     }
@@ -2159,7 +2166,7 @@ delCategory(Collection* coll, Category* self)
   rc = TRUE;
  error:
   if (!rc) {
-    logMemory(LOG_ERR, "%s", "delCategory fails");
+    logMemory(LOG_ERR, "delCategory fails");
   }
   return rc;
 }
@@ -2188,11 +2195,11 @@ diseaseCatalogTree(Collection* coll)
   logMemory(LOG_DEBUG, "diseaseCatalogTree %s", coll);
  
   // disease roles
-  while((role = rgHead(self->roles))) 
+  while ((role = rgHead(self->roles))) 
     if (!delRole(coll, role)) goto error;
 
  // diseases categories
-  while((category = rgHead(self->categories)))
+  while ((category = rgHead(self->categories)))
     if (!delCategory(coll, category)) goto error;
 
   // disease humans
@@ -2211,7 +2218,7 @@ diseaseCatalogTree(Collection* coll)
   }
 
   // disease caracs
-  while((carac = rgHead(self->caracs)))
+  while ((carac = rgHead(self->caracs)))
     if (!delCarac(coll, carac)) goto error;
 
   // try to disease archives
@@ -2220,109 +2227,11 @@ diseaseCatalogTree(Collection* coll)
   rc = TRUE;
  error:
   if (!rc) {
-    logMemory(LOG_ERR, "%s", "diseaseCatalogTree fails");
+    logMemory(LOG_ERR, "diseaseCatalogTree fails");
   }
   return rc;
 }
 
-/************************************************************************/
-
-#ifdef utMAIN
-#include "../misc/command.h"
-#include "utFunc.h"
-GLOBAL_STRUCT_DEF;
-
-/*=======================================================================
- * Function   : usage
- * Description: Print the usage.
- * Synopsis   : static void usage(char* programName)
- * Input      : programName = the name of the program; usually argv[0].
- * Output     : N/A
- =======================================================================*/
-static void 
-usage(char* programName)
-{
-  memoryUsage(programName);
-
-  memoryOptions();
-  //fprintf(stderr, "\t\t---\n");
-  return;
-}
-
-/*=======================================================================
- * Function   : main 
- * Author     : Nicolas ROCHE
- * modif      : 2012/05/01
- * Description: Unit test for confTree module.
- * Synopsis   : utconfTree
- * Input      : N/A
- * Output     : N/A
- =======================================================================*/
-int 
-main(int argc, char** argv)
-{
-  Collection* coll = 0;
-  // ---
-  int rc = 0;
-  int cOption = EOF;
-  char* programName = *argv;
-  char* options = MEMORY_SHORT_OPTIONS;
-  struct option longOptions[] = {
-    MEMORY_LONG_OPTIONS,
-    {0, 0, 0, 0}
-  };
-
-  // import mdtx environment
-  env.dryRun = FALSE;
-  env.debugMemory = TRUE;
-  getEnv(&env);
-
-  // parse the command line
-  while((cOption = getopt_long(argc, argv, options, longOptions, 0)) 
-	!= EOF) {
-    switch(cOption) {
-      
-      GET_MEMORY_OPTIONS; // generic options
-    }
-    if (rc) goto optError;
-  }
-
-  // export mdtx environment
-  if (!setEnv(programName, &env)) goto optError;
-
-  /************************************************************************/
-  if (!createExempleConfiguration()) goto error;
-  if (!(coll = getCollection("coll1"))) goto error;
-  if (!createExempleCatalogTree(coll)) goto error;
-  
-  // test serializing
-  if (!serializeCatalogTree(coll)) {
-    logMemory(LOG_ERR, "%s", "Error while serializing the catalog exemple");
-    goto error;
-  }
-
-  // test disease
-  if (!diseaseCatalogTree(coll)) goto error;
-  env.dryRun = TRUE;
-  if (!serializeCatalogTree(coll)) goto error;
-  if (coll->catalogTree->roles->nbItems != 0) goto error;
-  if (avl_count(coll->catalogTree->humans) != 0) goto error;
-  if (avl_count(coll->catalogTree->documents) != 0) goto error;
-  if (coll->catalogTree->categories->nbItems != 0) goto error;
-  if (coll->catalogTree->caracs->nbItems != 0) goto error;
-  /************************************************************************/
-
-  freeConfiguration();
-  rc = TRUE;
- error:
-  ENDINGS;
-  rc=!rc;
- optError:
-  exit(rc);
-}
-
-#endif // utMAIN
-
 /* Local Variables: */
 /* mode: c */
 /* mode: font-lock */
