@@ -1,9 +1,9 @@
 /*=======================================================================
- * Version: $Id: confTree.c,v 1.3 2015/06/03 14:03:38 nroche Exp $
+ * Version: $Id: confTree.c,v 1.15 2015/10/12 23:28:51 nroche Exp $
  * Project: mediaTeX
  * Module : configuration
  *
- * /etc configuration producer interface
+ * configuration producer interface
 
  MediaTex is an Electronic Records Management System
  Copyright (C) 2014 2015 Nicolas Roche
@@ -22,16 +22,7 @@
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  =======================================================================*/
 
-#include "../mediatex.h"
-#include "../misc/log.h"
-#include "../misc/command.h"
-#include "../misc/perm.h"
-#include "../misc/locks.h"
-#include "confTree.h"
-
-#include <dirent.h> // opendir
-#include <sys/types.h>
-#include <sys/stat.h>
+#include "mediatex-config.h"
 
 /*=======================================================================
  * Function   : cmpCollection
@@ -100,7 +91,7 @@ createCollection(void)
 
   return rc;
  error:
-  logMemory(LOG_ERR, "%s", "malloc: cannot create Collection");
+  logMemory(LOG_ERR, "malloc: cannot create Collection");
   return destroyCollection(rc);
 }
 
@@ -167,7 +158,7 @@ destroyCollection(Collection* self)
   
   // free the locks
   for (i=iCTLG; i<iCACH; ++i) {
-    if ((err = pthread_mutex_destroy(&self->mutex[i]) != 0)) {
+    if ((err = pthread_mutex_destroy(&self->mutex[i]))) {
       logMemory(LOG_INFO, "pthread_mutex_destroy[%i]: %s", i, strerror(err));
       goto error;
     }
@@ -191,7 +182,7 @@ expandCollection(Collection* self)
 {
   int rc = FALSE;
   Configuration* conf = 0;
-  char* urlPart = 0;
+  char urlPart[128];
   int i,j;
   char* dataV[] = {CONF_CATHFILE, CONF_SERVFILE, CONF_EXTRFILE, "/cgi"};
   char** dataP[] = {
@@ -209,7 +200,7 @@ expandCollection(Collection* self)
   if (isEmptyString(self->masterLabel) ||
       isEmptyString(self->label) ||
       isEmptyString(self->masterHost)) {
-    logMemory(LOG_ERR, "%s", 
+    logMemory(LOG_ERR, 
 	    "masterLabel, label and masterHost must be initialized");
     goto error;
   }
@@ -307,9 +298,14 @@ expandCollection(Collection* self)
     goto error;
 
   // urls
-  if (!(urlPart = createString("/~"))
-      || !(urlPart = catString(urlPart, self->user)))
-    goto error;
+  if (conf->wwwPort == 443) {
+    if (sprintf(urlPart, "/~%s", self->user) <= 0)
+      goto error;
+  }
+  else {
+    if (sprintf(urlPart, ":%i/~%s", conf->wwwPort, self->user) <= 0)
+      goto error;
+  }
 
   if (!(self->cacheUrl = createString("https://")) 
       || !(self->cacheUrl = catString(self->cacheUrl, conf->host))
@@ -344,16 +340,16 @@ expandCollection(Collection* self)
   mdtx = env.confLabel;
   user = self->user;
 
-  if (!checkDirectory(   self->homeDir,    user, mdtx, 0750)
-      || !checkDirectory(self->cacheDir,   mdtx, user, 02750)
-      || !checkDirectory(self->extractDir, mdtx, user, 02770)
-      || !checkDirectory(self->cvsDir,     mdtx, user, 02770)
+  if (!checkDirectoryPerm(   self->homeDir,    user, mdtx, 0750)
+      || !checkDirectoryPerm(self->cacheDir,   mdtx, user, 02750)
+      || !checkDirectoryPerm(self->extractDir, mdtx, user, 02770)
+      || !checkDirectoryPerm(self->cvsDir,     mdtx, user, 02770)
 
       /* mdtx was just been added to user group,
   	 so it need to reload its groups to check the above
   	 diretories */
-      || !checkDirectory(self->sshDir,     user, user, 0700)
-      || !checkDirectory(self->htmlDir,    mdtx, user, 02750)
+      || !checkDirectoryPerm(self->sshDir,     user, user, 0700)
+      || !checkDirectoryPerm(self->htmlDir,    mdtx, user, 02750)
       )
     goto error;
 
@@ -362,9 +358,8 @@ expandCollection(Collection* self)
   rc = TRUE;
  error:
   if (!rc) {
-    logMemory(LOG_ERR, "%s", "fails to expand collection");
+    logMemory(LOG_ERR, "fails to expand collection");
   }
-  urlPart = destroyString(urlPart);
   label = destroyString(label);
   return rc;
 }
@@ -387,7 +382,7 @@ populateCollection(Collection* self)
   if (self == 0) goto error;
   if (!(conf = getConfiguration())) goto error;
   if (!(self->memoryState & EXPANDED)) {
-    logMemory(LOG_ERR, "%s", "collection must be expanded first");
+    logMemory(LOG_ERR, "collection must be expanded first");
     goto error;
   }
   if (self->memoryState & POPULATED) {
@@ -408,7 +403,7 @@ populateCollection(Collection* self)
       (self->userKey = readPublicKey(self->sshRsaPublicKey))) goto next;
   if (!access(self->sshDsaPublicKey, F_OK) &&
       (self->userKey = readPublicKey(self->sshDsaPublicKey))) goto next;
-  logMemory(LOG_ERR, "%s", "fails to load the user public key");
+  logMemory(LOG_ERR, "fails to load the user public key");
   goto error;
 
  next:
@@ -505,7 +500,7 @@ serializeCollection(Collection* self, FILE* fd)
   rc = TRUE;
  error:
   if (!rc) {
-    logMemory(LOG_ERR, "%s", "error while serializing Collection");
+    logMemory(LOG_ERR, "error while serializing Collection");
   }
   return rc;
 }
@@ -527,10 +522,11 @@ createConfiguration(void)
   char* tmpDir = 0;
   char* pidDir = 0;
   char* label = 0;
+  int i = 0;
 
   if((conf = (Configuration*)malloc(sizeof(Configuration))) 
      == 0) {
-    logMemory(LOG_ERR, "%s", "malloc: cannot create Configuration");
+    logMemory(LOG_ERR, "malloc: cannot create Configuration");
     goto error;
   }
     
@@ -540,14 +536,28 @@ createConfiguration(void)
   if ((conf->gateways = createRing()) == 0) goto error;
   if ((conf->collections = createRing()) == 0) goto error;
   if ((conf->supports = createRing()) == 0) goto error;
-  
-  if (!(tmpDir = createString(CONF_TMPDIR))
-      || !(tmpDir = catString(tmpDir, DEFAULT_MDTXUSER)))
+
+  label = destroyString(label);
+  if (!(label = createString("/"))
+      || !(label = catString(label, env.confLabel)))
     goto error;
 
-  // push /tmp/ut-mdtx if needed
+  // prefix by "$PWD/tmp" on unit tests
   if (env.noRegression) {
-    if (!(pidDir = createString(tmpDir))
+    if (!(tmpDir = get_current_dir_name())) {
+      logMemory(LOG_ERR, "get_current_dir_name fails: %s", 
+		strerror(errno));
+      goto error;
+    }
+
+    remind(tmpDir);
+
+    // remove prefix up to "_build" on "make distcheck"
+    if (strstr(CONF_PREFIX, "_inst")) i = strlen(CONF_PREFIX);
+    //logMemory(LOG_NOTICE, "CONF_PREFIX=%s, i=%i", CONF_PREFIX, i);
+
+    if (!(tmpDir = catString(tmpDir, "/tmp"))
+	|| !(pidDir = createString(tmpDir))
 	|| !(conf->cvsRootDir = createString(tmpDir))
 	|| !(conf->homeDir = createString(tmpDir))
 	|| !(conf->scriptsDir = createString(tmpDir))
@@ -555,17 +565,12 @@ createConfiguration(void)
       goto error;
   }
 
-  label = destroyString(label);
-  if (!(label = createString("/"))
-      || !(label = catString(label, env.confLabel)))
-    goto error;
-
   // directories
-  if (!(pidDir = catString(pidDir, CONF_PIDDIR))
-      || !(conf->cvsRootDir = catString(conf->cvsRootDir, CONF_STATEDIR))
+  if (!(pidDir = catString(pidDir, CONF_PIDDIR+i))
+      || !(conf->cvsRootDir = catString(conf->cvsRootDir, CONF_STATEDIR+i))
       || !(conf->cvsRootDir = catString(conf->cvsRootDir, label))
-      || !(conf->scriptsDir = catString(conf->scriptsDir, CONF_SCRIPTS))
-      || !(conf->homeDir = catString(conf->homeDir, CONF_CACHEDIR))
+      || !(conf->scriptsDir = catString(conf->scriptsDir, CONF_SCRIPTS+i))
+      || !(conf->homeDir = catString(conf->homeDir, CONF_CACHEDIR+i))
       || !(conf->homeDir = catString(conf->homeDir, label))
       || !(conf->md5sumDir = createString(conf->homeDir))
       || !(conf->md5sumDir = catString(conf->md5sumDir, CONF_MD5SUMS))
@@ -577,7 +582,7 @@ createConfiguration(void)
       || !(conf->cvsDir = catString(conf->cvsDir, CONF_CVSCLT))
       || !(conf->mdtxCvsDir = createString(conf->cvsDir))
       || !(conf->mdtxCvsDir = catString(conf->mdtxCvsDir, label))
-      || !(conf->hostSshDir = catString(conf->hostSshDir, CONF_HOSTSSH)))
+      || !(conf->hostSshDir = catString(conf->hostSshDir, CONF_HOSTSSH+i)))
     goto error;
 
   // files
@@ -603,15 +608,17 @@ createConfiguration(void)
   conf->cacheTTL = DEFAULT_TTL_CACHE;
   conf->queryTTL = DEFAULT_TTL_QUERY;
   conf->checkTTL = DEFAULT_TTL_CHECK;
+  conf->fileTTL = DEFAULT_TTL_FILE;
   conf->scoreParam = defaultScoreParam;
   strncpy(conf->host, DEFAULT_HOST, MAX_SIZE_HOST);
   conf->sshPort = SSH_PORT;
+  conf->wwwPort = WWW_PORT;
   conf->mdtxPort = env.noRegression?TESTING_PORT:CONF_PORT;
 
   rc = conf;
  error:
   if (!rc) {
-    logMemory(LOG_ERR, "%s", "createConfiguration fails");
+    logMemory(LOG_ERR, "createConfiguration fails");
     conf = destroyConfiguration(conf);
   }
   tmpDir = destroyString(tmpDir);
@@ -634,7 +641,7 @@ destroyConfiguration(Configuration* self)
 {
   Configuration* rc = 0;
 
-  if(self != 0) {
+  if(self) {
 
     // directories
     self->cvsRootDir = destroyString(self->cvsRootDir);
@@ -658,9 +665,11 @@ destroyConfiguration(Configuration* self)
     self->host[0] = (char)0;
     self->mdtxPort = 0;
     self->sshPort = 0;
+    self->wwwPort = 0;
     self->cacheTTL = 0;
     self->queryTTL = 0;
     self->checkTTL = 0;
+    self->fileTTL = 0;
     self->hostKey = destroyString(self->hostKey);
 
     self->allNetworks = 
@@ -699,9 +708,9 @@ expandConfiguration()
 
   // defensive code
   if (!(conf = getConfiguration())) goto error;
-  logMemory(LOG_DEBUG, "%s", "expand configuration");
+  logMemory(LOG_DEBUG, "expand configuration");
   if (conf->memoryState & EXPANDED) {
-    logMemory(LOG_INFO, "%s", "configuration already expanded");
+    logMemory(LOG_INFO, "configuration already expanded");
     goto end;
   }
 
@@ -712,21 +721,21 @@ expandConfiguration()
     goto error;
 
   // check directories
-  if (!checkDirectory(jail,                "root", "root", 0755)
-      || !checkDirectory(conf->cvsRootDir,  mdtx,   meta,  0750)
-      || !checkDirectory(conf->homeDir,    "root", "root", 0755)
-      || !checkDirectory(conf->md5sumDir,   mdtx,   mdtx,  0750)
-      || !checkDirectory(conf->cacheDir,    mdtx,   meta,  0750)
-      || !checkDirectory(conf->extractDir,  mdtx,   meta,  0750)
-      || !checkDirectory(conf->cvsDir,      mdtx,   meta,  0750)
-      || !checkDirectory(conf->mdtxCvsDir,  mdtx,   mdtx,  02770)
-      || !checkDirectory(conf->hostSshDir, "root", "root", 0755)
+  if (!checkDirectoryPerm(jail,                "root", "root", 0755)
+      || !checkDirectoryPerm(conf->cvsRootDir,  mdtx,   meta,  0750)
+      || !checkDirectoryPerm(conf->homeDir,    "root", "root", 0755)
+      || !checkDirectoryPerm(conf->md5sumDir,   mdtx,   mdtx,  0750)
+      || !checkDirectoryPerm(conf->cacheDir,    mdtx,   meta,  0750)
+      || !checkDirectoryPerm(conf->extractDir,  mdtx,   meta,  0750)
+      || !checkDirectoryPerm(conf->cvsDir,      mdtx,   meta,  0750)
+      || !checkDirectoryPerm(conf->mdtxCvsDir,  mdtx,   mdtx,  02770)
+      || !checkDirectoryPerm(conf->hostSshDir, "root", "root", 0755)
       )
     goto error;
 
   // expand collections
-  if (conf->collections != 0) {
-    while((coll = rgNext_r(conf->collections, &curr)) != 0) {
+  if (conf->collections) {
+    while ((coll = rgNext_r(conf->collections, &curr))) {
       if (!expandCollection(coll)) goto error;
     }
   }
@@ -736,7 +745,7 @@ expandConfiguration()
   rc = TRUE;
  error:
   if (!rc) {
-    logMemory(LOG_ERR, "%s", "fails to expand configuration");
+    logMemory(LOG_ERR, "fails to expand configuration");
   }
   jail = destroyString(jail);
   meta = destroyString(meta);
@@ -759,21 +768,21 @@ populateConfiguration()
   // defensive code
   if (!(conf = getConfiguration())) goto error;
   /* if (!(conf->memoryState & EXPANDED)) { */
-  /*   logMemory(LOG_ERR, "%s", "configuration must be expanded first"); */
+  /*   logMemory(LOG_ERR, "configuration must be expanded first"); */
   /*   goto error; */
   /* } */
   if (conf->memoryState & POPULATED) {
-    logMemory(LOG_INFO, "%s", "configuration already populated");
+    logMemory(LOG_INFO, "configuration already populated");
     goto end;
   }
-  logMemory(LOG_DEBUG, "%s", "populate configuration");
+  logMemory(LOG_DEBUG, "populate configuration");
 
   // load the host public key
   if (!access(conf->sshRsaPublicKey, F_OK) && 
       (conf->hostKey = readPublicKey(conf->sshRsaPublicKey))) goto next;
   if (!access(conf->sshDsaPublicKey, F_OK) &&
       (conf->hostKey = readPublicKey(conf->sshDsaPublicKey))) goto next;
-  logMemory(LOG_ERR, "%s", "fails to load the host public key");
+  logMemory(LOG_ERR, "fails to load the host public key");
   goto error;
 
  next:
@@ -783,7 +792,7 @@ populateConfiguration()
   rc = TRUE;
  error:
   if (!rc) {
-    logMemory(LOG_ERR, "%s", "fails to populate Configuration");
+    logMemory(LOG_ERR, "fails to populate Configuration");
   }
   return(rc);
 }
@@ -810,22 +819,22 @@ serializeConfiguration(Configuration* self)
   int uid = getuid();
 
   if(self == 0) goto error;
-  logMemory(LOG_DEBUG, "%s", "serialize the configuration");
+  logMemory(LOG_DEBUG, "serialize the configuration");
 
   // we need the host key to be loaded so as to be able
   // to print the host fingerprint !
   if (!(self->memoryState & POPULATED)) {
-    logMemory(LOG_ERR, "%s", "configuration must be populated first");
+    logMemory(LOG_ERR, "configuration must be populated first");
     goto error;
   }
 
   if (!becomeUser(env.confLabel, TRUE)) goto error;
 
   // output file
-  if (env.dryRun == FALSE) path = self->confFile;
+  if (!env.dryRun) path = self->confFile;
   logMemory(LOG_INFO, "Serializing configuration into: %s", 
 	  path?path:"stdout");
-  if (path != 0 && *path != (char)0) {
+  if (path && *path != (char)0) {
     if ((fd = fopen(path, "w")) == 0) {
       logMemory(LOG_ERR, "fopen %s fails: %s", path, strerror(errno));
       fd = stdout;
@@ -852,6 +861,9 @@ serializeConfiguration(Configuration* self)
   fprintf(fd, "\n# port: listening port for SSHd\n");
   fprintf(fd, "%-10s %i\n", "sshPort", self->sshPort);
 
+  fprintf(fd, "\n# port: listening port for Apache\n");
+  fprintf(fd, "%-10s %i\n", "wwwPort", self->wwwPort);
+  
   fprintf(fd, "\n# networks: networks the host belongs to\n");
   fprintf(fd, "%-10s ", "networks");
   if (isEmptyRing(self->networks)) {
@@ -889,6 +901,7 @@ serializeConfiguration(Configuration* self)
 
   fprintf(fd, "\n# local support parameters\n");
   printLapsTime(fd,  "%-10s", "checkTTL", self->checkTTL);
+  printLapsTime(fd,  "%-10s", "fileTTL", self->fileTTL);
   printLapsTime(fd, "%-10s", "suppTTL",  self->scoreParam.suppTTL);
   fprintf(fd, "%-10s %.2f\n", "maxScore", self->scoreParam.maxScore);
   fprintf(fd, "%-10s %.2f\n", "badScore", self->scoreParam.badScore);
@@ -935,7 +948,7 @@ getConfiguration(void)
 
   if(env.confTree == 0) {
     if ((env.confTree = createConfiguration()) == 0) {
-      logMemory(LOG_ERR, "%s", "cannot malloc default collection");
+      logMemory(LOG_ERR, "cannot malloc default collection");
       goto error;
     }
   }
@@ -943,7 +956,7 @@ getConfiguration(void)
   rc = env.confTree;
  error:
   if (!rc) {
-    logMemory(LOG_ERR, "%s", "fails to get configuration");
+    logMemory(LOG_ERR, "fails to get configuration");
   }
   return rc;
 }
@@ -958,7 +971,7 @@ getConfiguration(void)
 void
 freeConfiguration(void)
 {
-  logMemory(LOG_INFO, "%s", "free configuration");
+  logMemory(LOG_INFO, "free configuration");
   env.confTree = destroyConfiguration(env.confTree);
 }
 
@@ -981,7 +994,7 @@ getCollection(char *label)
   logMemory(LOG_DEBUG, "getCollection %s", label);
 
   // look for collection
-  while((rc = rgNext_r(conf->collections, &curr)) != 0)
+  while ((rc = rgNext_r(conf->collections, &curr)))
     if (!strncmp(rc->label, label, MAX_SIZE_COLL)) break;
 
  error:
@@ -1019,7 +1032,7 @@ addCollection(char *label)
   rc = coll;
  error:
   if (!rc) {
-    logMemory(LOG_ERR, "%s", "fails to add a collection");
+    logMemory(LOG_ERR, "fails to add a collection");
     if (coll) destroyCollection(coll);
   }
   return rc;
@@ -1046,7 +1059,7 @@ delCollection(Collection* self)
 
   // delete support associations
   curr = 0;
-  while((supp = rgHead(self->supports))) {
+  while ((supp = rgHead(self->supports))) {
     if (!delSupportFromCollection(supp, self)) goto error;
   }
 
@@ -1060,7 +1073,7 @@ delCollection(Collection* self)
   rc = TRUE;
  error:
   if (!rc) {
-    logMemory(LOG_ERR, "%s", "delCollection fails");
+    logMemory(LOG_ERR, "delCollection fails");
   }
   return rc;
 }
@@ -1084,7 +1097,7 @@ getNetwork(char *label)
   logMemory(LOG_DEBUG, "getNetwork %s", label);
 
   // look for network
-  while((rc = rgNext_r(conf->allNetworks, &curr)) != 0)
+  while ((rc = rgNext_r(conf->allNetworks, &curr)))
     if (!strcmp(rc, label)) break;
 
  error:
@@ -1120,7 +1133,7 @@ addNetwork(char *label)
   rc = net;
  error:
   if (!rc) {
-    logMemory(LOG_ERR, "%s", "fails to add a network");
+    logMemory(LOG_ERR, "fails to add a network");
     if (net) destroyString(net);
   }
   return rc;
@@ -1140,7 +1153,7 @@ addNetworkToRing(RG* ring, char *label)
   int rc = FALSE;
   char* string = 0;
 
-  logMemory(LOG_DEBUG, "%s", "addNetworkToRing");
+  logMemory(LOG_DEBUG, "addNetworkToRing");
 
   if (!(string = addNetwork(label))) goto error;
   if (!rgHaveItem(ring, string)) {
@@ -1150,7 +1163,7 @@ addNetworkToRing(RG* ring, char *label)
   rc = TRUE;
  error:
   if (!rc) {
-    logMemory(LOG_ERR, "%s", "fails to add a network to a ring");
+    logMemory(LOG_ERR, "fails to add a network to a ring");
   }
   return rc;
 }
@@ -1184,7 +1197,7 @@ int addSupportToCollection(Support* support, Collection* coll)
   rc = TRUE;
  error:
   if (!rc) {
-    logMemory(LOG_ERR, "%s", "addSupportToCollection fails");
+    logMemory(LOG_ERR, "addSupportToCollection fails");
   }
   return rc;
 }
@@ -1221,7 +1234,7 @@ int delSupportFromCollection(Support* support, Collection* coll)
   rc = TRUE;
  error:
   if (!rc) {
-    logMemory(LOG_ERR, "%s", "delSupportFromCollection fails");
+    logMemory(LOG_ERR, "delSupportFromCollection fails");
   }
   return rc;
 }
@@ -1242,7 +1255,7 @@ getLocalHost(Collection* coll)
 
   checkCollection(coll);
   if (!(conf = getConfiguration())) goto error;
-  logMemory(LOG_DEBUG, "%s", "getLocalHost");
+  logMemory(LOG_DEBUG, "getLocalHost");
 
   // assert we have the localhost server object
   if (!coll->localhost) {
@@ -1258,143 +1271,11 @@ getLocalHost(Collection* coll)
   rc = coll->localhost;
  error:
   if (rc == 0) {
-    logMemory(LOG_ERR, "%s", "fails to get localhost server object");
+    logMemory(LOG_ERR, "fails to get localhost server object");
   }
   return rc;
 }
 
-/************************************************************************/
-
-#ifdef utMAIN
-#include "../misc/command.h"
-#include "utFunc.h"
-GLOBAL_STRUCT_DEF;
-
-/*=======================================================================
- * Function   : usage
- * Description: Print the usage.
- * Synopsis   : static void usage(char* programName)
- * Input      : programName = the name of the program; usually argv[0].
- * Output     : N/A
- =======================================================================*/
-static void 
-usage(char* programName)
-{
-  memoryUsage(programName);
-
-  memoryOptions();
-  //fprintf(stderr, "\t\t---\n");
-  return;
-}
-
-/*=======================================================================
- * Function   : main 
- * Author     : Nicolas ROCHE
- * modif      : 2012/05/01
- * Description: Unit test for confTree module.
- * Synopsis   : ./utconfTree -i
- * Input      : N/A
- * Output     : create the mediatex.conf file
- =======================================================================*/
-int 
-main(int argc, char** argv)
-{
-  Configuration* conf = 0;
-  Collection* coll = 0;
-  char* string = 0;
-  RGIT* curr = 0;
-  // ---
-  int rc = 0;
-  int cOption = EOF;
-  char* programName = *argv;
-  char* options = MEMORY_SHORT_OPTIONS;
-  struct option longOptions[] = {
-    MEMORY_LONG_OPTIONS,
-    {0, 0, 0, 0}
-  };
-       
-  // import mdtx environment
-  env.dryRun = FALSE;
-  env.debugMemory = TRUE;
-  getEnv(&env);
-
-  // parse the command line
-  while((cOption = getopt_long(argc, argv, options, longOptions, 0)) 
-	!= EOF) {
-    switch(cOption) {
-      
-      GET_MEMORY_OPTIONS; // generic options
-    }
-    if (rc) goto optError;
-  }
-
-  // export mdtx environment
-  if (!setEnv(programName, &env)) goto optError;
-
-  /************************************************************************/
-  // test building and serializing
-  if (!createExempleConfiguration()) goto error;  
-  if (!serializeConfiguration(getConfiguration())) goto error;
-
-  // test accessing the tree
-  if (getCollection("coll0")) goto error;
-  if (!(coll = getCollection("coll1"))) goto error;
-  if (!(coll = getCollection("coll2"))) goto error;
-  if (!(coll = getCollection("coll3"))) goto error;
-  if (!addCollection("coll4")) goto error;
-  freeConfiguration();
-
-  // Create 2 other configurations for later unit-tests based on
-  // network topologie (utNotify: not used, utExtract: todo). 
-  // So we have:
-  // - mdtx1 on "www" network (default)
-  // - mdtx2 is the gateway for private1 network
-  // - mdtx3 on "private1" network
-
-  // Each server share together 3 collections.
-  // Here, the collection's server keys are the sames for each server
-  // on every collection. This should never append, but remains possible.
-
-  env.confLabel="mdtx2";
-  if (!createExempleConfiguration()) goto error;
-  if (!(conf = getConfiguration())) goto error;
-  if (!(string = addNetwork("www"))) goto error;
-  if (!rgInsert(conf->networks, string)) goto error;
-  if (!(string = addNetwork("private1"))) goto error;
-  if (!rgInsert(conf->networks, string)) goto error;
-  if (!rgInsert(conf->gateways, string)) goto error;
-
-  // overwrite gateway on collection settings
-  if (!(coll = getCollection("coll3"))) goto error;
-  if (!(string = addNetwork("private2"))) goto error;
-  if ((curr = rgHaveItem(coll->gateways, string))) {
-    rgRemove_r(coll->gateways, &curr);
-  }
-  if (!(string = addNetwork("none"))) goto error;
-  if (!rgInsert(coll->gateways, string)) goto error;
-
-  if (!serializeConfiguration(getConfiguration())) goto error;
-  freeConfiguration();
-
-  env.confLabel="mdtx3";
-  if (!createExempleConfiguration()) goto error;
-  if (!(conf = getConfiguration())) goto error;
-  if (!(string = addNetwork("private1"))) goto error;
-  if (!rgInsert(conf->networks, string)) goto error;
-  if (!serializeConfiguration(getConfiguration())) goto error;
-  /************************************************************************/
-
-  rc = TRUE;
- error:
-  freeConfiguration();
-  ENDINGS;
-  rc=!rc;
- optError:
-  exit(rc);
-}
-
-#endif // utMAIN
-
 /* Local Variables: */
 /* mode: c */
 /* mode: font-lock */
