@@ -1,5 +1,5 @@
 /*=======================================================================
- * Version: $Id: confTree.h,v 1.4 2015/06/03 14:03:39 nroche Exp $
+ * Version: $Id: confTree.h,v 1.9 2015/09/21 01:01:51 nroche Exp $
  * Project: MediaTeX
  * Module: etcConf
  *
@@ -27,30 +27,10 @@
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  =======================================================================*/
 
-#ifndef MEMORY_ADMCONF_H
-#define MEMORY_ADMCONF_H 1
+#ifndef MDTX_MEMORY_CONF_H
+#define MDTX_MEMORY_CONF_H 1
 
-#include "../mediatex.h"
-#include "../misc/alloc.h"
-#include "../misc/log.h"
-#include "../misc/locks.h"
-#include "../misc/keys.h"
-#include "../misc/setuid.h"
-#include "../misc/perm.h"
-#include "ardsm.h"
-#include "strdsm.h"
-#include "archive.h"
-#include "cvsPrint.h"
-#include "recordTree.h"
-#include "supportTree.h"
-#include "serverTree.h"
-#include "extractTree.h"
-#include "catalogTree.h"
-#include "cacheTree.h"
-
-#include <string.h> // memset
-#include <avl.h>
-#include <pthread.h>
+#include "mediatex-types.h"
 
 // Object status :
 // EXPANDED: path allocated and checked
@@ -59,8 +39,9 @@ typedef enum {EXPANDED=1, POPULATED=2} MemoryState;
 
 // Load/Save data files
 // Note: LOADED FileState implies POPULATED MemoryState
-typedef enum {iCONF=0, iSUPP=1} ConfFileIdx;
-typedef enum {CONF=1, SUPP=2} ConfFile;
+#undef CONF // openssl/ossl_typ.h:165:24: typedef struct conf_st CONF;
+typedef enum {iCFG=0, iSUPP=1} ConfFileIdx;
+typedef enum {CFG=1, SUPP=2} ConfFile;
 typedef enum {iCTLG=0, iEXTR=1, iSERV=2, iCACH=3} CollFileIdx;
 typedef enum {CTLG=1, EXTR=2, SERV=4, CACH=8} CollFile;
 typedef enum {DISEASED=0, LOADED=1, MODIFIED=2} FileState;
@@ -92,12 +73,12 @@ struct Collection {
   RG *supports; // ring of support (Support*)
 
   /* ... expanded data ... */
-  char  *user;                   // ie: "MDTX-COLL""
-  char  *masterUser;             // ie: "MDTX2-COLL"
+  char  *user;       // ie: "MDTX-COLL""
+  char  *masterUser; // ie: "MDTX2-COLL"
 
   /* shared parameters (used by servers.txt) */
   char *userKey;   // ~/.ssh/id_dsa.pub content
-  char  userFingerPrint[MAX_SIZE_HASH+1];
+  char  userFingerPrint[MAX_SIZE_MD5+1];
 
   /* -load/save */
   MemoryState memoryState;
@@ -137,10 +118,10 @@ struct Collection {
   char *cacheUrl;   // base url to cache repository
 
   /* -parsed trees: */  
-  ServerTree*   serverTree;
-  ExtractTree*  extractTree;
-  CatalogTree*  catalogTree;  
-  CacheTree*    cacheTree;
+  ServerTree*  serverTree;
+  ExtractTree* extractTree;
+  CatalogTree* catalogTree;  
+  CacheTree*   cacheTree;
 };
 
 struct Configuration {
@@ -151,6 +132,7 @@ struct Configuration {
   char  host[MAX_SIZE_HOST+1]; // hostname
   int   mdtxPort;  // listening port for incoming requests (daemon)
   int   sshPort;   // listening port for incoming ssh queries
+  int   wwwPort;   // listening port for incoming web queries
   off_t uploadRate; // average upload rate
 
   /* default values for collections */
@@ -159,12 +141,13 @@ struct Configuration {
   time_t queryTTL;  // time to live for queries in memory
 
   /* local parameters */
-  time_t checkTTL;  // time period between 2 md5 checks on support
+  time_t checkTTL;  // time period between 2 md5 checks on supports
+  time_t fileTTL;   // time period between 2 md5 checks on support files
   ScoreParam scoreParam; // parameter use to compute score
 
   /* keys (not parsed from the configuration file) */
   char* hostKey;  // /etc/ssh/ssh_host_dsa.pub content
-  char  hostFingerPrint[MAX_SIZE_HASH+1];
+  char  hostFingerPrint[MAX_SIZE_MD5+1];
 
   /* computed paths */
   char* cvsRootDir;
@@ -229,7 +212,7 @@ char* addNetwork(char *label);
 int addNetworkToRing(RG* ring, char *label);
 Server* getLocalHost(Collection* coll);
 
-#endif /* MEMORY_ADMCONF_H */
+#endif /* MDTX_MEMORY_CONF_H */
 
 /* Local Variables: */
 /* mode: c */
