@@ -1,7 +1,7 @@
 /*=======================================================================
- * Version: $Id: cvsPrint.c,v 1.3 2015/06/03 14:03:39 nroche Exp $
+ * Version: $Id: cvsPrint.c,v 1.10 2015/09/21 01:01:51 nroche Exp $
  * Project: MediaTeX
- * Module : md5sumTree
+ * Module : cvs print
  *
  * cvs files producer interface
 
@@ -22,25 +22,21 @@
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  =======================================================================*/
 
-#include "../mediatex.h"
-#include "../misc/log.h"
-#include "../misc/locks.h"
-#include "strdsm.h"
-#include "cvsPrint.h"
+#include "mediatex-config.h"
 
 /*=======================================================================
- * Function   : cvsCloseFile
- * Description: 
- * Synopsis   : 
- * Input      : 
+ * Function   : cvsClose
+ * Description: Cut a big file into several ones
+ * Synopsis   : int cvsClose(CvsFile* fd)
+ * Input      : CvsFile* fd
  * Output     : TRUE on success
  =======================================================================*/
-int cvsCloseFile(CvsFile* fd)
+int cvsClose(CvsFile* fd)
 {
   int rc = FALSE;
 
   if (!fd) goto error;
-  logMemory(LOG_DEBUG, "cvsCloseFile %s", fd->path);
+  logMemory(LOG_DEBUG, "cvsClose %s", fd->path);
   if (!(fd->fd)) goto end;
 
   fprintf(fd->fd, "\n# Local Variables:\n"
@@ -64,19 +60,19 @@ int cvsCloseFile(CvsFile* fd)
   rc = TRUE;
 error:
   if (!rc) {
-    logMemory(LOG_ERR, "%s", "cvsCloseFile fails");
+    logMemory(LOG_ERR, "cvsClose fails");
   }
   return rc;
 }
 
 /*=======================================================================
- * Function   : cvsOpenFile
- * Description: 
- * Synopsis   : 
- * Input      : 
+ * Function   : cvsCutOpen
+ * Description: Cut a big file into several ones
+ * Synopsis   : int cvsCutOpen(CvsFile* fd)
+ * Input      : CvsFile* fd
  * Output     : TRUE on success
  =======================================================================*/
-int cvsOpenFile(CvsFile* fd)
+int cvsCutOpen(CvsFile* fd)
 {
   int rc = FALSE;
   char* path = 0;
@@ -85,18 +81,18 @@ int cvsOpenFile(CvsFile* fd)
 
   if (!fd) goto error;
   if (isEmptyString(fd->path)) goto error; 
-  logMemory(LOG_DEBUG, "cvsOpenFile %s %i", fd->path, fd->nb);
+  logMemory(LOG_DEBUG, "cvsCutOpen %s %i", fd->path, fd->nb);
 
   l = strlen(fd->path);
   if (!(path = createString(fd->path))
-      || !(path = catString(path, "00.txt"))) goto error;
+      || !(path = catString(path, "000.txt"))) goto error;
 
-  // first call: unlink existing files
+  // first call: empty existing files
   if (fd->nb == 0 && fd->fd != stdout) {
     // empty part files
     do {
-      if (!sprintf(path+l, "%02i.txt", i)) goto error;
-      if (access(path, R_OK) != 0) break;
+      if (!sprintf(path+l, "%03i.txt", i)) goto error;
+      if (access(path, R_OK)) break;
       if (!env.dryRun) {
 	logMemory(LOG_INFO, "empty %s", path);
 	if ((fd->fd = fopen(path, "w")) == 0) {
@@ -110,10 +106,10 @@ int cvsOpenFile(CvsFile* fd)
 	fd->fd = 0;
       }
     }
-    while (++i < 100);
+    while (++i < 1000);
     
     // unlink last addon
-    if (!sprintf(path+l, "%s", "NN.txt")) goto error;
+    if (!sprintf(path+l, "%s", "NNN.txt")) goto error;
     if (access(path, R_OK) == 0) {
       logMemory(LOG_INFO, "unlink %s", path);
       if (unlink(path) == -1) {
@@ -125,11 +121,11 @@ int cvsOpenFile(CvsFile* fd)
 
   // not first call
   if (fd->nb > 0) {
-    if (!cvsCloseFile(fd)) goto error;
+    if (!cvsClose(fd)) goto error;
   }
 
   // open file
-  if (!sprintf(path+l, "%02i.txt", fd->nb)) goto error;
+  if (!sprintf(path+l, "%03i.txt", fd->nb)) goto error;
   logMemory(LOG_INFO, "serialize into %s", path);
   if (fd->fd == stdout) goto end;
   if ((fd->fd = fopen(path, "w")) == 0) {
@@ -144,20 +140,61 @@ int cvsOpenFile(CvsFile* fd)
   rc = TRUE;
 error:
   if (!rc) {
-    logMemory(LOG_ERR, "%s", "cvsOpenFile fails");
+    logMemory(LOG_ERR, "cvsCutOpen fails");
   }
   path = destroyString(path);
   return rc;
 }
 
 /*=======================================================================
- * Function   : cvsPrint
- * Description: 
- * Synopsis   : 
- * Input      : 
+ * Function   : cvsCatOpen
+ * Description: Open metadata file for concatenation
+ * Synopsis   : int cvsCatOpen(CvsFile* fd)
+ * Input      : CvsFile* fd
  * Output     : TRUE on success
  =======================================================================*/
-int cvsPrint(CvsFile* fd, const char* format, ...)
+int cvsCatOpen(CvsFile* fd)
+{
+  int rc = FALSE;
+  char* path = 0;
+
+  if (!fd) goto error;
+  if (isEmptyString(fd->path)) goto error; 
+  logMemory(LOG_DEBUG, "cvsCatOpen %s %i", fd->path, fd->nb);
+
+  if (!(path = createString(fd->path))
+      || !(path = catString(path, "NNN.txt"))) goto error;
+
+  // open file
+  logMemory(LOG_INFO, "serialize into %s", path);
+  if (fd->fd == stdout) goto end;
+  if ((fd->fd = fopen(path, "a")) == 0) {
+    logMemory(LOG_ERR, "fdopen %s fails: %s", path, strerror(errno));
+    goto error;
+  }
+
+  if (!lock(fileno(fd->fd), F_WRLCK)) goto error;
+ end:
+  ++fd->nb;
+  rc = TRUE;
+error:
+  if (!rc) {
+    logMemory(LOG_ERR, "cvsCatOpen fails");
+  }
+  path = destroyString(path);
+  return rc;
+}
+
+/*=======================================================================
+ * Function   : cvsCutPrint
+ * Description: Cut a big file into several ones
+ * Synopsis   : int cvsCutPrint(CvsFile* fd, const char* format, ...)
+ * Input      : CvsFile* fd
+ *              const char* format : as printf
+ *              ... : as printf
+ * Output     : TRUE on success
+ =======================================================================*/
+int cvsCutPrint(CvsFile* fd, const char* format, ...)
 {
   int rc = FALSE;
   va_list args;
@@ -165,7 +202,7 @@ int cvsPrint(CvsFile* fd, const char* format, ...)
   if (!fd) goto error;
 
   if (fd->doCut && fd->offset > env.cvsprintMax) {
-    if (!cvsOpenFile(fd)) goto error;
+    if (!cvsCutOpen(fd)) goto error;
   }
 
   va_start(args, format);
@@ -174,97 +211,38 @@ int cvsPrint(CvsFile* fd, const char* format, ...)
   rc = TRUE;
 error:
   if (!rc) {
-    logMemory(LOG_ERR, "%s", "cvsPrint fails");
+    logMemory(LOG_ERR, "cvsCutPrint fails");
   }
   return rc;
 }
 
-/************************************************************************/
-
-#ifdef utMAIN
-#include "../misc/command.h"
-GLOBAL_STRUCT_DEF;
-
 /*=======================================================================
- * Function   : usage
- * Description: Print the usage.
- * Synopsis   : static void usage(char* programName)
- * Input      : programName = the name of the program; usually argv[0].
- * Output     : N/A
+ * Function   : cvsCatPrint
+ * Description: fprintf like
+ * Synopsis   : int cvsCatPrint(CvsFile* fd, const char* format, ...)
+ * Input      : CvsFile* fd
+ *              const char* format : as printf
+ *              ... : as printf
+ * Output     : TRUE on success
  =======================================================================*/
-static void 
-usage(char* programName)
+int cvsCatPrint(CvsFile* fd, const char* format, ...)
 {
-  memoryUsage(programName);
+  int rc = FALSE;
+  va_list args;
 
-  memoryOptions();
-  //fprintf(stderr, "\t\t---\n");
-  return;
-}
-
-/*=======================================================================
- * Function   : main 
- * Author     : Nicolas ROCHE
- * modif      : 2012/05/01
- * Description: Unit test for confTree module.
- * Synopsis   : utconfTree
- * Input      : N/A
- * Output     : N/A
- =======================================================================*/
-int 
-main(int argc, char** argv)
-{
-  CvsFile fd = {"filename", 0, stdout, FALSE, 0};
-  // ---
-  int rc = 0;
-  int cOption = EOF;
-  char* programName = *argv;
-  char* options = MEMORY_SHORT_OPTIONS;
-  struct option longOptions[] = {
-    MEMORY_LONG_OPTIONS,
-    {0, 0, 0, 0}
-  };
-
-  // import mdtx environment
-  env.dryRun = FALSE;
-  env.debugMemory = TRUE;
-  getEnv(&env);
-
-  // parse the command line
-  while((cOption = getopt_long(argc, argv, options, longOptions, 0)) 
-	!= EOF) {
-    switch(cOption) {
-      
-      GET_MEMORY_OPTIONS; // generic options
-    }
-    if (rc) goto optError;
-  }
-
-  // export mdtx environment
-  if (!setEnv(programName, &env)) goto optError;
-
-  /************************************************************************/
-  env.cvsprintMax = 10;
-  if (!cvsOpenFile(&fd)) goto error;
-  fd.doCut = FALSE;
-  if (!cvsPrint(&fd, "%s", "the lines should not be cut\n")) goto error;
-  if (!cvsPrint(&fd, "%s", "put 2nd line in same file\n")) goto error;
-  fd.doCut = TRUE;
-  if (!cvsPrint(&fd, "%s", "3rd line ...\n")) goto error;
-  if (!cvsPrint(&fd, "%s", "4rth line ...\n")) goto error;
-  if (!cvsCloseFile(&fd)) goto error;
-  /************************************************************************/
+  if (!fd) goto error;
 
+  va_start(args, format);
+  vfprintf(fd->fd, format, args);
+  va_end(args);
   rc = TRUE;
- error:
-  ENDINGS;
-  rc=!rc;
- optError:
-  exit(rc);
+error:
+  if (!rc) {
+    logMemory(LOG_ERR, "cvsCatPrint fails");
+  }
+  return rc;
 }
 
-#endif // utMAIN
-
 /* Local Variables: */
 /* mode: c */
 /* mode: font-lock */
