@@ -1,7 +1,7 @@
 /*=======================================================================
- * Version: $Id: cvsPrint.h,v 1.3 2015/06/03 14:03:39 nroche Exp $
+ * Version: $Id: cvsPrint.h,v 1.5 2015/08/11 18:14:24 nroche Exp $
  * Project: MediaTeX
- * Module : archive tree
+ * Module : cvs print
  *
  * cvs files producer interface
 
@@ -22,25 +22,33 @@
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 =======================================================================*/
 
-#ifndef MEMORY_ADMCVSPRINT_H
-#define MEMORY_ADMCVSPRINT_H 1
+#ifndef MISC_MEMORY_CVSPRINT_H
+#define MISC_MEMORY_CVSPRINT_H 1
 
 /* API */
 
-typedef struct CvsFile
+typedef struct CvsFile CvsFile;
+
+struct CvsFile
 {
   char     *path;
   int      nb;
   FILE     *fd;
   int      doCut;
   long int offset;
-} CvsFile;
+  int (*open)(CvsFile*);
+  int (*print)(CvsFile*, const char*, ...);
+};
 
-int cvsOpenFile(CvsFile* fd);
-int cvsPrint(CvsFile* fd, const char* format, ...);
-int cvsCloseFile(CvsFile* fd);
+int cvsCutOpen(CvsFile* fd);
+int cvsCutPrint(CvsFile* fd, const char* format, ...);
 
-#endif /* MEMORY_CVSPRINT_H */
+int cvsCatOpen(CvsFile* fd);
+int cvsCatPrint(CvsFile* fd, const char* format, ...);
+
+int cvsClose(CvsFile* fd);
+
+#endif /* MISC_MEMORY_CVSPRINT_H */
 
 /* Local Variables: */
 /* mode: c */
