@@ -1,5 +1,5 @@
 /*=======================================================================
- * Version: $Id: extractTree.c,v 1.3 2015/06/03 14:03:39 nroche Exp $
+ * Version: $Id: extractTree.c,v 1.14 2015/09/21 01:01:51 nroche Exp $
  * Project: MediaTeX
  * Module : extraction tree
  *
@@ -22,12 +22,7 @@
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  =======================================================================*/
 
-#include "../mediatex.h"
-#include "../misc/log.h"
-#include "strdsm.h"
-#include "extractTree.h"
-
-#include <avl.h>
+#include "mediatex-config.h"
 
 
 /*=======================================================================
@@ -43,7 +38,8 @@ strEType(EType self)
 {
 
   static char* typeLabels[ETYPE_MAX] =
-    {"UNDEF", "REC", "ISO", "CAT", 
+    {"UNDEF", 
+     "INC", "ISO", "CAT", 
      "TGZ", "TBZ", "AFIO",
      "TAR", "CPIO", 
      "GZIP", "BZIP",
@@ -68,7 +64,7 @@ strEType(EType self)
 EType
 getEType(char* label)
 {
-  if (!strcasecmp(label, "REC")) return REC;
+  if (!strcasecmp(label, "INC")) return INC;
   if (!strcasecmp(label, "ISO")) return ISO;
   if (!strcasecmp(label, "CAT")) return CAT;
   if (!strcasecmp(label, "TGZ")) return TGZ;
@@ -103,7 +99,7 @@ createFromAsso(void)
  
   return rc;  
  error:  
-  logMemory(LOG_ERR, "%s", "malloc: cannot create FromAsso");
+  logMemory(LOG_ERR, "malloc: cannot create FromAsso");
   return destroyFromAsso(rc);
 }
 
@@ -168,11 +164,11 @@ createContainer(void)
 	avl_alloc_tree(cmpFromAssoAvl, 
 		       (avl_freeitem_t)destroyFromAsso)))
     goto error;
-  rc->score = -1; // still not comuted
+  rc->score = -1; // still not computed
 
   return rc;  
  error:  
-  logMemory(LOG_ERR, "%s", "malloc: cannot create Container");
+  logMemory(LOG_ERR, "malloc: cannot create Container");
   return destroyContainer(rc);
 }
 
@@ -204,13 +200,15 @@ destroyContainer(Container* self)
 /*=======================================================================
  * Function   : serializeContainer
  * Description: Serialize a Container.
- * Synopsis   : int serializeContainer(Container* self, CvsFile* fd)
- * Input      : Container* self : what to serialize
+ * Synopsis   : int serializeContainer(Collection* coll, 
+ *                                     Container* self, CvsFile* fd)
+ * Input      : Collection* coll
+ *              Container* self : what to serialize
  *              CvsFile* fd : where to serialize
  * Output     : TRUE on success
  =======================================================================*/
 int 
-serializeContainer(Container* self, CvsFile* fd)
+serializeContainer(Collection* coll, Container* self, CvsFile* fd)
 {
   int rc = FALSE;
   FromAsso* asso = 0;
@@ -218,31 +216,36 @@ serializeContainer(Container* self, CvsFile* fd)
   AVLNode *node = 0;
 
   if(self == 0) {
-    logMemory(LOG_INFO, "%s", "cannot serialize empty Container");
+    logMemory(LOG_INFO, "cannot serialize empty Container");
     goto error;
   }
 
-  cvsPrint(fd, "\n(%s\n", strEType(self->type));
+  fd->print(fd, "\n(%s\n", strEType(self->type));
   fd->doCut = FALSE;
  
-  rgRewind(self->parents);
-  if ((archive = rgNext(self->parents)) == 0) goto error;
-  do {
-    if (!serializeExtractRecord(archive, fd)) goto error;
-    cvsPrint(fd, "\n");
-  }  while ((archive = rgNext(self->parents)) != 0);
+  // serialise parents (only INC container doesn't have parent)
+  if (self->type != INC) {
+    rgRewind(self->parents);
+    if ((archive = rgNext(self->parents)) == 0) goto error;
+    do {
+      if (!serializeExtractRecord(archive, fd)) goto error;
+      fd->print(fd, "\n");
+    }  while ((archive = rgNext(self->parents)));
+  }
 
+  // serialize childs
   if (avl_count(self->childs) > 0) {
-    cvsPrint(fd, "=>\n");
+    fd->print(fd, "=>\n");
 
     for(node = self->childs->head; node; node = node->next) {
       asso = node->item;
+      if (self->type == INC && !isIncoming(coll, asso->archive)) continue;
       if (!serializeExtractRecord(asso->archive, fd)) goto error;
-      cvsPrint(fd, "\t%s\n", asso->path);
+      fd->print(fd, "\t%s\n", asso->path);
     }
   }
 
-  cvsPrint(fd, ")\n");
+  fd->print(fd, ")\n");
   fd->doCut = TRUE;
   ++env.progBar.cur;
   rc = TRUE;
@@ -268,8 +271,13 @@ cmpContainerAvl(const void *p1, const void *p2)
   Container* v2 = (Container*)p2;
 
   rc = v1->type - v2->type;
-  if (!rc) rc = cmpArchive(&v1->parent, &v2->parent);
 
+  // manage INC container (which has no parent)
+  if (!v1->parent && !v2->parent) return 0;
+  if (!v1->parent) return -1;
+  if (!v2->parent) return +1;
+
+  if (!rc) rc = cmpArchive(&v1->parent, &v2->parent);
   return rc;
 }
 
@@ -288,11 +296,11 @@ serializeExtractRecord(Archive* self, CvsFile* fd)
   int rc = FALSE;
 
   if (self == 0) {
-    logMemory(LOG_WARNING, "%s", "do not serialize empty record"); 
+    logMemory(LOG_WARNING, "do not serialize empty record"); 
     goto error;
   }
 
-  cvsPrint(fd, "%s:%lli", self->hash, (long long int)self->size);
+  fd->print(fd, "%s:%lli", self->hash, (long long int)self->size);
   rc = TRUE;
  error:
   return rc;
@@ -318,11 +326,16 @@ createExtractTree(void)
 	avl_alloc_tree(cmpContainerAvl, 
 		       (avl_freeitem_t)destroyContainer)))
     goto error;
+
+  // special INC container for newly uploaded files
+  if (!(rc->incoming = createContainer())) goto error;
+  rc->incoming->type = INC;
+
   rc->score = -1;
 
   return rc;
  error:
-  logMemory(LOG_ERR, "%s", "malloc: cannot create ExtractTree");
+  logMemory(LOG_ERR, "malloc: cannot create ExtractTree");
   return destroyExtractTree(rc);
 }
 
@@ -340,6 +353,8 @@ destroyExtractTree(ExtractTree* self)
   if (!self) goto error;
 
   avl_free_tree(self->containers);
+  self->incoming = destroyContainer(self->incoming);
+
   free(self);
 
  error:
@@ -350,15 +365,17 @@ destroyExtractTree(ExtractTree* self)
 /*=======================================================================
  * Function   : serializeExtractTree 
  * Description: Serialize the extraction metadata
- * Synopsis   : int serializeExtractTree(Collection* coll)
+ * Synopsis   : int serializeExtractTree(Collection* coll, CvsFile* fd)
  * Input      : Collection* coll = what to serialize
+ *              CvsFile* fd = serializer object:
+ *              - fd = {0, 0, 0, FALSE, 0, cvsCutOpen, cvsCutPrint};
+ *              - fd = {0, 0, 0, FALSE, 0, cvsCatOpen, cvsCatPrint};
  * Output     : TRUE on success
  =======================================================================*/
 int 
-serializeExtractTree(Collection* coll)
+serializeExtractTree(Collection* coll, CvsFile* fd)
 { 
   int rc = FALSE;
-  CvsFile fd = {0, 0, 0, FALSE, 0};
   ExtractTree* self = 0;
   Container* container = 0;
   AVLNode *node = 0;
@@ -368,35 +385,47 @@ serializeExtractTree(Collection* coll)
   if (!(self = coll->extractTree)) goto error;
   logMemory(LOG_DEBUG, "serialize %s extract tree", coll->label);
 
+  if (!fd) goto error;
+  fd->nb = 0;
+  fd->fd = 0;
+  fd->doCut = FALSE;
+  fd->offset = 0;
+
   // we neeed to use the cvs collection directory
   if ((!coll->memoryState & EXPANDED)) {
-    logMemory(LOG_ERR, "%s", "collection must be expanded first");
+    logMemory(LOG_ERR, "collection must be expanded first");
     goto error;
   }
 
   if (!becomeUser(coll->user, TRUE)) goto error;
 
   // output file
-  if (env.dryRun) fd.fd = stdout;
-  fd.path = coll->extractDB;
-  if (!cvsOpenFile(&fd)) goto error;
+  if (env.dryRun) fd->fd = stdout;
+  fd->path = coll->extractDB;
+  if (!fd->open(fd)) goto error;
 
-  cvsPrint(&fd, "# MediaTeX extraction metadata: %s\n", coll->label);
-  //cvsPrint(&fd, "# Version: $" "Id" "$\n");
+  fd->print(fd, "# MediaTeX extraction metadata: %s\n", coll->label);
+  //fd->print(fd, "# Version: $" "Id" "$\n");
 
+  // serialize INC container if not empty
+  if (avl_count(self->incoming->childs) > 0) {
+    if (!serializeContainer(coll, self->incoming, fd)) goto error;
+  }
+
+  // serialize all other containers
   if (avl_count(self->containers)) {
     for(node = self->containers->head; node; node = node->next) {
       container = node->item;
-      if (!serializeContainer(container, &fd)) goto error;
+      if (!serializeContainer(coll, container, fd)) goto error;
     }
   }
  
   rc = TRUE;
  error:
-  if (!cvsCloseFile(&fd)) rc = FALSE;
+  if (!cvsClose(fd)) rc = FALSE;
   if (!logoutUser(uid)) rc = FALSE;
   if (!rc) {
-    logMemory(LOG_ERR, "%s", "serializeExtractTree fails");
+    logMemory(LOG_ERR, "serializeExtractTree fails");
   }
   return rc;
 }
@@ -420,16 +449,23 @@ addFromArchive(Collection* coll, Container* container, Archive* archive)
   checkCollection(coll);
   if (!container || !archive) goto error;
   logMemory(LOG_DEBUG, "addFromArchive %s/%s:%lli -> %s:%lli",
-	  strEType(container->type), container->parent->hash,
-	  (long long int)container->parent->size,
-	  archive->hash, (long long int)archive->size);
+	    strEType(container->type), 
+	    container->type == INC?"-":container->parent->hash,
+	    container->type == INC?0:
+	    (long long int)container->parent->size,
+	    archive->hash, (long long int)archive->size);
 
+  if (container->type == INC) {
+    logMemory(LOG_ERR, 
+	      "INC container cannot have parent");
+    goto error;
+  }
+  
   if (container->parents->nbItems == 0) goto next;
   switch (container->type) {
-  case REC:
   case ISO:
-    logMemory(LOG_ERR, "%s", 
-	    "REC and ISO containers must only comes from one archive");
+    logMemory(LOG_ERR, 
+	    "ISO containers must only comes from one archive");
     goto error;
   case TGZ:
   case TBZ:
@@ -437,12 +473,12 @@ addFromArchive(Collection* coll, Container* container, Archive* archive)
   case TAR:
   case CPIO:
   case ZIP:
-    logMemory(LOG_ERR, "%s", 
+    logMemory(LOG_ERR, 
 	    "multi-volume archive is only implemented for RAR container");
     goto error;
   case GZIP:
   case BZIP:
-    logMemory(LOG_ERR, "%s", 
+    logMemory(LOG_ERR, 
 	    "compression only container must only comes from one archive");
     goto error;
   default:
@@ -452,14 +488,17 @@ addFromArchive(Collection* coll, Container* container, Archive* archive)
 
   // add archive to container's parents ring
   if (rgHaveItem(container->parents, archive)) {
-    logMemory(LOG_ERR, "%s", "parent already added to the container");
+    logMemory(LOG_ERR, "parent already added to the container");
     goto error;
   }
   if (!rgInsert(container->parents, archive)) goto error;
 
   // link container to archive
   if (archive->toContainer) {
-    logMemory(LOG_ERR, "%s", "archive already comes from another container");
+    logMemory(LOG_ERR, "archive already comes from %s/%s:%lli container",
+	      strEType(archive->toContainer->type),
+	      archive->toContainer->parent->hash, 
+	      (long long int)archive->toContainer->parent->size);
     goto error;
   }
   archive->toContainer = container;
@@ -467,7 +506,7 @@ addFromArchive(Collection* coll, Container* container, Archive* archive)
   rc = TRUE;
  error:
   if (!rc) {
-    logMemory(LOG_ERR, "%s", "addFromArchive fails");
+    logMemory(LOG_ERR, "addFromArchive fails");
     if (container && archive) delFromArchive(coll, container, archive);
   }
   return rc;
@@ -475,7 +514,7 @@ addFromArchive(Collection* coll, Container* container, Archive* archive)
 
 /*=======================================================================
  * Function   : delFromArchive
- * Description: Del an archive prents to a container
+ * Description: Del an archive parent from a container
  * Synopsis   : int getFromArchive(Collection* coll, 
  *                               Container* container, Archive* archive);
  * Input      : Collection* coll : where to del
@@ -493,9 +532,11 @@ delFromArchive(Collection* coll, Container* container, Archive* archive)
   checkCollection(coll);
   if (!container || !archive) goto error;
   logMemory(LOG_DEBUG, "delFromArchive %s/%s:%lli -> %s:%lli",
-	  strEType(container->type), container->parent->hash, 
-	  (long long int)container->parent->size,
-	  archive->hash, (long long int)archive->size);
+	    strEType(container->type), 
+	    container->type == INC?"-":container->parent->hash,
+	    container->type == INC?0:
+	    (long long int)container->parent->size,
+	    archive->hash, (long long int)archive->size);
 
   // del archive to container's parents ring
   if ((curr = rgHaveItem(container->parents, archive))) {
@@ -513,7 +554,7 @@ delFromArchive(Collection* coll, Container* container, Archive* archive)
   rc = TRUE;
  error:
   if (!rc) {
-    logMemory(LOG_ERR, "%s", "delFromArchive fails");
+    logMemory(LOG_ERR, "delFromArchive fails");
   }
   return rc;
 }
@@ -538,45 +579,85 @@ addFromAsso(Collection* coll, Archive* archive, Container* container,
   FromAsso* rc = 0;
   FromAsso* asso = 0;
   char* string = 0;
-  
+  struct tm date;
+  time_t time = 0;
+
   checkCollection(coll);
   if (!container || !archive) goto error;
   logMemory(LOG_DEBUG, "addFromAsso %s:%lli -> %s/%s:%lli",
-	  archive->hash, (long long int)archive->size,
-	  strEType(container->type), container->parent->hash,
-	  (long long int)container->parent->size);
+	    archive->hash, (long long int)archive->size,
+	    strEType(container->type), 
+	    container->type == INC?"-":container->parent->hash,
+	    container->type == INC?0:
+	    (long long int)container->parent->size);
 
   switch (container->type) {
-  case REC:
-    logMemory(LOG_ERR, "%s", 
-	    "REC containers must not contains archive");
-    goto error;
   case GZIP:
   case BZIP:
     if (avl_count(container->childs) > 0) {
-      logMemory(LOG_ERR, "%s", 
+      logMemory(LOG_ERR, 
 	      "compression only container must only provides one archive");
       goto error;
+    }    
+    break;
+
+  case INC:
+    // having 1 inc asso and 1 normal asso => remove the inc asso
+    if (archive->fromContainers->nbItems > 0) {
+      logMemory(LOG_NOTICE, "remove %s:%lli archive from incomings", 
+		archive->hash, (long long int)archive->size);
+      asso = archive->fromContainers->head->it;
+      goto end;
     }
+
+    if (sscanf(path, "%d-%d-%d,%d:%d:%d",
+	       &date.tm_year, &date.tm_mon, &date.tm_mday,
+	       &date.tm_hour, &date.tm_min, &date.tm_sec)
+	!= 6) {
+      logCommon(LOG_ERR, "sscanf: error parsing date %s", path);
+      goto error;
+    }
+
+    date.tm_year -= 1900; // from GNU/Linux burning date
+    date.tm_mon -= 1;     // month are managed from 0 to 11 
+    date.tm_isdst = -1;   // no information available about spring date
+    if ((time = mktime(&date)) == -1) goto error;
+
+    // having 2 incoming asso we take the oldest date
+    if (!archive->uploadTime || archive->uploadTime > time) {
+      archive->uploadTime = time;
+    }
+
+    break;
   default:
+    // having 1 inc asso and 1 normal asso => remove the inc asso
+    if (archive->uploadTime) {
+      logMemory(LOG_NOTICE, "remove %s:%lli archive from incomings", 
+		archive->hash, (long long int)archive->size);
+      archive->uploadTime = 0;
+    }
     break;
   }
 
-  // add new one
+  // add new content
   if (!(string = createString(path))) goto error;
   if (!(asso = createFromAsso())) goto error;
   asso->archive = archive;
   asso->container = container;
   asso->path = string;
 
-  if (!rgInsert(archive->fromContainers, asso)) goto error;
+  // incomings do not provides extraction path
+  if (container->type != INC) {
+    if (!rgInsert(archive->fromContainers, asso)) goto error;
+  }
   if (!avl_insert(container->childs, asso)) goto error;
 
+ end:
   rc = asso;
  error:
   if (!rc) {
-    logMemory(LOG_ERR, "%s", "addFromAsso fails");
-    if (asso) delFromAsso(coll, asso, TRUE);
+    logMemory(LOG_ERR, "addFromAsso fails");
+    if (asso) delFromAsso(coll, asso);
   }
   return rc;
 }
@@ -587,11 +668,10 @@ addFromAsso(Collection* coll, Archive* archive, Container* container,
  * Synopsis   : void delFromAsso(Collection* coll, FromAsso* self)
  * Input      : Collection* coll: where to del
  *              FromAsso* self: association to del
- *              int doUnlinkContainer: FALSE if job done by delContainer
  * Output     : TRUE on success
  =======================================================================*/
 int
-delFromAsso(Collection* coll, FromAsso* self, int doUnlinkContainer)
+delFromAsso(Collection* coll, FromAsso* self)
 {
   int rc = FALSE;
   RGIT* curr = 0;
@@ -599,24 +679,30 @@ delFromAsso(Collection* coll, FromAsso* self, int doUnlinkContainer)
   checkCollection(coll);
   if (!self) goto error;
   logMemory(LOG_DEBUG, "delFromAsso %s:%lli -> %s/%s:%lli",
-	  self->archive->hash, (long long int)self->archive->size,
-	  strEType(self->container->type), self->container->parent->hash,
-	  (long long int)self->container->parent->size);
+	    self->archive->hash, (long long int)self->archive->size,
+	    strEType(self->container->type), 
+	    self->container->type == INC?"-":self->container->parent->hash,
+	    self->container->type == INC?0:
+	    (long long int)self->container->parent->size);
 
-  // delete asso from archive
-  if ((curr = rgHaveItem(self->archive->fromContainers, self))) {
-    rgRemove_r(self->archive->fromContainers, &curr);
+  // incomings do not provides extraction path
+  if (self->container->type == INC) {
+    self->archive->uploadTime = 0;
+  }
+  else {
+    // delete asso from archive
+    if ((curr = rgHaveItem(self->archive->fromContainers, self))) {
+      rgRemove_r(self->archive->fromContainers, &curr);
+    }
   }
 
   // delete asso from container and free the fromAsso
-  if (doUnlinkContainer) {
-    avl_delete(self->container->childs, self);
-  }
+  avl_delete(self->container->childs, self);
     
   rc = TRUE;
  error:
   if (!rc) {
-    logMemory(LOG_ERR, "%s", "delFromAsso fails");
+    logMemory(LOG_ERR, "delFromAsso fails");
   }
   return rc;
 }
@@ -656,9 +742,11 @@ getContainer(Collection* coll, EType type, Archive* parent)
 /*=======================================================================
  * Function   : addContainer
  * Description: Add a new extraction container
- * Synopsis   : Container* addContainer(Collection* coll, EType type)
+ * Synopsis   : Container* addContainer(Collection* coll, EType type,
+                           Archive* parent)
  * Input      : Collection* coll : where to add
  *              EType type : type of the new container
+ *              Archive* parent : first parent
  * Output     : Container* : the container we have just add
  =======================================================================*/
 Container*
@@ -671,9 +759,14 @@ addContainer(Collection* coll, EType type, Archive* parent)
   checkArchive(parent);
   logMemory(LOG_DEBUG, "addContainer %s", strEType(type));
 
+  if (type == INC) {
+    logMemory(LOG_ERR, "INC container always exists and cannot be add");
+    goto error;
+  }
+
   // already there
   if ((container = getContainer(coll, type, parent))) {
-    logMemory(LOG_ERR, "%s", "container already there");
+    logMemory(LOG_ERR, "container already there");
     goto error;
   }
 
@@ -687,7 +780,7 @@ addContainer(Collection* coll, EType type, Archive* parent)
   rc = container;
  error:
   if (!rc) {
-    logMemory(LOG_ERR, "%s", "addContainer fails");
+    logMemory(LOG_ERR, "addContainer fails");
     container = destroyContainer(container);
   }
   return rc;
@@ -712,21 +805,23 @@ delContainer(Collection* coll, Container* self)
   checkCollection(coll);
   if (!self) goto error;
   logMemory(LOG_DEBUG, "delContainer %s/%s:%lli", 
-	  strEType(self->type), self->parent->hash,
-	  (long long int)self->parent->size);
+	    strEType(self->type), 
+	    self->type == INC?"-":self->parent->hash,
+	    self->type == INC?0:
+	    (long long int)self->parent->size);
 
   // delete content associations to archives
-  for(node = self->childs->head; node; node = node->next) {
-    if (!delFromAsso(coll, node->item, FALSE)) goto error;
+  while ((node = self->childs->head)) {
+    if (!delFromAsso(coll, node->item)) goto error;
   }
 
   // delete container link with archives
-  while((arch = rgHead(self->parents))) {
+  while ((arch = rgHead(self->parents))) {
     arch->toContainer = 0;
-    rgDelete(self->parents);
+    rgRemove(self->parents);
   }
 
-  // delete container from catalog tree and free it
+  // delete container from extract tree and free it
   avl_delete(coll->extractTree->containers, self);
 
   rc = TRUE;
@@ -752,116 +847,24 @@ diseaseExtractTree(Collection* coll)
   logMemory(LOG_DEBUG, "diseaseExtractTree %s", coll);
 
   // diseases containers
+  if (!delContainer(coll, coll->extractTree->incoming)) goto error;
   while ((node = coll->extractTree->containers->head))
     if (!delContainer(coll, node->item)) goto error;
 
   // force scores to be re-computed next
   coll->extractTree->score = -1;
 
+  // try to disease archives
+  if (!diseaseArchives(coll)) goto error;
+
   rc = TRUE;
  error:
   if (!rc) {
-    logMemory(LOG_ERR, "%s", "diseaseExtractTree fails");
+    logMemory(LOG_ERR, "diseaseExtractTree fails");
   }
   return rc;
 }
 
-
-/************************************************************************/
-
-#ifdef utMAIN
-#include "../misc/command.h"
-#include "utFunc.h"
-GLOBAL_STRUCT_DEF;
-
-
-/*=======================================================================
- * Function   : usage
- * Description: Print the usage.
- * Synopsis   : static void usage(char* programName)
- * Input      : programName = the name of the program; usually argv[0].
- * Output     : N/A
- =======================================================================*/
-static void 
-usage(char* programName)
-{
-  memoryUsage(programName);
-
-  memoryOptions();
-  //fprintf(stderr, "\t\t---\n");
-  return;
-}
-
-/*=======================================================================
- * Function   : main 
- * Author     : Nicolas ROCHE
- * modif      : 2012/05/01
- * Description: Unit test for confTree module.
- * Synopsis   : utconfTree
- * Input      : N/A
- * Output     : N/A
- =======================================================================*/
-int 
-main(int argc, char** argv)
-{
-  Collection* coll = 0;
-  // ---
-  int rc = 0;
-  int cOption = EOF;
-  char* programName = *argv;
-  char* options = MEMORY_SHORT_OPTIONS;
-  struct option longOptions[] = {
-    MEMORY_LONG_OPTIONS,
-    {0, 0, 0, 0}
-  };
-
-  // import mdtx environment
-  env.dryRun = FALSE;
-  env.debugMemory = TRUE;
-  getEnv(&env);
-
-  // parse the command line
-  while((cOption = getopt_long(argc, argv, options, longOptions, 0)) 
-	!= EOF) {
-    switch(cOption) {
-      
-      GET_MEMORY_OPTIONS; // generic options
-    }
-    if (rc) goto optError;
-  }
-
-  // export mdtx environment
-  if (!setEnv(programName, &env)) goto optError;
-
-  /************************************************************************/
-  if (!createExempleConfiguration()) goto error;
-  if (!(coll = getCollection("coll1"))) goto error;
-  if (!createExempleExtractTree(coll)) goto error;
-  
-  // test serializing
-  if (!serializeExtractTree(coll)) {
-    logMemory(LOG_ERR, "%s", "Error while serializing the extract exemple");
-    goto error;
-  }
-  
-  // test disease
-  if (!diseaseExtractTree(coll)) goto error;
-  env.dryRun = TRUE;
-  if (!serializeExtractTree(coll)) goto error;
-  if (avl_count(coll->extractTree->containers) != 0) goto error;
-  /************************************************************************/
-
-  freeConfiguration();
-  rc = TRUE;
- error:
-  ENDINGS;
-  rc=!rc;
- optError:
-  exit(rc);
-}
-
-#endif // utMAIN
-
 /* Local Variables: */
 /* mode: c */
 /* mode: font-lock */
