@@ -1,5 +1,5 @@
 /*=======================================================================
- * Version: $Id: extractTree.h,v 1.3 2015/06/03 14:03:39 nroche Exp $
+ * Version: $Id: extractTree.h,v 1.9 2015/09/23 19:10:20 nroche Exp $
  * Project: MediaTeX
  * Module : extraction tree
  *
@@ -22,21 +22,25 @@
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 =======================================================================*/
 
-#ifndef MEMORY_ADMEXTRACT_H
-#define MEMORY_ADMEXTRACT_H 1
+#ifndef MDTX_MEMORY_EXTRACT_H
+#define MDTX_MEMORY_EXTRACT_H 1
 
-#include "confTree.h"
+#include "mediatex-types.h"
 
-typedef enum {UNDEF=0, REC, ISO, 
-	      CAT,                   // generic way to do multi-volume
-	      TGZ, TBZ, AFIO,        // GNU/Linux agregation + compression
-	      TAR, CPIO,             // GNU/Linux agregation only
-	      GZIP, BZIP,            // GNU/Linux compression only  
-	      ZIP, RAR,              // windows agregation + compression
+// Container types
+typedef enum {UNDEF=0, 
+	      INC,             // for uploads not already burned
+	      ISO,             // CD image
+	      CAT,             // generic way to do multi-volume
+	      TGZ, TBZ, AFIO,  // GNU/Linux agregation + compression
+	      TAR, CPIO,       // GNU/Linux agregation only
+	      GZIP, BZIP,      // GNU/Linux compression only  
+	      ZIP, RAR,        // windows agregation + compression
 	      ETYPE_MAX} EType;
+
 // note: native multi-volume is only managed for rar archives
 //       (this should be done later for the others too)
-//       however, split provide a generic way to do that for all
+//       however, split/cat provide a generic way to do that for all
 
 // Record from container association
 struct FromAsso {
@@ -47,23 +51,23 @@ struct FromAsso {
 
 struct Container {
   // the 2 entries bellow are the primary key
-  EType    type;               // container type: IMG, CAT, TGZ, ISO...
-  Archive* parent;             // same as the first entry in bellow ring
+  EType    type;         // container type: IMG, CAT, TGZ, ISO...
+  Archive* parent;       // same as the first entry in bellow ring
 
-  RG*      parents;            // ex: RAR source files (Archives)
-  AVLTree* childs;             // ex: RAR target files (FromAsso)
+  RG*      parents;      // ex: RAR source files (Archives)
+  AVLTree* childs;       // ex: RAR target files (FromAsso)
 
-  float    score;              // use by mdtx-make
+  float    score;        // use by mdtx-make
+  int      incInherency; // is a new incoming (even by inherency)
 };
 
 struct ExtractTree {
   AVLTree* containers;
+  Container* incoming;   // special container with no parent
 
   float score;           // global score for the collection
-  int   maxNodeNumber;   // use to set id to containers
 };
 
-
 char* strEType(EType self);
 EType getEType(char* label);
 
@@ -74,13 +78,13 @@ int cmpFromAssoAvl(const void *p1, const void *p2);
 Container* createContainer(void);
 Container* destroyContainer(Container* self);
 int cmpContainerAvl(const void *p1, const void *p2);
-int serializeContainer(Container* self, CvsFile* fd);
+int serializeContainer(Collection* coll, Container* self, CvsFile* fd);
 
 int serializeExtractRecord(Archive* self, CvsFile* fd);
 
 ExtractTree* createExtractTree(void);
 ExtractTree* destroyExtractTree(ExtractTree* self);
-int serializeExtractTree(Collection* coll);
+int serializeExtractTree(Collection* coll, CvsFile* fd);
 
 /* API */
 
@@ -91,14 +95,14 @@ int delFromArchive(Collection* coll, Container* container,
 
 FromAsso* addFromAsso(Collection* coll, Archive* archive, 
 		      Container* container, char* path);
-int delFromAsso(Collection* coll, FromAsso* self, int doUnlinkContainer);
+int delFromAsso(Collection* coll, FromAsso* self);
 
 Container* addContainer(Collection* coll, EType type, Archive* parent);
 int delContainer(Collection* coll, Container* self);
 
 int diseaseExtractTree(Collection* coll);
 
-#endif /* MEMORY_ADMEXTRACT_H */
+#endif /* MDTX_MEMORY_EXTRACT_H */
 
 /* Local Variables: */
 /* mode: c */
