@@ -1,5 +1,5 @@
 /*=======================================================================
- * Version: $Id: recordTree.c,v 1.3 2015/06/03 14:03:39 nroche Exp $
+ * Version: $Id: recordTree.c,v 1.17 2015/10/04 22:15:50 nroche Exp $
  * Project: MediaTeX
  * Module : recordTree
  *
@@ -26,21 +26,7 @@
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  =======================================================================*/
 
-#include "../mediatex.h"
-#include "../misc/log.h"
-#include "../misc/address.h"
-#include "../misc/perm.h"
-#include "recordTree.h"
-
-#include <string.h> // memset
-
-#include <sys/socket.h> // inet_ntoa
-#include <netinet/in.h>
-#include <arpa/inet.h>
-
-#include <sys/types.h> // open
-#include <sys/stat.h>
-#include <fcntl.h>
+#include "mediatex-config.h"
 
 /*=======================================================================
  * Function   : cmpRecordQuick
@@ -90,14 +76,11 @@ cmpRecord(const void *p1, const void *p2)
   if (!rc) rc = cmpArchive(&a1->archive, &a2->archive);
   if (!rc) rc = cmpServer(&a1->server, &a2->server);
 
-  // dont sort on REMOVE flag!
-  //if (!rc) rc = (a1->type & 0x3) - (a2->type & 0x3); 
-  
   // do sort en REMOVE flag!
   if (!rc) rc = a1->type - a2->type; 
 
   if (!rc) {
-    // extra should not but may be 0
+    // extra should not but may be null
     if (!isEmptyString(a1->extra) && !isEmptyString(a2->extra))
       rc = strcmp(a1->extra, a2->extra);
     if (isEmptyString(a1->extra) && !isEmptyString(a2->extra))
@@ -136,7 +119,7 @@ cmpRecordSize(const void *p1, const void *p2)
   if (!rc) rc = (a1->type & 0x3) - (a2->type & 0x3); 
 
   if (!rc) {
-    // extra should not but may be 0
+    // extra should not but may be null
     if ((a1->type & 0x3) == DEMAND) {
       if (!isEmptyString(a1->extra) && !isEmptyString(a2->extra))
 	rc = strcmp(a1->extra, a2->extra);
@@ -169,7 +152,7 @@ createRecord(void)
   memset(rc, 0, sizeof(Record));
   return rc;
  error:
-  logMemory(LOG_ERR, "%s", "malloc: cannot create Record");
+  logMemory(LOG_ERR, "malloc: cannot create Record");
   return rc;
 }
 
@@ -201,46 +184,51 @@ destroyRecord(Record* self)
   return(rc);
 }
 
-/* /\*======================================================================= */
-/*  * Function   : copyRecord */
-/*  * Description: Copy a source configuration into a destination */
-/*  *              configuration. */
-/*  * Synopsis   : Record* copyRecord(Record* destination, Record* source) */
-/*  * Input      : Record* destination */
-/*  *              Record* source */
-/*  * Output     : Record* destination */
-/*  =======================================================================*\/ */
-/* Record*  */
-/* copyRecord(Record* destination, Record* source) */
-/* { */
-/*   destination = destroyRecord(destination); */
+/*=======================================================================
+ * Function   : logRecord
+ * Description: Log a configuration.
+ * Synopsis   : void logRecord(int logModule, int logPriority, 
+ *                             Record* self)
+ * Input      : int logModule = caller module
+ *              int logPriority = log priority to use
+ *              Record* self = what to log
+ * Output     : TRUE on success
+ =======================================================================*/
+int 
+logRecord(int logModule, int logPriority, RecordTree* tree, Record* self)
+{
+  struct tm date;
 
-/*   if (source == 0) */
-/*     goto error; */
+  checkRecord(self);
 
-/*   if ((destination = createRecord()) == 0) */
-/*     goto error; */
+  if (self->type & REMOVE) goto end;
+  if (localtime_r(&self->date, &date) == (struct tm*)0) goto error;
 
-/*   if (!isEmptyString(source->extra) && */
-/*       (destination->extra = createString(source->extra)) == 0) */
-/*     goto error; */
+  logEmit(logModule, logPriority, "%c "
+	   "%04i-%02i-%02i,%02i:%02i:%02i "
+	   "%*s %*s %*llu %s",
+	  (self->type & 0x3) == DEMAND?'D':
+	  (self->type & 0x3) == SUPPLY?'S':'?',
+	  date.tm_year + 1900, date.tm_mon+1, date.tm_mday,
+	  date.tm_hour, date.tm_min, date.tm_sec,
+	  MAX_SIZE_MD5, self->server->fingerPrint, 
+	  MAX_SIZE_MD5, self->archive->hash, 
+	  MAX_SIZE_SIZE, (long long unsigned int)self->archive->size,
+	  self->extra?self->extra:"");
 
-/*   destination->archive = source->archive; */
-/*   destination->server = source->server; */
-/*   destination->date = source->date; */
-/*   destination->type = source->type; */
-
-/*   return destination; */
-/*  error: */
-/*   logMemory(LOG_ERR, "%s", "malloc: cannot copy Record"); */
-/*   return destroyRecord(destination); */
-/* } */
+  logEmit(logModule, logPriority, "# ^ %s\n", strRecordType(self));
+ end:
+  return TRUE;
+ error:
+  logEmit(logModule, LOG_ERR, "fails to log a record");
+  return FALSE;
+}
 
 /*=======================================================================
  * Function   : serializeRecord
  * Description: Serialize a configuration.
- * Synopsis   : int serializeRecord(AESData* aes, Record* self)
- * Input      : AESData* aes: encryption context
+ * Synopsis   : int serializeRecord(RecordTree* tree, Record* self)
+ * Input      : RecordTree* tree = context (to retrieve AESData)
  *              Record* self = what to serialize
  * Output     : TRUE on success
  =======================================================================*/
@@ -262,14 +250,14 @@ serializeRecord(RecordTree* tree, Record* self)
   if (self->type & REMOVE) goto end;
 
   if (getRecordType(self) == MALLOC_SUPPLY) {
-     logMemory(LOG_WARNING, "%s", "get a malloc record ?!");
+     logMemory(LOG_WARNING, "get a malloc record ?!");
   }
   if (getRecordType(self) == UNDEF_RECORD) {
-     logMemory(LOG_WARNING, "%s", "get an undef record ?!");
+     logMemory(LOG_WARNING, "get an undef record ?!");
   }
 
   if (localtime_r(&self->date, &date) == (struct tm*)0) {
-    logMemory(LOG_ERR, "%s", "localtime_r returns on error");
+    logMemory(LOG_ERR, "localtime_r returns on error");
     goto error;
   }
 
@@ -281,23 +269,19 @@ serializeRecord(RecordTree* tree, Record* self)
 	  (self->type & 0x3) == SUPPLY?'S':'?',
 	  date.tm_year + 1900, date.tm_mon+1, date.tm_mday,
 	  date.tm_hour, date.tm_min, date.tm_sec,
-	  MAX_SIZE_HASH, self->server->fingerPrint, 
-	  MAX_SIZE_HASH, self->archive->hash, 
+	  MAX_SIZE_MD5, self->server->fingerPrint, 
+	  MAX_SIZE_MD5, self->archive->hash, 
 	  MAX_SIZE_SIZE, (long long unsigned int)self->archive->size,
 	  self->extra?self->extra:"");
 
-#ifndef utMAIN
-  if (!strcmp(env.logSeverity, "debug")) {
-#endif
+  if (env.logHandler->severity[LOG_MEMORY]->code >=  LOG_INFO) {
     aesPrint(&tree->aes, "# ^ %s\n", strRecordType(self));
-#ifndef utMAIN
   }
-#endif
 
  end:
   return TRUE;
  error:
-  logMemory(LOG_ERR, "%s", "fails to serialize a record");
+  logMemory(LOG_ERR, "fails to serialize a record");
   return FALSE;
 }
 
@@ -313,8 +297,10 @@ getRecordType(Record* self)
 {
   RecordType rc = UNDEF_RECORD;
 
+  checkRecord(self);
+
   if (self->server->isLocalhost && isEmptyString(self->extra)) {
-    logMemory(LOG_ERR, "%s", 
+    logMemory(LOG_ERR, 
 	    "extra string is needed to get the local record type");
     goto error;
   }
@@ -323,38 +309,27 @@ getRecordType(Record* self)
   case DEMAND:
     if (!self->server->isLocalhost)  
       rc = REMOTE_DEMAND;
-    else {
-	if (self->extra[0] != '!')
-	  rc = FINALE_DEMAND;
-	else {
-	  if (self->extra[1] == 'w')
-	    rc = LOCALE_DEMAND;
-	  if (self->extra[1] == 't')
-	    rc = TOKEEP_DEMAND;
-	}
-    }
+    else if (self->extra[0] != '!')
+      rc = FINAL_DEMAND;
+    else if (self->extra[1] == 'w')
+      rc = LOCAL_DEMAND;
     break;
+
   case SUPPLY:
     if (!self->server->isLocalhost)  
       rc = REMOTE_SUPPLY;
-    else {
-      if (self->extra[0] == '/')
-	rc = FINALE_SUPPLY;
-      else {
-	if (self->extra[0] != '!')
-	  rc = LOCALE_SUPPLY;
-	else {
-	  if (self->extra[1] == 'm')
-	    rc = MALLOC_SUPPLY;
-	}
-      }
-    }
+    else if (self->extra[0] == '/')
+      rc = FINAL_SUPPLY;
+    else if (self->extra[0] != '!')
+      rc = LOCAL_SUPPLY;
+    else if (self->extra[1] == 'm')
+      rc = MALLOC_SUPPLY;
     break;
   }
 
  error:
   if (!rc) {
-    logMemory(LOG_ERR, "%s", "getRecordType fails");
+    logMemory(LOG_ERR, "getRecordType fails");
   }
   return rc;
 }
@@ -370,22 +345,20 @@ char*
 strRecordType2(RecordType type)
 {
   switch (type) {
-  case FINALE_SUPPLY:
-    return "FINALE_SUPPLY";
-  case LOCALE_SUPPLY:
-    return "LOCALE_SUPPLY";
+  case FINAL_SUPPLY:
+    return "FINAL_SUPPLY";
+  case LOCAL_SUPPLY:
+    return "LOCAL_SUPPLY";
   case REMOTE_SUPPLY:
     return "REMOTE_SUPPLY";
   case MALLOC_SUPPLY:
     return "MALLOC_SUPPLY";
-  case FINALE_DEMAND:
-    return "FINALE_DEMAND";
-  case LOCALE_DEMAND:
-    return "LOCALE_DEMAND";
+  case FINAL_DEMAND:
+    return "FINAL_DEMAND";
+  case LOCAL_DEMAND:
+    return "LOCAL_DEMAND";
   case REMOTE_DEMAND:
     return "REMOTE_DEMAND";
-  case TOKEEP_DEMAND:
-    return "TOKEEP_DEMAND";
   default:
     return "UNDEF_RECORD";
   }
@@ -419,7 +392,7 @@ createRecordTree(void)
 
   if ((rc = (RecordTree*) malloc (sizeof (RecordTree))) 
      == 0) {
-    logMemory(LOG_ERR, "%s", "malloc: cannot create RecordTree");
+    logMemory(LOG_ERR, "malloc: cannot create RecordTree");
     goto error;
   }
 
@@ -435,7 +408,7 @@ createRecordTree(void)
   
   return rc;
  error:
-  logMemory(LOG_ERR, "%s", "fails to create RecordTree");
+  logMemory(LOG_ERR, "fails to create RecordTree");
   return destroyRecordTree(rc);
 }
 
@@ -452,7 +425,7 @@ destroyRecordTree(RecordTree* self)
 {
   RecordTree* rc = 0;
 
-  if(self != 0)
+  if(self)
     {
       self->records 
 	= destroyRing(self->records,
@@ -463,50 +436,6 @@ destroyRecordTree(RecordTree* self)
   return(rc);
 }
 
-/* /\*======================================================================= */
-/*  * Function   : copyRecordTree */
-/*  * Description: Copy a source configuration into a destination */
-/*  *              configuration. */
-/*  * Synopsis   : RecordTree* copyRecordTree(RecordTree* destination,  */
-/*  *                                           RecordTree* source) */
-/*  * Input      : RecordTree* destination */
-/*  *              RecordTree* source */
-/*  * Output     : RecordTree* destination */
-/*  * Note       : We still not copy the AES key */
-/*  =======================================================================*\/ */
-/* RecordTree*  */
-/* copyRecordTree(RecordTree* destination, RecordTree* source) */
-/* { */
-/*   RecordTree* rc = 0; */
-
-/*   destination = destroyRecordTree(destination); */
-
-/*   if(source != 0) */
-/*     { */
-/*       destination = createRecordTree(); */
-/*     } */
-
-/*   if (destination != 0) */
-/*     { */
-/*       //strncpy(destination->collectionLabel, source->collectionLabel, */
-/*       //      MAX_SIZE_COLL); */
-
-/*       if ((destination->records  */
-/* 	   = copyRing(destination->records,  */
-/* 		      source->records,  */
-/* 		      (void*(*)(void*)) destroyRecord, */
-/* 		      (void*(*)(void*, const void*)) copyRecord))  */
-/* 	  == 0) goto error; */
-
-/*       rc = destination; */
-/*     } */
-  
-/*   return(rc); */
-/*  error: */
-/*   logMemory(LOG_ERR, "%s", "malloc: cannot copy RecordTree !"); */
-/*   return destroyRecordTree(destination); */
-/* } */
-
 /*=======================================================================
  * Function   : strMessageType
  * Description: return a string for the record type
@@ -533,10 +462,74 @@ strMessageType(MessageType self)
   }
 }
 
+/*=======================================================================
+ * Function   : logRecordTree
+ * Description: Log a recordTree
+ * Synopsis   : int logRecordTree(int logModule, int logPriority,
+ *                                RecordTree* self, char* fingerPrint)
+ * Input      : int logModule = caller module
+ *              int logPriority = log priority to use
+ *              RecordTree* self = what to log
+ *              char* fingerPrint = original fingerprint when Natted
+ * Output     : N/A
+ =======================================================================*/
+void 
+logRecordTree(int logModule, int logPriority,
+	      RecordTree* self, char* fingerPrint)
+{ 
+  int rc = FALSE;
+  Record *record = 0;
+  RGIT* curr = 0;
+
+  checkRecordTree(self);
+ 
+  // use local server fingerPrint if not provided
+  if (fingerPrint == 0) {
+    fingerPrint = self->collection->userFingerPrint;
+  }
+
+  if (self->records) {
+    rgSort(self->records, cmpRecord);
+  }
+
+  // headers
+  logEmit(logModule, logPriority, "%s", "# Collection's records:");
+  logEmit(logModule, logPriority, "%s", "Headers"); 
+  logEmit(logModule, logPriority, "  Collection %-*s",
+	   MAX_SIZE_COLL, self->collection->label);
+  logEmit(logModule, logPriority, "  Type       %s", 
+	  strMessageType(self->messageType));
+  logEmit(logModule, logPriority, "  Server     %s", fingerPrint);
+  logEmit(logModule, logPriority, "  DoCypher   %s", 
+	  (self->doCypher==TRUE)?"TRUE":"FALSE");
+
+  logEmit(logModule, logPriority, "%s", "Body");
+
+  // body
+  logEmit(logModule, logPriority, "# %19s %*s %*s %*s %s",
+	   "date", 
+	   MAX_SIZE_MD5, "host",
+	   MAX_SIZE_MD5, "hash", 
+	   MAX_SIZE_SIZE, "size", 
+	   "extra");
+
+  rc = TRUE;
+  if (self->records) {
+    while ((record = rgNext_r(self->records, &curr)))
+      if (!logRecord(logModule, logPriority, self, record)) rc = FALSE;
+  }
+  
+ error:
+  if (!rc) {
+    logEmit(logModule, LOG_ERR, "logRecordTree fails");
+  }
+}
+
 /*=======================================================================
  * Function   : serializeRecordTree
  * Description: Serialize a configuration.
- * Synopsis   : int serializeRecordTree(RecordTree* self, char* path)
+ * Synopsis   : int serializeRecordTree(RecordTree* self, char* path,
+ *                                      char* fingerPrint)
  * Input      : RecordTree* self = what to serialize
  *              char* path       = file where to write
  *              fingerPrint      = original fingerprint when Natted
@@ -568,12 +561,12 @@ serializeRecordTree(RecordTree* self, char* path, char* fingerPrint)
     }
   }
 
-  // print local server fingerPrint if not overrided
+  // use local server fingerPrint if not provided
   if (fingerPrint == 0) {
     fingerPrint = self->collection->userFingerPrint;
   }
 
-  if(self != 0 && self->records != 0) {
+  if(self && self->records) {
     rgSort(self->records, cmpRecord);
   }
 
@@ -582,29 +575,28 @@ serializeRecordTree(RecordTree* self, char* path, char* fingerPrint)
   
   aesPrint(aes, "%s", "# Collection's records:\n");
   aesPrint(aes, "%s", "Headers\n"); 
-  aesPrint(aes, "\tCollection\t%-*s\n",
+  aesPrint(aes, "  Collection %-*s\n",
 	   MAX_SIZE_COLL, self->collection->label);
-  aesPrint(aes, "\tType\t\t%s\n", strMessageType(self->messageType));
-  aesPrint(aes, "\tServer\t\t%s\n", fingerPrint);
-  aesPrint(aes, "\tDoCypher\t%s", (self->doCypher==TRUE)?"TRUE":"FALSE");
+  aesPrint(aes, "  Type       %s\n", strMessageType(self->messageType));
+  aesPrint(aes, "  Server     %s\n", fingerPrint);
+  aesPrint(aes, "  DoCypher   %s", (self->doCypher==TRUE)?"TRUE":"FALSE");
 
-  // finish properly the un-encrypted headers
-  aesFlush(aes);
-  aesPrint(aes, "%s", "\nBody          \n"); // take care here !!
+  aesFlush(aes); // finish properly the un-encrypted headers
+  aesPrint(aes, "%s", "\nBody          \n"); // must be 16 char here
 
   // crypted body
   if (self->doCypher) aes->doCypher = TRUE;
   aesPrint(aes, "# %19s %*s %*s %*s %s\n",
 	   "date", 
-	   MAX_SIZE_HASH, "host",
-	   MAX_SIZE_HASH, "hash", 
+	   MAX_SIZE_MD5, "host",
+	   MAX_SIZE_MD5, "hash", 
 	   MAX_SIZE_SIZE, "size", 
 	   "extra");
   rc = TRUE;
 
-  if(self != 0) {
-    if (self->records != 0) {
-      while((record = rgNext_r(self->records, &curr)) != 0)
+  if(self) {
+    if (self->records) {
+      while ((record = rgNext_r(self->records, &curr)))
 	if (!serializeRecord(self, record)) rc=FALSE;
     }
   }
@@ -625,8 +617,8 @@ serializeRecordTree(RecordTree* self, char* path, char* fingerPrint)
 /*=======================================================================
  * Function   : newRecord
  * Description: find a record 
- * Synopsis   : Record* newRecord(time_t now, char* coll, Type type,
- *	                            char* hash, off_t size, char* extra)
+ * Synopsis   : Record* newRecord(Server* server, Archive* archive, 
+ *                                Type type, char* extra)
  * Input      : Collection* coll: where to find
  *              Server* server: id1
  *              Archive* archive: id2
@@ -647,7 +639,7 @@ newRecord(Server* server, Archive* archive, Type type, char* extra)
 	  archive->hash, (long long int)archive->size);
 
   if ((type&0x3) != SUPPLY && (type&0x3) != DEMAND) {
-    logMemory(LOG_ERR, "%s", "please choose a type (supply or demand) "
+    logMemory(LOG_ERR, "please choose a type (supply or demand) "
 	    "for the new Record");
     goto error;
   }
@@ -664,7 +656,7 @@ newRecord(Server* server, Archive* archive, Type type, char* extra)
   rc = record;
  error:
   if (!rc) {
-    logMemory(LOG_ERR, "%s", "newRecord fails");
+    logMemory(LOG_ERR, "newRecord fails");
     record = destroyRecord(record);
   }
   destroyString(extra);
@@ -675,9 +667,8 @@ newRecord(Server* server, Archive* archive, Type type, char* extra)
 /*=======================================================================
  * Function   : addRecord
  * Description: find a record 
- * Synopsis   : Record* addRecord(Collection* coll
- *                   time_t now, char* coll, Type type,
- *		     char* hash, off_t size, char* extra)
+ * Synopsis   : Record* addRecord(Collection* coll, Server* server, 
+ *                            Archive* archive, Type type, char* extra)
  * Input      : Collection* coll: where to find
  *              Server* server: id1
  *              Archive* archive: id2
@@ -711,7 +702,7 @@ Record* addRecord(Collection* coll, Server* server, Archive* archive,
   rc = record;
  error:
   if (!rc) {
-    logMemory(LOG_ERR, "%s", "newRecord fails");
+    logMemory(LOG_ERR, "addRecord fails");
     if (record) delRecord(coll, record); 
   }
   return rc;
@@ -747,17 +738,13 @@ int delRecord(Collection* coll, Record* self)
     rgRemove_r(self->server->records, &curr);
   }
 
-  // del record to collection's cache
-  if ((curr = rgHaveItem(coll->cacheTree->recordTree->records, self))) {
-    rgRemove_r(coll->cacheTree->recordTree->records, &curr);
-  }
-
   // free the record
   self = destroyRecord(self);
+
   rc = TRUE;
  error:
  if (!rc) {
-    logMemory(LOG_ERR, "%s", "delRecord fails");
+    logMemory(LOG_ERR, "delRecord fails");
  }
   return rc;
 }
@@ -780,125 +767,19 @@ diseaseRecordTree(RecordTree* self)
   logMemory(LOG_DEBUG, "Disease %s related record tree", 
 	  self->collection->label);
   
-  while((record = rgHead(self->records)) != 0)
+  while ((record = rgHead(self->records))) {
     if (!delRecord(self->collection, record)) goto error;
+    rgRemove(self->records);
+  }
   
   rc = TRUE;
  error:
   if (!rc) {
-    logMemory(LOG_INFO, "%s", "diseaseRecordTree fails");
+    logMemory(LOG_INFO, "diseaseRecordTree fails");
   }
   return(rc);
 }
 
-/************************************************************************/
-
-#ifdef utMAIN
-#include "../misc/command.h"
-#include "utFunc.h"
-GLOBAL_STRUCT_DEF;
-
-/*=======================================================================
- * Function   : usage
- * Description: Print the usage.
- * Synopsis   : static void usage(char* programName)
- * Input      : programName = the name of the program; usually argv[0].
- * Output     : N/A
- =======================================================================*/
-static void 
-usage(char* programName)
-{
-  mdtxUsage(programName);
-  fprintf(stderr, " [ -d repository ]");
-
-  memoryOptions();
-  //fprintf(stderr, "\t\t---\n");
-  return;
-}
-
-/*=======================================================================
- * Function   : main
- * Author     : Nicolas Roche
- * modif      : 2012/02/11
- * Description: Unit test for md5sumTree module.
- * Synopsis   : utmd5sumTree
- * Input      : N/A
- * Output     : /tmp/mdtx/var/local/cache/mdtx/md5sums.txt
- =======================================================================*/
-int 
-main(int argc, char** argv)
-{
-  Collection* coll = 0;
-  char key[MAX_SIZE_AES+1] = "1000000000000000";
-  AESData* aes = 0;
-  // ---
-  int rc = 0;
-  int cOption = EOF;
-  char* programName = *argv;
-  char* options = MEMORY_SHORT_OPTIONS;
-  struct option longOptions[] = {
-    MEMORY_LONG_OPTIONS,
-    {0, 0, 0, 0}
-  };
-       
-  // import mdtx environment
-  env.dryRun = FALSE;
-  env.debugMemory = TRUE;
-  getEnv(&env);
-
-  // parse the command line
-  while((cOption = getopt_long(argc, argv, options, longOptions, 0)) 
-	!= EOF) {
-    switch(cOption) {
-      
-      GET_MEMORY_OPTIONS; // generic options
-    }
-    if (rc) goto optError;
-  }
-
-  // export mdtx environment
-  if (!setEnv(programName, &env)) goto optError;
-
-  /************************************************************************/
-  if (!createExempleConfiguration()) goto error;
-  if (!(coll = getCollection("coll1"))) goto error;
-  if (!createExempleRecordTree(coll)) goto error;
-
-  aes = &coll->cacheTree->recordTree->aes;
-  if (!aesInit(aes, key, ENCRYPT)) goto error;
-
-  aes = &coll->cacheTree->recordTree->aes;
-  if (!aesInit(aes, key, ENCRYPT)) goto error;
-
-  // serialize uncrypted file
-  if (!serializeRecordTree(coll->cacheTree->recordTree, coll->md5sumsDB,
-			   0)) goto error;
-
-  // serialize crypted file
-  strncpy(coll->md5sumsDB + strlen(coll->md5sumsDB) -3, "aes", 3);
-  coll->cacheTree->recordTree->doCypher = TRUE;
-  if (!serializeRecordTree(coll->cacheTree->recordTree, coll->md5sumsDB, 
-			   0)) goto error;
-
-  // disease
-  aes->doCypher = FALSE;
-  aes->fd = STDOUT_FILENO;
-  if (!diseaseRecordTree(coll->cacheTree->recordTree)) goto error;
-  env.dryRun = TRUE;
-  if (coll->cacheTree->recordTree->records->nbItems != 0) goto error;
-  /************************************************************************/
-
-  freeConfiguration();
-  rc = TRUE;
- error:
-  ENDINGS;
-  rc=!rc;
- optError:
-  exit(rc);
-}
-
-#endif // utMAIN
-
 /* Local Variables: */
 /* mode: c */
 /* mode: font-lock */
