@@ -1,5 +1,5 @@
 /*=======================================================================
- * Version: $Id: recordTree.h,v 1.3 2015/06/03 14:03:39 nroche Exp $
+ * Version: $Id: recordTree.h,v 1.7 2015/09/17 18:53:47 nroche Exp $
  * Project: MediaTeX
  * Module : record tree
  *
@@ -22,14 +22,11 @@
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 =======================================================================*/
 
-#ifndef MDTX_MEMORY_RECORD_TREE_H
-#define MDTX_MEMORY_RECORD_TREE_H 1
+#ifndef MDTX_MEMORY_RECORD_H
+#define MDTX_MEMORY_RECORD_H 1
 
-#include "../mediatex.h"
-#include "../misc/cypher.h"
-#include "confTree.h"
-
-#include <netinet/in.h>
+#include "mediatex-types.h"
+//#include <netinet/in.h>
 
 // message type
 typedef enum {UNKNOWN, DISK, CGI, HAVE, NOTIFY, UPLOAD} MessageType;
@@ -59,7 +56,7 @@ struct RecordTree
 {
   Collection* collection;
   MessageType messageType;
-  char        fingerPrint[MAX_SIZE_HASH+1]; /* servr id */
+  char        fingerPrint[MAX_SIZE_MD5+1]; /* server id */
   AESData     aes;
   int         doCypher;   // do AES cypher the body when serializing
   RG*         records;
@@ -72,12 +69,13 @@ Record* createRecord(void);
 Record* destroyRecord(Record* self);
 Record* copyRecord(Record* destination, Record* source);
 int serializeRecordTree(RecordTree* self, char* path, char* fingerPrint);
+void logRecordTree(int logModule, int logPriority,
+		   RecordTree* self, char* fingerPrint);
 
 RecordTree* createRecordTree(void);
 RecordTree* destroyRecordTree(RecordTree* self);
-//RecordTree* copyRecordTree(RecordTree* destination, RecordTree* source);
 int serializeRecord(RecordTree* tree, Record* self);
-
+int logRecord(int logModule, int logPriority, RecordTree* tree, Record* self);
 
 /* API */
 char* strMessageType(MessageType self);
@@ -92,7 +90,7 @@ int delRecord(Collection* coll, Record* self);
 
 int diseaseRecordTree(RecordTree* self);
 
-#endif /* MDTX_MEMORY_RECORD_TREE_H */
+#endif /* MDTX_MEMORY_RECORD_H */
 
 /* Local Variables: */
 /* mode: c */
