@@ -1,5 +1,5 @@
 /*=======================================================================
- * Version: $Id: serverTree.c,v 1.3 2015/06/03 14:03:39 nroche Exp $
+ * Version: $Id: serverTree.c,v 1.14 2015/09/17 18:53:47 nroche Exp $
  * Project: MediaTeX
  * Module : serverTree
 
@@ -22,9 +22,7 @@ You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 =======================================================================*/
 
-#include "../mediatex.h"
-#include "../misc/log.h"
-#include "serverTree.h"
+#include "mediatex-config.h"
 
 
 /*=======================================================================
@@ -47,7 +45,7 @@ createImage(void)
 
   return(rc);
  error:
-  logMemory(LOG_ERR, "%s", "malloc: cannot create an Image");
+  logMemory(LOG_ERR, "malloc: cannot create an Image");
   return(rc);
 }
 
@@ -87,7 +85,7 @@ serializeImage(Image* self, FILE* fd)
   int rc = FALSE;
 
   if(self == 0) {
-    logMemory(LOG_ERR, "%s", "empty image");
+    logMemory(LOG_ERR, "empty image");
     goto error;
   }
 
@@ -99,7 +97,7 @@ serializeImage(Image* self, FILE* fd)
   rc = TRUE;
  error:
   if (!rc) {
-    logMemory(LOG_ERR, "%s", "serializeImage fails");
+    logMemory(LOG_ERR, "serializeImage fails");
   }
   return rc;
 }
@@ -177,8 +175,6 @@ createServer(void)
   // note: we do not set default ports (to allow to change them)
   rc->score = -1;
   rc->address.sin_addr.s_addr = LOCALHOST; // localhost by default
-  rc->scoreParam = (ScoreParam)DEFAULT_SCORE_PARAM;
-  rc->minGeoDup = DEFAULT_MIN_GEO;
 
   if ((rc->networks = createRing()) == 0) goto error;
   if ((rc->gateways = createRing()) == 0) goto error;
@@ -187,7 +183,7 @@ createServer(void)
 
   return rc;
  error:
-  logMemory(LOG_ERR, "%s", "malloc: cannot create Server");
+  logMemory(LOG_ERR, "malloc: cannot create Server");
   return destroyServer(rc);
 }
 
@@ -208,6 +204,7 @@ destroyServer(Server* self)
   self->comment = destroyString(self->comment);
   self->mdtxPort = 0;
   self->sshPort = 0;
+  self->wwwPort = 0;
   self->userKey = destroyString(self->userKey);
   self->hostKey = destroyString(self->hostKey);
   
@@ -240,9 +237,15 @@ serializeServer(Server* self, FILE* fd)
   Image* image = 0;
   char* string = 0;
   RGIT* curr = 0;
+  struct tm date;
 
   if(self == 0) {
-    logMemory(LOG_ERR, "%s", "cannot serialize empty Server");
+    logMemory(LOG_ERR, "cannot serialize empty Server");
+    goto error;
+  }
+
+  if (localtime_r(&self->lastCommit, &date) == (struct tm*)0) {
+    logMemory(LOG_ERR, "localtime_r returns on error");
     goto error;
   }
   
@@ -256,12 +259,20 @@ serializeServer(Server* self, FILE* fd)
   if (!isEmptyString(self->host)) {
     fprintf(fd, "\t%-9s %s\n", "host", self->host);
   }
+  
+  fprintf(fd, "\t%-9s %04i-%02i-%02i,%02i:%02i:%02i \n", "lastCommit",
+	  date.tm_year + 1900, date.tm_mon+1, date.tm_mday,
+	  date.tm_hour, date.tm_min, date.tm_sec);
+  
   if (self->mdtxPort) {
     fprintf(fd, "\t%-9s %i\n", "mdtxPort", self->mdtxPort);
   }
   if (self->sshPort) {
     fprintf(fd, "\t%-9s %i\n", "sshPort", self->sshPort);
   }
+  if (self->wwwPort) {
+    fprintf(fd, "\t%-9s %i\n", "wwwPort", self->wwwPort);
+  }
 
   if (!isEmptyRing(self->networks)) {
     fprintf(fd, "\t%-9s ", "networks");
@@ -288,13 +299,13 @@ serializeServer(Server* self, FILE* fd)
   }
 
   /* cache parameters (take care, this use macro) */
-  if (self->cacheSize != 0) {
+  if (self->cacheSize) {
     printCacheSize(fd, "\t%-9s", "cacheSize", self->cacheSize);
   }
-  if (self->cacheTTL != 0) {
+  if (self->cacheTTL) {
     printLapsTime(fd, "\t%-9s", "cacheTTL", self->cacheTTL);
   }
-  if (self->queryTTL != 0) {
+  if (self->queryTTL) {
     printLapsTime(fd, "\t%-9s", "queryTTL", self->queryTTL);
   }
 
@@ -307,9 +318,9 @@ serializeServer(Server* self, FILE* fd)
     do {
       if (!serializeImage(image, fd)) goto error;
       image = rgNext_r(self->images, &curr);
-      if (image != 0) fprintf(fd, ",\n\t\t  ");
+      if (image) fprintf(fd, ",\n\t\t  ");
     }
-    while(image != 0);
+    while (image);
     fprintf(fd, "\n");
   } 
 
@@ -369,6 +380,8 @@ createServerTree(void)
   memset(rc, 0, sizeof(ServerTree));
   strncpy(rc->aesKey, "01234567890abcdef", MAX_SIZE_AES);
 
+  rc->uploadTTL = DEFAULT_TTL_UPLOAD;
+  rc->serverTTL = DEFAULT_TTL_SERVER;
   rc->scoreParam = defaultScoreParam;
   rc->minGeoDup = DEFAULT_MIN_GEO;
 
@@ -377,7 +390,7 @@ createServerTree(void)
   
   return rc;
  error:
-  logMemory(LOG_ERR, "%s", "malloc: cannot create a serverTree");
+  logMemory(LOG_ERR, "malloc: cannot create a serverTree");
   return destroyServerTree(rc);
 }
 
@@ -426,7 +439,7 @@ serializeServerTree(Collection* coll)
 
   // we neeed to use the home cvs collection directory
   if (!(coll->memoryState & EXPANDED)) {
-    logMemory(LOG_ERR, "%s", "collection must be expanded first");
+    logMemory(LOG_ERR, "collection must be expanded first");
     goto error;
   }
 
@@ -436,8 +449,8 @@ serializeServerTree(Collection* coll)
   if (env.dryRun == FALSE) path = coll->serversDB;
   logMemory(LOG_INFO, "Serializing the server tree file: %s", 
 	  path?path:"stdout");
-  if (path != 0 && *path != (char)0) {
-    if ((fd = fopen(path, "w")) == 0) {
+  if (path && *path != (char)0) {
+    if (!(fd = fopen(path, "w"))) {
       logMemory(LOG_ERR, "fdopen %s fails: %s", path, strerror(errno));
       fd = stdout;
       goto error;
@@ -466,17 +479,20 @@ serializeServerTree(Collection* coll)
   fprintf(fd, "%-10s %s\n", "collKey", self->aesKey);
 
   fprintf(fd, "\n# score parameters\n");
+  printLapsTime(fd, "%-10s", "uploadTTL", self->uploadTTL);
+  printLapsTime(fd, "%-10s", "serverTTL", self->serverTTL);
   printLapsTime(fd, "%-10s", "suppTTL",  self->scoreParam.suppTTL);
   fprintf(fd, "%-10s %.2f\n", "maxScore", self->scoreParam.maxScore);
   fprintf(fd, "%-10s %.2f\n", "badScore", self->scoreParam.badScore);
   fprintf(fd, "%-10s %.2f\n", "powSupp",  self->scoreParam.powSupp);
   fprintf(fd, "%-10s %.2f\n", "factSupp", self->scoreParam.factSupp);
+  fprintf(fd, "%-10s %.2f\n", "fileScore", self->scoreParam.fileScore);
   fprintf(fd,  "%-10s %i", "minGeoDup", self->minGeoDup);
   fprintf(fd, "\n");
 
   if (!isEmptyRing(self->servers)) {
     if (!rgSort(self->servers, cmpServer)) goto error;
-    while((server = rgNext_r(self->servers, &curr)) != 0) {
+    while ((server = rgNext_r(self->servers, &curr))) {
       if (!serializeServer(server, fd)) goto error;
     }
   }
@@ -525,7 +541,7 @@ getImage(Collection* coll, Server* server, Archive* archive)
 	  (long long int)archive->size);
   
   // look for image
-  while((rc = rgNext_r(server->images, &curr)) != 0)
+  while ((rc = rgNext_r(server->images, &curr)))
     if (!cmpArchive(&rc->archive, &archive)) break;
 
  error:
@@ -577,7 +593,7 @@ addImage(Collection* coll, Server* server, Archive* archive)
   rc = image;
  error:
   if (!rc) {
-    logMemory(LOG_ERR, "%s", "fails to add an image");
+    logMemory(LOG_ERR, "fails to add an image");
     if (image) delImage(coll, image);
   }
   return rc;
@@ -605,7 +621,7 @@ delImage(Collection* coll, Image* image)
   logMemory(LOG_DEBUG, "delImage %s, %s:%i, %s:%lli",
 	  coll, image->server->host, image->server->mdtxPort, 
 	  image->archive->hash, (long long int)image->archive->size);
-  logMemory(LOG_DEBUG, "%s", "delImage");
+  logMemory(LOG_DEBUG, "delImage");
 
   // delete image from server
   if ((curr = rgHaveItem(image->server->images, image))) {
@@ -629,106 +645,11 @@ delImage(Collection* coll, Image* image)
   rc = TRUE;
  error:
  if (!rc) {
-    logMemory(LOG_ERR, "%s", "delImage fails");
+    logMemory(LOG_ERR, "delImage fails");
   }
   return rc;
 }
 
-/*=======================================================================
- * Function   : isReachable
- * Description: test if "from" server may use gateways to reach "to" 
- *              server
- * Synopsis   : int isReachable(Collection* coll, 
- *                                         Server* from, Server* to)
- * Input      : Collection* coll : where to add
- *              Server* server = the proxy server 
- *              Server* proxy  = the proxy client
- * Output     : TRUE on success
- * Note       : this function is not symmetric
- =======================================================================*/
-int 
-isReachable(Collection* coll, Server* from, Server* to)
-{
-  int rc = FALSE;
-  int loop = TRUE;
-  RG* reach = 0;
-  void* it = 0;
-  RG* tmp = 0;
-  //RG* tmp2 = 0;
-  RGIT* curr = 0;
-  Server* server = 0;
-  int nbReachable = 0;
-
-  logMemory(LOG_DEBUG, "isReachable from %s to %s",
-	  from->fingerPrint, to->fingerPrint);
-
-  // networks we can reach
-  if (!(reach = createRing())) goto error;
-  while((it = rgNext_r(from->networks, &curr))) {
-    if (!rgInsert(reach, it)) goto error;
-  }
-  nbReachable = reach->nbItems;
-
-  // loop until "to" is located under a reachable network
-  /* printf("\n"); */
-  while (loop) {
-
-    /* printf("looping...\n"); */
-    /* printf("we now we can reach:"); */
-    /* while((it = rgNext(reach))) printf(" %s", (char*)it); */
-    /* printf ("\n"); */
-
-    /* printf("we want to reach on of them:"); */
-    /* while((it = rgNext(to->networks))) printf(" %s", (char*)it); */
-    /* printf ("\n"); */
-
-    // exit when reachable
-    if (!(tmp = rgInter(reach, to->networks))) goto error;
-    if (!isEmptyRing(tmp)) {
-      rc = TRUE;
-      tmp = destroyOnlyRing(tmp);
-      /* printf("... ok reachable\n"); */
-      goto end;
-    }
-    tmp = destroyOnlyRing(tmp);
-
-    // look for a new gateway (juste one)
-    loop = FALSE;
-    curr = 0; 
-    while(!loop && (server = rgNext_r(coll->serverTree->servers, &curr))) {
-      if (!(tmp = rgInter(reach, server->gateways))) goto error;
-      if (!isEmptyRing(tmp)) {
-
-	/* printf("new reachable networks:"); */
-	/* while((it = rgNext(server->networks))) printf(" %s", (char*)it); */
-	/* printf ("\n");      */
-
-	// we find one so we now we can reach its networks
-	tmp = destroyOnlyRing(tmp);
-	if (!(tmp = rgUnion(reach, server->networks))) goto error;
-	reach = destroyOnlyRing(reach);
-	reach = tmp;
-	tmp = 0;
-
-	// but is there new networks ?
-	loop = (reach->nbItems > nbReachable);
-      }
-      tmp = destroyOnlyRing(tmp);
-    }
-  }
-
-  /* printf("... not reachable\n"); */
- end:
-  logMemory(LOG_INFO, "%s may %sreach %s",
-	  from->fingerPrint, rc?"":"not ", to->fingerPrint);
-  reach = destroyOnlyRing(reach);
-  return rc;
- error:
-  logMemory(LOG_DEBUG, "%s", "isReachable fails");
-  reach = destroyOnlyRing(reach);
-  return FALSE;
-}
-
 
 /*=======================================================================
  * Function   : getServer
@@ -750,8 +671,8 @@ getServer(Collection* coll, char* fingerPrint)
   logMemory(LOG_DEBUG, "getServer %s", fingerPrint);
   
   // look for server
-  while((rc = rgNext_r(coll->serverTree->servers, &curr)) != 0)
-    if (!strncmp(rc->fingerPrint, fingerPrint, MAX_SIZE_HASH)) break;
+  while ((rc = rgNext_r(coll->serverTree->servers, &curr)))
+    if (!strncmp(rc->fingerPrint, fingerPrint, MAX_SIZE_MD5)) break;
 
  error:
   return rc;
@@ -781,19 +702,19 @@ addServer(Collection* coll, char* fingerPrint)
 
   // add new one if not already there
   if (!(server = createServer())) goto error;
-  strncpy(server->fingerPrint, fingerPrint, MAX_SIZE_HASH);
-  server->fingerPrint[MAX_SIZE_HASH] = (char)0; // developpement code
+  strncpy(server->fingerPrint, fingerPrint, MAX_SIZE_MD5);
+  server->fingerPrint[MAX_SIZE_MD5] = (char)0; // developpement code
   if (!rgInsert(coll->serverTree->servers, server)) goto error;
 
   // shorter than a function even if not used a lot
   server->isLocalhost = 
-    !strncmp(fingerPrint, coll->userFingerPrint, MAX_SIZE_HASH);
+    !strncmp(fingerPrint, coll->userFingerPrint, MAX_SIZE_MD5);
 
  end:
   rc = server;
  error:
   if (!rc) {
-    logMemory(LOG_ERR, "%s", "addServer fails");
+    logMemory(LOG_ERR, "addServer fails");
     server = destroyServer(server);
   }
   return rc;
@@ -823,11 +744,11 @@ delServer(Collection* coll, Server* server)
   if (coll->localhost == server) coll->localhost = 0;
 
   // delete images own by the this server
-  while ((img = rgHead(server->images)) != 0)
+  while ((img = rgHead(server->images)))
     if (!delImage(coll, img)) goto error;
 
   // delete records
-  while((rec = rgHead(server->records)) != 0)
+  while ((rec = rgHead(server->records)))
     if (!delRecord(coll, rec)) goto error;
 
   // delete server from collection ring
@@ -862,7 +783,7 @@ diseaseServer(Collection* coll, Server* server)
   logMemory(LOG_DEBUG, "disease %s server", server->fingerPrint);
 
   // delete images own by the this server
-  while ((image = rgHead(server->images)) != 0) {
+  while ((image = rgHead(server->images))) {
 
     // delete archive from serverTree
     if ((curr = rgHaveItem(coll->serverTree->archives, image->archive))) {
@@ -904,7 +825,7 @@ diseaseServer(Collection* coll, Server* server)
   
   rc = TRUE;
  error:
-  if (!rc) logMemory(LOG_ERR, "%s", "diseaseServer fails");
+  if (!rc) logMemory(LOG_ERR, "diseaseServer fails");
   return rc;
 }
 
@@ -929,128 +850,16 @@ diseaseServerTree(Collection* coll)
 
   // disease servers
   curr = 0;
-  while((server = rgNext_r(self->servers, &curr)) != 0) {
+  while ((server = rgNext_r(self->servers, &curr))) {
     if (!diseaseServer(coll, server)) goto error;
   }
 
   rc = TRUE;
  error:
-  if (!rc) logMemory(LOG_ERR, "%s", "diseaseServerTree fails");
+  if (!rc) logMemory(LOG_ERR, "diseaseServerTree fails");
   return rc;
 }
 
-/************************************************************************/
-
-#ifdef utMAIN
-#include "../misc/command.h"
-#include "utFunc.h"
-GLOBAL_STRUCT_DEF;
-
-/*=======================================================================
- * Function   : usage
- * Description: Print the usage.
- * Synopsis   : static void usage(char* programName)
- * Input      : programName = the name of the program; usually argv[0].
- * Output     : N/A
- =======================================================================*/
-static void 
-usage(char* programName)
-{
-  memoryUsage(programName);
-
-  memoryOptions();
-  //fprintf(stderr, "\t\t---\n");
-  return;
-}
-
-/*=======================================================================
- * Function   : main 
- * Author     : Nicolas ROCHE
- * modif      : 2012/05/01
- * Description: Unit test for serverTree module.
- * Synopsis   : utconfTree
- * Input      : N/A
- * Output     : N/A
- =======================================================================*/
-int 
-main(int argc, char** argv)
-{
-  Collection* coll = 0;
-  Server* server1 = 0;
-  Server* server2 = 0;
-  Server* server3 = 0;
-  // ---
-  int rc = 0;
-  int cOption = EOF;
-  char* programName = *argv;
-  char* options = MEMORY_SHORT_OPTIONS;
-  struct option longOptions[] = {
-    MEMORY_LONG_OPTIONS,
-    {0, 0, 0, 0}
-  };
-
-  // import mdtx environment
-  env.dryRun = FALSE;
-  env.debugMemory = TRUE;
-  getEnv(&env);
-
-  // parse the command line
-  while((cOption = getopt_long(argc, argv, options, longOptions, 0)) 
-	!= EOF) {
-    switch(cOption) {
-      
-      GET_MEMORY_OPTIONS; // generic options
-    }
-    if (rc) goto optError;
-  }
-
-  // export mdtx environment
-  if (!setEnv(programName, &env)) goto optError;
-
-  /************************************************************************/
-  if (!createExempleConfiguration()) goto error;
-  if (!(coll = getCollection("coll1"))) goto error;
-  if (!createExempleServerTree(coll)) goto error;
-  
-  // test serializing
-  if (!serializeServerTree(coll)) {
-    logMemory(LOG_ERR, "%s", "sorry, cannot serialize the exemple");
-    goto error;
-  }
-
-  if (!(server1 = getServer(coll, "746d6ceeb76e05cfa2dea92a1c5753cd"))
-      || !(server2 = getServer(coll, "6b18ed0194b0fbadd08e0a13cccda00e"))
-      || !(server3 = getServer(coll, "bedac32422739d7eced624ba20f5912e")))
-    goto error;
-  if (rgShareItems(server1->networks, server3->networks)) goto error;
-
-  // test reachability
-  if (!isReachable(coll, server1, server2)) goto error;
-  if (isReachable(coll, server1, server3)) goto error;
-  if (!isReachable(coll, server2, server1)) goto error;
-  if (!isReachable(coll, server2, server3)) goto error;
-  if (!isReachable(coll, server3, server1)) goto error;
-  if (!isReachable(coll, server3, server2)) goto error;
-
-  // test disease
-  if (!diseaseServer(coll, server1)) goto error;
-  if (!diseaseServer(coll, server2)) goto error;
-  if (!diseaseServer(coll, server3)) goto error;
-  env.dryRun = TRUE;
-  if (!serializeServerTree(coll)) goto error;
-  /************************************************************************/
-
-  rc = TRUE;  
- error:
-  freeConfiguration();
-  ENDINGS;
-  rc=!rc;
- optError:
-  exit(rc);
-}
-
-#endif // utMAIN
-
 /* Local Variables: */
 /* mode: c */
 /* mode: font-lock */
