@@ -1,5 +1,5 @@
 /*=======================================================================
- * Version: $Id: serverTree.h,v 1.3 2015/06/03 14:03:39 nroche Exp $
+ * Version: $Id: serverTree.h,v 1.10 2015/10/05 21:46:29 nroche Exp $
  * Project: MediaTeX
  * Module : server tree
  *
@@ -22,17 +22,14 @@
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 =======================================================================*/
 
-#ifndef MEMORY_ADMSERVER_H
-#define MEMORY_ADMSERVER_H 1
+#ifndef MISC_MEMORY_SERVER_H
+#define MISC_MEMORY_SERVER_H 1
 
-#include "../mediatex.h"
-#include "../misc/keys.h"
-#include "confTree.h"
-
-#include <netinet/in.h>
+#include "mediatex-types.h"
+//#include <netinet/in.h>
 
 /* 
-   There at more 1 ISO image by archive and server.
+   There is maximum 1 ISO image by archive and server.
    Images are listed by servers and archives.
    Archives matching one or more images are listed by the serverTree
  */
@@ -43,7 +40,7 @@ struct Image {
 };
 
 struct Server {
-  char  fingerPrint[MAX_SIZE_HASH+1]; // destruction id
+  char  fingerPrint[MAX_SIZE_MD5+1]; // destruction id
   char* label; // ie "MDTX2"
   char* user;  // ie "MDTX2-COLL"
 
@@ -51,6 +48,7 @@ struct Server {
   char  host[MAX_SIZE_HOST+1];
   int   mdtxPort;
   int   sshPort;
+  int   wwwPort;
   RG*   networks;
   RG*   gateways;
 
@@ -63,16 +61,13 @@ struct Server {
   //struct in_addr ipv4; // manage by connect.c
   struct sockaddr_in address; // manage by connect.c
   float score;                // manage by extractHtml.c
+  time_t lastCommit;
 
   // manage by cache.c
   off_t  cacheSize; // maximum size for cache
   time_t cacheTTL;  // time to live for target files in cache
   time_t queryTTL;  // time to live for queries in memory
 
-  // parameters use to compute image's score
-  ScoreParam scoreParam; 
-  int minGeoDup; // minimum number of support remote copies
-
   int isLocalhost; // = (fingerPrint == coll->userFingerPrint)
 };
 
@@ -86,7 +81,9 @@ struct ServerTree {
   // but several in the serverTree context, up to one by server
 
   ScoreParam scoreParam; // parameter use to compute score
-  int    minGeoDup;     // number of distantes copies expected
+  int    minGeoDup;      // number of remote copies expected
+  time_t uploadTTL;      // incoming content do not implies a bad score
+  time_t serverTTL;      // used to check lastCommit
 };
 
 Image* createImage(void);
@@ -117,10 +114,7 @@ int delServer(Collection* coll, Server* Server);
 int diseaseServer(Collection* coll, Server* server);
 int diseaseServerTree(Collection* coll);
 
-// only used by cgi client
-int isReachable(Collection* coll, Server* from, Server* to);
-
-#endif /* MEMORY_ADMSERVER_H */
+#endif /* MISC_MEMORY_SERVER_H */
 
 /* Local Variables: */
 /* mode: c */
