@@ -1,5 +1,5 @@
 /*=======================================================================
- * Version: $Id: strdsm.c,v 1.3 2015/06/03 14:03:40 nroche Exp $
+ * Version: $Id: strdsm.c,v 1.6 2015/08/13 21:14:34 nroche Exp $
  * Project: MediaTeX
  * Module : strdsm
  *
@@ -23,11 +23,7 @@
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  =======================================================================*/
 
-#include <string.h>
-
-#include "strdsm.h"
-#include "../misc/alloc.h"
-#include "../misc/log.h"
+#include "mediatex-config.h"
 
 /*=======================================================================
  * Function   : createString (strdsm) [MediaTeX]
@@ -43,7 +39,7 @@ createString(const char* content)
   char* rc = 0;
 
   if (content == 0) {
-    logMemory(LOG_WARNING, "%s", "create null String");
+    logMemory(LOG_WARNING, "create null String");
   }
 
   if ((rc = copyString(rc, content)) == 0) {
@@ -93,7 +89,7 @@ destroyString(char* self)
 {
   char* rc = 0;
 
-  if(self != 0) {
+  if(self) {
     free(self);
   }
 	
@@ -116,19 +112,19 @@ copyString(char* destination, const char* source)
 {
   char* rc = 0;
 
-  if(destination != 0) {
+  if(destination) {
     free(destination);
     destination = 0;
   }
 
-  if(source != 0) {
+  if(source) {
     if ((destination 
 	 = (char*)malloc(sizeof(char) * (strlen(source) + 1)))
 	== 0) {
-      logMemory(LOG_ERR, "%s", "malloc: cannot allocate String");
+      logMemory(LOG_ERR, "malloc: cannot allocate String");
     }
     
-    if(destination != 0) {
+    if(destination) {
       strcpy(destination, source);
     }
   }
@@ -156,19 +152,19 @@ copySizedString(size_t size, char* destination, const char* source)
 {
   char* rc = 0;
 
-  if(destination != 0) {
+  if(destination) {
     free(destination);
     destination = 0;
   }
 
-  if(source != 0) {
+  if(source) {
     if ((destination 
 	 = (char*)malloc(sizeof(char) * (size + 1))) 
 	== 0) {
       logMemory(LOG_ERR, "%", "malloc: cannot allocate String");
     }
     
-    if(destination != 0) {
+    if(destination) {
       size_t eos = strlen(source);
       
       eos = ((eos <= size) ? eos : size);
@@ -195,25 +191,25 @@ catString(char* prefix, const char* suffix)
 {
   char* rc = prefix;
 
-  if(suffix != 0) {
+  if(suffix) {
     int size = strlen(suffix);
     
-    if(prefix != 0) {
+    if(prefix) {
       size += strlen(prefix);
     }
     
     if ((rc 
 	 = (char*)malloc(sizeof(char) * (size + 1))) 
 	== 0) {
-      logMemory(LOG_ERR, "%s", "malloc: cannot allocate String");
+      logMemory(LOG_ERR, "malloc: cannot allocate String");
     }
     
-    if(rc != 0) {
+    if(rc) {
       /* on Solaris 10 u2 sparc, malloc doesn't sets memory to
 	 nil */
       memset(rc, 0, (size + 1));
       
-      if(prefix != 0) {
+      if(prefix) {
 	strcat(rc, prefix);
 	prefix = destroyString(prefix);
       }
@@ -261,185 +257,6 @@ cmpString(const void *p1, const void *p2)
   return strcmp(w1, w2);
 }
 
-/************************************************************************/
-
-#ifdef utMAIN
-#include "../misc/command.h"
-GLOBAL_STRUCT_DEF;
-
-/*=======================================================================
- * Function   : usage
- * Description: Print the usage.
- * Synopsis   : static void usage(char* programName)
- * Input      : programName = the name of the program; usually argv[0].
- * Output     : N/A
- =======================================================================*/
-static void 
-usage(char* programName)
-{
-  memoryUsage(programName);
-  fprintf(stderr, " [ -i input ] [ -o output ]");
-
-  memoryOptions();
-  fprintf(stderr, "  ---\n");
-  fprintf(stderr, "  -i, --input\t\tinput stream\n");
-  fprintf(stderr, "  -o, --output\t\toutput stream\n");
-  return;
-}
-
-/*=======================================================================
- * Function   : main
- * Author     : Peter FELECAN, Nicolas Roche
- * Description: Unit test for strdsm module.
- * Synopsis   : utstrdsm
- * Input      : stdin
- * Output     : stdout
- =======================================================================*/
-int 
-main(int argc, char** argv)
-{
-  FILE* hin = (FILE*)stdin;
-  FILE* hout = (FILE*)stdout;
-  // ---
-  int rc = 0;
-  int cOption = EOF;
-  char* programName = *argv;
-  char* options = MEMORY_SHORT_OPTIONS"i:o:";
-  struct option longOptions[] = {
-    MEMORY_LONG_OPTIONS,
-    {"input", required_argument, 0, 'i'},
-    {"output", required_argument, 0, 'o'},
-    {0, 0, 0, 0}
-  };
-
-  // import mdtx environment
-  env.debugMemory = TRUE;
-  getEnv(&env);
-
-  // parse the command line
-  while((cOption = getopt_long(argc, argv, options, longOptions, 0)) 
-	!= EOF) {
-    switch(cOption) {
-
-    case 'i':
-      if(isEmptyString(optarg)) {
-	fprintf(stderr, 
-		"%s: nil or empty argument for the input stream\n",
-		programName);
-	rc = EINVAL;
-      }
-      else {
-	if ((hin = fopen(optarg, "r")) == 0) {
-	  fprintf(stderr, 
-		  "cannot open '%s' for input, "
-		  "will try to revert to the standard input\n", optarg);
-	  rc = ENOENT;
-	}
-      }
-      break;
-		
-    case 'o':
-      if(isEmptyString(optarg)) {
-	fprintf(stderr, 
-		"%s: nil or empty argument for the output stream\n",
-		programName);
-	rc = EINVAL;
-      }
-      else {
-	if ((hin = fopen(optarg, "r")) == 0) {
-	  fprintf(stderr, 
-		  "cannot open '%s' for input, "
-		  "will try to revert to the standard output\n", optarg);
-	  rc = ENOENT;
-	}
-      }
-      break;
-
-    GET_MEMORY_OPTIONS; // generic options
-    }
-    if (rc) goto optError;
-  }
-  
-  // export mdtx environment
-  if (!setEnv(programName, &env)) goto optError;
-  
-  /************************************************************************/
-  char buffer[BUFSIZ];
-  char* string = 0;
-  char* copy = 0;
-  
-  char* prefix = createString("prefix");
-  char* suffix = createString("/suffix");
-
-  rc = FALSE;
-  prefix = catString(prefix, "/suffix");
-  fprintf(hout, "concatenate 1/1 %s\n", prefix);
-  
-  prefix = copyString(prefix, "prefix/");
-  prefix = catString(prefix, (char*)0);
-  fprintf(hout, "concatenate 1/0 %s\n", prefix);
-  
-  prefix = destroyString(prefix);
-  prefix = catString(prefix, suffix);
-  fprintf(hout, "concatenate 0/1 %s\n", prefix);
-   
-  fprintf(hout, 
-	  "Enter items, one per line.\nEnd the list by EOF (ctl-d)\n");
-		
-  while(fgets(buffer, BUFSIZ, hin) != 0) {	
-    if (!strcmp(buffer, "quit\n")) break;
-    
-    fprintf(hout, "content = %s", buffer);
-
-    fprintf(hout, "created = ");
-    if ((string = createString(buffer)) == 0) goto error;
-    fprintf(hout, "%s", string);
-    
-    fprintf(hout, "copied  = ");
-    if ((copy = copyString(copy, string)) == 0) goto error;
-    fprintf(hout, "%s", copy);
-    
-    string = destroyString(string);
-    copy = destroyString(copy);
-  }
-
-  clearerr(hin);
-		
-  fprintf(hout, "Enter items, one per line.\nEnd the list by EOF (ctl-d)\n"
-	  "Only the first 4 characters are used for the creation\n"
-	  "Only the first 2 characters are copied\n");
-		
-  while(fgets(buffer, BUFSIZ, hin) != 0)	{
-
-    fprintf(hout, "content = %s", buffer);
-    
-    fprintf(hout, "created = ");
-    if ((string = createSizedString(4, buffer)) == 0) goto error;
-    fprintf(hout, "%s\n", string);
-
-    fprintf(hout, "copied  = ");
-    if ((copy = copySizedString(2, copy, string)) == 0) goto error;
-    fprintf(hout, "%s\n", copy);
-    
-    string = destroyString(string);
-    copy = destroyString(copy);
-  }
-
-  destroyString(suffix);
-  destroyString(prefix);
-  fflush(hout);
-  /************************************************************************/
-
-  rc = TRUE;
- error:
-  ENDINGS;
-  rc=!rc;
- optError:
-  exit(rc);
-}
- 
-#endif // utMAIN
-
 /* Local Variables: */
 /* mode: c */
 /* mode: font-lock */
