@@ -1,5 +1,5 @@
 /*=======================================================================
- * Version: $Id: supportTree.c,v 1.4 2015/06/03 14:03:40 nroche Exp $
+ * Version: $Id: supportTree.c,v 1.12 2015/10/02 18:02:21 nroche Exp $
  * Project: MediaTeX
  * Module : md5sumTree
  *
@@ -22,9 +22,7 @@
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  =======================================================================*/
 
-#include "../mediatex.h"
-#include "supportTree.h"
-#include "confTree.h"
+#include "mediatex-config.h"
 
 /*=======================================================================
  * Function   : cmpSupport
@@ -44,7 +42,7 @@ int cmpSupport(const void *p1, const void *p2)
   Support* a1 = *((Support**)p1);
   Support* a2 = *((Support**)p2);
 
-  rc = strncmp(a1->name, a2->name, MAX_SIZE_NAME);
+  rc = strncmp(a1->name, a2->name, MAX_SIZE_STRING);
   return rc;
 }
 
@@ -71,7 +69,7 @@ createSupport(void)
 
   return(rc);
  error:
-  logMemory(LOG_ERR, "%s", "malloc: cannot create Support");
+  logMemory(LOG_ERR, "malloc: cannot create Support");
   return destroySupport(rc);
 }
 
@@ -88,7 +86,7 @@ destroySupport(Support* self)
 {
   Support* rc = 0;
 
-  if(self != 0) {
+  if(self) {
     // we do not free the objects (owned by conf), just the rings
     self->collections = destroyOnlyRing(self->collections);
     free(self);
@@ -116,30 +114,34 @@ serializeSupport(Support* self, FILE *fd)
   if (fd == 0) fd = stdout;
 
   if(self == 0) {
-    logMemory(LOG_ERR, "%s", "cannot serialize empty support");
+    logMemory(LOG_ERR, "cannot serialize empty support");
     goto error;
   }
 
   if (localtime_r(&self->firstSeen, &firstSeen) == (struct tm*)0 ||
       localtime_r(&self->lastCheck, &lastCheck)  == (struct tm*)0 ||
       localtime_r(&self->lastSeen, &lastSeen) == (struct tm*)0 ) {
-    logMemory(LOG_ERR, "%s", "localtime_r returns on error");
+    logMemory(LOG_ERR, "localtime_r returns on error");
     goto error;
   }
 
-  fprintf(fd, "\
-%04i-%02i-%02i,%02i:%02i:%02i \
-%04i-%02i-%02i,%02i:%02i:%02i \
-%04i-%02i-%02i,%02i:%02i:%02i \
-%*s %*s %*lli %*s %s\n", 
+  fprintf(fd, 
+	  "%04i-%02i-%02i,%02i:%02i:%02i "
+	  "%04i-%02i-%02i,%02i:%02i:%02i "
+	  "%04i-%02i-%02i,%02i:%02i:%02i "
+	  "%*s %*s "
+	  "%*s %*s "
+	  "%*lli %*s %s\n", 
 	  firstSeen.tm_year + 1900, firstSeen.tm_mon+1, firstSeen.tm_mday,
 	  firstSeen.tm_hour, firstSeen.tm_min, firstSeen.tm_sec,
 	  lastCheck.tm_year + 1900, lastCheck.tm_mon+1, lastCheck.tm_mday,
 	  lastCheck.tm_hour, lastCheck.tm_min, lastCheck.tm_sec,
 	  lastSeen.tm_year + 1900, lastSeen.tm_mon+1, lastSeen.tm_mday,
 	  lastSeen.tm_hour, lastSeen.tm_min, lastSeen.tm_sec,
-	  MAX_SIZE_HASH, self->quickHash, 
-	  MAX_SIZE_HASH, self->fullHash, 
+	  MAX_SIZE_MD5, self->quickMd5sum, 
+	  MAX_SIZE_MD5, self->fullMd5sum, 
+	  MAX_SIZE_SHA, self->quickShasum, 
+	  MAX_SIZE_SHA, self->fullShasum, 
 	  MAX_SIZE_SIZE, (long long int)self->size, 
 	  MAX_SIZE_STAT, self->status, self->name);
 
@@ -165,11 +167,12 @@ serializeSupports()
   Support *supp = 0;
   RGIT* curr = 0;
   int uid = getuid();
+  mode_t mask;
 
-  logMemory(LOG_DEBUG, "%s", "serialize supports");
+  logMemory(LOG_DEBUG, "serialize supports");
 
   if ((conf = getConfiguration()) == 0) {
-    logMemory(LOG_ERR, "%s", "cannot load configuration");
+    logMemory(LOG_ERR, "cannot load configuration");
     goto error;
   }
 
@@ -179,12 +182,15 @@ serializeSupports()
   if (env.dryRun == FALSE) path = conf->supportDB;
   logMemory(LOG_INFO, "Serializing the supports list file: %s", 
 	  path?path:"stdout");
-  if (path != 0 && *path != (char)0) {
+  if (path && *path != (char)0) {
+    mask = umask(0177);
     if ((fd = fopen(path, "w")) == 0) {
       logMemory(LOG_ERR, "fdopen %s fails: %s", path, strerror(errno));
       fd = stdout;
+      mask = umask(mask);
       goto error;
     }
+    mask = umask(mask);
     if (!lock(fileno(fd), F_WRLCK)) goto error;
   }
 
@@ -192,14 +198,18 @@ serializeSupports()
   fprintf(fd, "# Version: $" "Id" "$\n");
   fprintf(fd, "# Local Supports:\n\n");
 
-  fprintf(fd, "# %17s %19s %19s %*s %*s %*s %*s %s\n", 
+  fprintf(fd, "# %17s %19s %19s "
+	  "%*s %*s "
+	  "%*s %*s "
+	  "%*s %*s %s\n", 
 	  "firstSeen", "lastCheck", "lastSeen",
-	  MAX_SIZE_HASH, "quickHash", MAX_SIZE_HASH, "fullHash",
+	  MAX_SIZE_MD5, "quickMd5sum", MAX_SIZE_MD5, "fullMd5sum",
+	  MAX_SIZE_SHA, "quickShasum", MAX_SIZE_SHA, "fullShasum",
 	  MAX_SIZE_SIZE, "size", MAX_SIZE_STAT, "status", "name");
 
   if (!isEmptyRing(conf->supports)) {
     if (!rgSort(conf->supports, cmpSupport)) goto error;
-    while((supp = rgNext_r(conf->supports, &curr))) {
+    while ((supp = rgNext_r(conf->supports, &curr))) {
       if (!serializeSupport(supp, fd)) goto error;
     }
   }
@@ -239,8 +249,8 @@ getSupport(char* name)
   logMemory(LOG_DEBUG, "getSupport %s", name);
   
   // look for support
-  while((rc = rgNext_r(conf->supports, &curr)) != 0)
-    if (!strncmp(rc->name, name, MAX_SIZE_NAME)) break;
+  while ((rc = rgNext_r(conf->supports, &curr)))
+    if (!strncmp(rc->name, name, MAX_SIZE_STRING)) break;
 
  error:
   return rc;
@@ -269,15 +279,15 @@ addSupport(char* name)
   // add new one if not already there
   if (!(conf = getConfiguration())) goto error;
   if ((supp = createSupport()) == 0) goto error;
-  strncpy(supp->name, name, MAX_SIZE_NAME);
-  supp->name[MAX_SIZE_NAME] = (char)0; // developpement code
+  strncpy(supp->name, name, MAX_SIZE_STRING);
+  supp->name[MAX_SIZE_STRING] = (char)0; // developpement code
   if (!rgInsert(conf->supports, supp)) goto error;
 
  end:
   rc = supp;
  error:
   if (rc == 0) {
-    logMemory(LOG_ERR, "%s", "fails to add a support");
+    logMemory(LOG_ERR, "fails to add a support");
     supp = destroySupport(supp);
   }
   return rc;
@@ -304,7 +314,7 @@ delSupport(Support* self)
 
   // delete support from collections rings
   curr = 0;
-  while((coll = rgNext_r(conf->collections, &curr)) != 0)
+  while ((coll = rgNext_r(conf->collections, &curr)))
     if (!delSupportFromCollection(self, coll)) goto error;
   
   // delete support from configuration ring
@@ -317,106 +327,30 @@ delSupport(Support* self)
   rc = TRUE;
  error:
  if (!rc) {
-    logMemory(LOG_ERR, "%s", "delSupport fails");
+    logMemory(LOG_ERR, "delSupport fails");
   }
   return rc;
 }
 
-/************************************************************************/
-
-#ifdef utMAIN
-#include "../misc/command.h"
-#include "utFunc.h"
-GLOBAL_STRUCT_DEF;
-
 /*=======================================================================
- * Function   : usage
- * Description: Print the usage.
- * Synopsis   : static void usage(char* programName)
- * Input      : programName = the name of the program; usually argv[0].
- * Output     : N/A
- =======================================================================*/
-static void 
-usage(char* programName)
-{
-  memoryUsage(programName);
-
-  memoryOptions();
-  //fprintf(stderr, "\t\t---\n");
-  return;
-}
-
-/*=======================================================================
- * Function   : main 
- * Author     : Nicolas ROCHE
- * modif      : 2012/05/01
- * Description: Unit test for confTree module.
- * Synopsis   : utconfTree
- * Input      : N/A
- * Output     : N/A
+ * Function   : isSupportFile
+ * Description: check if support is in fact a local file
+ * Synopsis   : int isSupportFile(Support* self)
+ * Input      : Support* self
+ * Output     : TRUE on success
  =======================================================================*/
 int 
-main(int argc, char** argv)
+isSupportFile(Support* self)
 {
-  Support* supp = 0;
-  // ---
-  int rc = 0;
-  int cOption = EOF;
-  char* programName = *argv;
-  char* options = MEMORY_SHORT_OPTIONS;
-  struct option longOptions[] = {
-    MEMORY_LONG_OPTIONS,
-    {0, 0, 0, 0}
-  };
+  int rc = FALSE;
 
-  // import mdtx environment
-  env.dryRun = FALSE;
-  env.debugMemory = TRUE;
-  getEnv(&env);
-
-  // parse the command line
-  while((cOption = getopt_long(argc, argv, options, longOptions, 0)) 
-	!= EOF) {
-    switch(cOption) {
-      
-      GET_MEMORY_OPTIONS; // generic options
-    }
-    if (rc) goto optError;
-  }
-
-  // export mdtx environment
-  if (!setEnv(programName, &env)) goto optError;
-
-  /************************************************************************/
-  // test types on this architecture:
-  off_t offset = 0xFFFFFFFFFFFFFFFFULL; // 2^64
-  time_t timer = 0x7FFFFFFF; // 2^32
-  logMemory(LOG_DEBUG, "type off_t is store into %u bytes", 
-	  (unsigned int)sizeof(off_t));
-  logMemory(LOG_DEBUG, "type time_t is store into %u bytes", 
-	  (unsigned int) sizeof(time_t));
-  logMemory(LOG_NOTICE,  "off_t max value is: %llu", 
-	  (unsigned long long int)offset);
-  logMemory(LOG_NOTICE, "time_t max value is: %lu", 
-	  (unsigned long int)timer);
-
-  // test memory tree
-  if (!createExempleSupportTree()) goto error;
-  if (!(supp = getSupport("SUPP11_logo.png"))) goto error;
-  if (!serializeSupports()) goto error;
-  /************************************************************************/
-
-  freeConfiguration();
-  rc = TRUE;
+  checkSupport(self);
+  rc = (*self->name == '/');
+  
  error:
-  ENDINGS;
-  rc=!rc;
- optError:
-  exit(rc);
+  return rc;
 }
 
-#endif // utMAIN
-
 /* Local Variables: */
 /* mode: c */
 /* mode: font-lock */
