@@ -1,5 +1,5 @@
 /*=======================================================================
- * Version: $Id: supportTree.h,v 1.3 2015/06/03 14:03:40 nroche Exp $
+ * Version: $Id: supportTree.h,v 1.7 2015/09/17 18:53:48 nroche Exp $
  * Project: MediaTeX
  * Module : archive tree
  *
@@ -22,20 +22,20 @@
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 =======================================================================*/
 
-#ifndef MEMORY_ADMSUPP_H
-#define MEMORY_ADMSUPP_H 1
+#ifndef MDTX_MEMORY_SUPP_H
+#define MDTX_MEMORY_SUPP_H 1
 
-#include "confTree.h"
-
-#include <sys/types.h>
+#include "mediatex-types.h"
 
 struct Support
 {
-  char     name[MAX_SIZE_NAME+1];
+  char     name[MAX_SIZE_STRING+1];
 
   Archive* archive;
-  char     quickHash[MAX_SIZE_HASH+1];
-  char     fullHash[MAX_SIZE_HASH+1];
+  char     quickMd5sum[MAX_SIZE_MD5+1];
+  char     fullMd5sum[MAX_SIZE_MD5+1];
+  char     quickShasum[MAX_SIZE_SHA+1];
+  char     fullShasum[MAX_SIZE_SHA+1];
 
   // off_t must be on 64bit to manage CDRom
   // (set -D_FILE_OFFSET_BITS=64 to CFLAGS)
@@ -67,7 +67,9 @@ Support* getSupport(char* label);
 Support* addSupport(char* label);
 int delSupport(Support* self);
 
-#endif /* MEMORY_ADMSUPP_H */
+int isSupportFile(Support* self);
+
+#endif /* MDTX_MEMORY_SUPP_H */
 
 /* Local Variables: */
 /* mode: c */
