@@ -1,10 +1,8 @@
 /* ======================================================================= 
- * Version: $Id: address.c,v 1.4 2015/06/03 14:03:43 nroche Exp $
- * Project: 
+ * Version: $Id: address.c,v 1.10 2015/08/07 17:50:31 nroche Exp $
+ * Project: Mediatex
  * Module : socket address
-
- * affect socket address
- * note: 
+ *
  * The  gethostbyname*()  and  gethostbyaddr*()  functions  are  obsolete.
  * Applications should use getaddrinfo(3) and getnameinfo(3) instead.
 
@@ -25,75 +23,81 @@
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  ======================================================================= */
 
-#include "../mediatex.h"
-#include "alloc.h"
-#include "log.h"
-#include "address.h"
+#include "mediatex-config.h"
 
-#include <string.h>  /* for memset */
-#include <netdb.h>
+#include <netdb.h> // gethostbyaddr_r
 
-#include <netinet/tcp.h> /* for TCP_NODELAY */
-#include <sys/socket.h>
-#include <arpa/inet.h>
+#include <sys/socket.h>  //
+#include <netinet/tcp.h> // inet_ntoa
+#include <arpa/inet.h>   //
+
+// It seems that gethostby*_r functions are obsolete too:
+//  https://sourceware.org/bugzilla/show_bug.cgi?id=515
+//  using 256 we get: gethostbyname_r fails: (-1) Resolver internal error
+#define GETHOSTBY_BUFFER_SIZE 1024
 
 
 /*=======================================================================
  * Function   : getHostNameByAddr
- * Author     : Nicolas ROCHE
  * Description: Retrieve the host name from the IP address
  * Synopsis   : getHostNameByAddr(struct in_addr* inAddr)
  * Input      : struct in_addr* inAddr
- * Output     : the host name
+ * Output     : an allocated string for the host name
  * Note       : Need an entry in /etc/hosts for local machine.
  *              Maybe need /etc/host.conf: order hosts,bind
  *              We should prefer to retrieve IP from hostname if possible
- * TODO       : use gethostbyaddr_r instead
  =======================================================================*/
 char*
 getHostNameByAddr(struct in_addr* inAddr)
 {
   char* rc = 0;
-  struct hostent  *sHost;
+  struct hostent sHost;
+  struct hostent *result = 0;
+  char buf[GETHOSTBY_BUFFER_SIZE];
+  int h_errnop = 0;
 
-  sHost = gethostbyaddr(inAddr, sizeof(struct in_addr), AF_INET);
+  if ((gethostbyaddr_r(inAddr, sizeof(struct in_addr), AF_INET,
+		       &sHost, buf, GETHOSTBY_BUFFER_SIZE, &result, &h_errnop)) 
+      || !result) {
+    logMisc(LOG_NOTICE, 
+	    "gethostbyaddr_r: cannot retrieve host name for %s: %s",
+	    inet_ntoa(*inAddr), hstrerror(h_errnop));
 
-  if (sHost == (struct hostent*)0) {
-    logEmit(LOG_NOTICE, 
-	    "gethostbyaddr: cannot retrieve host name for %s: %s",
-	    inet_ntoa(*inAddr), strerror(errno));
-    switch (h_errno) {
+    switch (h_errnop) {
     case HOST_NOT_FOUND:
-      logEmit(LOG_INFO, "gethostbyaddr: %s", "HOST_NOT_FOUND");
+      logMisc(LOG_INFO, "gethostbyaddr: %s", "HOST_NOT_FOUND");
       
       // do not found an hostname: use IP instead
       if ((rc = (char*)malloc(16)) == 0) {
-	logEmit(LOG_ERR, "%s", "malloc cannot allocate string for IP");
+	logMisc(LOG_ERR, "malloc cannot allocate string for IP");
 	goto error;
       }
       memset(rc, 0, 16);
       strcpy(rc, inet_ntoa(*inAddr));
       goto end;
     case NO_ADDRESS:
-      /* case NO_DATA: // same case value as NO_ADDRESS */
-      logEmit(LOG_ERR, "gethostbyaddr: %s", "NO_ADDRESS");
-      break;
+      logMisc(LOG_ERR, "gethostbyaddr: %s", "NO_ADDRESS");
+      goto error;
     case NO_RECOVERY:
-      logEmit(LOG_ERR, "gethostbyaddr: %s", "NO_RECOVERY");
+      logMisc(LOG_ERR, "gethostbyaddr: %s", "NO_RECOVERY");
       goto error;
     case TRY_AGAIN:
-      logEmit(LOG_ERR, "gethostbyaddr: %s", "TRY_AGAIN");
+      logMisc(LOG_ERR, "gethostbyaddr: %s", "TRY_AGAIN");
+      goto error;
+    case ERANGE:
+      logMisc(LOG_ERR, "gethostbyaddr: %s", "ERANGE");
       goto error;
     }
+    goto error;
   }
 
   // normal case (found a hostname)
-  if ((rc = (char*)malloc(strlen(sHost->h_name)+1)) == 0) {
-    logEmit(LOG_ERR, "malloc cannot allocate string of len %i+1",
-	    strlen(sHost->h_name));
+  if ((rc = (char*)malloc(strlen(sHost.h_name)+1)) == 0) {
+    logMisc(LOG_ERR, "malloc cannot allocate string of len %i+1",
+	    strlen(sHost.h_name));
     goto error;
   }
-  strcpy(rc, sHost->h_name);
+  strcpy(rc, sHost.h_name);
  end:
  error:
   return rc;
@@ -108,36 +112,44 @@ getHostNameByAddr(struct in_addr* inAddr)
  * Input      : char* hostname = the hostname
  *              struct in_addr *ipv4 = structure to fill
  * Output     : TRUE on success
- * TODO       : The  gethostbyname*() and gethostbyaddr*() functions are
- *              obsolete. Applications should use getaddrinfo(3) and 
- *              getnameinfo(3) instead.
  =======================================================================*/
 int
 getIpFromHostname(struct in_addr *ipv4, const char* hostname)
 {
-  struct hostent  *sHost = (struct hostent*)0;
+  int rc = FALSE;
   int a,b,c,d;
+  struct hostent sHost;
+  struct hostent *result = 0;
+  char buf[GETHOSTBY_BUFFER_SIZE];
+  int h_errnop = 0;
 
+  logMisc(LOG_DEBUG, "getIpFromHostname %s", hostname);
   memset(ipv4, 0, sizeof(struct in_addr));
 
   // It should be an ipv4 address or a host name.
   if (sscanf(hostname, "%d.%d.%d.%d", &a, &b, &c, &d) == 4) {
     if (inet_aton(hostname, ipv4) == 0) {
-      logEmit(LOG_ERR, "inet_aton: ", strerror(errno));
+      logMisc(LOG_ERR, "inet_aton: ", strerror(errno));
       goto error;
     }
   }
   else {
-    if ((sHost = gethostbyname(hostname)) == (struct hostent *)0) {
-      logEmit(LOG_ERR, "gethostbyname %s: %s", hostname, strerror(errno));
+    if (gethostbyname_r(hostname, &sHost, buf, GETHOSTBY_BUFFER_SIZE,
+			&result, &h_errnop)
+	|| !result) {
+      logMisc(LOG_ERR, "gethostbyname_r %s: %s", 
+	      hostname, hstrerror(h_errnop));
       goto error;
     }
-    *ipv4 = *((struct in_addr *) sHost->h_addr);
+    *ipv4 = *((struct in_addr *) sHost.h_addr);
   }
 
-  return TRUE;
+  rc = TRUE;
  error:
-  return FALSE;
+  if(!rc) {
+    logMisc(LOG_ERR, "getIpFromHostname fails");
+  }
+  return rc;
 }
 
 
@@ -163,7 +175,7 @@ buildSocketAddressEasy(struct sockaddr_in* rc,
   rc->sin_port        = htons(port);
   rc->sin_addr.s_addr = htonl(host);
 
-  logEmit(LOG_INFO, "build socket address %i.%i.%i.%i:%i", 
+  logMisc(LOG_INFO, "build socket address %i.%i.%i.%i:%i", 
 	  (ntohl(rc->sin_addr.s_addr) & 0xFF000000) >> 24,
 	  (ntohl(rc->sin_addr.s_addr) & 0x00FF0000) >> 16,
 	  (ntohl(rc->sin_addr.s_addr) & 0x0000FF00) >> 8,
@@ -202,11 +214,11 @@ buildSocketAddress(struct sockaddr_in* address,
   int port = -1;
   struct in_addr ipv4;
 
-  logEmit(LOG_DEBUG, "%s", "buildSocketAddress");
+  logMisc(LOG_DEBUG, "buildSocketAddress");
 
   // Convert protocol parameter (we need it for service conversion)
   if ((sProtocol = getprotobyname(protocol)) == (struct protoent *)0) {
-    logEmit(LOG_ERR, "getprotoyname: %s", strerror(errno));
+    logMisc(LOG_ERR, "getprotoyname: %s", strerror(errno));
     perror("getprotobyname");
     goto error;
   }
@@ -214,7 +226,7 @@ buildSocketAddress(struct sockaddr_in* address,
   // Convert service parameter. (we need to build socket address)
   // It should be a number or a string.
   if (service == 0 || *service == (char)0) {
-    logEmit(LOG_WARNING, "no port defined for %s address", host);
+    logMisc(LOG_WARNING, "no port defined for %s address", host);
     port = htons(CONF_PORT);
   }
   else if (sscanf(service, "%d", &port) == 1) {
@@ -223,7 +235,7 @@ buildSocketAddress(struct sockaddr_in* address,
   else {
     if ((sService = getservbyname(service, sProtocol->p_name)) 
 	== (struct servent*)0) {
-      logEmit(LOG_ERR, "getservbyname: cannot find '%s' in /etc/services", 
+      logMisc(LOG_ERR, "getservbyname: cannot find '%s' in /etc/services", 
 	      service);
       goto error;
     }
@@ -244,108 +256,11 @@ buildSocketAddress(struct sockaddr_in* address,
   rc = TRUE;
  error:
   if(!rc) {
-    logEmit(LOG_ERR, "%s", "buildSocketAddress fails");
+    logMisc(LOG_ERR, "buildSocketAddress fails");
   }
   return rc;
 }
 
-/************************************************************************/
-
-#ifdef utMAIN
-#include "command.h"
-GLOBAL_STRUCT_DEF;
-
-/*=======================================================================
- * Function   : usage
- * Description: Print the usage.
- * Synopsis   : static void usage(char* programName)
- * Input      : programName = the name of the program; usually argv[0].
- * Output     : N/A
- =======================================================================*/
-static void 
-usage(char* programName)
-{
-  miscUsage(programName);
-
-  miscOptions();
-  //fprintf(stderr, "\t\t---\n");
-
-  return;
-}
-
-
-/*=======================================================================
- * Function   : main 
- * Author     : Nicolas ROCHE
- * Description: Unit test for udp module
- * Synopsis   : utudp
- * Input      : -c option for client (else act as a server)
- * Output     : N/A
- =======================================================================*/
-int 
-main(int argc, char** argv)
-{
-  struct sockaddr_in address;
-  struct in_addr ipv4;
-  char* text = 0;
-  // ---
-  int rc = 0;
-  int cOption = EOF;
-  char* programName = *argv;
-  char* options = MISC_SHORT_OPTIONS"";
-  struct option longOptions[] = {
-    MISC_LONG_OPTIONS,
-    //{"input-file", required_argument, 0, 'i'},
-    {0, 0, 0, 0}
-  };
-
-  // import mdtx environment
-  getEnv(&env);
-
-  // parse the command line
-  while((cOption = getopt_long(argc, argv, options, longOptions, 0)) 
-	!= EOF) {
-    switch(cOption) {
-      
-      GET_MISC_OPTIONS; // generic options
-    }
-    if (rc) goto optError;
-  }
-
-  // export mdtx environment
-  if (!setEnv(programName, &env)) goto optError;
-
-  /************************************************************************/
-  if (!getIpFromHostname(&ipv4, "localhost")) goto error;;
-  printf("IP of localhost is: %s\n", inet_ntoa(ipv4)); 
-  
-  if (!buildSocketAddressEasy(&address, 0x7f000001, 7)) {
-    logEmit(LOG_ERR, "%s", "error while building socket address (1)");
-    goto error;
-  } 
- 
-  if ((text = getHostNameByAddr(&address.sin_addr)) == 0)
-    goto error;
-
-  printf("host name of 0x7f000001 is: %s\n", text);
-  free(text);
-
-  if (!buildSocketAddress(&address, "localhost", "udp", "echo")) {
-    logEmit(LOG_ERR, "%s", "error while building socket address (2)");
-    goto error;
-  }
-  /************************************************************************/
-
-  rc = TRUE;
- error:
-  ENDINGS;
-  rc=!rc;
- optError:
-  exit(rc);
-}
-
-#endif // utMAIN
-
 /* Local Variables: */
 /* mode: c */
 /* mode: font-lock */
