@@ -1,5 +1,5 @@
 /*=======================================================================
- * Version: $Id: command.c,v 1.4 2015/06/03 14:03:44 nroche Exp $
+ * Version: $Id: command.c,v 1.18 2015/10/08 21:43:50 nroche Exp $
  * Project: MediaTeX
  * Module : command
  *
@@ -23,19 +23,8 @@
  =======================================================================*/
 
 #include "mediatex-config.h"
-#include "command.h"
-#include "setuid.h"
-
-// for setEnv to call libraries befor setting memory
-#include <netdb.h> // gethostbyname, gethostbyaddr
-
-#include <unistd.h>
-#include <sys/types.h>
-#include <sys/wait.h>
 #include <libgen.h>    // basename
-
-#include <sys/stat.h> // open
-#include <fcntl.h>
+#include <sys/wait.h>  // waitpid
 
 extern char **environ;
 
@@ -50,14 +39,30 @@ void
 version()
 {
   fprintf(stderr, 
-	  "\n" PACKAGE_STRING " Copyright (C) 2014 <Nicolas Roche>\n"
-	  "\n<http://www.gnu.org/licenses/gpl.html>\n"
-	  "This program comes with ABSOLUTELY NO WARRANTY\n"
-	  "This is free software, and you are welcome to redistribute it\n"
-	  "\nPlease report bugs to: <" PACKAGE_BUGREPORT ">.\n"
-	  PACKAGE_NAME " home page: <http://www.nongnu.org/mediatex>.\n"
+	  PACKAGE_STRING "\n"
+	  "\nCopyright (C) 2014 2015 <Nicolas Roche>.\n"
+	  "License GPLv3+: GNU GPL version 3 or later"
+	  " <http://www.gnu.org/licenses/gpl.html>\n"
+	  "This is free software, and you are welcome to redistribute it.\n"
+	  "There is NO WARRANTY, to the extent permitted by law.\n"
+	  "\nWritten by Nicolas Roche.\n");
+}
+
+/*=======================================================================
+ * Function   : help
+ * Description: Print ending help
+ * Synopsis   : void help()
+ * Input      : N/A
+ * Output     : N/A
+ =======================================================================*/
+void 
+mdtxHelp()
+{
+  fprintf(stderr,
+	  "\nReport bugs to: <" PACKAGE_BUGREPORT ">.\n"
+	  PACKAGE_NAME " home page: <http://www.nongnu.org/mediatex>\n"
 	  "General help using GNU software: "
-	  "<http://www.gnu.org/gethelp/>\n\n");
+	  "<http://www.gnu.org/gethelp/>\n");
 }
 
 /*=======================================================================
@@ -70,10 +75,12 @@ version()
 void 
 miscUsage(char* programName)
 {
-  fprintf(stderr, "The usage for %s is:\n", basename(programName));
-  fprintf(stderr, "%s\t{ -h | -v |\n", basename(programName));
-  fprintf(stderr, "\t\t[ -f facility ] [ -s severity ] [ -l logFile ]");
-  fprintf(stderr, "\n\t\t[-a memoryLimit ] [ -n ] [ -A ] [ -S ]");
+  fprintf(stderr, "\nUsage: %s", basename(programName));
+  fprintf(stderr, 
+	  "-h | -v |"
+	  " [ -f facility ] [ -l logFile ]"
+	  " [ -s severity[:module(,module)*] ]"
+	  " [ -m memoryLimit ] [ -S ] [ -n ]");
 }
 
 /*=======================================================================
@@ -86,7 +93,6 @@ miscUsage(char* programName)
 void 
 memoryUsage(char* programName)
 {
-  fprintf(stderr, "\n\t\t[ -M ]");
   miscUsage(programName);
 }
 
@@ -101,7 +107,7 @@ void
 parserUsage(char* programName)
 {
   memoryUsage(programName);
-  fprintf(stderr, "\n\t\t[ -L ] [ -P ]");
+  fprintf(stderr, " [ -L ]");
 }
 
 /*=======================================================================
@@ -115,7 +121,7 @@ void
 mdtxUsage(char* programName)
 {
   parserUsage(programName);
-  fprintf(stderr, "\n\t\t[ -O ] [ -c confFile ]");
+  fprintf(stderr, " [ -c confFile ]");
 }
 
 /*=======================================================================
@@ -129,20 +135,21 @@ void
 miscOptions()
 {
   fprintf(stderr, 
-	  " }\nwhere:\n"
+	  "\n\nOptions:\n"
 	  "  -h, --help\t\tdisplay this message\n"
 	  "  -v, --version\t\tdisplay the " PACKAGE_NAME 
 	  " software version\n"
-	  "  -f, --facility\tuse facility for logging\n"
+	  "  -f, --facility\tset facility to use for logging\n"
 	  "\t\t\tsee syslog(3) : mainly 'file' or 'local2' here\n"
-	  "  -s, --severity\tuse severity for logging\n"
-	  "\t\t\tamongs 'err' 'warning' 'notice' 'info' 'debug'\n"
-	  "  -l, --log-file\tlog to logFile\n"
-	  "\t\t\tneed to be coupled with the 'file' facility\n"
-	  "  -a, --memory-limit\tlimit for malloc in Mo\n"
-	  "  -n, --dry-run\t\tdo a dry run\n"
-	  "  -A, --debug-alloc\tenable logs from malloc/free\n"
-	  "  -S, --debug-script\tdo not hide outpouts from scripts\n");
+	  "  -l, --log-file\tlog into a file\n"
+	  "\t\t\tneeds 'file' facility (default)\n"
+	  "  -s, --severity\tset severity to log, by modules.\n"
+	  "\t\t\tamongs 'err', 'warning', 'notice', 'info', 'debug';\n"
+	  "\t\t\tmodules amongs 'alloc', 'script', 'misc', 'memory', "
+	  "'parser', 'common', 'main'\n"
+	  "  -m, --memory-limit\tnice limit for malloc in Mo\n"
+	  "  -S, --script-out\tenable stdout for scripts\n"
+	  "  -n, --dry-run\t\tdo a dry run\n");
 }
 
 /*=======================================================================
@@ -156,8 +163,6 @@ void
 memoryOptions()
 {
   miscOptions();
-  fprintf(stderr,
-	  "  -M, --debug-memory\tenable logs from the memory objects\n");
 }
 
 /*=======================================================================
@@ -172,8 +177,7 @@ parserOptions()
 {
   memoryOptions();
   fprintf(stderr, 
-	  "  -L, --debug-lexer\tdebug information from lexers\n"
-	  "  -P, --debug-parser\tenable logs from the parsers\n");
+	  "  -L, --debug-lexer\tdebug information from lexers\n");
 }
 
 /*=======================================================================
@@ -188,9 +192,7 @@ mdtxOptions()
 {
   parserOptions();
   fprintf(stderr, 
-	  "  -C, --debug-common\tenable logs from the common code\n"
-	  "  -c, --conf-label\tto overhide default configuration file"
-	  " mdtx.conf\n");
+	  "  -c, --conf-label\toverhide 'mdtx.conf' configuration file\n");
 }
 
 /*=======================================================================
@@ -204,20 +206,37 @@ void
 getEnv(MdtxEnv* self)
 {
   char* tmpValue = 0;
+  int i =0;
+
+  static char logModuleVar[7][32] = {
+    "MDTX_LOG_SEVERITY_ALLOC",
+    "MDTX_LOG_SEVERITY_SCRIPT",
+    "MDTX_LOG_SEVERITY_MISC",
+    "MDTX_LOG_SEVERITY_MEMORY",
+    "MDTX_LOG_SEVERITY_PARSER",
+    "MDTX_LOG_SEVERITY_COMMON",
+    "MDTX_LOG_SEVERITY_MAIN"
+  };
 
   // no logging available here
  
   // check the environment variables
-  if ((tmpValue = getenv("MDTX_LOG_FILE")) != 0)
+  if ((tmpValue = getenv("MDTX_LOG_FACILITY")))
+    self->logFacility = getLogFacility(tmpValue);
+  if ((tmpValue = getenv("MDTX_LOG_FILE")))
     self->logFile = tmpValue;
-  if ((tmpValue = getenv("MDTX_LOG_FACILITY")) != 0)
-    self->logFacility = tmpValue;
-  if ((tmpValue = getenv("MDTX_LOG_SEVERITY")) != 0)
-    self->logSeverity = tmpValue;
-  if ((tmpValue = getenv("MDTX_MDTXUSER")) != 0)
+
+  for (i=0; i<LOG_MAX_MODULE; ++i) {
+    if ((tmpValue = getenv(logModuleVar[i])))
+      self->logSeverity[i] = getLogSeverity(tmpValue);
+  }
+
+  if ((tmpValue = getenv("MDTX_MDTXUSER")))
     self->confLabel = tmpValue;
-  if ((tmpValue = getenv("MDTX_DRY_RUN")) != 0)
+  if ((tmpValue = getenv("MDTX_DRY_RUN")))
     self->dryRun = !strncmp(tmpValue, "1", 2);
+  if ((tmpValue = getenv("MDTX_NO_REGRESSION")))
+    self->noRegression = !strncmp(tmpValue, "1", 2);
 }
 
 /*=======================================================================
@@ -233,59 +252,68 @@ int
 setEnv(char* programName, MdtxEnv *self)
 {
   int rc = FALSE;
-  int logFacility = -1;
-  int logSeverity = -1;
-  LogHandler* logHandler = 0;
+  int ko = FALSE;
+  int i = 0;
 
-  // no logging available here
+  static char logModuleVar[7][32] = {
+    "MDTX_LOG_SEVERITY_ALLOC",
+    "MDTX_LOG_SEVERITY_SCRIPT",
+    "MDTX_LOG_SEVERITY_MISC",
+    "MDTX_LOG_SEVERITY_MEMORY",
+    "MDTX_LOG_SEVERITY_PARSER",
+    "MDTX_LOG_SEVERITY_COMMON",
+    "MDTX_LOG_SEVERITY_MAIN"
+  };
+
+  // no logging available yet here
+
+  // unset previous log handler if it exists (on bad malloc init)
+  self->logHandler = logClose(self->logHandler);
 
   // set the log handler
-  if ((logFacility = getLogFacility(self->logFacility)) == -1) {
-    fprintf(stderr, "%s: incorrect facility name '%s'\n", 
-	    programName, optarg); goto error;
-  }
-  if ((logSeverity = getLogSeverity(self->logSeverity)) == -1) {
-    fprintf(stderr, "%s: incorrect severity name '%s'\n", 
-	    programName, optarg); goto error;
-  }
-  if((logHandler = 
-      logOpen(programName, logFacility, logSeverity, self->logFile)) 
-     == 0) {
+  if(!(self->logHandler = 
+       logOpen(programName, self->logFacility, self->logSeverity, 
+	       self->logFile))) {
     fprintf(stderr, "%s: cannot allocate the logHandler\n", programName);
     goto error;
   }
-  logDefault(logHandler);
 
-#ifdef utMAIN
-  logEmit(LOG_DEBUG, "%s", "set the environment variables");
-#endif
+  logMisc(LOG_DEBUG, "set the environment variables");
 
-  // export the environment
-  if (setenv("MDTX_LOG_FILE", self->logFile, 1) == -1
-      || setenv("MDTX_LOG_FACILITY", self->logFacility, 1) == -1
-      || setenv("MDTX_LOG_SEVERITY", self->logSeverity, 1) == -1
-      || setenv("MDTX_MDTXUSER", self->confLabel, 1) == -1
-      || setenv("MDTX_DRY_RUN", self->dryRun?"1":"0", 1) == -1
-      || setenv("LD_LIBRARY_PATH", "", 1) == -1
-      || setenv("IFS", "", 1) == -1
-      ) {
-    logEmit(LOG_ERR, "setenv variables failed: ", strerror(errno));
-    goto error;
+  // export the environment (used by executed binaries or scripts)
+  ko=ko| setenv("MDTX_LOG_FACILITY", self->logHandler->facility->name, 1);
+  ko=ko| setenv("MDTX_LOG_FILE", self->logFile?self->logFile:"", 1);
+
+  for (i=0; !ko && i<LOG_MAX_MODULE; ++i) {
+    ko=ko| setenv(logModuleVar[i], self->logHandler->severity[i]->name, 1);
   }
 
-  // export srcdir (first used by "make check") to source scripts
-  // too after installation
-  if (setenv("srcdir", CONF_SCRIPTS , 1) == -1)
-    goto error;
+  ko=ko| setenv("MDTX_MDTXUSER", self->confLabel, 1);
+  ko=ko| setenv("MDTX_DRY_RUN", self->dryRun?"1":"0", 1);
+  ko=ko| setenv("LD_LIBRARY_PATH", "", 1);
+  ko=ko| setenv("IFS", "", 1);
 
-  // - record a callback to free memory if malloc fails
-  initMalloc(env.allocLimit*MEGA, env.allocDiseaseCallBack);
+  if (ko) {
+    logMisc(LOG_ERR, "setenv variables failed: ", strerror(errno));
+    goto error2;
+  }
+
+  // Because of "make distcheck", scripts use $srcdir to source each
+  // others. Here, we reuse this automake variable so as scripts will
+  // still be able to source each others after installation.
+  if (setenv("srcdir", CONF_SCRIPTS , 1) == -1)
+    goto error2;
+
+  // custumize malloc, record a callback to free memory if malloc fails
+  if (!initMalloc(self->allocLimit*MEGA, self->allocDiseaseCallBack))
+    goto error;
 
   rc = TRUE;
- error:
+ error2:
   if (!rc) {
-    logEmit(LOG_ERR, "%s", "fails to set the environment variables");
+    logMisc(LOG_ERR, "fails to set the environment variables");
   }
+ error:
   return rc;
 }
 
@@ -303,12 +331,10 @@ execChild(char** argv, int doHideStderr)
   int rc = 0;
   int fd;
 
-#ifndef utMAIN
   if (argv[0][0] != '/') {
-    logEmit(LOG_ERR, "%s", "refuse to exec from a relative path");
+    logMisc(LOG_ERR, "refuse to exec from a relative path");
     goto error;
   }
-#endif
 
   // be quiet: close stdout
   if (!env.debugScript) {
@@ -320,13 +346,11 @@ execChild(char** argv, int doHideStderr)
   }
 
   rc = execve(argv[0], argv, environ);
-#ifndef utMAIN
  error:
-#endif
   if (rc == -1) {
-    logEmit(LOG_ERR, "execve failed: ", strerror(errno));
+    logMisc(LOG_ERR, "execve failed: ", strerror(errno));
   } else {
-    logEmit(LOG_ERR, "%s", "execve returns: you should improve ram");
+    logMisc(LOG_ERR, "execve returns: you should improve ram");
   }
 }
 
@@ -351,22 +375,22 @@ execScript(char** argv, char* user, char* pwd, int doHideStderr)
   int i = 0;
   
   if (argv[0] == 0 || *argv[0] == (char)0) {
-    logEmit(LOG_ERR, "%s", "please provide a script to exec");
+    logMisc(LOG_ERR, "please provide a script to exec");
     goto error;
   }
 
-  logEmit(LOG_INFO, "execScript%s%s%s%s: %s", 
+  logMisc(LOG_INFO, "execScript%s%s%s%s: %s", 
 	  user?" as ":"", user?user:"", 
 	  pwd?" PWD=":"", pwd?pwd:"",
 	  argv[0]);
 
-  while (argv[++i] != 0 && *argv[i] != (char)0) {
-    logEmit(LOG_INFO, " arg%i: %s", i, argv[i]);
+  while (argv[++i] && *argv[i] != (char)0) {
+    logMisc(LOG_INFO, " arg%i: %s", i, argv[i]);
   }
 
   // fork: new process
   if ((childId = fork()) == -1) {
-      logEmit(LOG_ERR, "fork failed: ", strerror(errno));
+      logMisc(LOG_ERR, "fork failed: ", strerror(errno));
       goto error;
     }
   
@@ -374,32 +398,28 @@ execScript(char** argv, char* user, char* pwd, int doHideStderr)
   case 0:
     // child
 
-#ifndef utMAIN
     // change user
     if (user && !becomeUser(user, FALSE)) goto error;
-#else
-    (void) user;
-#endif
 
     // change working directory
     if (pwd && chdir(pwd)) {
-      logEmit(LOG_ERR, "chdir fails: %s", strerror(errno));
+      logMisc(LOG_ERR, "chdir fails: %s", strerror(errno));
       goto error;
     }
 
     execChild(argv, doHideStderr);
-    logEmit(LOG_ERR, "failed to exec %s", argv[0]);
+    logMisc(LOG_ERR, "failed to exec %s", argv[0]);
     exit(EXIT_FAILURE);
     break;
  
   default:
    // father
     if ((pid = waitpid(childId, &status, 0)) == -1) {
-      logEmit(LOG_ERR, "wait failed (%i): %s", errno, strerror(errno));
+      logMisc(LOG_ERR, "wait failed (%i): %s", errno, strerror(errno));
       goto error;
     }
     if (pid != childId) {
-      logEmit(LOG_ERR, 
+      logMisc(LOG_ERR, 
 	      "wait exit with unexpected process %i (waiting for %i)", 
 	      rc, childId);
       goto error;
@@ -407,115 +427,18 @@ execScript(char** argv, char* user, char* pwd, int doHideStderr)
   }
 
   if (WIFEXITED(status)) rcChild = WEXITSTATUS(status);
-  logEmit(LOG_INFO, "%s execution returns %i", argv[0], rcChild);
+  logMisc(LOG_INFO, "%s execution returns %i", argv[0], rcChild);
   if (rcChild == -1) {
-    logEmit(LOG_INFO, "%s", "if -1 you may try to improve ram");
+    logMisc(LOG_INFO, "if -1 you may try to improve ram");
   }
   rc = (rcChild == EXIT_SUCCESS);
  error:
   if (!rc) {
-    logEmit(LOG_ERR, "%s", "execScript fails");
+    logMisc(LOG_ERR, "execScript fails");
   }
   return rc;
 }
 
-/************************************************************************/
-
-#ifdef utMAIN
-GLOBAL_STRUCT_DEF;
-
-/*=======================================================================
- * Function   : usage
- * Description: Print the usage.
- * Synopsis   : static void usage(char* programName)
- * Input      : programName = the name of the program; usually argv[0].
- * Output     : N/A
- =======================================================================*/
-static void 
-usage(char* programName)
-{
-  mdtxUsage(programName);
-  fprintf(stderr, "\n\t\t[ -i scriptPath ]");
-
-  mdtxOptions();
-  fprintf(stderr, "  ---\n");
-  fprintf(stderr, "  -i, --input-file\tinput script to exec\n");
-
-  return;
-}
-
-
-/*=======================================================================
- * Function   : main 
- * Author     : Nicolas ROCHE
- * modif      : 2012/11/11
- * Description: Unit test for md5sum module
- * Synopsis   : ./utcommand -i scriptPath
- * Input      : -i option for scriptPath to exec
- * Output     : N/A
- =======================================================================*/
-int 
-main(int argc, char** argv)
-{
-  char* inputFile = 0;
-  char *argvExec[] = { 0, "parameter1", 0};
-  // ---
-  int rc = 0;
-  int cOption = EOF;
-  char* programName = *argv;
-  char* options = MDTX_SHORT_OPTIONS"i:";
-  struct option longOptions[] = {
-    MDTX_LONG_OPTIONS,
-    {"input-file", required_argument, 0, 'i'},
-    {0, 0, 0, 0}
-  };
-
-  // import mdtx environment
-  getEnv(&env);
-
-  // parse the command line
-  while((cOption = getopt_long(argc, argv, options, longOptions, 0)) 
-	!= EOF) {
-    switch(cOption) {
-      
-    case 'i':
-      if(optarg == 0 || *optarg == (char)0) {
-	fprintf(stderr, "%s: nil or empty argument for the input stream\n", 
-		programName);
-	rc = EINVAL;
-      }
-      inputFile = optarg;
-      break;
-      
-      GET_MDTX_OPTIONS; // generic options
-    }
-    if (rc) goto optError;
-  }
-
-  // export mdtx environment
-  if (!setEnv(programName, &env)) goto optError;
-
-  /************************************************************************/
-  if (inputFile == 0) {
-    usage(programName);
-    //logEmit(LOG_ERR, "%s", "Please provide an input file");
-    goto error;
-  }
-
-  argvExec[0] = inputFile;
-  if (!execScript(argvExec, 0, 0, FALSE)) goto error;
-  /************************************************************************/
-
-  rc = TRUE;
- error:
-  ENDINGS;
-  rc=!rc;
- optError:
-  exit(rc);
-}
-
-#endif // utMAIN
-
 /* Local Variables: */
 /* mode: c */
 /* mode: font-lock */
