@@ -1,5 +1,5 @@
 /*=======================================================================
- * Version: $Id: command.h,v 1.3 2015/06/03 14:03:44 nroche Exp $
+ * Version: $Id: command.h,v 1.13 2015/10/01 21:52:40 nroche Exp $
  * Project: MediaTeX
  * Module : command
  *
@@ -22,13 +22,13 @@
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  =======================================================================*/
 
-#ifndef MISC_COMMAND_H
-#define MISC_COMMAND_H 1
+#ifndef MDTX_MISC_COMMAND_H
+#define MDTX_MISC_COMMAND_H 1
 
-#include "alloc.h"
+#include "mediatex-types.h"
 #include <getopt.h>
 
-#define MISC_SHORT_OPTIONS "hvf:s:l:na:AS"
+#define MISC_SHORT_OPTIONS "hvf:s:l:nm:S"
 #define MISC_LONG_OPTIONS				\
   {"help", no_argument, 0, 'h'},			\
   {"version", no_argument, 0, 'v'},			\
@@ -36,26 +36,22 @@
   {"severity", required_argument, 0, 's'},		\
   {"log-file", required_argument, 0, 'l'},		\
   {"dry-run", no_argument, 0, 'n'},			\
-  {"alloc-limit", required_argument, 0, 'a'},		\
-  {"debug-alloc", no_argument, 0, 'A'},			\
-  {"debug-script", required_argument, 0, 'S'}
+  {"memory-limit", required_argument, 0, 'm'},		\
+  {"script-out", required_argument, 0, 'S'}
 
-#define MEMORY_SHORT_OPTIONS MISC_SHORT_OPTIONS "M"
+#define MEMORY_SHORT_OPTIONS MISC_SHORT_OPTIONS
 #define MEMORY_LONG_OPTIONS				\
-  MISC_LONG_OPTIONS,					\
-  {"debug-memory", no_argument, 0, 'M'}			
+  MISC_LONG_OPTIONS
 
-#define PARSER_SHORT_OPTIONS MEMORY_SHORT_OPTIONS "LP"
+#define PARSER_SHORT_OPTIONS MEMORY_SHORT_OPTIONS "L"
 #define PARSER_LONG_OPTIONS			        \
   MEMORY_LONG_OPTIONS,					\
-  {"debug-lexer", no_argument, 0, 'L'},			\
-  {"debug-parser", no_argument, 0, 'P'}
+  {"debug-lexer", no_argument, 0, 'L'}
 
-#define MDTX_SHORT_OPTIONS PARSER_SHORT_OPTIONS "c:C"
+#define MDTX_SHORT_OPTIONS PARSER_SHORT_OPTIONS "c:a"
 #define MDTX_LONG_OPTIONS				\
   PARSER_LONG_OPTIONS,					\
-  {"conf-label", required_argument, 0, 'c'},		\
-  {"debug-Common", no_argument, 0, 'C'}
+  {"conf-label", required_argument, 0, 'c'}
 
 void version();
 
@@ -63,6 +59,7 @@ void miscUsage(char* programName);
 void memoryUsage(char* programName);
 void parserUsage(char* programName);
 void mdtxUsage(char* programName);
+void mdtxHelp();
 
 void miscOptions();
 void memoryOptions();
@@ -108,7 +105,11 @@ int execScript(char** argv, char* user, char* pwd, int doHideStderr);
 	      programName);						\
       rc = EINVAL;							\
     }									\
-    env.logFacility = optarg;						\
+    if ((env.logFacility = getLogFacility(optarg)) == -1) {		\
+      fprintf(stderr, "%s: incorrect facility name '%s'\n",		\
+	      programName, optarg);					\
+      rc = EINVAL;							\
+    }									\
     break;								\
 									\
   case 's':								\
@@ -118,7 +119,9 @@ int execScript(char** argv, char* user, char* pwd, int doHideStderr);
 	      programName);						\
       rc = EINVAL;							\
     }									\
-    env.logSeverity = optarg;						\
+    if (!parseLogSeverityOption(optarg, env.logSeverity)) {		\
+      rc = EINVAL;							\
+    }									\
     break;								\
 									\
   case 'l':								\
@@ -135,10 +138,10 @@ int execScript(char** argv, char* user, char* pwd, int doHideStderr);
     env.dryRun = 1;							\
     break;								\
 									\
-   case 'a':								\
+  case 'm':								\
     if(optarg == (char*)0 || *optarg == (char)0) {			\
       fprintf(stderr,							\
-	      "%s: nil or empty argument for the nice limit\n",		\
+	      "%s: nil or empty argument for the nice memory limit\n",	\
 	      programName);						\
       rc = EINVAL;							\
       rc = 1;								\
@@ -146,10 +149,6 @@ int execScript(char** argv, char* user, char* pwd, int doHideStderr);
     env.allocLimit = atoi(optarg);					\
     break;								\
 									\
-  case 'A':								\
-    env.debugAlloc = 1;							\
-    break;								\
-									\
   case 'S':								\
     env.debugScript = 1;						\
     break;								\
@@ -166,9 +165,6 @@ int execScript(char** argv, char* user, char* pwd, int doHideStderr);
  * Output     : N/A
  =======================================================================*/
 #define GET_MEMORY_OPTIONS 						\
-  case 'M':								\
-    env.debugMemory = 1;						\
-    break;								\
 									\
   GET_MISC_OPTIONS;
 
@@ -185,12 +181,8 @@ int execScript(char** argv, char* user, char* pwd, int doHideStderr);
   case 'L':								\
     env.debugLexer = 1;							\
     break;								\
-  									\
- case 'P':								\
-   env.debugParser = 1;							\
-   break;								\
     									\
- GET_MEMORY_OPTIONS;
+   GET_MEMORY_OPTIONS;
 
 /*=======================================================================
  * Macro      : GET_MDTX_OPTIONS
@@ -211,10 +203,6 @@ int execScript(char** argv, char* user, char* pwd, int doHideStderr);
     env.confLabel = optarg;						\
     break;								\
 									\
-  case 'C':								\
-    env.debugCommon = 1;						\
-    break;								\
-   									\
   GET_PARSER_OPTIONS;
 
 /*=======================================================================
@@ -224,13 +212,15 @@ int execScript(char** argv, char* user, char* pwd, int doHideStderr);
  * Input      : N/A
  * Output     : N/A
  =======================================================================*/
-#define ENDINGS							\
-  logEmit(LOG_INFO, "exit on %s", rc?"success":"error");	\
-  if (env.debugAlloc) memoryStatus(LOG_NOTICE);			\
-  exitMalloc();							\
-  DefaultLog = logClose(DefaultLog)
+#define ENDINGS								\
+  logMain(LOG_INFO, "exit on %s", rc?"success":"error");		\
+  if (!env.noRegression) {						\
+    memoryStatus(LOG_INFO, __FILE__, __LINE__);				\
+  }									\
+  exitMalloc();								\
+  env.logHandler = logClose(env.logHandler)
 
-#endif /* MISC_COMMAND_H */
+#endif /* MDTX_MISC_COMMAND_H */
 
 /* Local Variables: */
 /* mode: c */
