@@ -1,9 +1,9 @@
 /*=======================================================================
- * Version: $Id: cypher.c,v 1.3 2015/06/03 14:03:44 nroche Exp $
+ * Version: $Id: cypher.c,v 1.7 2015/08/13 21:14:35 nroche Exp $
  * Project: MediaTeX
- * Module : checksums
+ * Module : cypher
  *
- * md5sum computation
+ * aes encryption
 
  MediaTex is an Electronic Records Management System
  Copyright (C) 2014 2015 Nicolas Roche
@@ -22,11 +22,7 @@
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  =======================================================================*/
 
-#include "log.h"
-#include "tcp.h"
-#include "cypher.h"
-
-//#include <stdarg.h>
+#include "mediatex-config.h"
 
 /*=======================================================================
  * Function   : aesInit
@@ -45,9 +41,10 @@ aesInit(AESData* data, char key[MAX_SIZE_AES+1], MDTX_AES_WAY way)
   int rc = FALSE;
 
   if (key == 0 || key[MAX_SIZE_AES] != (char)0) goto error;
-  logEmit(LOG_DEBUG, "loadAesKey: '%s'", key);
+  logMisc(LOG_DEBUG, "loadAesKey: '%s' for %s", key,
+	  way==ENCRYPT?"writing":(way==DECRYPT?"reading":"??"));
   if (data == 0) {
-    logEmit(LOG_ERR, "%s", "please provide a AESData structure");
+    logMisc(LOG_ERR, "please provide a AESData structure");
     goto error;
   }
 
@@ -58,8 +55,8 @@ aesInit(AESData* data, char key[MAX_SIZE_AES+1], MDTX_AES_WAY way)
      * holding a transformed version of the key, for efficiency. 
      */
     if (AES_set_encrypt_key((const unsigned char *) key, 
-			    128, &data->aesKey) != 0) {
-      logEmit(LOG_ERR, "%s", "AES_set_encrypt_key fails");
+			    128, &data->aesKey)) {
+      logMisc(LOG_ERR, "AES_set_encrypt_key fails");
       goto error;
     }
     break;
@@ -71,14 +68,14 @@ aesInit(AESData* data, char key[MAX_SIZE_AES+1], MDTX_AES_WAY way)
      * AESkey is changing (for reasons of efficiency).
      */
     if (AES_set_decrypt_key((const unsigned char *) key, 
-			    128, &data->aesKey) != 0) {
-      logEmit(LOG_ERR, "%s", "AES_set_decrypt_key fails");
+			    128, &data->aesKey)) {
+      logMisc(LOG_ERR, "AES_set_decrypt_key fails");
       goto error;
     }
     break;
 
   default:
-    logEmit(LOG_ERR, "%s", "crypt way should be ENCRYPT or DECRYPT");
+    logMisc(LOG_ERR, "crypt way should be ENCRYPT or DECRYPT");
     goto error;
   }
   
@@ -95,7 +92,7 @@ aesInit(AESData* data, char key[MAX_SIZE_AES+1], MDTX_AES_WAY way)
   rc = TRUE;
  error:
   if (!rc) {
-    logEmit(LOG_ERR, "%s", "loadAesKey fails");
+    logMisc(LOG_ERR, "loadAesKey fails");
   }
   return rc;
 }
@@ -113,12 +110,10 @@ doCypher(AESData* data) {
   int rc = FALSE;
   //int i;
 
-#ifdef utMAIN
-  logEmit(LOG_DEBUG, "%s", "doCypher");
-#endif
+  logMisc(LOG_DEBUG, "doCypher");
 
   if (data == 0) {
-    logEmit(LOG_ERR, "%s", "please provide a AESData structure");
+    logMisc(LOG_ERR, "please provide a AESData structure");
     goto error;
   }
 
@@ -153,14 +148,14 @@ doCypher(AESData* data) {
     break;
     
   default:
-    logEmit(LOG_ERR, "%s", "crypt order should be ENCRYPT or DECRYPT");
+    logMisc(LOG_ERR, "crypt order should be ENCRYPT or DECRYPT");
     goto error;
   }
 
   rc = TRUE;
  error:
   if (!rc) {
-    logEmit(LOG_ERR, "%s", "doCypher fails");
+    logMisc(LOG_ERR, "doCypher fails");
   }
   return rc;
 }
@@ -185,22 +180,21 @@ fdWrite(int fd, void* buffer, size_t bufferSize)
   while (remaining > 0){
     while ((writen = write(fd, next, remaining)) == -1) {
       if (errno == EINTR) {
-	logEmit(LOG_WARNING, "writting file interrupted by kernel: %s",
+	logMisc(LOG_WARNING, "writting file interrupted by kernel: %s",
 		strerror(errno));
 	continue;
       }
       if (errno != EAGAIN) {
-	logEmit(LOG_ERR, "writting file error: %s", strerror(errno));
+	logMisc(LOG_ERR, "writting file error: %s", strerror(errno));
 	goto error;
       }
-      logEmit(LOG_WARNING, "writting file keep EAGAIN error: %s", 
+      logMisc(LOG_WARNING, "writting file keep EAGAIN error: %s", 
 	      strerror(errno));
     }
     remaining -= writen;
     next += writen;
-/* #ifdef utMAIN */
-/*     logEmit(LOG_INFO, "written %d ; remain %d", writen, remaining); */
-/* #endif */
+
+    //logMisc(LOG_INFO, "written %d ; remain %d", writen, remaining); */
   }
 
   rc = (remaining == 0);
@@ -225,22 +219,21 @@ fdRead(int fd, void* buffer, size_t bufferSize)
   size_t remaining = bufferSize;
   ssize_t nread = -1;
 
-  while (remaining > 0 && (nread = read(fd, next, remaining)) != 0) {
+  while (remaining > 0 && (nread = read(fd, next, remaining))) {
     if (nread == -1) {
       if (errno != EINTR) {
-	logEmit(LOG_ERR, "reading file error: %s", strerror(errno));
+	logMisc(LOG_ERR, "reading file error: %s", strerror(errno));
 	goto error;
       }
-      logEmit(LOG_WARNING, "reading file interrupted by kernel: %s",
+      logMisc(LOG_WARNING, "reading file interrupted by kernel: %s",
 	      strerror(errno));
     }
     else {
       rc += nread;
       next += nread;
       remaining -= nread;
-/* #ifdef utMAIN */
-/*       logEmit(LOG_INFO, "read %d ; remain %d", rc, remaining); */
-/* #endif */
+
+      //logMisc(LOG_INFO, "read %d ; remain %d", rc, remaining); */
     }
   }
 
@@ -261,17 +254,15 @@ aesFlush(AESData* data)
 {
   int rc = FALSE;
 
-#ifdef utMAIN
-  logEmit(LOG_DEBUG, "%s", "aesFlush"); 
-#endif
+  logMisc(LOG_DEBUG, "aesFlush"); 
 
   if (data == 0) {
-    logEmit(LOG_ERR, "%s", "please provide a AESData structure");
+    logMisc(LOG_ERR, "please provide a AESData structure");
     goto error;
   }
 
   if (data->way != ENCRYPT) {
-    logEmit(LOG_ERR, "%s", "AESData isn't initialized for writing");
+    logMisc(LOG_ERR, "AESData isn't initialized for writing");
     goto error;
   }
 
@@ -295,7 +286,7 @@ aesFlush(AESData* data)
   rc = TRUE;
  error:
   if (!rc) {
-    logEmit(LOG_ERR, "%s", "aesFlush fails");
+    logMisc(LOG_ERR, "aesFlush fails");
   }
 
   return rc;
@@ -324,17 +315,15 @@ aesPrint(AESData* data, const char* format, ...)
   int len = 0;
   int max = 0;
 
-#ifdef utMAIN
-  logEmit(LOG_DEBUG, "%s", "aesPrint"); 
-#endif
+  logMisc(LOG_DEBUG, "aesPrint"); 
 
   if (data == 0) {
-    logEmit(LOG_ERR, "%s", "please provide a AESData structure");
+    logMisc(LOG_ERR, "please provide a AESData structure");
     goto error;
   }
 
   if (data->way != ENCRYPT) {
-    logEmit(LOG_ERR, "%s", "AESData isn't initialized for writing");
+    logMisc(LOG_ERR, "AESData isn't initialized for writing");
     goto error;
   }
 
@@ -342,7 +331,7 @@ aesPrint(AESData* data, const char* format, ...)
   va_start(args, format);
   len = vsnprintf(buffer, maxSize, format, args);
   if (len < 0 || len > maxSize) {
-    logEmit(LOG_ERR, "%s", "vnsprintf fails: size=%i/%i", len, maxSize);
+    logMisc(LOG_ERR, "vnsprintf fails: size=%i/%i", len, maxSize);
     goto error;
   }
   va_end(args);
@@ -376,7 +365,7 @@ aesPrint(AESData* data, const char* format, ...)
   rc = TRUE;
  error:
   if (!rc) {
-    logEmit(LOG_ERR, "%s", "aesPrint fails");
+    logMisc(LOG_ERR, "aesPrint fails");
   }
   return rc;
 }
@@ -401,17 +390,15 @@ aesInput(AESData* data, char* buf, int *result, int maxsize)
   (void) maxsize;
   *result = 0;
 
-#ifdef utMAIN
-  logEmit(LOG_DEBUG, "%s", "aesInput"); 
-#endif
+  logMisc(LOG_DEBUG, "aesInput"); 
 
   if (data == 0) {
-    logEmit(LOG_ERR, "%s", "please provide a AESData structure");
+    logMisc(LOG_ERR, "please provide a AESData structure");
     goto error;
   }
 
   if (data->way != DECRYPT) {
-    logEmit(LOG_ERR, "%s", "AESData isn't initialized for reading");
+    logMisc(LOG_ERR, "AESData isn't initialized for reading");
     goto error;
   }
 
@@ -419,7 +406,7 @@ aesInput(AESData* data, char* buf, int *result, int maxsize)
   len = fdRead(data->fd, data->cBlock, MAX_SIZE_AES);
   if (len == 0) goto empty;
   if (len != MAX_SIZE_AES) {
-    logEmit(LOG_WARNING, "crypted input was'nt padded: remains %i bytes",
+    logMisc(LOG_WARNING, "crypted input was'nt padded: remains %i bytes",
 	    MAX_SIZE_AES - len);
 
     // we pad with space if not cyphered (ie: telnet tests)
@@ -446,175 +433,11 @@ aesInput(AESData* data, char* buf, int *result, int maxsize)
   rc = TRUE;
  error:
   if (!rc) {
-    logEmit(LOG_ERR, "%s", "aesInput fails");
+    logMisc(LOG_ERR, "aesInput fails");
   }
   return rc;
 }
 
-/************************************************************************/
-
-#ifdef utMAIN
-#include "command.h"
-
-#include <sys/types.h> //open
-#include <sys/stat.h>
-#include <fcntl.h>
-
-GLOBAL_STRUCT_DEF;
-
-/*=======================================================================
- * Function   : usage
- * Description: Print the usage.
- * Synopsis   : static void usage(char* programName)
- * Input      : programName = the name of the program; usually
- *                                  argv[0].
- * Output     : N/A
- =======================================================================*/
-static 
-void usage(char* programName)
-{
-  miscUsage(programName);
-  miscOptions();
-  return;
-}
-
-
-/*=======================================================================
- * Function   : main 
- * Author     : Nicolas ROCHE
- * modif      : 
- * Description: Unit test for md5sum module
- * Synopsis   : ./utcommand -i scriptPath
- * Input      : N/A
- * Output     : N/A
- =======================================================================*/
-int 
-main(int argc, char** argv)
-{
-  char key[MAX_SIZE_AES+1] = "1000000000000000";
-  AESData data;
-  int pipefd[2];
-  char buf[512];
-  int result = 0;
-  int i = 0;
-  // ---
-  int rc = 0;
-  int cOption = EOF;
-  char* programName = *argv;
-  char* options = MISC_SHORT_OPTIONS"";
-  struct option longOptions[] = {
-    MISC_LONG_OPTIONS,
-    {0, 0, 0, 0}
-  };
-
-  // import mdtx environment
-  getEnv(&env);
-
-  // parse the command line
-  while((cOption = getopt_long(argc, argv, options, longOptions, 0)) 
-	!= EOF) {
-    switch(cOption) {
-      GET_MISC_OPTIONS; // generic options
-    }
-    if (rc) goto optError;
-  }
-
-  // export mdtx environment
-  if (!setEnv(programName, &env)) goto optError;
-
-  /************************************************************************/
-  
-  logEmit(LOG_NOTICE, "%s", "*** low level functions");
-
-  memcpy(data.mBlock, "top secret messg\0", 17);
-  logEmit(LOG_NOTICE, "message: %s", data.mBlock);
-
-  if (!aesInit(&data, key, ENCRYPT)) goto error;
-  if (!doCypher(&data)) goto error;
-  logEmit(LOG_NOTICE, "encrypt:  %s", data.cBlock);
-
-  if (!aesInit(&data, key, DECRYPT)) goto error;
-  if (!doCypher(&data)) goto error;
-  logEmit(LOG_NOTICE, "decrypt: %s", data.mBlock);
-
-  // =================
-
-  logEmit(LOG_NOTICE, "%s", "***  encrypt API");
-
-  if (!aesInit(&data, key, ENCRYPT)) goto error;
-  //data.fd = STDOUT_FILENO;
-  data.fd = open("/dev/null", O_WRONLY);
-
-  aesPrint(&data, "%s", "# Collection's archives:\n");
-  aesPrint(&data, "%s", "Headers\n"); 
-  aesPrint(&data, "\tCollection\t%-*s\n", MAX_SIZE_COLL, "unit-test");
-  aesPrint(&data, "\tDoCypher\t%s\n", "TRUE");
-  aesFlush(&data);
-  aesPrint(&data, "%s", "\nBody          \n");
-  data.doCypher = TRUE;
-  aesPrint(&data, "# %20s %15s %*s %*s %s\n",
-	   "date", "host", 
-	   MAX_SIZE_HASH, "hash", 
-	   MAX_SIZE_SIZE, "size", 
-	   "path");
-  aesFlush(&data);
-
-  // =====================
-
-  logEmit(LOG_NOTICE, "%s", "***  decrypt API");
-
-  if (pipe(pipefd) != 0) {
-    logEmit(LOG_NOTICE, "pipe fails: %s", strerror(errno));
-    goto error;
-  }
-
-  if (!aesInit(&data, key, ENCRYPT)) goto error;
-  data.fd = pipefd[1];
-
-  aesPrint(&data, "%s", "# Collection's archives:\n");
-  aesPrint(&data, "%s", "Headers\n"); 
-  aesPrint(&data, "\tCollection\t%-*s\n", MAX_SIZE_COLL, "unit-test");
-  aesPrint(&data, "\tDoCypher\t%s\n", "TRUE");
-  aesFlush(&data);
-  aesPrint(&data, "%s", "\nBody          \n");
-  data.doCypher = TRUE;
-  aesPrint(&data, "# %20s %15s %*s %*s %s\n",
-	   "date", "host", 
-	   MAX_SIZE_HASH, "hash", 
-	   MAX_SIZE_SIZE, "size", 
-	   "path");
-  aesFlush(&data);
-
-  close (pipefd[1]);
-  if (!aesInit(&data, key, DECRYPT)) goto error;
-  data.fd = pipefd[0];
- 
-  // because we know here we have 7*16 byte of header here
-  for (i=0; i<7; ++i) {
-    if (!aesInput(&data, buf, &result, 1024)) goto error;
-    buf[result] = (char)0;
-    printf("%s", buf);
-  };
-  data.doCypher = TRUE;
-  do {
-    if (!aesInput(&data, buf, &result, 1024)) goto error;
-    buf[result] = (char)0;
-    printf("%s", buf);
-  } while (result > 0);
-  
-  close (pipefd[0]);
-  /************************************************************************/
-
-  rc = TRUE;
- error:
-  ENDINGS;
-  rc=!rc;
- optError:
-  exit(rc);
-}
-
-#endif // utMAIN
-
 /* Local Variables: */
 /* mode: c */
 /* mode: font-lock */
