@@ -1,5 +1,5 @@
 /*=======================================================================
- * Version: $Id: device.c,v 1.3 2015/06/03 14:03:44 nroche Exp $
+ * Version: $Id: device.c,v 1.10 2015/09/04 15:30:27 nroche Exp $
  * Project: MediaTeX
  * Module : checksums
  *
@@ -22,17 +22,13 @@
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  =======================================================================*/
 
-#include "../mediatex.h"
-#include "alloc.h"
-#include "device.h"
-
-#include <unistd.h>
-#include <mntent.h>
+#include "mediatex-config.h"
+#include <mntent.h> // setmntent
 
 /*=======================================================================
- * Function   : absolutePath
+ * Function   : getAbsolutePath
  * Description: return the absolute path (and resolv symlinks into dirname)
- * Synopsis   : char* absolutePath(char* path)
+ * Synopsis   : char* getAbsolutePath(char* path)
  * Input      : char* path: potential relative path
  * Output     : char*: absolute path (0 on error)
 
@@ -42,7 +38,7 @@
  *   path/file
  =======================================================================*/
 char* 
-absolutePath(char* path)
+getAbsolutePath(char* path)
 {
   char* rc = 0;
   char* pwd1 = 0;
@@ -53,7 +49,7 @@ absolutePath(char* path)
 
   // remind the current directory for cd back into
   if ((pwd1 = getcwd(0, 0)) == 0) {
-    logEmit(LOG_ERR, "getcwd: %s", strerror(errno));
+    logMisc(LOG_ERR, "getcwd: %s", strerror(errno));
     goto error;
   }
   remind(pwd1);
@@ -74,21 +70,21 @@ absolutePath(char* path)
     path[i+1] = (char)0; // now path is the dirname
 
     // change directory to dirname
-    if (chdir(path) != 0) {
-      logEmit(LOG_ERR, "chdir %s: %s", path, strerror(errno));
+    if (chdir(path)) {
+      logMisc(LOG_ERR, "chdir %s: %s", path, strerror(errno));
       goto error;
     }
 
     // get the absolute dirname
     if ((pwd2 = getcwd(0, 0)) == 0) {
-      logEmit(LOG_ERR, "getcwd: %s", strerror(errno));
+      logMisc(LOG_ERR, "getcwd: %s", strerror(errno));
       goto error;
     }
     remind(pwd2);
 
     // cd back to the previous current directory 
-    if (chdir(pwd1) != 0) {
-      logEmit(LOG_ERR, "chdir %s: %s", path, strerror(errno));
+    if (chdir(pwd1)) {
+      logMisc(LOG_ERR, "chdir %s: %s", path, strerror(errno));
       goto error;
     }
    
@@ -101,7 +97,7 @@ absolutePath(char* path)
   // concatenate absolute dirname and the basename
   len2 = strlen(pwd2);
   if ((rc = malloc(len2 + 1 + strlen(base) + 1)) == 0) {
-    logEmit(LOG_ERR, "cannot malloc absolute path: %s", strerror(errno));
+    logMisc(LOG_ERR, "cannot malloc absolute path: %s", strerror(errno));
     goto error;
   }
 
@@ -109,14 +105,12 @@ absolutePath(char* path)
   rc[len2] = '/';
   strncpy(rc + 1 + len2, base, strlen(base)+1);
 
-  if (!env.noRegression) {
-    logEmit(LOG_INFO, "absolute path is %s", rc);
-  }
+  logMisc(LOG_DEBUG, "absolute path is %s", rc);
   
  error:
   if (!rc) {
     if (car != (char)0) path[i+1] = car; // path rewind as it was provided
-    logEmit(LOG_ERR, "fails to get absolute path for: %s", path);
+    logMisc(LOG_ERR, "fails to get absolute path for: %s", path);
   }
   free(pwd1);
   free(pwd2);
@@ -136,39 +130,35 @@ char* symlinkTarget(char* path) {
   struct stat statBuffer;
 
   if (path == 0 || *path == (char)0) {
-    logEmit(LOG_ERR, "%s", "please provide a path for the path");
+    logMisc(LOG_ERR, "please provide a path for the path");
     goto error;
   }
  
   // get file attributes
   if (lstat(path, &statBuffer)) {
-    logEmit(LOG_ERR, "status error on %s: %s", path, strerror(errno));
+    logMisc(LOG_ERR, "status error on %s: %s", path, strerror(errno));
     goto error;
   }
   
   if (!S_ISLNK(statBuffer.st_mode)) {
-    if (!env.noRegression) {
-      logEmit(LOG_INFO, "not a symlink: %s", path);
-    }
+      logMisc(LOG_INFO, "not a symlink: %s", path);
     goto end;
   }
 
   /* The size of a symbolic  link  is the length of the pathname 
      it contains, without a terminating null byte. */
   if ((rc = malloc(statBuffer.st_size+1)) == 0) {
-    logEmit(LOG_ERR, "cannot malloc symlink path: %s", strerror(errno));
+    logMisc(LOG_ERR, "cannot malloc symlink path: %s", strerror(errno));
     goto error;
   }
     
   if (readlink(path, rc, statBuffer.st_size) == -1) {
-    logEmit(LOG_ERR, "cannot copy symlink path: %s", strerror(errno));
+    logMisc(LOG_ERR, "cannot copy symlink path: %s", strerror(errno));
     goto error;
   }
   
   rc[statBuffer.st_size] = (char)0;
-  if (!env.noRegression) {
-    logEmit(LOG_INFO, "find a symlink: %s -> %s", path, rc);
-  }
+  logMisc(LOG_INFO, "find a symlink: %s -> %s", path, rc);
  end:
  error:
   return rc;
@@ -193,42 +183,40 @@ char* mount2device(char* absPath)
 
   // loop on mtab
   if ((mtab = setmntent(MISC_CHECKSUMS_MTAB, "r")) == 0) {
-    logEmit(LOG_ERR, "setmntent error on %s: %s", 
+    logMisc(LOG_ERR, "setmntent error on %s: %s", 
 	    MISC_CHECKSUMS_MTAB, strerror(errno));
     goto error;
   }
   
   errno = 0;
-  while(1) {
+  while (1) {
     if (getmntent_r(mtab, &mntEntry, buf, buflen) == 0)  {
       if (errno == 0) break;
-      logEmit(LOG_ERR, "getmntent_r error: %s", strerror(errno));
+      logMisc(LOG_ERR, "getmntent_r error: %s", strerror(errno));
       goto error;
     }
 
     // looking for matchin dirname
     if (!strncmp(mntEntry.mnt_dir, absPath, strlen(absPath))) {
       if ((rc = malloc(strlen(mntEntry.mnt_fsname)+1)) == 0) {
-	logEmit(LOG_ERR, "cannot malloc device path: %s", strerror(errno));
+	logMisc(LOG_ERR, "cannot malloc device path: %s", strerror(errno));
 	goto error;
       }
 
       strcpy(rc, mntEntry.mnt_fsname);
-      logEmit(LOG_INFO, "found mounted device %s", rc);
+      logMisc(LOG_INFO, "found mounted device %s", rc);
       break;
     }
   }
   
-  if (fclose(mtab) != 0) {
-    logEmit(LOG_ERR, "fclose fails: %s", strerror(errno));
+  if (fclose(mtab)) {
+    logMisc(LOG_ERR, "fclose fails: %s", strerror(errno));
     goto error;
   }
 
   return rc;
  error:
-  if(!env.noRegression) {
-    logEmit(LOG_INFO, "cannot match a device path: %s", absPath);
-  }
+  logMisc(LOG_INFO, "cannot match a device path: %s", absPath);
   return rc;
 }
 
@@ -252,17 +240,17 @@ int normalizePath(char* inPath, char** outPath)
 
   path = inPath;
   if (path == 0 || *path == (char)0) {
-    logEmit(LOG_ERR, "%s", "please provide a path for the device");
+    logMisc(LOG_ERR, "please provide a path for the device");
     goto error;
   }
 
-  logEmit(LOG_DEBUG, "%s", "normalizePath");
+  logMisc(LOG_DEBUG, "normalizePath");
   
   do {
     if (basename) free(basename);
     
     // get absolute path
-    if ((absPath = absolutePath(path)) == 0) {
+    if ((absPath = getAbsolutePath(path)) == 0) {
       goto error;
     }
     if (path && path != inPath) free(path);
@@ -271,7 +259,7 @@ int normalizePath(char* inPath, char** outPath)
     for (i=strlen(absPath); i>0 && absPath[i] != '/'; --i);
 
     // look for symlink
-    if ((basename = symlinkTarget(absPath)) != 0) {
+    if ((basename = symlinkTarget(absPath))) {
       ++nbLink;
 
       // if an absolute symlink delete the previous path
@@ -282,7 +270,7 @@ int normalizePath(char* inPath, char** outPath)
       
       if ((path = malloc(strlen(absPath) + strlen(basename) + 1))
   	  == 0) {
-  	logEmit(LOG_ERR, "cannot malloc path: %s", strerror(errno));
+  	logMisc(LOG_ERR, "cannot malloc path: %s", strerror(errno));
   	goto error;
       }
 
@@ -298,9 +286,9 @@ int normalizePath(char* inPath, char** outPath)
       absPath = 0;
     }
 
-  } while (nbLink < MISC_CHECKSUMS_MAX_NBLINK && basename != 0);
+  } while (nbLink < MISC_CHECKSUMS_MAX_NBLINK && basename);
   if (nbLink >= MISC_CHECKSUMS_MAX_NBLINK) {
-    logEmit(LOG_ERR, "reach %i symlinks (is there a loop ?)",
+    logMisc(LOG_ERR, "reach %i symlinks (is there a loop ?)",
   	    MISC_CHECKSUMS_MAX_NBLINK);
     goto error;
   }
@@ -310,7 +298,7 @@ int normalizePath(char* inPath, char** outPath)
   rc = TRUE;
  error:
   if (!rc) {
-    logEmit(LOG_ERR, "%s", "normalizePath fails");
+    logMisc(LOG_ERR, "normalizePath fails");
   }
   free(absPath);   
   free(basename);
@@ -332,14 +320,14 @@ int getDevice(char* inPath, char** outPath)
   char *oldPath = 0;
   char *newPath = 0;
 
-  logEmit(LOG_DEBUG, "%s", "getDevice");
+  logMisc(LOG_DEBUG, "getDevice");
   
   oldPath = inPath;
   if (!normalizePath(oldPath, &newPath)) goto error;
   /*
   // find if one device matchs in mtab
   oldPath = newPath;
-  if ((newPath = mount2device(oldPath)) != 0) {
+  if ((newPath = mount2device(oldPath))) {
     oldPath = newPath;
     if (!normalizePath(oldPath, &newPath)) goto error;
   } else {
@@ -351,7 +339,7 @@ int getDevice(char* inPath, char** outPath)
   rc = TRUE;
  error:
   if (!rc) {
-    logEmit(LOG_ERR, "%s", "getDevice fails");
+    logMisc(LOG_ERR, "getDevice fails");
   }
   return rc;
 }
@@ -367,40 +355,37 @@ int isBlockDevice(char* path, int* isB) {
   int rc = FALSE;
   struct stat statBuffer;
 
-  logEmit(LOG_DEBUG, "%s", "isBlockDevice");
+  logMisc(LOG_DEBUG, "isBlockDevice");
   *isB = FALSE;
 
   if (path == 0 || *path == (char)0) {
-    logEmit(LOG_ERR, "%s", "please provide a path for the device");
+    logMisc(LOG_ERR, "please provide a path for the device");
     goto error;
   }
 
   // get file attributes
   if (stat(path, &statBuffer)) {
-    logEmit(LOG_ERR, "status error on %s: %s", path, strerror(errno));
+    logMisc(LOG_ERR, "status error on %s: %s", path, strerror(errno));
     goto error;
   }
 
   rc = TRUE;
-#ifndef utMAIN
-  if (env.noRegression) goto end;
-#endif
 
   if (S_ISCHR(statBuffer.st_mode)) {
-    logEmit(LOG_INFO, "find character device: %s", path);
+    logMisc(LOG_INFO, "find character device: %s", path);
     goto end;
   }
     
   if (S_ISBLK(statBuffer.st_mode)) {
-    logEmit(LOG_INFO, "find bloc device: %s", path);
+    logMisc(LOG_INFO, "find bloc device: %s", path);
     *isB = TRUE;
     goto end;
   }
   
-  logEmit(LOG_INFO, "do not match a block device: %s", path);
+  logMisc(LOG_INFO, "do not match a block device: %s", path);
  end:
   if (!rc) {
-    logEmit(LOG_ERR, "%s", "isBlockDevice fails");
+    logMisc(LOG_ERR, "isBlockDevice fails");
   }
  error:
   return rc;
@@ -427,7 +412,7 @@ int getIsoSize(int fd, off_t *size,
   char invariant[8] = ".CD001.";
   char buffer[8]    = "       "; 
 
-  logEmit(LOG_DEBUG, "%s", "getIsoSize");
+  logMisc(LOG_DEBUG, "getIsoSize");
   invariant[0] = 1;
   invariant[6] = 1;
   *size = 0;
@@ -437,15 +422,15 @@ int getIsoSize(int fd, off_t *size,
   // Identifier: invariant on iso
   offset = (8<<12);
   if ((lseek(fd, offset, SEEK_SET)) == -1) {
-    logEmit(LOG_ERR, "lseek: %s", strerror(errno));
+    logMisc(LOG_ERR, "lseek: %s", strerror(errno));
     goto error;
   }	
   if (read(fd, buffer, 8) < 0) {
-    logEmit(LOG_ERR, "read: %s", strerror(errno));
+    logMisc(LOG_ERR, "read: %s", strerror(errno));
     goto error;
   }
   if (strncmp(buffer, invariant, 7)) {
-    logEmit(LOG_INFO, "%s", "is not an iso");
+    logMisc(LOG_INFO, "is not an iso");
     goto end;
   }
 
@@ -456,11 +441,11 @@ int getIsoSize(int fd, off_t *size,
 #endif
 
   if ((lseek(fd, offset, SEEK_SET)) == -1) {
-    logEmit(LOG_ERR, "lseek: %s", strerror(errno));
+    logMisc(LOG_ERR, "lseek: %s", strerror(errno));
     goto error;
   }	
   if (read(fd, count, 4) < 0) {
-    logEmit(LOG_ERR, "read: %s", strerror(errno));
+    logMisc(LOG_ERR, "read: %s", strerror(errno));
     goto error;
   }
  
@@ -471,154 +456,25 @@ int getIsoSize(int fd, off_t *size,
 #endif
 
   if ((lseek(fd, offset, SEEK_SET)) == -1) {
-    logEmit(LOG_ERR, "lseek: %s", strerror(errno));
+    logMisc(LOG_ERR, "lseek: %s", strerror(errno));
     goto error;
   }	
   if (read(fd, bs, 2) < 0) {
-    logEmit(LOG_ERR, "read: %s", strerror(errno));
+    logMisc(LOG_ERR, "read: %s", strerror(errno));
     goto error;
   }
 
   *size = (*count)*(*bs);
-  logEmit(LOG_INFO, "iso size: %lli", *size);
+  logMisc(LOG_INFO, "iso size: %lli", *size);
  end:
   rc = TRUE;
  error:
   if (!rc) {
-    logEmit(LOG_ERR, "%s", "getIsoSize fails");
+    logMisc(LOG_ERR, "getIsoSize fails");
   }
   return rc;
 }
 
-/************************************************************************/
-
-#ifdef utMAIN
-#include "command.h"
-GLOBAL_STRUCT_DEF;
-
-/*=======================================================================
- * Function   : usage
- * Description: Print the usage.
- * Synopsis   : static void usage(char* programName)
- * Input      : programName = the name of the program; usually
- *                                  argv[0].
- * Output     : N/A
- =======================================================================*/
-static void usage(char* programName)
-{
-  miscUsage(programName);
-  fprintf(stderr, "\n\t\t[ -i device ]");
-
-  miscOptions();
-  fprintf(stderr, "  ---\n" 
-	  "  -i, --input-file\tinput device file to test\n");
-  return;
-}
-
-
-/*=======================================================================
- * Function   : main 
- * Author     : Nicolas ROCHE
- * modif      : 
- * Description: Unit test for md5sum module
- * Synopsis   : ./utcommand -i scriptPath
- * Input      : N/A
- * Output     : N/A
- =======================================================================*/
-int 
-main(int argc, char** argv)
-{
-  char* inputPath = 0;
-  char* devicePath = 0;
-  int isBlockDev = FALSE;
-  int fd = 0;
-  off_t size = 0;
-  unsigned short int bs = 0;
-  unsigned long int count = 0;
-  // ---
-  int rc = 0;
-  int cOption = EOF;
-  char* programName = *argv;
-  char* options = MISC_SHORT_OPTIONS"i:";
-  struct option longOptions[] = {
-    MISC_LONG_OPTIONS,
-    {"input-file", required_argument, 0, 'i'},
-    {0, 0, 0, 0}
-  };
-  
-  // import mdtx environment
-  getEnv(&env);
-
-  // parse the command line
-  while((cOption = getopt_long(argc, argv, options, longOptions, 0)) 
-	!= EOF) {
-    switch(cOption) {
-      
-    case 'i':
-      if(optarg == 0 || *optarg == (char)0) {
-	fprintf(stderr, "%s: nil or empty argument for the input device\n",
-		programName);
-	rc = EINVAL;
-	break;
-      }
-      if ((inputPath = malloc(strlen(optarg) + 1)) == 0) {
-	fprintf(stderr, "cannot malloc the input device path: %s", 
-		strerror(errno));
-	rc = ENOMEM;
-	break;
-      }
-      
-      strncpy(inputPath, optarg, strlen(optarg)+1);
-      break;
-      
-      GET_MISC_OPTIONS; // generic options
-    }
-    if (rc) goto optError;
-  }
-
-  // export mdtx environment
-  if (!setEnv(programName, &env)) goto optError;
-
-  /************************************************************************/
-  if (inputPath == 0) {
-    usage(programName);
-    logEmit(LOG_ERR, "%s", "Please provide an input device path");
-    goto error;
-  }
-
-  if (!getDevice(inputPath, &devicePath)) goto error;
-  if (!isBlockDevice(devicePath, &isBlockDev)) goto error;
-  logEmit(LOG_NOTICE, "%s -> %s (is %sa block device)",
-	  inputPath, devicePath, isBlockDev?"":"not ");
-
-  if ((fd = open(devicePath, O_RDONLY)) == -1) {
-    logEmit(LOG_ERR, "open: %s", strerror(errno));
-    goto error;
-  }
-  
-  // compute iso size if block device
-  if (!getIsoSize(fd, &size, &count, &bs)) goto error;
-  logEmit(LOG_NOTICE, "%s is %san iso",
-	  devicePath, (size > 0)?"":"not ");
-  if (size > 0) {
-    logEmit(LOG_NOTICE, "volume size = %lu", count);
-    logEmit(LOG_NOTICE, "block size = %hu", bs);
-    logEmit(LOG_NOTICE, "size = %lli", (long long int)size);
-  }
-  /************************************************************************/
-
-  rc = TRUE;
- error:
-  free(devicePath);
-  free(inputPath);
-  ENDINGS;
-  rc=!rc;
- optError:
-  exit(rc);
-}
-
-#endif // utMAIN
-
 /* Local Variables: */
 /* mode: c */
 /* mode: font-lock */
