@@ -1,5 +1,5 @@
 /*=======================================================================
- * Version: $Id: device.h,v 1.3 2015/06/03 14:03:44 nroche Exp $
+ * Version: $Id: device.h,v 1.5 2015/08/27 10:51:52 nroche Exp $
  * Project: MediaTeX
  * Module : checksums
  *
@@ -22,20 +22,16 @@
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  =======================================================================*/
 
-#ifndef MISC_CHECKSUMS_DEVICE_H
-#define MISC_CHECKSUMS_DEVICE_H 1
+#ifndef MDTX_MISC_DEVICE_H
+#define MDTX_MISC_DEVICE_H 1
 
-#include <sys/types.h>   // open
-#include <sys/stat.h>    // open
-#include <fcntl.h>       // open
-
-char* absolutePath(char* path);
+char* getAbsolutePath(char* path);
 int getDevice(char* inPath, char** outPath);
 int isBlockDevice(char* path, int* isB);
 int getIsoSize(int fd, off_t *size, 
 	       unsigned long int *count, unsigned short int *bs);
 
-#endif /* MISC_CHECKSUMS_DEVICE_H */
+#endif /* MDTX_MISC_DEVICE_H */
 
 /* Local Variables: */
 /* mode: c */
