@@ -1,9 +1,9 @@
 /*=======================================================================
- * Version: $Id: keys.c,v 1.3 2015/06/03 14:03:45 nroche Exp $
+ * Version: $Id: keys.c,v 1.7 2015/09/17 18:53:48 nroche Exp $
  * Project: MediaTeX
  * Module : keys
  *
- * uuid and keys retrievals
+ * ssh keys retrievals
 
  MediaTex is an Electronic Records Management System
  Copyright (C) 2014 2015 Nicolas Roche
@@ -22,11 +22,9 @@
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  =======================================================================*/
 
-#include "alloc.h"
-#include "keys.h"
-
-#include <openssl/evp.h>
-#include <openssl/md5.h>
+#include "mediatex-config.h"
+#include <openssl/md5.h> // MD5_DIGEST_LENGTH
+#include <openssl/evp.h> // EVP_DecodeBlock
 
 
 /*=======================================================================
@@ -46,15 +44,15 @@ readPublicKey(char* path)
   int n = 0;
 
   if (path == 0 || *path == (char)0) {
-    logEmit(LOG_ERR, "%s", 
+    logMisc(LOG_ERR, 
 	    "please provide a path for the public key to read");
     goto error;
   }
 
-  logEmit(LOG_DEBUG, "readPublicKey: %s", path);
+  logMisc(LOG_DEBUG, "readPublicKey: %s", path);
 
   if ((fd = fopen(path, "r")) == 0) {
-    logEmit(LOG_ERR, "fopen fails: %s", strerror(errno));
+    logMisc(LOG_ERR, "fopen fails: %s", strerror(errno));
     goto error;
   }
 
@@ -65,12 +63,12 @@ readPublicKey(char* path)
   }
 
   if (ferror(fd)) {
-    logEmit(LOG_ERR, "%s", "fread fails.");
+    logMisc(LOG_ERR, "fread fails.");
     goto error;
   }
 
   if (fclose(fd)) {
-    logEmit(LOG_ERR, "fclose fails: %s", strerror(errno));
+    logMisc(LOG_ERR, "fclose fails: %s", strerror(errno));
     goto error;
   }
 
@@ -80,14 +78,14 @@ readPublicKey(char* path)
   }
 
   if ((rc = malloc (strlen(buf)+1)) == 0) {
-    logEmit(LOG_ERR, "malloc fails: %s", strerror(errno));
+    logMisc(LOG_ERR, "malloc fails: %s", strerror(errno));
     goto error;
   }
 
   strcpy(rc, buf);
  error:
   if (rc == 0) {
-    logEmit(LOG_ERR, "%s", "readPublicKey fails");
+    logMisc(LOG_ERR, "readPublicKey fails");
   }
   return rc;
 }
@@ -98,9 +96,9 @@ readPublicKey(char* path)
  * Description: compute the fingerprint of a key as:
  *              ssh-keygen -lf /etc/ssh/ssh_host_dsa_key.pub
  * Synopsis   : int getFingerPrint(char* key, 
- *                                 char fingerprint[MAX_SIZE_HASH])
+ *                                 char fingerprint[MAX_SIZE_MD5])
  * Input      : char* key: the input key
- *              char fingerprint[MAX_SIZE_HASH]: the fingerprint to store
+ *              char fingerprint[MAX_SIZE_MD5]: the fingerprint to store
  * Output     : TRUE on success
  *
  * Note       :
@@ -112,7 +110,7 @@ readPublicKey(char* path)
  * strange (but working)
  =======================================================================*/
 int 
-getFingerPrint(char* key, char fingerprint[MAX_SIZE_HASH+1])
+getFingerPrint(char* key, char fingerprint[MAX_SIZE_MD5+1])
 {
   int rc = FALSE;
   unsigned char *key_unbase64 = (unsigned char *)0;
@@ -125,7 +123,7 @@ getFingerPrint(char* key, char fingerprint[MAX_SIZE_HASH+1])
   char* ptr;
   int nbEquals = 0;
   
-  logEmit(LOG_DEBUG, "%s", "getFingerPrint");
+  logMisc(LOG_DEBUG, "getFingerPrint");
 
   // get only the key
   while (*key != ' ') ++key;
@@ -141,7 +139,7 @@ getFingerPrint(char* key, char fingerprint[MAX_SIZE_HASH+1])
 
   // we just use the size of the public key for now
   if ((key_unbase64 = malloc(strlen(key))) == 0) {
-    logEmit(LOG_ERR, "malloc fails: %s", strerror(errno));
+    logMisc(LOG_ERR, "malloc fails: %s", strerror(errno));
     goto error;
   }
 
@@ -153,7 +151,7 @@ getFingerPrint(char* key, char fingerprint[MAX_SIZE_HASH+1])
   key_unbased64_length = 
     EVP_DecodeBlock(key_unbase64, (unsigned char *) key, strlen(key));
   if (key_unbased64_length <= 0) {
-    logEmit(LOG_ERR, "EVP_DecodeBlock fails: %i", key_unbased64_length);
+    logMisc(LOG_ERR, "EVP_DecodeBlock fails: %i", key_unbased64_length);
     goto error;
   }
 
@@ -164,7 +162,7 @@ getFingerPrint(char* key, char fingerprint[MAX_SIZE_HASH+1])
 
   // initialize our context to use MD5 as the hashing algorithm
   if (EVP_DigestInit_ex(&mdctx, EVP_md5(), 0) != 1) {
-    logEmit(LOG_ERR, "%s", "EVP_DigestInit_ex fails");
+    logMisc(LOG_ERR, "EVP_DigestInit_ex fails");
     goto error;
   }
 
@@ -172,20 +170,20 @@ getFingerPrint(char* key, char fingerprint[MAX_SIZE_HASH+1])
   // -nbEquals is neeeded to work by looks very strange
   if (EVP_DigestUpdate(&mdctx, key_unbase64,
   		       key_unbased64_length - nbEquals) != 1) {
-    logEmit(LOG_ERR, "%s", "EVP_DigestUpdate fails");
+    logMisc(LOG_ERR, "EVP_DigestUpdate fails");
     goto error;
   }
 
   // finish the hashing and get us the hash value in md_value
   if (EVP_DigestFinal_ex(&mdctx, md_value, &md_len) != 1) {
-    logEmit(LOG_ERR, "%s", "EVP_DigestFinal fails");
+    logMisc(LOG_ERR, "EVP_DigestFinal fails");
     goto error;
   }
 
   // retrieve the md5sum
   for(i=0; i<MD5_DIGEST_LENGTH; i++)
     sprintf(fingerprint+(i<<1), "%02x", md_value[i]);
-  fingerprint[MAX_SIZE_HASH] = (char)0;
+  fingerprint[MAX_SIZE_MD5] = (char)0;
  
   EVP_MD_CTX_cleanup(&mdctx);
   rc = TRUE;
@@ -195,121 +193,6 @@ getFingerPrint(char* key, char fingerprint[MAX_SIZE_HASH+1])
   return rc;
 }
 
-/************************************************************************/
-
-#ifdef utMAIN
-#include "command.h"
-GLOBAL_STRUCT_DEF;
-
-/*=======================================================================
- * Function   : usage
- * Description: Print the usage.
- * Synopsis   : static void usage(char* programName)
- * Input      : programName = the name of the program; usually
- *                                  argv[0].
- * Output     : N/A
- =======================================================================*/
-static 
-void usage(char* programName)
-{
-  miscUsage(programName);
-  fprintf(stderr, "\n\t\t-i path");
-
-  miscOptions();
-  fprintf(stderr, "  ---\n"
-  	  "  -i, --input-key\tprint the key content\n");
-  return;
-}
-
-
-/*=======================================================================
- * Function   : main 
- * Author     : Nicolas ROCHE
- * modif      : 
- * Description: Unit test for md5sum module
- * Synopsis   : ./utkeys -d ici -u toto -g toto -p 777
- * Input      : N/A
- * Output     : N/A
- =======================================================================*/
-int 
-main(int argc, char** argv)
-{
-  char* inputFile = 0;
-  char* key = 0;
-  char fingerprint[MAX_SIZE_HASH+1];
-  int i;
-  // ---
-  int rc = 0;
-  int cOption = EOF;
-  char* programName = *argv;
-  char* options = MISC_SHORT_OPTIONS"i:";
-  struct option longOptions[] = {
-    MISC_LONG_OPTIONS,
-    {"input-key", required_argument, 0, 'i'},
-    {0, 0, 0, 0}
-  };
-
-  // import mdtx environment
-  getEnv(&env);
-
-  // parse the command line
-  while((cOption = getopt_long(argc, argv, options, longOptions, 0)) 
-	!= EOF) {
-    switch(cOption) {					
-					
-    case 'i':
-      if(optarg == 0 || *optarg == (char)0) {
-	fprintf(stderr, "%s: nil or empty argument for the input device\n",
-		programName);
-	rc = EINVAL;
-	break;
-      }
-      if ((inputFile = malloc(strlen(optarg) + 1)) == 0) {
-	fprintf(stderr, "cannot malloc the input device path: %s", 
-		strerror(errno));
-	rc = ENOMEM;
-	break;
-      }
-      strncpy(inputFile, optarg, strlen(optarg)+1);
-      break;
-
-      GET_MISC_OPTIONS; // generic options
-    }
-    if (rc) goto optError;
-  }
-
-  // export mdtx environment
-  if (!setEnv(programName, &env)) goto optError;
-
-  /************************************************************************/
-  if (inputFile == 0) {
-    usage(programName);
-    goto error;	
-  }
-  
-  // load the dsa public key
-  if ((key = readPublicKey(inputFile)) == 0) goto error;
-  if (!getFingerPrint(key, fingerprint)) goto error;
-
-  // print the fingerprint
-  printf("%c%c", fingerprint[0], fingerprint[1]);
-  for (i=2; i<MAX_SIZE_HASH; i+=2)
-    printf(":%c%c", fingerprint[i], fingerprint[i+1]);
-  printf("\n");
-  /************************************************************************/
-
-  rc = TRUE;
- error:
-  ENDINGS;
-  rc=!rc;
- optError:
-  if (inputFile) free(inputFile);
-  if (key) free(key);
-  exit(rc);
-}
-
-#endif // utMAIN
-
 /* Local Variables: */
 /* mode: c */
 /* mode: font-lock */
