@@ -1,5 +1,5 @@
 /*=======================================================================
- * Version: $Id: md5sum.c,v 1.3 2015/06/03 14:03:46 nroche Exp $
+ * Version: $Id: md5sum.c,v 1.10 2015/09/21 01:01:51 nroche Exp $
  * Project: MediaTeX
  * Module : checksums
  *
@@ -22,16 +22,18 @@
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  =======================================================================*/
 
-#include "alloc.h"
-#include "signals.h"
-#include "md5sum.h"
+#include "mediatex-config.h"
+#include <openssl/md5.h>
+#include <openssl/sha.h>
 
-#include "progbar.h"
-#include "device.h"
+#if MAX_SIZE_MD5 != (MD5_DIGEST_LENGTH << 1)
+#error Bad size used to store md5sums !!
+#endif
+
+#if MAX_SIZE_SHA != (SHA_DIGEST_LENGTH << 1)
+#error Bad size used to store shasums !!
+#endif
 
-#include <sys/types.h>   // open
-#include <sys/stat.h>    // open
-#include <fcntl.h>       // open
 
 /*=======================================================================
  * Function   : manageSIGALRM
@@ -51,8 +53,8 @@ manageSIGALRM(void (*manager)(int))
   action.sa_handler = manager;
   sigemptyset(&(action.sa_mask));
   action.sa_flags = SA_RESTART;
-  if (sigaction(SIGALRM, &action, 0) != 0) {
-    logEmit(LOG_ERR, "%s", "sigaction fails: %s", strerror(errno));
+  if (sigaction(SIGALRM, &action, 0)) {
+    logMisc(LOG_ERR, "sigaction fails: %s", strerror(errno));
     goto error;
   }
 
@@ -61,7 +63,7 @@ manageSIGALRM(void (*manager)(int))
   rc = TRUE;
  error:
  if (!rc) {
-    logEmit(LOG_ERR, "%s", "manageSIGALRM fails");
+    logMisc(LOG_ERR, "manageSIGALRM fails");
   }
   return TRUE;
 }
@@ -99,7 +101,7 @@ gestionnaireSIGALRM(int i)
 int startProgBar(char* label)
 {
   // only run progbar for client (but not for cgi or server)
-  if (env.noRegression || strncmp(env.logFacility, "file", 4)) 
+  if (env.noRegression || env.logFacility != 99) 
     return TRUE; 
 
   env.progBar.label = label;
@@ -116,7 +118,7 @@ int startProgBar(char* label)
 void stopProgBar()
 {
   // only run progbar for client (but not for cgi or server)
-  if (env.noRegression || strncmp(env.logFacility, "file", 4)) return; 
+  if (env.noRegression || env.logFacility != 99) return; 
 
   e2fsck_clear_progbar(&env.progBar.bar);
   env.progBar.label = 0;
@@ -127,221 +129,284 @@ void stopProgBar()
  * Description: hexa[12] to char[33] convertion
  * Synopsis   : char* md5sum2string(
  *                              unsigned char md5sum[MD5_DIGEST_LENGTH], 
- *                              char rc[MAX_SIZE_HASH + 1])
+ *                              char rc[MAX_SIZE_MD5 + 1])
  * Input      : unsigned char md5sum[MD5_DIGEST_LENGTH]: 
  *               the md5sum to convert
- * Output     : char rc[MAX_SIZE_HASH + 1]: the allocated array to return
+ * Output     : char rc[MAX_SIZE_MD5 + 1]: the allocated array to return
  =======================================================================*/
 char* 
 md5sum2string(unsigned char md5sum[MD5_DIGEST_LENGTH], 
-	      char rc[MAX_SIZE_HASH + 1])
+	      char rc[MAX_SIZE_MD5 + 1])
 {
   int n;
 
   for(n=0; n<MD5_DIGEST_LENGTH; n++) 
     sprintf(rc+(n<<1), "%02x", md5sum[n]);
 
-  rc[MAX_SIZE_HASH] = (char)0;
+  rc[MAX_SIZE_MD5] = (char)0;
   return rc;
 }
 
 /*=======================================================================
- * Function   : computeQuickMd5
- * Description: Compute md5sum on first mega byte
- * Synopsis   : static int computeQuickMd5(int fd, ssize_t *sum, 
- *                                  MD5_CTX *c, off_t size, 
- *                                  char quickMd5sum[MAX_SIZE_HASH+1])
+ * Function   : sha1sum2string
+ * Description: hexa[20] to char[40] convertion
+ * Synopsis   : char* sha1sum2string(
+ *                              unsigned char sha1sum[SHA_DIGEST_LENGTH], 
+ *                              char rc[MAX_SIZE_SHA1 + 1])
+ * Input      : unsigned char sha1sum[SHA_DIGEST_LENGTH]: 
+ *               the sha1sum to convert
+ * Output     : char rc[MAX_SIZE_SHA1 + 1]: the input array
+ =======================================================================*/
+char* 
+sha1sum2string(unsigned char sha1sum[SHA_DIGEST_LENGTH], 
+	      char rc[MAX_SIZE_SHA + 1])
+{
+  int n;
+
+  for(n=0; n<SHA_DIGEST_LENGTH; n++) 
+    sprintf(rc+(n<<1), "%02x", sha1sum[n]);
+
+  rc[MAX_SIZE_SHA] = (char)0;
+  return rc;
+}
+
+/*=======================================================================
+ * Function   : quickChecksum
+ * Description: Compute checksum(s) on first mega byte
+ * Synopsis   : static int quickChecksum(int fd, off_t size, ssize_t *sum,
+ *                   MD5_CTX *md5Ctx, char quickMd5sum[MAX_SIZE_MD5 + 1],
+                     SHA_CTX *shaCtx, char quickShasum[MAX_SIZE_SHA + 1])
  * Input      : int fd: file descriptor to use for computation
- *              off_t size: maximum size of the file (for progbar)
+ *              off_t size: maximum size of the file
  * Output     : ssize_t *sum: size used for computation
- *              MD5_CTX *c: md5sum data at the end (to be re-use next)
- *              char quickMd5sum[MAX_SIZE_HASH + 1]: the resulting md5sum
+ *              MD5_CTX *md5Ctx: md5sum data at the end (to be re-use next)
+ *              char quickMd5sum[MAX_SIZE_MD5 + 1]: the resulting md5sum
+ *              SHA_CTX *shaCtx: shasum data at the end (to be re-use next)
+ *              char quickShasum[MAX_SIZE_SHA + 1]: the resulting sha1sum
  * Note       : On GNU/Linux there is a bug with last block on CDROM
  *              so we truncate reading using size parameter
  =======================================================================*/
 static int 
-computeQuickMd5(int fd, ssize_t *sum, MD5_CTX *c, 
-		off_t size, char quickMd5sum[MAX_SIZE_HASH + 1])
+quickChecksum(int fd, off_t size, ssize_t *sum,
+	      MD5_CTX *md5Ctx, char quickMd5sum[MAX_SIZE_MD5 + 1],
+	      SHA_CTX *shaCtx, char quickShasum[MAX_SIZE_SHA + 1])
 {
   int rc = FALSE;
   char buf[512];
   ssize_t bytes;
   unsigned char md5sum[MD5_DIGEST_LENGTH];
-  MD5_CTX copy;
+  unsigned char shasum[SHA_DIGEST_LENGTH];
+  MD5_CTX tmpMd5;
+  SHA_CTX tmpSha;
+  int doSha1 = FALSE;
 
-  logEmit(LOG_DEBUG, "%s", "computeQuickMd5");
+  logMisc(LOG_DEBUG, "quickChecksum");
+  doSha1 = (shaCtx && quickShasum);
   env.progBar.max = size;
 
   if (fd <= 0) {
-    logEmit(LOG_ERR, "%s", "quickMd5: please provide a file descriptor");
+    logMisc(LOG_ERR, "please provide a file descriptor");
     goto error;
   }
 
   if (sum == 0) {
-  logEmit(LOG_ERR, "%s", "quickMd5: allocate provide a ssize_t argument");
+  logMisc(LOG_ERR, "allocate provide a ssize_t argument");
     goto error;
   }
 
   if (quickMd5sum == 0) {
-    logEmit(LOG_ERR, "%s", "quickMd5 please allocate quickMd5sum argument");
+    logMisc(LOG_ERR, "please allocate quickMd5sum argument");
     goto error;
   } 
 
-  if (lseek(fd, 0, SEEK_SET) != 0) {
-    logEmit(LOG_ERR, "lseek: %s", strerror(errno));
+  MD5_Init(md5Ctx);
+  if (doSha1) SHA1_Init(shaCtx);
+
+  if (lseek(fd, 0, SEEK_SET)) {
+    logMisc(LOG_ERR, "lseek: %s", strerror(errno));
     goto error;
   }
 
   *sum = 0;
-  MD5_Init(c);
   bytes=read(fd, buf, 512);
-
-  while((!size || *sum < size) &&
-	*sum < MEGABYTE && bytes > 0) {
-    if (*sum + bytes > MEGABYTE) bytes -= ((*sum + bytes) - MEGABYTE);
+  while ((!size || *sum < size) &&
+	*sum < MEGA && bytes > 0) {
+    if (*sum + bytes > MEGA) bytes -= ((*sum + bytes) - MEGA);
     *sum += bytes;
-    MD5_Update(c, buf, bytes);
+    MD5_Update(md5Ctx, buf, bytes);
+    if (doSha1) SHA1_Update(shaCtx, buf, bytes);
     env.progBar.cur = *sum;
     bytes=read(fd, buf, 512);
   }
   
-  memcpy(&copy, c, sizeof(MD5_CTX));
-  MD5_Final(md5sum, &copy);
+  memcpy(&tmpMd5, md5Ctx, sizeof(MD5_CTX));
+  MD5_Final(md5sum, &tmpMd5);
   quickMd5sum = md5sum2string(md5sum, quickMd5sum);
-
-  logEmit(LOG_INFO, "%s quick md5sum computed on %llu bytes", 
+  logMisc(LOG_INFO, "%s quick md5sum computed on %llu bytes", 
 	  quickMd5sum, (long long unsigned int)*sum);
+  
+  if (doSha1) {
+    memcpy(&tmpSha, shaCtx, sizeof(SHA_CTX));
+    SHA1_Final(shasum, &tmpSha);
+    quickShasum = sha1sum2string(shasum, quickShasum);
+    logMisc(LOG_INFO, "%s quick sha1sum computed on %llu bytes", 
+	    quickShasum, (long long unsigned int)*sum);
+  }
 
-  rc = (*sum > 0 && *sum <= MEGABYTE);
+  rc = (*sum > 0 && *sum <= MEGA);
  error:
+  if (!rc) {
+    logMisc(LOG_ERR, "quickChecksum fails");
+  }
   return(rc);
 }
 
 /*=======================================================================
- * Function   : computeFullMd5
- * Description: Continue to compute md5sum after the quickIndex bytes
- * Synopsis   : static int computeFullMd5(int fd, ssize_t *sum, MD5_CTX *c, 
- *                          off_t size, char fullMd5sum[MAX_SIZE_HASH+1])
-
+ * Function   : fullChecksum
+ * Description: Continue to compute checksum(s) after the first mega byte
+ * Synopsis   : static int fullChecksum(int fd, ssize_t *sum, off_t size,
+ *                    MD5_CTX *md5Ctx, char fullMd5sum[MAX_SIZE_MD5 + 1],
+ *                    SHA_CTX *shaCtx, char fullShasum[MAX_SIZE_SHA + 1])
  * Input      : int fd: file descriptor to use for computation
  *              ssize_t *sum: off_t size: maximum size of the file 
- *                 (for progbar)
- *              MD5_CTX *c: md5sum data at the end of quick computation
  *              off_t size: size where we continue computation
- * Output     : char fullMd5sum[MAX_SIZE_HASH + 1]): the resuling md5sum
+ * Output     : MD5_CTX *md5Ctx: md5sum at the end of quick computation
+ *              char fullMd5sum[MAX_SIZE_MD5 + 1]: the resuling md5sum
+ *              SHA_CTX *shaCtx: shasum at the end of quick computation
+ *              char fullShasum[MAX_SIZE_SHA + 1]: the resuling shasum
  * Note       : On GNU/Linux there is a bug with last block on CDROM
  *              so we truncate reading using size parameter
  =======================================================================*/
 static int 
-computeFullMd5(int fd, ssize_t *sum, MD5_CTX *c, 
-	       off_t size, char fullMd5sum[MAX_SIZE_HASH + 1])
+fullChecksum(int fd, off_t size, ssize_t *sum,
+	       MD5_CTX *md5Ctx, char fullMd5sum[MAX_SIZE_MD5 + 1],
+	       SHA_CTX *shaCtx, char fullShasum[MAX_SIZE_SHA + 1])
 {
   int rc = FALSE;
   char buf[512];
   ssize_t bytes;
   unsigned char md5sum[MD5_DIGEST_LENGTH];
+  unsigned char shasum[SHA_DIGEST_LENGTH];
+  int doSha1 = FALSE;
 
-  logEmit(LOG_DEBUG, "%s", "computeFullMd5");
+  logMisc(LOG_DEBUG, "fullChecksum");
+  doSha1 = (shaCtx && fullShasum);
   env.progBar.max = size;
 
   if (fd <= 0) {
-    logEmit(LOG_ERR, "%s", "fullMd5: please provide a file descriptor");
+    logMisc(LOG_ERR, "please provide a file descriptor");
     goto error;
   }
   
   if (sum == (ssize_t*)0) {
-    logEmit(LOG_ERR, "%s", "fullMd5: please allocate a ssize_t argument");
+    logMisc(LOG_ERR, "please allocate a ssize_t argument");
     goto error;
   }
 
-  if (c == (MD5_CTX*)0) {
-    logEmit(LOG_ERR, "%s", "fullMd5 please allocate MD5_CTX argument");
+  if (md5Ctx == (MD5_CTX*)0) {
+    logMisc(LOG_ERR, "please allocate MD5_CTX argument");
     goto error;
   } 
 
   if (fullMd5sum == 0) {
-    logEmit(LOG_ERR, "%s", "fullMd5 please allocate fullMd5sum argument");
+    logMisc(LOG_ERR, "please allocate fullMd5sum argument");
     goto error;
   } 
   
   if (lseek(fd, *sum, SEEK_SET) != *sum) {
-    logEmit(LOG_ERR, "lseek: %s", strerror(errno));
+    logMisc(LOG_ERR, "lseek: %s", strerror(errno));
     goto error;
   }
   
   bytes=read(fd, buf, 512);
-  while((!size || *sum < size) && bytes > 0) {
+  while ((!size || *sum < size) && bytes > 0) {
     *sum += bytes;
-    MD5_Update(c, buf, bytes);
+    MD5_Update(md5Ctx, buf, bytes);
+    if (doSha1) SHA1_Update(shaCtx, buf, bytes);
     env.progBar.cur = *sum;
     bytes=read(fd, buf, 512);
   }
   
-  MD5_Final(md5sum, c);
+  MD5_Final(md5sum, md5Ctx);
   fullMd5sum = md5sum2string(md5sum, fullMd5sum);
-  logEmit(LOG_INFO, "%s  full md5sum computed on %llu bytes", 
+  logMisc(LOG_INFO, "%s  full md5sum computed on %llu bytes", 
 	  fullMd5sum, (long long unsigned int)*sum);
 
+  if (doSha1) {
+    SHA1_Final(shasum, shaCtx);
+    fullShasum = sha1sum2string(shasum, fullShasum);
+    logMisc(LOG_INFO, "%s full sha1sum computed on %llu bytes", 
+	    fullShasum, (long long unsigned int)*sum);
+  }
+
   rc = TRUE;
  error:
+  if (!rc) {
+    logMisc(LOG_ERR, "fullChecksum fails");
+  }
   return(rc);
 }
 
 /*=======================================================================
- * Function   : doMd5sum
+ * Function   : doChecksum
  * Description: API for md5sum computations
- * Synopsis   : int doMd5sum(Md5Data* data)
- * Input      : Md5Data* data: see md5sum.h
+ * Synopsis   : int doChecksum(CheckData* data)
+ * Input      : CheckData* data: see md5sum.h
  * Output     : TRUE on success
  =======================================================================*/
 int 
-doMd5sum(Md5Data* data)
+doChecksum(CheckData* data)
 {
   int rc = FALSE;
   int fd = -1;
   ssize_t sum = 0;
-  MD5_CTX c;
+  MD5_CTX md5Ctx;
+  SHA_CTX shaCtx;
   off_t size;
-  char quickMd5sum[MAX_SIZE_HASH+1];
-  char fullMd5sum[MAX_SIZE_HASH+1];
+  char quickMd5sum[MAX_SIZE_MD5+1];
+  char fullMd5sum[MAX_SIZE_MD5+1];
+  char quickShasum[MAX_SIZE_SHA+1];
+  char fullShasum[MAX_SIZE_SHA+1];
   char* backupPath = 0;
   int isBlockDev = FALSE;
   unsigned short int bs = 0;
   unsigned long int count = 0;
 
-  logEmit(LOG_DEBUG, "%s", "doMd5sum");
+  logMisc(LOG_DEBUG, "doChecksum");
 
   // backup the parameter values
   backupPath = data->path;
   size = data->size;
-  strncpy(quickMd5sum, data->quickMd5sum, MAX_SIZE_HASH+1); 
-  strncpy(fullMd5sum, data->fullMd5sum, MAX_SIZE_HASH+1); 
+  strncpy(quickMd5sum, data->quickMd5sum, MAX_SIZE_MD5+1); 
+  strncpy(fullMd5sum, data->fullMd5sum, MAX_SIZE_MD5+1); 
+  strncpy(quickShasum, data->quickShasum, MAX_SIZE_SHA+1); 
+  strncpy(fullShasum, data->fullShasum, MAX_SIZE_SHA+1); 
 
   if (data->path == 0 || *(data->path) == (char)0) {
-    logEmit(LOG_ERR, "%s", "Please provide a path for md5sum computing");
+    logMisc(LOG_ERR, "Please provide a path for checksum computing");
     goto error;
   }
 
   // when we deal with support devices
-  if (data->opp != MD5_CACHE_ID) {
+  if (data->opp != CHECK_CACHE_ID) {
     // look for an external device real path
     if (!getDevice(backupPath, &data->path)) goto error;
   }
   
   if ((fd = open(data->path, O_RDONLY)) == -1) {
-    logEmit(LOG_ERR, "open: %s", strerror(errno));
+    logMisc(LOG_ERR, "open: %s", strerror(errno));
     goto error;
   }
 
   // compute size
-  if (data->opp != MD5_CACHE_ID) {
+  if (data->opp != CHECK_CACHE_ID) {
     if (!isBlockDevice(data->path, &isBlockDev)) goto error;
     if (isBlockDev) {
       if (!getIsoSize(fd, &data->size, &count, &bs)) goto error;
     }
     else {
       if ((data->size = lseek(fd, 0, SEEK_END)) == -1) {
-	logEmit(LOG_ERR, "lseek: %s", strerror(errno));
+	logMisc(LOG_ERR, "lseek: %s", strerror(errno));
 	goto error;
       }
     }
@@ -350,58 +415,82 @@ doMd5sum(Md5Data* data)
     if (!startProgBar(data->path)) goto error;
   }
   
-  data->rc = 0; // MD5_SUCCESS
+  data->rc = 0; // CHECK_SUCCESS
   switch (data->opp) {
-  case MD5_CACHE_ID:
-    rc = computeQuickMd5(fd, &sum, &c, data->size, data->quickMd5sum);
-    rc&= computeFullMd5(fd, &sum, &c, data->size, data->fullMd5sum);
+  case CHECK_CACHE_ID:
+    rc = quickChecksum(fd, data->size, &sum, 
+		       &md5Ctx, data->quickMd5sum, 0, 0);
+    rc&= fullChecksum(fd, data->size, &sum, 
+		      &md5Ctx, data->fullMd5sum, 0, 0);
     break;
-  case MD5_SUPP_ADD:
-    MD5_Init(&c);
-    rc = computeQuickMd5(fd, &sum, &c, data->size, data->quickMd5sum);
-    rc&= computeFullMd5(fd, &sum, &c, data->size, data->fullMd5sum);
+  case CHECK_SUPP_ADD:
+    rc = quickChecksum(fd, data->size, &sum, 
+		       &md5Ctx, data->quickMd5sum, 
+		       &shaCtx, data->quickShasum);
+    rc&= fullChecksum(fd, data->size, &sum, 
+		      &md5Ctx, data->fullMd5sum, 
+		      &shaCtx, data->fullShasum);
     break;
-  case MD5_SUPP_ID:
-  case MD5_SUPP_CHECK:
-    if (size != 0 && data->size != size) {
-      logEmit(LOG_WARNING, "size doesn't match: %llu vs %llu expected", 
+  case CHECK_SUPP_ID:
+  case CHECK_SUPP_CHECK:
+    if (size && data->size != size) {
+      logMisc(LOG_WARNING, "size doesn't match: %llu vs %llu expected", 
 	      (long long unsigned int) data->size, 
 	      (long long unsigned int) size);
-      data->rc |= MD5_FALSE_SIZE;
+      data->rc |= CHECK_FALSE_SIZE;
       rc = TRUE;
       goto error;
     }
 
-    rc = computeQuickMd5(fd, &sum, &c, data->size, data->quickMd5sum);
-    if (strncmp(data->quickMd5sum, quickMd5sum, MAX_SIZE_HASH)) {
-      logEmit(LOG_INFO, "quick md5sum doesn't match: %s vs %s expected", 
+    rc = quickChecksum(fd, data->size, &sum, 
+		       &md5Ctx, data->quickMd5sum, 
+		       &shaCtx, data->quickShasum);
+    
+    if (strncmp(data->quickMd5sum, quickMd5sum, MAX_SIZE_MD5)) {
+      logMisc(LOG_INFO, "quick md5sum doesn't match: %s vs %s expected", 
 	     data->quickMd5sum, quickMd5sum);
-      data->rc |= MD5_FALSE_QUICK;
+      data->rc |= CHECK_FALSE_QUICK;
+      goto error;
+    }
+    if (strncmp(data->quickShasum, quickShasum, MAX_SIZE_SHA)) {
+      logMisc(LOG_INFO, "quick sha1sum doesn't match: %s vs %s expected", 
+	     data->quickShasum, quickShasum);
+      data->rc |= CHECK_FALSE_QUICK;
       goto error;
     }
 
-    if (data->opp == MD5_SUPP_ID) break;
+    if (data->opp == CHECK_SUPP_ID) break;
     
-    rc = computeFullMd5(fd, &sum, &c, data->size, data->fullMd5sum);
-    if (strncmp(data->fullMd5sum, fullMd5sum, MAX_SIZE_HASH)) {
-      logEmit(LOG_INFO, "full md5sum doesn't match: %s vs %s expected", 
+    rc&= fullChecksum(fd, data->size, &sum, 
+		      &md5Ctx, data->quickMd5sum, 
+		      &shaCtx, data->quickShasum);
+
+    if (strncmp(data->fullMd5sum, fullMd5sum, MAX_SIZE_MD5)) {
+      logMisc(LOG_INFO, "full md5sum doesn't match: %s vs %s expected", 
 	      data->fullMd5sum, fullMd5sum);
-      data->rc |= MD5_FALSE_QUICK;
+      data->rc |= CHECK_FALSE_QUICK;
       goto error;
     }
+    if (strncmp(data->fullShasum, fullShasum, MAX_SIZE_SHA)) {
+      logMisc(LOG_INFO, "full sha1sum doesn't match: %s vs %s expected", 
+	      data->fullShasum, fullShasum);
+      data->rc |= CHECK_FALSE_QUICK;
+      goto error;
+    }
+
     break;
   default:
-    logEmit(LOG_ERR, "unknown value for Md5Opp parameter: %i", data->opp);
+    logMisc(LOG_ERR, "unknown value for Md5Opp parameter: %i", data->opp);
     goto error;
   }
 
  error:
   stopProgBar(); // stop progBar
   if (fd != -1 && close(fd) == -1) {
-    logEmit(LOG_ERR, "close: %s", strerror(errno));
+    logMisc(LOG_ERR, "close: %s", strerror(errno));
     rc = FALSE;
   }
-  data->rc |= ((~rc) & 1); // |= MD5_ERROR (if !rc)
+  data->rc |= ((~rc) & 1); // |= CHECK_ERROR (if !rc)
   if (data->path != backupPath) {
     free(data->path);
     data->path = backupPath;
@@ -409,140 +498,6 @@ doMd5sum(Md5Data* data)
   return rc;
 }
 
-
-/************************************************************************/
-
-#ifdef utMAIN
-#include "command.h"
-GLOBAL_STRUCT_DEF;
-
-/*=======================================================================
- * Function   : usage
- * Description: Print the usage.
- * Synopsis   : static void usage(char* programName)
- * Input      : programName = the name of the program; usually
- *                                  argv[0].
- * Output     : N/A
- =======================================================================*/
-static 
-void usage(char* programName)
-{
-  miscUsage(programName);
-  fprintf(stderr, "\n\t\t[ -i device ] [ -p ]");
-
-  miscOptions();
-  fprintf(stderr, "  ---\n"
-	  "  -i, --input-file\tinput device to compute checksums on\n"
-	  "  -p, --no-progbar\tdo not show the progbar\n");
-  return;
-}
-
-
-/*=======================================================================
- * Function   : main 
- * Author     : Nicolas ROCHE
- * modif      : 
- * Description: Unit test for md5sum module
- * Synopsis   : ./utcommand -i scriptPath
- * Input      : N/A
- * Output     : N/A
- =======================================================================*/
-int 
-main(int argc, char** argv)
-{
-  char* inputPath = 0;
-  Md5Data data;
-  // ---
-  int rc = 0;
-  int cOption = EOF;
-  char* programName = *argv;
-  char* options = MISC_SHORT_OPTIONS"i:p";
-  struct option longOptions[] = {
-    MISC_LONG_OPTIONS,
-    {"input-file", required_argument, 0, 'i'},
-    {"no-progbar", no_argument, 0, 'p'},
-    {0, 0, 0, 0}
-  };
-
-  // import mdtx environment
-  getEnv(&env);
-  env.noRegression = FALSE; // show the progbar 
-
-  // parse the command line
-  while((cOption = getopt_long(argc, argv, options, longOptions, 0)) 
-	!= EOF) {
-    switch(cOption) {
-      
-    case 'i':
-      if(optarg == 0 || *optarg == (char)0) {
-	fprintf(stderr, "%s: nil or empty argument for the input device\n",
-		programName);
-	rc = EINVAL;
-	break;
-      }
-      if ((inputPath = malloc(strlen(optarg) + 1)) == 0) {
-	fprintf(stderr, "cannot malloc the input device path: %s", 
-		strerror(errno));
-	rc = ENOMEM;
-	break;
-      }
-      strncpy(inputPath, optarg, strlen(optarg)+1);
-      break;
-      
-    case 'p':
-      env.noRegression = TRUE; // hide the progbar
-      break;
-
-      GET_MISC_OPTIONS; // generic options
-    }
-    if (rc) goto optError;
-  }
-
-  // export mdtx environment
-  if (!setEnv(programName, &env)) goto optError;
-
-  /************************************************************************/
-  if (inputPath == 0) {
-    usage(programName);
-    logEmit(LOG_ERR, "%s", "Please provide a file to compute checksums");
-    goto error;
-  }
-
-  memset((void*)&data, 0, sizeof(data)); // valgrind complains
-  data.path = inputPath;
-  data.size = 0; // undef
-  
-  logEmit(LOG_DEBUG, "%s", 
-	  "Quick computation, no path resolution, no progbar");
-  data.opp = MD5_CACHE_ID;
-  if (!doMd5sum(&data)) goto error;
-  
-  logEmit(LOG_NOTICE, "%s", "Quick computation, path resolution, progbar");
-  data.opp = MD5_SUPP_ID;
-  if (!doMd5sum(&data)) goto error;
-      
-  logEmit(LOG_NOTICE, "%s", "Full computation, path resolution, progbar");
-  data.opp = MD5_SUPP_ADD;
-  if (!doMd5sum(&data)) goto error;
-  
-  logEmit(LOG_NOTICE, "%s", "Full check, path resolution, progbar");
-  data.opp = MD5_SUPP_CHECK;
-  if (!doMd5sum(&data)) goto error;
-  
-  if (data.rc != MD5_SUCCESS) goto error;
-  /************************************************************************/
-
-  rc = TRUE;
- error:
-  if (inputPath) free(inputPath);
-  ENDINGS;
-  rc=!rc;
- optError:
-  exit(rc);
-}
-
-#endif // utMAIN
-
 /* Local Variables: */
 /* mode: c */
 /* mode: font-lock */
