@@ -1,5 +1,5 @@
 /*=======================================================================
- * Version: $Id: perm.h,v 1.3 2015/06/03 14:03:46 nroche Exp $
+ * Version: $Id: perm.h,v 1.5 2015/08/23 23:39:16 nroche Exp $
  * Project: MediaTeX
  * Module : checksums
  *
@@ -22,17 +22,26 @@
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  =======================================================================*/
 
-#ifndef MISC_PERM_H
-#define MISC_PERM_H 1
-
-#include "../mediatex.h"
+#ifndef MDTX_MISC_PERM_H
+#define MDTX_MISC_PERM_H 1
 
+#include "mediatex.h"
 #include <time.h>
 
 time_t currentTime();
-int checkDirectory(char* path, char* user, char* group, mode_t mode);
+int checkDirectoryPerm(char* path, char* user, char* group, mode_t mode);
 
-#endif /* MISC_PERM_H */
+// seems only used by server (mainly extract.c)
+int callAccess(char* path, int* isThere);
+int checkDirectory(char* path, int *isDirectory);
+int makeDir(char* base, char* path, mode_t mode);
+int removeDir(char* base, char* path);
+int getUnusedPath(char* path, int lenFilename) ;
+int buildAbsoluteTargetPath(char** newAbsolutePath, 
+			    char* prefix, char* postfix);
+
+
+#endif /* MDTX_MISC_PERM_H */
 
 /* Local Variables: */
 /* mode: c */
