@@ -1,5 +1,5 @@
 /*=======================================================================
- * Version: $Id: progbar.c,v 1.3 2015/06/03 14:03:47 nroche Exp $
+ * Version: $Id: progbar.c,v 1.6 2015/09/22 11:42:41 nroche Exp $
  * Project: MediaTeX
  * Module : checksums
  *
@@ -85,9 +85,9 @@ void
 e2fsck_clear_progbar(struct ProgBar* progbar)
 {
 #if !MISC_CHECKSUMS_PROGBAR_DEBUG
-  printf("%s\r", progbar->spaces + (sizeof(progbar->spaces) - 80));
+  fprintf(stderr, "%s\r", progbar->spaces + (sizeof(progbar->spaces) - 80));
 #else
-  printf("(clear)\n");
+  fprintf(stderr, "(clear)\n");
 #endif
 }
 
@@ -120,7 +120,7 @@ e2fsck_simple_progress(struct ProgBar* progbar, const char *label,
   gettimeofday(&tv, 0);
   tick = (tv.tv_sec << 3) + (tv.tv_usec / (1000000 / 8));
   if ((tick == progbar->progress_last_time) &&
-      (fixed_percent != 0) && (fixed_percent != 1000))
+      (fixed_percent) && (fixed_percent != 1000))
     return;
   progbar->progress_last_time = tick;
   
@@ -134,94 +134,22 @@ e2fsck_simple_progress(struct ProgBar* progbar, const char *label,
   dpywidth = 8 * (dpywidth / 8);
   
   i = ((percent * dpywidth) + 50) / 100;
-  printf("%s: |%s%s", label,
+  fprintf(stderr, "%s: |%s%s", label,
 	 progbar->bar + (sizeof(progbar->bar) - (i+1)),
 	 progbar->spaces + (sizeof(progbar->spaces) - (dpywidth - i + 1)));
   if (fixed_percent == 1000)
-    fputc('|', stdout);
+    fputc('|', stderr);
   else
-    fputc(spinner[progbar->progress_pos & 3], stdout);
-  printf(" %4.1f%%  ", percent);
+    fputc(spinner[progbar->progress_pos & 3], stderr);
+  fprintf(stderr, " %4.1f%%  ", percent);
 #if !MISC_CHECKSUMS_PROGBAR_DEBUG
-  fputs(" \r", stdout);
+  fputs(" \r", stderr);
 #else
-  fputs(" \n", stdout);
+  fputs(" \n", stderr);
 #endif
   if (fixed_percent == 1000)
     e2fsck_clear_progbar(progbar);
-  fflush(stdout);
+  fflush(stderr);
   
   return;
 }
-
-
-/*************************************************************************/
-#ifdef utMAIN
-
-void 
-e2fsck_progress(struct ProgBar* progbar, const char *label, 
-		     unsigned long max)
-{
-  unsigned long cur = 0;
-  float percent = 0;
-
-  progbar->progress_last_percent = -1;
-  progbar->progress_last_time = 0;
-  progbar->progress_pos = 0;
-
-  for (cur=0; cur<max; ++cur) {
-    percent = calc_percent(cur, max);
-    e2fsck_simple_progress(progbar, label, percent);
-    usleep(1000);
-  }
-  e2fsck_clear_progbar(progbar);
-}
-
-/*=======================================================================
- * Function   : main 
- * Author     : Nicolas ROCHE
- * modif      : 
- * Description: Unit test for md5sum module
- * Synopsis   : ./utmd5sum -i file
- * Input      : N/A
- * Output     : N/A
- =======================================================================*/
-int 
-main() 
-{
-  struct ProgBar progbar;
-  char test[] = "sapin_de_noel";
-  char buff[20];
-  unsigned int i;
-  int p;
-
-  // algo init
-  initProgBar(&progbar);
-
-  // test 1
-  memset(buff, 0, sizeof(buff));
-
-  for (i=0; i<sizeof(test)-1; ++i) {
-    usleep(200000);
-    buff[i] = test[i];
-    p = i*100/(sizeof(test)-2);
-    //printf("%s %i\n", buff, p);
-    e2fsck_simple_progress(&progbar, buff, p);
-  }
-
-  // test 2
-  e2fsck_progress(&progbar, ":)", 1234);
-  e2fsck_progress(&progbar, "coucou", 3234);
-  e2fsck_progress(&progbar, "thank you very much Theodore Ts'o", 2345);
-  e2fsck_progress(&progbar, ":)", 1234);
-
-  return 0;
-}
-
-#endif	/*	: utMAIN	*/
-
-/* Local Variables: */
-/* mode: c */
-/* mode: font-lock */
-/* mode: auto-fill */
-/* End: */
