@@ -1,5 +1,5 @@
 /*=======================================================================
- * Version: $Id: setuid.c,v 1.3 2015/06/03 14:03:47 nroche Exp $
+ * Version: $Id: setuid.c,v 1.7 2015/08/13 21:14:36 nroche Exp $
  * Project: MediaTeX
  * Module : command
  *
@@ -24,9 +24,7 @@
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  =======================================================================*/
 
-#include "log.h"
-#include "command.h"
-#include "setuid.h"
+#include "mediatex-config.h"
 
 /*=======================================================================
  * Function   : getPasswdLine
@@ -46,9 +44,7 @@ getPasswdLine (char* label, uid_t uid, struct passwd* pw, char** buffer)
   size_t bufsize = 0;
   int err = 0;
 
-#ifdef utMAIN  
-  logEmit (LOG_DEBUG, "%s", "find an /etc/passwd line");
-#endif
+  logMisc (LOG_DEBUG, "find an /etc/passwd line");
 
   // allocate buffer
   *buffer = 0;
@@ -56,26 +52,26 @@ getPasswdLine (char* label, uid_t uid, struct passwd* pw, char** buffer)
     bufsize = 16384;        // Should be more than enough
   }
   if ((*buffer = malloc(bufsize)) == 0) {
-    logEmit (LOG_ERR, "cannot malloc: %s", strerror (errno));
+    logMisc (LOG_ERR, "cannot malloc: %s", strerror (errno));
     goto error;
   }
 
   // use the uid if no label is provided
   if (label == 0 || *label == (char)0) {
     if ((err = getpwuid_r(uid, pw, *buffer, bufsize, &result))) {
-	logEmit (LOG_ERR, "getpwuid_r fails: %s", strerror (err));
+	logMisc (LOG_ERR, "getpwuid_r fails: %s", strerror (err));
 	goto error;
       }
   }
   else {
     if ((err = getpwnam_r(label, pw, *buffer, bufsize, &result))) {
-      logEmit (LOG_ERR, "getpwnam_r fails: %s", strerror (err));
+      logMisc (LOG_ERR, "getpwnam_r fails: %s", strerror (err));
       goto error;
     }
   }
 
   if (result == 0) {
-    logEmit (LOG_WARNING, "%s/%i user not found", label, uid);
+    logMisc (LOG_WARNING, "%s/%i user not found", label, uid);
     goto error;
   }
   
@@ -104,9 +100,7 @@ getGroupLine (char* label, gid_t gid, struct group* gr, char** buffer)
   size_t bufsize = 0;
   int s;
 
-#ifdef utMAIN
-  logEmit (LOG_DEBUG, "%s", "find an /etc/group line");
-#endif
+  logMisc (LOG_DEBUG, "find an /etc/group line");
 
   // allocate buffer
   *buffer = 0;
@@ -114,7 +108,7 @@ getGroupLine (char* label, gid_t gid, struct group* gr, char** buffer)
     bufsize = 16384;        /* I do not know what to put here ? */
   }
   if ((*buffer = malloc(bufsize)) == 0) {
-    logEmit (LOG_ERR, "cannot malloc: %s", strerror (errno));
+    logMisc (LOG_ERR, "cannot malloc: %s", strerror (errno));
     goto error;
   }
 
@@ -127,10 +121,10 @@ getGroupLine (char* label, gid_t gid, struct group* gr, char** buffer)
   }
   if (result == 0) {
     if (s == 0) {
-      logEmit (LOG_WARNING, "group not found: %s", label);
+      logMisc (LOG_WARNING, "group not found: %s", label);
     }
     else {
-      logEmit (LOG_ERR, "getgrnam_r error: %s", strerror (s));
+      logMisc (LOG_ERR, "getgrnam_r error: %s", strerror (s));
     }
     goto error;
   }
@@ -158,31 +152,27 @@ undo_seteuid (void)
   int rc = FALSE;
   int uid = getuid();
 
-  logEmit (LOG_DEBUG, "%s", "hide euid");
+  logMisc (LOG_DEBUG, "hide euid");
 
   // we do not return on error for unit tests
-  if (geteuid() != 0) {
-    logEmit (LOG_ERR, "%s", 
+  if (geteuid()) {
+    logMisc (LOG_ERR, 
 	     "binary not owned by root or setuid bit not set");
     goto error;
   } 
 
-#ifdef utMAIN
-  logEmit (LOG_DEBUG, "= ruid=%i euid=%i", getuid (), geteuid ());     
-#endif
+  //logMisc (LOG_DEBUG, "= ruid=%i euid=%i", getuid (), geteuid ());     
 
   if ((rc = setresuid (-1, uid, 0))) {
-    logEmit (LOG_ERR, "setrsuid fails: %s", strerror (errno));
+    logMisc (LOG_ERR, "setrsuid fails: %s", strerror (errno));
     goto error;
   }
   
   rc = TRUE;
  error:
-#ifdef utMAIN
-  logEmit (LOG_DEBUG, "> ruid=%i euid=%i", getuid (), geteuid ());
-#endif
+  //logMisc (LOG_DEBUG, "> ruid=%i euid=%i", getuid (), geteuid ());
   if (!rc) {
-    logEmit (LOG_ERR, "%s", "fails to hide eid");
+    logMisc (LOG_ERR, "fails to hide eid");
   }
   return rc;
 }
@@ -206,28 +196,19 @@ allowedUser (char* label)
   int belongs = 0;
 
   if (!label) goto error;
-  logEmit (LOG_DEBUG, "check permissions to become %s user", label);
+  logMisc (LOG_DEBUG, "check permissions to become %s user", label);
 
-#ifndef utMAIN
   if (env.noRegression) return TRUE;
-#endif
 
-  if (
-#ifdef utMAIN
-      strncmp(label, "ut-", 3) &&
-      strncmp(label+3, env.confLabel, strlen(env.confLabel))
-#else 
-      strncmp(label, env.confLabel, strlen(env.confLabel))
-#endif
-      ) {
-    logEmit (LOG_ERR, "the %s user account is not manage by mediatex", 
+  if (strncmp(label, env.confLabel, strlen(env.confLabel))) {
+    logMisc (LOG_ERR, "the %s user account is not manage by mediatex", 
 	     label);
     goto error;
   }
 
   // get current user name
   if (!getPasswdLine (0, getuid(), &pw, &buf1)) goto error;
-  logEmit (LOG_INFO, "you are %s", pw.pw_name);
+  logMisc (LOG_INFO, "you are %s", pw.pw_name);
 
   // if current user is already label
   if (strlen(label) == strlen(pw.pw_name) &&
@@ -242,14 +223,14 @@ allowedUser (char* label)
 
   // check if current user belongs to the mdtx group
   if (!getGroupLine (env.confLabel, -1, &gr, &buf2)) goto error;
-  while (*(gr.gr_mem) != 0) {
+  while (*(gr.gr_mem)) {
     if (!strcmp(*(gr.gr_mem), pw.pw_name)) {
       belongs=1;
       break;
     }
     ++(gr.gr_mem);
   }
-  logEmit (LOG_INFO, "you do%s belongs to the %s group", 
+  logMisc (LOG_INFO, "you do%s belongs to the %s group", 
 	   belongs?"":" NOT", env.confLabel);
   if (!belongs) goto error; 
 
@@ -259,7 +240,7 @@ allowedUser (char* label)
   if (buf1) free (buf1);
   if (buf2) free (buf2);
   if (!rc) {
-    logEmit (LOG_ERR, "%s", "allowedUser fails");
+    logMisc (LOG_ERR, "allowedUser fails");
   }
   return rc;
 }
@@ -285,10 +266,9 @@ becomeUser (char* label, int doCheck)
   char *buf2 = 0;
 
   if (!label) goto error;
-  logEmit (LOG_DEBUG, "becomeUser %s", label);
-#ifndef utMAIN
+  logMisc (LOG_DEBUG, "becomeUser %s", label);
+
   if (env.noRegression) return TRUE;
-#endif
   if (doCheck && !allowedUser (label)) goto error;
 
   // get current user name
@@ -303,7 +283,7 @@ becomeUser (char* label, int doCheck)
 
   // get privileges  
   if ((rc = setresuid (0, 0, -1))) {
-    logEmit (LOG_ERR, "setresuid fails: %s", strerror (errno));
+    logMisc (LOG_ERR, "setresuid fails: %s", strerror (errno));
     goto error;
   }
   
@@ -312,36 +292,36 @@ becomeUser (char* label, int doCheck)
   // => need to call initgroups("mdtx", 0) as root before setuid
   // to give group indirect access (like cdrom).
   if (initgroups(label, gr.gr_gid) == -1) {
-    logEmit (LOG_ERR, "fails to reset groups list: %s", strerror (errno));
+    logMisc (LOG_ERR, "fails to reset groups list: %s", strerror (errno));
     goto error;
   }
 
   // change group
   if ((rc = setgid (gr.gr_gid))) {
-    logEmit (LOG_ERR, "setgid fails: %s", strerror (errno));
+    logMisc (LOG_ERR, "setgid fails: %s", strerror (errno));
     goto error;
   }
 
   // export the HOME environment variable
   if (setenv("HOME", pw.pw_dir, 1) == -1) {
-    logEmit(LOG_ERR, "setenv home variable failed: ", strerror(errno));
+    logMisc(LOG_ERR, "setenv home variable failed: ", strerror(errno));
     goto error;
   }
   
   // change to label user
   if ((rc = setresuid (pw.pw_uid, pw.pw_uid, 0))) {
-    logEmit (LOG_ERR, "setrsuid fails: %s", strerror (errno));
+    logMisc (LOG_ERR, "setrsuid fails: %s", strerror (errno));
     goto error;
   }
 
-  logEmit (LOG_INFO, "current user is %s", label);
+  logMisc (LOG_INFO, "current user is %s", label);
  nothingToDo:
   rc = TRUE;
  error:
   if (buf1) free (buf1);
   if (buf2) free (buf2);
   if (!rc) {
-    logEmit (LOG_ERR, "%s", "becomeUser fails");
+    logMisc (LOG_ERR, "becomeUser fails");
   }
   return rc;
 }
@@ -363,11 +343,9 @@ logoutUser (int uid)
   char* buf = 0;
 
   //if (uid == 0) goto error; // needed by setConcurentAccessLock
-  logEmit (LOG_DEBUG, "logoutUser %i", uid);
-#ifndef utMAIN
-  if (env.noRegression) return TRUE;
-#endif
+  logMisc (LOG_DEBUG, "logoutUser %i", uid);
 
+  if (env.noRegression) return TRUE;
   if (uid == getuid()) goto nothingToDo;
 
   // get current user name
@@ -378,174 +356,12 @@ logoutUser (int uid)
   rc = TRUE;
  error:
   if (!rc) {
-    logEmit (LOG_ERR, "%s", "logoutUser fails");
+    logMisc (LOG_ERR, "logoutUser fails");
   }
   if (buf) free (buf);
   return rc;
 }
 
-/************************************************************************/
-
-#ifdef utMAIN
-#include <pthread.h>
-#include "command.h"
-GLOBAL_STRUCT_DEF;
-
-/*=======================================================================
- * Function   : usage
- * Description: Print the usage.
- * Synopsis   : static void usage (char* programName)
- * Input      : programName = the name of the program; usually argv[0].
- * Output     : N/A
- =======================================================================*/
-static void 
-usage (char* programName)
-{
-  mdtxUsage (programName);
-  fprintf (stderr, "\n\t\t -u user");
-  fprintf (stderr, "\n\t\t -i scriptPath");
-
-  mdtxOptions();
-  fprintf (stderr, "  ---\n");
-  fprintf (stderr, "  -u, --sudo-user\tuser to become\n");
-  fprintf (stderr, "  -i, --input-file\tinput script to exec\n");
-
-  fprintf (stderr, "\nNeed prior to do as root:\n" \
-	  "# chown root. utsetuid\n" \
-	  "# chmod u+s utsetuid\n");
-
-  return;
-}
-
-
-/*=======================================================================
- * Function   : main 
- * Author     : Nicolas ROCHE
- * modif      : 2012/11/11
- * Description: Unit test for md5sum module
- * Synopsis   : ./utcommand -i scriptPath
- * Input      : -i option for scriptPath to exec
- * Output     : N/A
- =======================================================================*/
-int 
-main (int argc, char** argv)
-{
-  char* inputFile = 0;
-  int i;
-  char *argvExec[] = { 0, "parameter1", 0};
-  int uid = getuid();
-  // ---
-  int rc = 0;
-  int cOption = EOF;
-  char* programName = *argv;
-  char* options = MDTX_SHORT_OPTIONS"i:u:";
-  struct option longOptions[] = {
-    MDTX_LONG_OPTIONS,
-    {"sudo-user", required_argument, 0, 'u'},
-    {"input-file", required_argument, 0, 'i'},
-    {0, 0, 0, 0}
-  };
-
-  // import mdtx environment
-  getEnv (&env);
-
-  // parse the command line
-  while ((cOption = getopt_long (argc, argv, options, longOptions, 0)) 
-	!= EOF) {
-    switch (cOption) {
-      
-    case 'i':
-      if (optarg == 0 || *optarg == (char)0) {
-	fprintf (stderr, 
-		 "%s: nil or empty argument for the input stream\n", 
-		 programName);
-	rc = EINVAL;
-      }
-      inputFile = optarg;
-      break;
-
-    case 'u':
-      if (optarg == 0 || *optarg == (char)0) {
-	fprintf (stderr, "%s: nil or empty argument for the user name\n", 
-		programName);
-	rc = EINVAL;
-      }
-      env.confLabel = optarg;
-      break;
-      
-      GET_MDTX_OPTIONS; // generic options
-    }
-    if (rc) goto optError;
-  }
-
-  // export mdtx environment
-  if (!setEnv (programName, &env)) goto optError;
-
-  /************************************************************************/
-  if (env.confLabel == 0) {
-    usage (programName);
-    logEmit (LOG_ERR, "%s", "Please provide a user to become");
-    goto error;
-  }
-  if (inputFile == 0) {
-    usage (programName);
-    logEmit (LOG_ERR, "%s", "Please provide an input file");
-    goto error;
-  }
-  argvExec[0] = inputFile;
-
-  // must be done first
-  if (!undo_seteuid ()) goto error;
-
-  // first layer
-  logEmit (LOG_NOTICE, "%s", "** first layer");
-  for (i=0; i<2; ++i) {
-
-    // get privileges
-    if ((rc = setresuid (0, 0, -1))) {
-      logEmit (LOG_ERR, "setresuid fails: %s", strerror (errno));
-      goto error;
-    }
-
-    logEmit (LOG_INFO, "> ruid=%i euid=%i", getuid (), geteuid ());
-
-    // change to label user
-    if ((rc = setresuid (uid, uid, 0))) {
-      logEmit (LOG_ERR, "setrsuid fails: %s", strerror (errno));
-      goto error;
-    }
-
-    logEmit (LOG_INFO, "< ruid=%i euid=%i", getuid (), geteuid ());
-  }
-
-  // API for wrapper
-  logEmit (LOG_NOTICE, "%s", "** API for wrapper");
-  uid = getuid();
-  for (i=0; i<2; ++i) {
-    if (!(rc = execScript (argvExec, 0, 0, FALSE))) goto error;
-    if (!becomeUser(env.confLabel, TRUE)) goto error;
-    if (!(execScript (argvExec, 0, 0, FALSE))) goto error;
-    if (!logoutUser(uid)) goto error;
-  }
-
-  // API for thread
-  logEmit (LOG_NOTICE, "%s", "** API for thread");
-  for (i=0; i<2; ++i) {
-    if (!execScript(argvExec, env.confLabel, 0, FALSE)) goto error;
-    if (!execScript(argvExec, 0, 0, FALSE)) goto error;
-  }
-  /************************************************************************/
-
-  rc = TRUE;
- error:
-  ENDINGS;
-  rc=!rc;
- optError:
-  exit(rc);
-}
-
-#endif // utMAIN
-
 /* Local Variables: */
 /* mode: c */
 /* mode: font-lock */
