@@ -30,8 +30,8 @@
    This special exception was added by the Free Software Foundation in
    version 2.2 of Bison.  */
 
-#ifndef YY_CATA_CATALOGFILE_TAB_H_INCLUDED
-# define YY_CATA_CATALOGFILE_TAB_H_INCLUDED
+#ifndef YY_CATA_PARSER_CATALOGFILE_TAB_H_INCLUDED
+# define YY_CATA_PARSER_CATALOGFILE_TAB_H_INCLUDED
 /* Debug traces.  */
 #ifndef CATA_DEBUG
 # if defined YYDEBUG
@@ -53,62 +53,52 @@ extern int cata_debug;
 # define CATA_TOKENTYPE
   enum cata_tokentype
   {
-    catHUMCARAC = 258,
-    catCONCARAC = 259,
-    catRECCARAC = 260,
-    catDOCCARAC = 261,
-    catTOP = 262,
-    catCATEGORY = 263,
-    catROLE = 264,
-    catHUMAN = 265,
-    catDOCUMENT = 266,
-    catWITH = 267,
-    catARCHIVE = 268,
-    catCOLON = 269,
-    catEQUAL = 270,
-    catDOT = 271,
-    catCOMMA = 272,
-    catHASH = 273,
-    catNUMBER = 274,
-    catSTRING = 275
+    cataERROR = 258,
+    cataTOP = 259,
+    cataCATEGORY = 260,
+    cataDOCUMENT = 261,
+    cataHUMAN = 262,
+    cataWITH = 263,
+    cataARCHIVE = 264,
+    cataEQUAL = 265,
+    cataCOLON = 266,
+    cataCOMMA = 267,
+    cataHASH = 268,
+    cataNUMBER = 269,
+    cataSTRING = 270
   };
 #endif
 /* Tokens.  */
-#define catHUMCARAC 258
-#define catCONCARAC 259
-#define catRECCARAC 260
-#define catDOCCARAC 261
-#define catTOP 262
-#define catCATEGORY 263
-#define catROLE 264
-#define catHUMAN 265
-#define catDOCUMENT 266
-#define catWITH 267
-#define catARCHIVE 268
-#define catCOLON 269
-#define catEQUAL 270
-#define catDOT 271
-#define catCOMMA 272
-#define catHASH 273
-#define catNUMBER 274
-#define catSTRING 275
+#define cataERROR 258
+#define cataTOP 259
+#define cataCATEGORY 260
+#define cataDOCUMENT 261
+#define cataHUMAN 262
+#define cataWITH 263
+#define cataARCHIVE 264
+#define cataEQUAL 265
+#define cataCOLON 266
+#define cataCOMMA 267
+#define cataHASH 268
+#define cataNUMBER 269
+#define cataSTRING 270
 
 /* Value type.  */
 #if ! defined CATA_STYPE && ! defined CATA_STYPE_IS_DECLARED
 typedef union CATA_STYPE CATA_STYPE;
 union CATA_STYPE
 {
-#line 37 "../parser/catalogFile.y" /* yacc.c:1909  */
+#line 61 "parser/catalogFile.y" /* yacc.c:1909  */
 
   off_t  size;
   char   string[MAX_SIZE_STRING+1];
-  char   hash[MAX_SIZE_HASH+1];
+  char   hash[MAX_SIZE_MD5+1];
   Category* category;
   Human*    human;
   Document* document;
   Archive*  archive;
 
-#line 112 "catalogFile.tab.h" /* yacc.c:1909  */
+#line 102 "parser/catalogFile.tab.h" /* yacc.c:1909  */
 };
 # define CATA_STYPE_IS_TRIVIAL 1
 # define CATA_STYPE_IS_DECLARED 1
@@ -118,14 +108,14 @@ union CATA_STYPE
 
 int cata_parse (yyscan_t yyscanner, Collection* coll, Category* category, Human* human, Document* document, Archive* archive);
 /* "%code provides" blocks.  */
-#line 58 "../parser/catalogFile.y" /* yacc.c:1909  */
+#line 27 "parser/catalogFile.y" /* yacc.c:1909  */
 
 /*=======================================================================
  * Version: this file is generated by BISON using catalogFile.y
  * Project: MediaTeX
  * Module : catalogFile parser
  *
- * catalog parser
+ * catalog file parser
 
  MediaTex is an Electronic Records Management System
  Copyright (C) 2014 2015 Nicolas Roche
@@ -143,9 +133,9 @@ int cata_parse (yyscan_t yyscanner, Collection* coll, Category* category, Human*
  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  =======================================================================*/
-  #include "../memory/catalogTree.h"
-  int parseCatalogFile(Collection* coll, const char* path);
 
-#line 150 "catalogFile.tab.h" /* yacc.c:1909  */
+#define YYSTYPE CATA_STYPE
 
-#endif /* !YY_CATA_CATALOGFILE_TAB_H_INCLUDED  */
+#line 140 "parser/catalogFile.tab.h" /* yacc.c:1909  */
+
+#endif /* !YY_CATA_PARSER_CATALOGFILE_TAB_H_INCLUDED  */
