@@ -30,8 +30,8 @@
    This special exception was added by the Free Software Foundation in
    version 2.2 of Bison.  */
 
-#ifndef YY_CONF_CONFFILE_TAB_H_INCLUDED
-# define YY_CONF_CONFFILE_TAB_H_INCLUDED
+#ifndef YY_CONF_PARSER_CONFFILE_TAB_H_INCLUDED
+# define YY_CONF_PARSER_CONFFILE_TAB_H_INCLUDED
 /* Debug traces.  */
 #ifndef CONF_DEBUG
 # if defined YYDEBUG
@@ -53,76 +53,80 @@ extern int conf_debug;
 # define CONF_TOKENTYPE
   enum conf_tokentype
   {
-    confHOST = 258,
-    confNETWORKS = 259,
-    confGATEWAYS = 260,
-    confMDTXPORT = 261,
-    confSSHPORT = 262,
-    confCACHESIZE = 263,
-    confCACHETTL = 264,
-    confQUERYTTL = 265,
-    confCHECKTTL = 266,
-    confSUPPTTL = 267,
-    confMAXSCORE = 268,
-    confBADSCORE = 269,
-    confPOWSUPP = 270,
-    confPOWIMAGE = 271,
-    confFACTSUPP = 272,
-    confCOLL = 273,
-    confCOMMENT = 274,
-    confSHARE = 275,
-    confLOCALHOST = 276,
-    confCOMMA = 277,
-    confDOT = 278,
-    confCOLON = 279,
-    confAROBASE = 280,
-    confMINUS = 281,
-    confENDBLOCK = 282,
-    confSTRING = 283,
-    confNUMBER = 284,
-    confSCORE = 285,
-    confSIZE = 286,
-    confTIME = 287
+    confERROR = 258,
+    confHOST = 259,
+    confNETWORKS = 260,
+    confGATEWAYS = 261,
+    confMDTXPORT = 262,
+    confSSHPORT = 263,
+    confWWWPORT = 264,
+    confCACHESIZE = 265,
+    confCACHETTL = 266,
+    confQUERYTTL = 267,
+    confCHECKTTL = 268,
+    confFILETTL = 269,
+    confSUPPTTL = 270,
+    confMAXSCORE = 271,
+    confBADSCORE = 272,
+    confPOWSUPP = 273,
+    confFACTSUPP = 274,
+    confCOLL = 275,
+    confCOMMENT = 276,
+    confSHARE = 277,
+    confLOCALHOST = 278,
+    confCOMMA = 279,
+    confDOT = 280,
+    confCOLON = 281,
+    confAROBASE = 282,
+    confMINUS = 283,
+    confENDBLOCK = 284,
+    confSTRING = 285,
+    confNUMBER = 286,
+    confSCORE = 287,
+    confSIZE = 288,
+    confTIME = 289
   };
 #endif
 /* Tokens.  */
-#define confHOST 258
-#define confNETWORKS 259
-#define confGATEWAYS 260
-#define confMDTXPORT 261
-#define confSSHPORT 262
-#define confCACHESIZE 263
-#define confCACHETTL 264
-#define confQUERYTTL 265
-#define confCHECKTTL 266
-#define confSUPPTTL 267
-#define confMAXSCORE 268
-#define confBADSCORE 269
-#define confPOWSUPP 270
-#define confPOWIMAGE 271
-#define confFACTSUPP 272
-#define confCOLL 273
-#define confCOMMENT 274
-#define confSHARE 275
-#define confLOCALHOST 276
-#define confCOMMA 277
-#define confDOT 278
-#define confCOLON 279
-#define confAROBASE 280
-#define confMINUS 281
-#define confENDBLOCK 282
-#define confSTRING 283
-#define confNUMBER 284
-#define confSCORE 285
-#define confSIZE 286
-#define confTIME 287
+#define confERROR 258
+#define confHOST 259
+#define confNETWORKS 260
+#define confGATEWAYS 261
+#define confMDTXPORT 262
+#define confSSHPORT 263
+#define confWWWPORT 264
+#define confCACHESIZE 265
+#define confCACHETTL 266
+#define confQUERYTTL 267
+#define confCHECKTTL 268
+#define confFILETTL 269
+#define confSUPPTTL 270
+#define confMAXSCORE 271
+#define confBADSCORE 272
+#define confPOWSUPP 273
+#define confFACTSUPP 274
+#define confCOLL 275
+#define confCOMMENT 276
+#define confSHARE 277
+#define confLOCALHOST 278
+#define confCOMMA 279
+#define confDOT 280
+#define confCOLON 281
+#define confAROBASE 282
+#define confMINUS 283
+#define confENDBLOCK 284
+#define confSTRING 285
+#define confNUMBER 286
+#define confSCORE 287
+#define confSIZE 288
+#define confTIME 289
 
 /* Value type.  */
 #if ! defined CONF_STYPE && ! defined CONF_STYPE_IS_DECLARED
 typedef union CONF_STYPE CONF_STYPE;
 union CONF_STYPE
 {
-#line 36 "../parser/confFile.y" /* yacc.c:1909  */
+#line 61 "parser/confFile.y" /* yacc.c:1909  */
 
   char          string[MAX_SIZE_STRING+1];
   unsigned int  number;
@@ -130,7 +134,7 @@ union CONF_STYPE
   off_t         size;
   time_t        time;
 
-#line 134 "confFile.tab.h" /* yacc.c:1909  */
+#line 138 "parser/confFile.tab.h" /* yacc.c:1909  */
 };
 # define CONF_STYPE_IS_TRIVIAL 1
 # define CONF_STYPE_IS_DECLARED 1
@@ -140,14 +144,14 @@ union CONF_STYPE
 
 int conf_parse (yyscan_t yyscanner, Collection* coll);
 /* "%code provides" blocks.  */
-#line 53 "../parser/confFile.y" /* yacc.c:1909  */
+#line 27 "parser/confFile.y" /* yacc.c:1909  */
 
 /*=======================================================================
  * Version: this file is generated by BISON using confFile.y
  * Project: MediaTeX
- * Module : confFile parser
+ * Module : conf parser
  *
- * configuation file parser.
+ * configuation file parser
 
  MediaTex is an Electronic Records Management System
  Copyright (C) 2014 2015 Nicolas Roche
@@ -165,9 +169,9 @@ int conf_parse (yyscan_t yyscanner, Collection* coll);
  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  =======================================================================*/
-#include "../memory/confTree.h"
-int parseConfiguration(const char* path);
 
-#line 172 "confFile.tab.h" /* yacc.c:1909  */
+#define YYSTYPE CONF_STYPE
 
-#endif /* !YY_CONF_CONFFILE_TAB_H_INCLUDED  */
+#line 176 "parser/confFile.tab.h" /* yacc.c:1909  */
+
+#endif /* !YY_CONF_PARSER_CONFFILE_TAB_H_INCLUDED  */
