@@ -69,17 +69,13 @@
 
 
 /* Copy the first part of user declarations.  */
-#line 26 "../parser/extractFile.y" /* yacc.c:339  */
+#line 55 "parser/extractFile.y" /* yacc.c:339  */
+  
+#include "mediatex-config.h"
+  /* yyscan_t is pre-defined by mediatex-config.h and will be defined
+     by Flex header bellow */
 
-#include "../mediatex.h"
-#include "../misc/log.h"
-#include "../misc/locks.h"
-#include "../memory/extractTree.h"
-
-// hack because Flex needs YYSTYPE from tab.h and Bison needs yyscan_t from .h
-typedef void* yyscan_t;
-
-#line 83 "extractFile.tab.c" /* yacc.c:339  */
+#line 79 "parser/extractFile.tab.c" /* yacc.c:339  */
 
 # ifndef YY_NULLPTR
 #  if defined __cplusplus && 201103L <= __cplusplus
@@ -99,8 +95,8 @@ typedef void* yyscan_t;
 
 /* In a future release of Bison, this section will be replaced
    by #include "extractFile.tab.h".  */
-#ifndef YY_EXTR_EXTRACTFILE_TAB_H_INCLUDED
-# define YY_EXTR_EXTRACTFILE_TAB_H_INCLUDED
+#ifndef YY_EXTR_PARSER_EXTRACTFILE_TAB_H_INCLUDED
+# define YY_EXTR_PARSER_EXTRACTFILE_TAB_H_INCLUDED
 /* Debug traces.  */
 #ifndef EXTR_DEBUG
 # if defined YYDEBUG
@@ -122,44 +118,46 @@ extern int extr_debug;
 # define EXTR_TOKENTYPE
   enum extr_tokentype
   {
-    extOPEN = 258,
-    extCLOSE = 259,
-    extTYPE = 260,
-    extIMPLIES = 261,
-    extAS = 262,
-    extHASH = 263,
-    extCOLON = 264,
-    extSIZE = 265,
-    extCOMMA = 266,
-    extSTRING = 267
+    extrERROR = 258,
+    extrOPEN = 259,
+    extrCLOSE = 260,
+    extrTYPE = 261,
+    extrIMPLIES = 262,
+    extrAS = 263,
+    extrHASH = 264,
+    extrCOLON = 265,
+    extrSIZE = 266,
+    extrCOMMA = 267,
+    extrSTRING = 268
   };
 #endif
 /* Tokens.  */
-#define extOPEN 258
-#define extCLOSE 259
-#define extTYPE 260
-#define extIMPLIES 261
-#define extAS 262
-#define extHASH 263
-#define extCOLON 264
-#define extSIZE 265
-#define extCOMMA 266
-#define extSTRING 267
+#define extrERROR 258
+#define extrOPEN 259
+#define extrCLOSE 260
+#define extrTYPE 261
+#define extrIMPLIES 262
+#define extrAS 263
+#define extrHASH 264
+#define extrCOLON 265
+#define extrSIZE 266
+#define extrCOMMA 267
+#define extrSTRING 268
 
 /* Value type.  */
 #if ! defined EXTR_STYPE && ! defined EXTR_STYPE_IS_DECLARED
 typedef union EXTR_STYPE EXTR_STYPE;
 union EXTR_STYPE
 {
-#line 36 "../parser/extractFile.y" /* yacc.c:355  */
+#line 61 "parser/extractFile.y" /* yacc.c:355  */
 
   off_t  size;
   char   string[MAX_SIZE_STRING+1];
-  char   hash[MAX_SIZE_HASH+1];
+  char   hash[MAX_SIZE_MD5+1];
   EType  type; 
   Archive* archive;
 
-#line 163 "extractFile.tab.c" /* yacc.c:355  */
+#line 161 "parser/extractFile.tab.c" /* yacc.c:355  */
 };
 # define EXTR_STYPE_IS_TRIVIAL 1
 # define EXTR_STYPE_IS_DECLARED 1
@@ -169,12 +167,12 @@ union EXTR_STYPE
 
 int extr_parse (yyscan_t yyscanner, Collection* coll, Container* container);
 /* "%code provides" blocks.  */
-#line 54 "../parser/extractFile.y" /* yacc.c:355  */
+#line 27 "parser/extractFile.y" /* yacc.c:355  */
 
 /*=======================================================================
  * Version: this file is generated by BISON using extractFile.y
  * Project: MediaTeX
- * Module : extractFile parser
+ * Module : extraction meta-date parser
  *
  * extract parser.
 
@@ -194,25 +192,25 @@ int extr_parse (yyscan_t yyscanner, Collection* coll, Container* container);
  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  =======================================================================*/
-#include "../memory/extractTree.h"
-int parseExtractFile(Collection* coll, const char* path);
 
-#line 201 "extractFile.tab.c" /* yacc.c:355  */
+#define YYSTYPE EXTR_STYPE
 
-#endif /* !YY_EXTR_EXTRACTFILE_TAB_H_INCLUDED  */
+#line 199 "parser/extractFile.tab.c" /* yacc.c:355  */
+
+#endif /* !YY_EXTR_PARSER_EXTRACTFILE_TAB_H_INCLUDED  */
 
 /* Copy the second part of user declarations.  */
-#line 44 "../parser/extractFile.y" /* yacc.c:358  */
+#line 69 "parser/extractFile.y" /* yacc.c:358  */
 
 // we need YYSTYPE defined first to include the Flex headers
-#include "extractFile.h"
+#include "parser/extractFile.h"
 
 #define LINENO extr_get_lineno(yyscanner)
   
-void extr_error(yyscan_t yyscanner, Collection* coll, Container* container,
-		const char* message);
+void extr_error(yyscan_t yyscanner, Collection* coll, 
+		Container* container, const char* message);
 
-#line 216 "extractFile.tab.c" /* yacc.c:358  */
+#line 214 "parser/extractFile.tab.c" /* yacc.c:358  */
 
 #ifdef short
 # undef short
@@ -452,23 +450,23 @@ union yyalloc
 #endif /* !YYCOPY_NEEDED */
 
 /* YYFINAL -- State number of the termination state.  */
-#define YYFINAL  7
+#define YYFINAL  9
 /* YYLAST -- Last index in YYTABLE.  */
-#define YYLAST   28
+#define YYLAST   23
 
 /* YYNTOKENS -- Number of terminals.  */
-#define YYNTOKENS  13
+#define YYNTOKENS  14
 /* YYNNTS -- Number of nonterminals.  */
-#define YYNNTS  10
+#define YYNNTS  12
 /* YYNRULES -- Number of rules.  */
-#define YYNRULES  16
+#define YYNRULES  18
 /* YYNSTATES -- Number of states.  */
-#define YYNSTATES  28
+#define YYNSTATES  26
 
 /* YYTRANSLATE[YYX] -- Symbol number corresponding to YYX as returned
    by yylex, with out-of-bounds checking.  */
 #define YYUNDEFTOK  2
-#define YYMAXUTOK   267
+#define YYMAXUTOK   268
 
 #define YYTRANSLATE(YYX)                                                \
   ((unsigned int) (YYX) <= YYMAXUTOK ? yytranslate[YYX] : YYUNDEFTOK)
@@ -503,15 +501,15 @@ static const yytype_uint8 yytranslate[] =
        2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
        2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
        2,     2,     2,     2,     2,     2,     1,     2,     3,     4,
-       5,     6,     7,     8,     9,    10,    11,    12
+       5,     6,     7,     8,     9,    10,    11,    12,    13
 };
 
 #if EXTR_DEBUG
   /* YYRLINE[YYN] -- Source line where rule number YYN was defined.  */
 static const yytype_uint8 yyrline[] =
 {
-       0,   112,   112,   114,   119,   120,   123,   124,   125,   128,
-     134,   135,   138,   139,   142,   148,   154
+       0,   111,   111,   113,   118,   122,   128,   135,   139,   143,
+     150,   157,   165,   169,   175,   179,   185,   192,   199
 };
 #endif
 
@@ -520,10 +518,11 @@ static const yytype_uint8 yyrline[] =
    First, the terminals, then, starting at YYNTOKENS, nonterminals.  */
 static const char *const yytname[] =
 {
-  "$end", "error", "$undefined", "extOPEN", "extCLOSE", "extTYPE",
-  "extIMPLIES", "extAS", "extHASH", "extCOLON", "extSIZE", "extCOMMA",
-  "extSTRING", "$accept", "file", "stanzas", "stanza", "container",
-  "parents", "childs", "parent", "child", "archive", YY_NULLPTR
+  "$end", "error", "$undefined", "extrERROR", "extrOPEN", "extrCLOSE",
+  "extrTYPE", "extrIMPLIES", "extrAS", "extrHASH", "extrCOLON", "extrSIZE",
+  "extrCOMMA", "extrSTRING", "$accept", "file", "stanzas", "stanza",
+  "container", "incContainer", "stdContainer", "parents", "childs",
+  "parent", "child", "archive", YY_NULLPTR
 };
 #endif
 
@@ -533,14 +532,14 @@ static const char *const yytname[] =
 static const yytype_uint16 yytoknum[] =
 {
        0,   256,   257,   258,   259,   260,   261,   262,   263,   264,
-     265,   266,   267
+     265,   266,   267,   268
 };
 # endif
 
-#define YYPACT_NINF -18
+#define YYPACT_NINF -7
 
 #define yypact_value_is_default(Yystate) \
-  (!!((Yystate) == (-18)))
+  (!!((Yystate) == (-7)))
 
 #define YYTABLE_NINF -1
 
@@ -551,9 +550,9 @@ static const yytype_uint16 yytoknum[] =
      STATE-NUM.  */
 static const yytype_int8 yypact[] =
 {
-      -2,     9,     5,    -2,   -18,    10,     0,   -18,   -18,    11,
-     -18,   -18,    10,     7,   -18,   -18,    12,     3,   -18,    13,
-      10,   -18,   -18,   -18,   -18,   -18,     8,   -18
+      -2,    -3,     4,    -2,    -7,     0,    -1,    -7,     0,    -7,
+      -7,     1,    -7,     0,     0,    -7,    -7,     3,    -4,    -7,
+      -6,    -7,    -7,    -7,    -7,    -7
 };
 
   /* YYDEFACT[STATE-NUM] -- Default reduction number in state STATE-NUM.
@@ -561,21 +560,23 @@ static const yytype_int8 yypact[] =
      means the default is an error.  */
 static const yytype_uint8 yydefact[] =
 {
-       3,     0,     0,     2,     5,     0,     0,     1,     4,     0,
-       9,     8,     0,     0,    11,    14,     0,     0,    13,     0,
-       0,    10,    16,     7,    12,    15,     0,     6
+       3,     0,     0,     2,     5,    10,     0,     7,     8,     1,
+       4,     0,    11,     0,     9,    13,    16,     0,     0,    15,
+       0,    12,    18,     6,    14,    17
 };
 
   /* YYPGOTO[NTERM-NUM].  */
 static const yytype_int8 yypgoto[] =
 {
-     -18,   -18,   -18,    14,   -18,   -18,    -1,    15,   -17,    -3
+      -7,    -7,    -7,     7,    -7,    -7,    -7,    -7,    -7,     2,
+       5,    -5
 };
 
   /* YYDEFGOTO[NTERM-NUM].  */
 static const yytype_int8 yydefgoto[] =
 {
-      -1,     2,     3,     4,     6,    13,    17,    14,    18,    19
+      -1,     2,     3,     4,     6,     7,     8,    14,    18,    15,
+      19,    16
 };
 
   /* YYTABLE[YYPACT[STATE-NUM]] -- What to do in state STATE-NUM.  If
@@ -583,39 +584,39 @@ static const yytype_int8 yydefgoto[] =
      number is the opposite.  If YYTABLE_NINF, syntax error.  */
 static const yytype_uint8 yytable[] =
 {
-      24,     1,    10,    15,    11,     7,    12,    23,     9,    24,
-      15,     9,    27,    20,     5,     9,     9,     8,     9,    26,
-      16,     0,    22,     0,     0,    25,     0,     0,    21
+      12,    23,     1,     5,     9,    11,    13,    25,    20,    11,
+      10,    17,     0,    20,    22,     0,    21,     0,     0,     0,
+       0,     0,     0,    24
 };
 
 static const yytype_int8 yycheck[] =
 {
-      17,     3,     5,     6,     4,     0,     6,     4,     8,    26,
-      13,     8,     4,     6,     5,     8,     8,     3,     8,    20,
-       9,    -1,    10,    -1,    -1,    12,    -1,    -1,    13
+       5,     5,     4,     6,     0,     9,     7,    13,    13,     9,
+       3,    10,    -1,    18,    11,    -1,    14,    -1,    -1,    -1,
+      -1,    -1,    -1,    18
 };
 
   /* YYSTOS[STATE-NUM] -- The (internal number of the) accessing
      symbol of state STATE-NUM.  */
 static const yytype_uint8 yystos[] =
 {
-       0,     3,    14,    15,    16,     5,    17,     0,    16,     8,
-      22,     4,     6,    18,    20,    22,     9,    19,    21,    22,
-       6,    20,    10,     4,    21,    12,    19,     4
+       0,     4,    15,    16,    17,     6,    18,    19,    20,     0,
+      17,     9,    25,     7,    21,    23,    25,    10,    22,    24,
+      25,    23,    11,     5,    24,    13
 };
 
   /* YYR1[YYN] -- Symbol number of symbol that rule YYN derives.  */
 static const yytype_uint8 yyr1[] =
 {
-       0,    13,    14,    14,    15,    15,    16,    16,    16,    17,
-      18,    18,    19,    19,    20,    21,    22
+       0,    14,    15,    15,    16,    16,    17,    18,    18,    18,
+      19,    20,    21,    21,    22,    22,    23,    24,    25
 };
 
   /* YYR2[YYN] -- Number of symbols on the right hand side of rule YYN.  */
 static const yytype_uint8 yyr2[] =
 {
-       0,     2,     1,     0,     2,     1,     6,     5,     3,     2,
-       2,     1,     2,     1,     1,     2,     3
+       0,     2,     1,     0,     2,     1,     5,     1,     1,     2,
+       1,     2,     2,     1,     2,     1,     1,     2,     3
 };
 
 
@@ -1302,47 +1303,143 @@ yyreduce:
   switch (yyn)
     {
         case 3:
-#line 114 "../parser/extractFile.y" /* yacc.c:1646  */
+#line 113 "parser/extractFile.y" /* yacc.c:1646  */
     {
   logParser(LOG_WARNING, "%s", "the extract file was empty");
 }
-#line 1310 "extractFile.tab.c" /* yacc.c:1646  */
+#line 1311 "parser/extractFile.tab.c" /* yacc.c:1646  */
+    break;
+
+  case 4:
+#line 119 "parser/extractFile.y" /* yacc.c:1646  */
+    {
+  logParser(LOG_DEBUG, "line %i: stanzas: stanzas stanza", LINENO);
+}
+#line 1319 "parser/extractFile.tab.c" /* yacc.c:1646  */
+    break;
+
+  case 5:
+#line 123 "parser/extractFile.y" /* yacc.c:1646  */
+    {
+  logParser(LOG_DEBUG, "line %i: stanzas: stanza", LINENO);
+}
+#line 1327 "parser/extractFile.tab.c" /* yacc.c:1646  */
+    break;
+
+  case 6:
+#line 129 "parser/extractFile.y" /* yacc.c:1646  */
+    {
+  logParser(LOG_DEBUG, "line %i: %s", LINENO, 
+	    "stanza: (container => childs)");
+}
+#line 1336 "parser/extractFile.tab.c" /* yacc.c:1646  */
+    break;
+
+  case 7:
+#line 136 "parser/extractFile.y" /* yacc.c:1646  */
+    {
+  logParser(LOG_DEBUG, "line %i: incContainer", LINENO);
+}
+#line 1344 "parser/extractFile.tab.c" /* yacc.c:1646  */
+    break;
+
+  case 8:
+#line 140 "parser/extractFile.y" /* yacc.c:1646  */
+    {
+  logParser(LOG_DEBUG, "line %i: stdContainer", LINENO);
+}
+#line 1352 "parser/extractFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 9:
-#line 129 "../parser/extractFile.y" /* yacc.c:1646  */
+#line 144 "parser/extractFile.y" /* yacc.c:1646  */
     {
+  logParser(LOG_DEBUG, "line %i: stdContainer parents", LINENO);
+}
+#line 1360 "parser/extractFile.tab.c" /* yacc.c:1646  */
+    break;
+
+  case 10:
+#line 151 "parser/extractFile.y" /* yacc.c:1646  */
+    {
+  logParser(LOG_DEBUG, "line %i: incContainer: %s", 
+	    LINENO, strEType((yyvsp[0].type)));
+  container = coll->extractTree->incoming;
+}
+#line 1370 "parser/extractFile.tab.c" /* yacc.c:1646  */
+    break;
+
+  case 11:
+#line 158 "parser/extractFile.y" /* yacc.c:1646  */
+    {
+  logParser(LOG_DEBUG, "line %i: stdContainer: %s archive",
+	    LINENO, strEType((yyvsp[-1].type)));
   if (!(container = addContainer(coll, (yyvsp[-1].type), (yyvsp[0].archive)))) YYERROR;
 }
-#line 1318 "extractFile.tab.c" /* yacc.c:1646  */
+#line 1380 "parser/extractFile.tab.c" /* yacc.c:1646  */
+    break;
+
+  case 12:
+#line 166 "parser/extractFile.y" /* yacc.c:1646  */
+    {
+  logParser(LOG_DEBUG, "line %i: parents: parents parent", LINENO);
+}
+#line 1388 "parser/extractFile.tab.c" /* yacc.c:1646  */
+    break;
+
+  case 13:
+#line 170 "parser/extractFile.y" /* yacc.c:1646  */
+    {
+  logParser(LOG_DEBUG, "line %i: parents: parent", LINENO);
+}
+#line 1396 "parser/extractFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 14:
-#line 143 "../parser/extractFile.y" /* yacc.c:1646  */
+#line 176 "parser/extractFile.y" /* yacc.c:1646  */
     {
-  if (!addFromArchive(coll, container, (yyvsp[0].archive))) YYERROR;
+  logParser(LOG_DEBUG, "line %i: childs: childs child", LINENO);
 }
-#line 1326 "extractFile.tab.c" /* yacc.c:1646  */
+#line 1404 "parser/extractFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 15:
-#line 149 "../parser/extractFile.y" /* yacc.c:1646  */
+#line 180 "parser/extractFile.y" /* yacc.c:1646  */
     {
-  if (!(addFromAsso(coll, (yyvsp[-1].archive), container, (yyvsp[0].string)))) YYERROR;
+  logParser(LOG_DEBUG, "line %i: childs: child", LINENO);
 }
-#line 1334 "extractFile.tab.c" /* yacc.c:1646  */
+#line 1412 "parser/extractFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 16:
-#line 155 "../parser/extractFile.y" /* yacc.c:1646  */
+#line 186 "parser/extractFile.y" /* yacc.c:1646  */
     {
+  logParser(LOG_DEBUG, "line %i: parent: archive", LINENO);
+  if (!addFromArchive(coll, container, (yyvsp[0].archive))) YYERROR;
+}
+#line 1421 "parser/extractFile.tab.c" /* yacc.c:1646  */
+    break;
+
+  case 17:
+#line 193 "parser/extractFile.y" /* yacc.c:1646  */
+    {
+  logParser(LOG_DEBUG, "line %i: child: archive %s", LINENO, (yyvsp[0].string));
+  if (!(addFromAsso(coll, (yyvsp[-1].archive), container, (yyvsp[0].string)))) YYERROR;
+}
+#line 1430 "parser/extractFile.tab.c" /* yacc.c:1646  */
+    break;
+
+  case 18:
+#line 200 "parser/extractFile.y" /* yacc.c:1646  */
+    {
+  logParser(LOG_DEBUG, "line %i: archive: %s:%lli", LINENO, (yyvsp[-2].hash), (yyvsp[0].size));
   if (!((yyval.archive) = addArchive(coll, (yyvsp[-2].hash), (yyvsp[0].size)))) YYERROR;
 }
-#line 1342 "extractFile.tab.c" /* yacc.c:1646  */
+#line 1439 "parser/extractFile.tab.c" /* yacc.c:1646  */
     break;
 
 
-#line 1346 "extractFile.tab.c" /* yacc.c:1646  */
+#line 1443 "parser/extractFile.tab.c" /* yacc.c:1646  */
       default: break;
     }
   /* User semantic actions sometimes alter yychar, and that requires
@@ -1570,7 +1667,7 @@ yyreturn:
 #endif
   return yyresult;
 }
-#line 160 "../parser/extractFile.y" /* yacc.c:1906  */
+#line 206 "parser/extractFile.y" /* yacc.c:1906  */
 
 
 /* epilogue: =======================================================*/
@@ -1587,16 +1684,17 @@ yyreturn:
 void extr_error(yyscan_t yyscanner, Collection* coll,
 		Container* container, const char* message)
 {
-  logEmit(LOG_ERR, "%s on token '%s' line %i\n",
+  logParser(LOG_ERR, "%s on token '%s' line %i",
 	  message, extr_get_text(yyscanner), LINENO);
 }
 
 
 /*=======================================================================
  * Function   : parseExtractList
- * Description: Parse a file
- * Synopsis   : int parseExtractList(const char* path, int debugFlag)
- * Input      : const char* path: the file to parse
+ * Description: Parse an extraction meta-data file
+ * Synopsis   : int parseExtractList(Collection* coll, const char* path)
+ * Input      : Collection* coll: related collection
+ *              const char* path: the file to parse
  * Output     : TRUE on success
 =======================================================================*/
 int parseExtractFile(Collection* coll, const char* path)
@@ -1607,164 +1705,54 @@ int parseExtractFile(Collection* coll, const char* path)
   Container* container = 0;
 
   checkCollection(coll);
-  logParser(LOG_INFO, "parse %s extraction data", coll->label);
+  logParser(LOG_INFO, "parse %s extraction data from %s",
+	    coll->label, path?path:"stdin");
 
   // initialise scanner
   if (extr_lex_init(&scanner)) {
-    logEmit(LOG_ERR, "%s", "error initializing scanner");
+    logParser(LOG_ERR, "%s", "error initializing scanner");
     goto error;
   }
 
-  // scan input file if defined (else stdin)
-  inputStream = stdin;
   if (path != 0) {
     if (!(inputStream = fopen(path, "r"))) {
-      logEmit(LOG_ERR, "cannot open input stream: %s", path); 
+      logParser(LOG_ERR, "cannot open input stream: %s", path); 
       goto error;
     }
-    if (!lock(fileno(inputStream), F_RDLCK)) goto error;
-    logEmit(LOG_DEBUG, "parse extraction file: %s", path);
+    if (!lock(fileno(inputStream), F_RDLCK)) goto error2;
   }
+
   extr_set_in(inputStream, scanner);
 
   // debug mode for scanner
   extr_set_debug(env.debugLexer, scanner);
-  logEmit(LOG_DEBUG, "extr_set_debug = %i", extr_get_debug(scanner));
+  logParser(LOG_DEBUG, "extr_set_debug = %i", extr_get_debug(scanner));
 
   // call the parser
   if (extr_parse(scanner, coll, container)) {
-    logEmit(LOG_ERR, "extract file parser error on line %i",
+    logParser(LOG_ERR, "extract parser fails on line %i",
 	    extr_get_lineno(scanner));
-    logEmit(LOG_ERR, "please edit %s", path);
-    goto error;
+    logParser(LOG_ERR, "please edit %s", path?path:"stdin");
+    goto error3;
   }
 
+  rc = TRUE;
+ error3:
+  if (inputStream != stdin) {
+    if (!unLock(fileno(inputStream))) rc = FALSE;
+  }
+ error2:
   if (inputStream != stdin) {
-    if (!unLock(fileno(inputStream))) goto error;
     fclose(inputStream);
   }
-  rc = TRUE;
  error:
   if (!rc) {
-    logEmit(LOG_ERR, "%s", "extract file parser error");
+    logParser(LOG_ERR, "%s", "extract parser error");
   }
   extr_lex_destroy(scanner);
   return rc;
 }
 
-/************************************************************************/
-
-#ifdef utMAIN
-#include "../misc/command.h"
-#include "confFile.tab.h"
-GLOBAL_STRUCT_DEF;
-
-/*=======================================================================
- * Function   : usage
- * Description: Print the usage.
- * Synopsis   : static void usage(char* programName)
- * Input      : programName = the name of the program; usually argv[0].
- * Output     : N/A
- =======================================================================*/
-static void 
-usage(char* programName)
-{
-  parserUsage(programName);
-  fprintf(stderr, " [ -i inputPath ]");
-    
-  parserOptions();
-  fprintf(stderr, "  ---\n"
-	  "  -i, --input\t\tinput file to parse\n");
-  return;
-}
-
-
-/*=======================================================================
- * Function   : main 
- * Author     : Nicolas ROCHE
- * modif      : 2012/05/01
- * Description: unit test the the extract parser
- * Synopsis   : ./utextractFile.tab
- * Input      : -i inputPath
- * Output     : Should display the same content
- =======================================================================*/
-int 
-main(int argc, char** argv)
-{
-  Configuration* conf = (Configuration*)conf;
-  Collection* coll = 0;
-  char* inputPath = 0;
-  // ---
-  int rc = 0;
-  int cOption = EOF;
-  char* programName = *argv;
-  char* options = PARSER_SHORT_OPTIONS"i:";
-  struct option longOptions[] = {
-     {"input", required_argument, 0, 'i'},
-    PARSER_LONG_OPTIONS,
-    {0, 0, 0, 0}
-  };
-
-  // import mdtx environment
-  env.debugParser = TRUE;
-  getEnv(&env);
-
-  // parse the command line
-  while((cOption = getopt_long(argc, argv, options, longOptions, 0)) 
-	!= EOF) {
-    switch(cOption) {
-      
-    case 'i':
-      if(isEmptyString(optarg)) {
-	fprintf(stderr, 
-		"%s: nil or empty argument for the input stream\n",
-		programName);
-	rc = 2;
-      }
-      else {
-	if ((inputPath = (char*)malloc(sizeof(char) * strlen(optarg) + 1))
-	    == 0) {
-	  fprintf(stderr, 
-		  "%s: cannot allocate memory for the input stream name\n", 
-		  programName);
-	  rc = 3;
-	}
-	else {
-	  strcpy(inputPath, optarg);
-	}
-      }
-      break;
-		
-      GET_PARSER_OPTIONS; // generic options
-    }
-    if (rc) goto optError;
-  }
-
-  // export mdtx environment
-  if (!setEnv(programName, &env)) goto optError;
-
-  /************************************************************************/
-  if (!(conf = getConfiguration())) goto error;
-  if (!parseConfiguration(conf->confFile)) goto error;
-  if (!(coll = getCollection("coll1"))) goto error;
-  if (!expandCollection(coll)) goto error;
-
-  if (!parseExtractFile(coll, inputPath)) goto error;
-  if (!serializeExtractTree(coll)) goto error;
-  /************************************************************************/
-
-  rc = TRUE;
- error:
-  freeConfiguration();
-  destroyString(inputPath);
-  ENDINGS;
-  rc=!rc;
- optError:
-  exit(rc);
-}
- 
-#endif // utMAIN
-
 /* Local Variables: */
 /* mode: c *//* mode: font-lock */
 /* mode: auto-fill */
