@@ -30,8 +30,8 @@
    This special exception was added by the Free Software Foundation in
    version 2.2 of Bison.  */
 
-#ifndef YY_EXTR_EXTRACTFILE_TAB_H_INCLUDED
-# define YY_EXTR_EXTRACTFILE_TAB_H_INCLUDED
+#ifndef YY_EXTR_PARSER_EXTRACTFILE_TAB_H_INCLUDED
+# define YY_EXTR_PARSER_EXTRACTFILE_TAB_H_INCLUDED
 /* Debug traces.  */
 #ifndef EXTR_DEBUG
 # if defined YYDEBUG
@@ -53,44 +53,46 @@ extern int extr_debug;
 # define EXTR_TOKENTYPE
   enum extr_tokentype
   {
-    extOPEN = 258,
-    extCLOSE = 259,
-    extTYPE = 260,
-    extIMPLIES = 261,
-    extAS = 262,
-    extHASH = 263,
-    extCOLON = 264,
-    extSIZE = 265,
-    extCOMMA = 266,
-    extSTRING = 267
+    extrERROR = 258,
+    extrOPEN = 259,
+    extrCLOSE = 260,
+    extrTYPE = 261,
+    extrIMPLIES = 262,
+    extrAS = 263,
+    extrHASH = 264,
+    extrCOLON = 265,
+    extrSIZE = 266,
+    extrCOMMA = 267,
+    extrSTRING = 268
   };
 #endif
 /* Tokens.  */
-#define extOPEN 258
-#define extCLOSE 259
-#define extTYPE 260
-#define extIMPLIES 261
-#define extAS 262
-#define extHASH 263
-#define extCOLON 264
-#define extSIZE 265
-#define extCOMMA 266
-#define extSTRING 267
+#define extrERROR 258
+#define extrOPEN 259
+#define extrCLOSE 260
+#define extrTYPE 261
+#define extrIMPLIES 262
+#define extrAS 263
+#define extrHASH 264
+#define extrCOLON 265
+#define extrSIZE 266
+#define extrCOMMA 267
+#define extrSTRING 268
 
 /* Value type.  */
 #if ! defined EXTR_STYPE && ! defined EXTR_STYPE_IS_DECLARED
 typedef union EXTR_STYPE EXTR_STYPE;
 union EXTR_STYPE
 {
-#line 36 "../parser/extractFile.y" /* yacc.c:1909  */
+#line 61 "parser/extractFile.y" /* yacc.c:1909  */
 
   off_t  size;
   char   string[MAX_SIZE_STRING+1];
-  char   hash[MAX_SIZE_HASH+1];
+  char   hash[MAX_SIZE_MD5+1];
   EType  type; 
   Archive* archive;
 
-#line 94 "extractFile.tab.h" /* yacc.c:1909  */
+#line 96 "parser/extractFile.tab.h" /* yacc.c:1909  */
 };
 # define EXTR_STYPE_IS_TRIVIAL 1
 # define EXTR_STYPE_IS_DECLARED 1
@@ -100,12 +102,12 @@ union EXTR_STYPE
 
 int extr_parse (yyscan_t yyscanner, Collection* coll, Container* container);
 /* "%code provides" blocks.  */
-#line 54 "../parser/extractFile.y" /* yacc.c:1909  */
+#line 27 "parser/extractFile.y" /* yacc.c:1909  */
 
 /*=======================================================================
  * Version: this file is generated by BISON using extractFile.y
  * Project: MediaTeX
- * Module : extractFile parser
+ * Module : extraction meta-date parser
  *
  * extract parser.
 
@@ -125,9 +127,9 @@ int extr_parse (yyscan_t yyscanner, Collection* coll, Container* container);
  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  =======================================================================*/
-#include "../memory/extractTree.h"
-int parseExtractFile(Collection* coll, const char* path);
 
-#line 132 "extractFile.tab.h" /* yacc.c:1909  */
+#define YYSTYPE EXTR_STYPE
 
-#endif /* !YY_EXTR_EXTRACTFILE_TAB_H_INCLUDED  */
+#line 134 "parser/extractFile.tab.h" /* yacc.c:1909  */
+
+#endif /* !YY_EXTR_PARSER_EXTRACTFILE_TAB_H_INCLUDED  */
