@@ -30,8 +30,8 @@
    This special exception was added by the Free Software Foundation in
    version 2.2 of Bison.  */
 
-#ifndef YY_SERV_SERVERFILE_TAB_H_INCLUDED
-# define YY_SERV_SERVERFILE_TAB_H_INCLUDED
+#ifndef YY_SERV_PARSER_SERVERFILE_TAB_H_INCLUDED
+# define YY_SERV_PARSER_SERVERFILE_TAB_H_INCLUDED
 /* Debug traces.  */
 #ifndef SERV_DEBUG
 # if defined YYDEBUG
@@ -53,91 +53,103 @@ extern int serv_debug;
 # define SERV_TOKENTYPE
   enum serv_tokentype
   {
-    srvMASTER = 258,
-    srvSERVER = 259,
-    srvCOMMENT = 260,
-    srvLABEL = 261,
-    srvHOST = 262,
-    srvNETWORKS = 263,
-    srvGATEWAYS = 264,
-    srvMDTXPORT = 265,
-    srvSSHPORT = 266,
-    srvCOLLKEY = 267,
-    srvUSERKEY = 268,
-    srvHOSTKEY = 269,
-    srvPROVIDE = 270,
-    srvCOMMA = 271,
-    srvCOLON = 272,
-    srvEQUAL = 273,
-    srvENDBLOCK = 274,
-    srvCACHESIZE = 275,
-    srvCACHETTL = 276,
-    srvQUERYTTL = 277,
-    srvSUPPTTL = 278,
-    srvMAXSCORE = 279,
-    srvBADSCORE = 280,
-    srvPOWSUPP = 281,
-    srvPOWIMAGE = 282,
-    srvFACTSUPP = 283,
-    srvMINGEODUP = 284,
-    srvSTRING = 285,
-    srvNUMBER = 286,
-    srvSCORE = 287,
-    srvHASH = 288,
-    srvSIZE = 289,
-    srvTIME = 290
+    servMASTER = 258,
+    servSERVER = 259,
+    servCOMMENT = 260,
+    servLABEL = 261,
+    servHOST = 262,
+    servLASTCOMMIT = 263,
+    servNETWORKS = 264,
+    servGATEWAYS = 265,
+    servMDTXPORT = 266,
+    servSSHPORT = 267,
+    servWWWPORT = 268,
+    servCOLLKEY = 269,
+    servUSERKEY = 270,
+    servHOSTKEY = 271,
+    servPROVIDE = 272,
+    servCOMMA = 273,
+    servCOLON = 274,
+    servEQUAL = 275,
+    servENDBLOCK = 276,
+    servCACHESIZE = 277,
+    servCACHETTL = 278,
+    servQUERYTTL = 279,
+    servSUPPTTL = 280,
+    servUPLOADTTL = 281,
+    servSERVERTTL = 282,
+    servMAXSCORE = 283,
+    servBADSCORE = 284,
+    servPOWSUPP = 285,
+    servFACTSUPP = 286,
+    servFILESCORE = 287,
+    servMINGEODUP = 288,
+    servERROR = 289,
+    servSTRING = 290,
+    servNUMBER = 291,
+    servSCORE = 292,
+    servHASH = 293,
+    servSIZE = 294,
+    servTIME = 295,
+    servDATE = 296
   };
 #endif
 /* Tokens.  */
-#define srvMASTER 258
-#define srvSERVER 259
-#define srvCOMMENT 260
-#define srvLABEL 261
-#define srvHOST 262
-#define srvNETWORKS 263
-#define srvGATEWAYS 264
-#define srvMDTXPORT 265
-#define srvSSHPORT 266
-#define srvCOLLKEY 267
-#define srvUSERKEY 268
-#define srvHOSTKEY 269
-#define srvPROVIDE 270
-#define srvCOMMA 271
-#define srvCOLON 272
-#define srvEQUAL 273
-#define srvENDBLOCK 274
-#define srvCACHESIZE 275
-#define srvCACHETTL 276
-#define srvQUERYTTL 277
-#define srvSUPPTTL 278
-#define srvMAXSCORE 279
-#define srvBADSCORE 280
-#define srvPOWSUPP 281
-#define srvPOWIMAGE 282
-#define srvFACTSUPP 283
-#define srvMINGEODUP 284
-#define srvSTRING 285
-#define srvNUMBER 286
-#define srvSCORE 287
-#define srvHASH 288
-#define srvSIZE 289
-#define srvTIME 290
+#define servMASTER 258
+#define servSERVER 259
+#define servCOMMENT 260
+#define servLABEL 261
+#define servHOST 262
+#define servLASTCOMMIT 263
+#define servNETWORKS 264
+#define servGATEWAYS 265
+#define servMDTXPORT 266
+#define servSSHPORT 267
+#define servWWWPORT 268
+#define servCOLLKEY 269
+#define servUSERKEY 270
+#define servHOSTKEY 271
+#define servPROVIDE 272
+#define servCOMMA 273
+#define servCOLON 274
+#define servEQUAL 275
+#define servENDBLOCK 276
+#define servCACHESIZE 277
+#define servCACHETTL 278
+#define servQUERYTTL 279
+#define servSUPPTTL 280
+#define servUPLOADTTL 281
+#define servSERVERTTL 282
+#define servMAXSCORE 283
+#define servBADSCORE 284
+#define servPOWSUPP 285
+#define servFACTSUPP 286
+#define servFILESCORE 287
+#define servMINGEODUP 288
+#define servERROR 289
+#define servSTRING 290
+#define servNUMBER 291
+#define servSCORE 292
+#define servHASH 293
+#define servSIZE 294
+#define servTIME 295
+#define servDATE 296
 
 /* Value type.  */
 #if ! defined SERV_STYPE && ! defined SERV_STYPE_IS_DECLARED
 typedef union SERV_STYPE SERV_STYPE;
 union SERV_STYPE
 {
-#line 36 "../parser/serverFile.y" /* yacc.c:1909  */
+#line 61 "parser/serverFile.y" /* yacc.c:1909  */
 
   off_t  number;
   off_t  size;
   time_t time;
   float  score;
   char   string[(MAX_SIZE_STRING+1)*2]; // keys needs more place
-  char   hash[MAX_SIZE_HASH+1];
+  char   hash[MAX_SIZE_MD5+1];
 
-#line 141 "serverFile.tab.h" /* yacc.c:1909  */
+#line 153 "parser/serverFile.tab.h" /* yacc.c:1909  */
 };
 # define SERV_STYPE_IS_TRIVIAL 1
 # define SERV_STYPE_IS_DECLARED 1
@@ -147,14 +159,14 @@ union SERV_STYPE
 
 int serv_parse (yyscan_t yyscanner, Collection* coll, Server* server);
 /* "%code provides" blocks.  */
-#line 55 "../parser/serverFile.y" /* yacc.c:1909  */
+#line 27 "parser/serverFile.y" /* yacc.c:1909  */
 
 /*=======================================================================
  * Version: this file is generated by BISON using serverFile.y
  * Project: MediaTeX
- * Module : serverFile parser
+ * Module : server parser
  *
- * serverFile parser
+ * server file parser
 
  MediaTex is an Electronic Records Management System
  Copyright (C) 2014 2015 Nicolas Roche
@@ -172,9 +184,9 @@ int serv_parse (yyscan_t yyscanner, Collection* coll, Server* server);
  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  =======================================================================*/
-#include "../memory/serverTree.h"
-int parseServerFile(Collection* coll, const char* path);
 
-#line 179 "serverFile.tab.h" /* yacc.c:1909  */
+#define YYSTYPE SERV_STYPE
 
-#endif /* !YY_SERV_SERVERFILE_TAB_H_INCLUDED  */
+#line 191 "parser/serverFile.tab.h" /* yacc.c:1909  */
+
+#endif /* !YY_SERV_PARSER_SERVERFILE_TAB_H_INCLUDED  */
