@@ -69,17 +69,13 @@
 
 
 /* Copy the first part of user declarations.  */
-#line 26 "../parser/supportFile.y" /* yacc.c:339  */
+#line 55 "parser/supportFile.y" /* yacc.c:339  */
   
-#include "../mediatex.h"
-#include "../misc/log.h"
-#include "../misc/locks.h"
-#include "../memory/supportTree.h"
+#include "mediatex-config.h"
+  /* yyscan_t is pre-defined by mediatex-config.h and will be defined
+     by Flex header bellow */
 
-// hack because Flex needs YYSTYPE from tab.h and Bison needs yyscan_t from .h
-typedef void* yyscan_t;
-
-#line 83 "supportFile.tab.c" /* yacc.c:339  */
+#line 79 "parser/supportFile.tab.c" /* yacc.c:339  */
 
 # ifndef YY_NULLPTR
 #  if defined __cplusplus && 201103L <= __cplusplus
@@ -99,8 +95,8 @@ typedef void* yyscan_t;
 
 /* In a future release of Bison, this section will be replaced
    by #include "supportFile.tab.h".  */
-#ifndef YY_SUPP_SUPPORTFILE_TAB_H_INCLUDED
-# define YY_SUPP_SUPPORTFILE_TAB_H_INCLUDED
+#ifndef YY_SUPP_PARSER_SUPPORTFILE_TAB_H_INCLUDED
+# define YY_SUPP_PARSER_SUPPORTFILE_TAB_H_INCLUDED
 /* Debug traces.  */
 #ifndef SUPP_DEBUG
 # if defined YYDEBUG
@@ -123,35 +119,38 @@ extern int supp_debug;
   enum supp_tokentype
   {
     suppDATE = 258,
-    suppHASH = 259,
-    suppSIZE = 260,
-    suppSTATUS = 261,
-    suppNAME = 262,
-    suppERROR = 263
+    suppMD5 = 259,
+    suppSHA = 260,
+    suppSIZE = 261,
+    suppSTATUS = 262,
+    suppNAME = 263,
+    suppERROR = 264
   };
 #endif
 /* Tokens.  */
 #define suppDATE 258
-#define suppHASH 259
-#define suppSIZE 260
-#define suppSTATUS 261
-#define suppNAME 262
-#define suppERROR 263
+#define suppMD5 259
+#define suppSHA 260
+#define suppSIZE 261
+#define suppSTATUS 262
+#define suppNAME 263
+#define suppERROR 264
 
 /* Value type.  */
 #if ! defined SUPP_STYPE && ! defined SUPP_STYPE_IS_DECLARED
 typedef union SUPP_STYPE SUPP_STYPE;
 union SUPP_STYPE
 {
-#line 36 "../parser/supportFile.y" /* yacc.c:355  */
+#line 61 "parser/supportFile.y" /* yacc.c:355  */
 
   off_t  size;
   time_t time;
-  char   hash[MAX_SIZE_HASH+1];
+  char   md5sum[MAX_SIZE_MD5+1];
+  char   shasum[MAX_SIZE_SHA+1];
   char   status[MAX_SIZE_STAT+1];
-  char   name[MAX_SIZE_NAME+1];
+  char   name[MAX_SIZE_STRING+1];
 
-#line 155 "supportFile.tab.c" /* yacc.c:355  */
+#line 154 "parser/supportFile.tab.c" /* yacc.c:355  */
 };
 # define SUPP_STYPE_IS_TRIVIAL 1
 # define SUPP_STYPE_IS_DECLARED 1
@@ -161,14 +160,14 @@ union SUPP_STYPE
 
 int supp_parse (yyscan_t yyscanner);
 /* "%code provides" blocks.  */
-#line 51 "../parser/supportFile.y" /* yacc.c:355  */
+#line 27 "parser/supportFile.y" /* yacc.c:355  */
 
 /*=======================================================================
  * Version: this file is generated by BISON using supportFile.y
  * Project: MediaTeX
- * Module : supportFile parser
+ * Module : support parser
  *
- * supportFile parser.
+ * support file parser
 
  MediaTex is an Electronic Records Management System
  Copyright (C) 2014 2015 Nicolas Roche
@@ -186,22 +185,24 @@ int supp_parse (yyscan_t yyscanner);
  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  =======================================================================*/
-#include "../memory/supportTree.h"
-int parseSupports(const char* path);
 
-#line 193 "supportFile.tab.c" /* yacc.c:355  */
+#define YYSTYPE SUPP_STYPE
 
-#endif /* !YY_SUPP_SUPPORTFILE_TAB_H_INCLUDED  */
+#line 192 "parser/supportFile.tab.c" /* yacc.c:355  */
+
+#endif /* !YY_SUPP_PARSER_SUPPORTFILE_TAB_H_INCLUDED  */
 
 /* Copy the second part of user declarations.  */
-#line 44 "../parser/supportFile.y" /* yacc.c:358  */
+#line 70 "parser/supportFile.y" /* yacc.c:358  */
+
+  // upper YYSTYPE union is required by Flex headers
+#include "parser/supportFile.h"
+ 
+#define LINENO supp_get_lineno(yyscanner)
 
-// we need YYSTYPE defined first to include the Flex headers
-#include "supportFile.h"
-  
 void supp_error(yyscan_t yyscanner, const char* message);
 
-#line 205 "supportFile.tab.c" /* yacc.c:358  */
+#line 206 "parser/supportFile.tab.c" /* yacc.c:358  */
 
 #ifdef short
 # undef short
@@ -443,21 +444,21 @@ union yyalloc
 /* YYFINAL -- State number of the termination state.  */
 #define YYFINAL  6
 /* YYLAST -- Last index in YYTABLE.  */
-#define YYLAST   12
+#define YYLAST   15
 
 /* YYNTOKENS -- Number of terminals.  */
-#define YYNTOKENS  9
+#define YYNTOKENS  10
 /* YYNNTS -- Number of nonterminals.  */
 #define YYNNTS  4
 /* YYNRULES -- Number of rules.  */
 #define YYNRULES  6
 /* YYNSTATES -- Number of states.  */
-#define YYNSTATES  14
+#define YYNSTATES  16
 
 /* YYTRANSLATE[YYX] -- Symbol number corresponding to YYX as returned
    by yylex, with out-of-bounds checking.  */
 #define YYUNDEFTOK  2
-#define YYMAXUTOK   263
+#define YYMAXUTOK   264
 
 #define YYTRANSLATE(YYX)                                                \
   ((unsigned int) (YYX) <= YYMAXUTOK ? yytranslate[YYX] : YYUNDEFTOK)
@@ -492,7 +493,7 @@ static const yytype_uint8 yytranslate[] =
        2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
        2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
        2,     2,     2,     2,     2,     2,     1,     2,     3,     4,
-       5,     6,     7,     8
+       5,     6,     7,     8,     9
 };
 
 #if SUPP_DEBUG
@@ -508,9 +509,9 @@ static const yytype_uint8 yyrline[] =
    First, the terminals, then, starting at YYNTOKENS, nonterminals.  */
 static const char *const yytname[] =
 {
-  "$end", "error", "$undefined", "suppDATE", "suppHASH", "suppSIZE",
-  "suppSTATUS", "suppNAME", "suppERROR", "$accept", "file", "lines",
-  "line", YY_NULLPTR
+  "$end", "error", "$undefined", "suppDATE", "suppMD5", "suppSHA",
+  "suppSIZE", "suppSTATUS", "suppNAME", "suppERROR", "$accept", "file",
+  "lines", "line", YY_NULLPTR
 };
 #endif
 
@@ -519,7 +520,7 @@ static const char *const yytname[] =
    (internal) symbol number NUM (which must be that of a token).  */
 static const yytype_uint16 yytoknum[] =
 {
-       0,   256,   257,   258,   259,   260,   261,   262,   263
+       0,   256,   257,   258,   259,   260,   261,   262,   263,   264
 };
 # endif
 
@@ -538,7 +539,7 @@ static const yytype_uint16 yytoknum[] =
 static const yytype_int8 yypact[] =
 {
       -3,    -2,     2,    -3,    -4,     0,    -4,    -4,     1,     3,
-      -1,     4,     5,    -4
+      -1,     4,     5,     6,     7,    -4
 };
 
   /* YYDEFACT[STATE-NUM] -- Default reduction number in state STATE-NUM.
@@ -547,13 +548,13 @@ static const yytype_int8 yypact[] =
 static const yytype_uint8 yydefact[] =
 {
        3,     0,     0,     2,     5,     0,     1,     4,     0,     0,
-       0,     0,     0,     6
+       0,     0,     0,     0,     0,     6
 };
 
   /* YYPGOTO[NTERM-NUM].  */
 static const yytype_int8 yypgoto[] =
 {
-      -4,    -4,    -4,     6
+      -4,    -4,    -4,     9
 };
 
   /* YYDEFGOTO[NTERM-NUM].  */
@@ -567,34 +568,34 @@ static const yytype_int8 yydefgoto[] =
      number is the opposite.  If YYTABLE_NINF, syntax error.  */
 static const yytype_uint8 yytable[] =
 {
-       1,     5,     6,     8,    11,     9,     0,    10,     0,     7,
-      12,     0,    13
+       1,     5,     6,     8,    11,     9,     0,    10,     0,    12,
+       0,    13,     7,    14,     0,    15
 };
 
 static const yytype_int8 yycheck[] =
 {
-       3,     3,     0,     3,     5,     4,    -1,     4,    -1,     3,
-       6,    -1,     7
+       3,     3,     0,     3,     5,     4,    -1,     4,    -1,     5,
+      -1,     6,     3,     7,    -1,     8
 };
 
   /* YYSTOS[STATE-NUM] -- The (internal number of the) accessing
      symbol of state STATE-NUM.  */
 static const yytype_uint8 yystos[] =
 {
-       0,     3,    10,    11,    12,     3,     0,    12,     3,     4,
-       4,     5,     6,     7
+       0,     3,    11,    12,    13,     3,     0,    13,     3,     4,
+       4,     5,     5,     6,     7,     8
 };
 
   /* YYR1[YYN] -- Symbol number of symbol that rule YYN derives.  */
 static const yytype_uint8 yyr1[] =
 {
-       0,     9,    10,    10,    11,    11,    12
+       0,    10,    11,    11,    12,    12,    13
 };
 
   /* YYR2[YYN] -- Number of symbols on the right hand side of rule YYN.  */
 static const yytype_uint8 yyr2[] =
 {
-       0,     2,     1,     0,     2,     1,     8
+       0,     2,     1,     0,     2,     1,    10
 };
 
 
@@ -1277,58 +1278,65 @@ yyreduce:
   switch (yyn)
     {
         case 3:
-#line 104 "../parser/supportFile.y" /* yacc.c:1646  */
+#line 104 "parser/supportFile.y" /* yacc.c:1646  */
     {
-  logParser(LOG_WARNING, "%s", "the supports file was empty");
+  logParser(LOG_WARNING, "the supports file was empty");
 }
-#line 1285 "supportFile.tab.c" /* yacc.c:1646  */
+#line 1286 "parser/supportFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 6:
-#line 114 "../parser/supportFile.y" /* yacc.c:1646  */
+#line 117 "parser/supportFile.y" /* yacc.c:1646  */
     {
   Support *support = 0;
   struct tm date1;
   struct tm date2;
   struct tm date3;
 
-  if (localtime_r(&(yyvsp[-7].time), &date1) == (struct tm*)0 ||
-      localtime_r(&(yyvsp[-6].time), &date2) == (struct tm*)0 ||
-      localtime_r(&(yyvsp[-5].time), &date3) == (struct tm*)0) {
+  if (localtime_r(&(yyvsp[-9].time), &date1) == (struct tm*)0 ||
+      localtime_r(&(yyvsp[-8].time), &date2) == (struct tm*)0 ||
+      localtime_r(&(yyvsp[-7].time), &date3) == (struct tm*)0) {
     logParser(LOG_ERR, "%s", "localtime_r returns on error");
     YYABORT;
   }
 
-  logParser(LOG_DEBUG, "line %-3i: %04i-%02i-%02i,%02i:%02i:%02i "
-	    "%04i-%02i-%02i,%02i:%02i:%02i %04i-%02i-%02i,%02i:%02i:%02i "
-	    "%*s %*s %*lli %*s %s",
-	    supp_get_lineno(yyscanner),
+  logParser(LOG_DEBUG, "line %-3i: "
+	    "%04i-%02i-%02i,%02i:%02i:%02i "
+	    "%04i-%02i-%02i,%02i:%02i:%02i "
+	    "%04i-%02i-%02i,%02i:%02i:%02i "
+	    "%*s %*s "
+	    "%*s %*s "
+	    "%*lli %*s %s",
+	    LINENO,
 	    date1.tm_year + 1900, date1.tm_mon+1, date1.tm_mday,
 	    date1.tm_hour, date1.tm_min, date1.tm_sec,
 	    date2.tm_year + 1900, date2.tm_mon+1, date2.tm_mday,
 	    date2.tm_hour, date2.tm_min, date2.tm_sec,
 	    date3.tm_year + 1900, date3.tm_mon+1, date3.tm_mday,
 	    date3.tm_hour, date3.tm_min, date3.tm_sec,
-	    MAX_SIZE_HASH, (yyvsp[-4].hash), MAX_SIZE_HASH, (yyvsp[-3].hash),
+	    MAX_SIZE_MD5, (yyvsp[-6].md5sum), MAX_SIZE_MD5, (yyvsp[-5].md5sum),
+	    MAX_SIZE_SHA, (yyvsp[-4].shasum), MAX_SIZE_SHA, (yyvsp[-3].shasum),
 	    MAX_SIZE_SIZE, (long long int)(yyvsp[-2].size), 
 	    MAX_SIZE_STAT, (yyvsp[-1].status), (yyvsp[0].name));
 
   if ((support = addSupport((yyvsp[0].name))) == 0) YYERROR;
-  support->firstSeen = (yyvsp[-7].time);
-  support->lastCheck = (yyvsp[-6].time);
-  support->lastSeen = (yyvsp[-5].time);
-  strncpy(support->quickHash, (yyvsp[-4].hash), MAX_SIZE_HASH);
-  strncpy(support->fullHash, (yyvsp[-3].hash), MAX_SIZE_HASH);
+  support->firstSeen = (yyvsp[-9].time);
+  support->lastCheck = (yyvsp[-8].time);
+  support->lastSeen = (yyvsp[-7].time);
+  strncpy(support->quickMd5sum, (yyvsp[-6].md5sum), MAX_SIZE_MD5);
+  strncpy(support->fullMd5sum, (yyvsp[-5].md5sum), MAX_SIZE_MD5);
+  strncpy(support->quickShasum, (yyvsp[-4].shasum), MAX_SIZE_SHA);
+  strncpy(support->fullShasum, (yyvsp[-3].shasum), MAX_SIZE_SHA);
   support->size = (yyvsp[-2].size);
   strncpy(support->status, (yyvsp[-1].status), MAX_SIZE_STAT);
-  strncpy(support->name, (yyvsp[0].name), MAX_SIZE_NAME);
+  strncpy(support->name, (yyvsp[0].name), MAX_SIZE_STRING);
   support = 0;
 }
-#line 1328 "supportFile.tab.c" /* yacc.c:1646  */
+#line 1336 "parser/supportFile.tab.c" /* yacc.c:1646  */
     break;
 
 
-#line 1332 "supportFile.tab.c" /* yacc.c:1646  */
+#line 1340 "parser/supportFile.tab.c" /* yacc.c:1646  */
       default: break;
     }
   /* User semantic actions sometimes alter yychar, and that requires
@@ -1556,10 +1564,9 @@ yyreturn:
 #endif
   return yyresult;
 }
-#line 154 "../parser/supportFile.y" /* yacc.c:1906  */
+#line 164 "parser/supportFile.y" /* yacc.c:1906  */
 
-
-/* epilogue: =======================================================*/
+      /* epilogue: =====================================================*/
 
 
 /*=======================================================================
@@ -1573,14 +1580,14 @@ yyreturn:
 void 
 supp_error(yyscan_t yyscanner, const char* message)
 {
-  logEmit(LOG_ERR, "%s on token '%s' line %i\n",
-	  message, supp_get_text(yyscanner), supp_get_lineno (yyscanner));
+  logParser(LOG_ERR, "%s on token '%s' line %i", message, 
+	    supp_get_text(yyscanner), LINENO);
 }
 
 /*=======================================================================
  * Function   : parseLocalSuppTree
  * Description: Parse the support File
- * Synopsis   : int parseLocalSuppTree(const char* path, int debugFlag)
+ * Synopsis   : int parseSupports(const char* path)
  * Input      : const char* path: the support file path
  * Output     : TRUE on success
 =======================================================================*/
@@ -1591,155 +1598,54 @@ parseSupports(const char* path)
   FILE* inputStream = stdin;
   yyscan_t scanner;
 
-  logParser(LOG_NOTICE, "%s", "parse supports");
+  logParser(LOG_INFO, "parse supports from %s",
+	    path?path:"stdin");
 
   // initialise scanner
   if (supp_lex_init(&scanner)) {
-    logEmit(LOG_ERR, "%s", "error initializing scanner");
+    logParser(LOG_ERR, "%s", "error initializing scanner");
     goto error;
   }
 
-  // scan input file if defined (else stdin)
-  inputStream = stdin;
   if (path != 0) {
     if ((inputStream = fopen(path, "r")) == 0) {
-      logEmit(LOG_ERR, "cannot open input stream: %s", path); 
+      logParser(LOG_ERR, "cannot open input stream: %s", path); 
       goto error;
     }
-    if (!lock(fileno(inputStream), F_RDLCK)) goto error;
-    logEmit(LOG_DEBUG, "parse support file: %s", path);
+    if (!lock(fileno(inputStream), F_RDLCK)) goto error2;
   }
+
   supp_set_in(inputStream, scanner);
 
   // debug mode for scanner
   supp_set_debug(env.debugLexer, scanner);
-  logEmit(LOG_DEBUG, "supp_set_debug = %i", supp_get_debug(scanner));
+  logParser(LOG_DEBUG, "supp_set_debug = %i", supp_get_debug(scanner));
 
   // call the parser
   if (supp_parse(scanner)) {
-    logEmit(LOG_ERR, "support file parser error on line %i",
+    logParser(LOG_ERR, "support parser fails on line %i", 
 	    supp_get_lineno(scanner));
-    logEmit(LOG_ERR, "please edit %s", path);
-    goto error;
+    logParser(LOG_ERR, "please edit %s", path?path:"stdin");
+    goto error3;
   }
 
+  rc = TRUE;
+ error3:
+  if (inputStream != stdin) {
+    if (!unLock(fileno(inputStream))) rc = FALSE;
+  }
+ error2:
   if (inputStream != stdin) {
-    if (!unLock(fileno(inputStream))) goto error;
     fclose(inputStream);
   }
-  rc = TRUE;
  error:
   if (!rc) {
-    logEmit(LOG_ERR, "%s", "support file parser error");
+    logParser(LOG_ERR, "%s", "support parser fails");
   }
   supp_lex_destroy(scanner);
   return rc;
 }
 
-/************************************************************************/
-
-#ifdef utMAIN
-#include "../misc/command.h"
-GLOBAL_STRUCT_DEF;
-
-/*=======================================================================
- * Function   : usage
- * Description: Print the usage.
- * Synopsis   : static void usage(char* programName)
- * Input      : programName = the name of the program; usually argv[0].
- * Output     : N/A
- =======================================================================*/
-static void 
-usage(char* programName)
-{
-  parserUsage(programName);
-  fprintf(stderr, " [ -i inputPath ]");
-  
-  parserOptions();
-  fprintf(stderr, "  ---\n"
-	  "  -i, --input\t\tinput file to parse\n");
-  return;
-}
-
-/*=======================================================================
- * Function   : main 
- * Author     : Nicolas ROCHE
- * modif      : 2010/11/10
- * Description: unitary test for supportFile module
- * Synopsis   : ./utsupportFile.tab
- * Input      : -i inputPath
- * Output     : Should display the same content
- =======================================================================*/
-int 
-main(int argc, char** argv)
-{
-  char* inputPath = 0;
-  // ---
-  int rc = 0;
-  int cOption = EOF;
-  char* programName = *argv;
-  char* options = PARSER_SHORT_OPTIONS"i:";
-  struct option longOptions[] = {
-     {"input", required_argument, 0, 'i'},
-    PARSER_LONG_OPTIONS,
-    {0, 0, 0, 0}
-  };
-
-  // import mdtx environment
-  env.debugParser = TRUE;
-  getEnv(&env);
-
-  // parse the command line
-  while((cOption = getopt_long(argc, argv, options, longOptions, 0)) 
-	!= EOF) {
-    switch(cOption) {
-      
-    case 'i':
-      if(isEmptyString(optarg)) {
-	fprintf(stderr, 
-		"%s: nil or empty argument for the input stream\n",
-		programName);
-	rc = 2;
-      }
-      else {
-	if ((inputPath = (char*)malloc(sizeof(char) * strlen(optarg) + 1))
-	    == 0) {
-	  fprintf(stderr, 
-		  "%s: cannot allocate memory for the input stream name\n", 
-		  programName);
-	  rc = 3;
-	}
-	else {
-	  strcpy(inputPath, optarg);
-	}
-      }
-      break;
-		
-      GET_PARSER_OPTIONS; // generic options
-    }
-    if (rc) goto optError;
-  }
-
-  // export mdtx environment
-  if (!setEnv(programName, &env)) goto optError;
-
-  /************************************************************************/
-  if (!parseSupports(inputPath)) goto error;
-  if (!serializeSupports()) goto error;
-  /************************************************************************/
-
-  freeConfiguration();
-  destroyString(inputPath);
-  rc = TRUE;
- error:
-  ENDINGS;
-  rc=!rc;
- optError:
-  exit(rc);
-}
- 
-#endif // utMAIN
-
 /* Local Variables: */
 /* mode: c */
 /* mode: font-lock */
