@@ -1,5 +1,5 @@
 /*=======================================================================
- * Version: $Id: cache.h,v 1.3 2015/06/03 14:03:55 nroche Exp $
+ * Version: $Id: cache.h,v 1.8 2015/08/23 23:39:16 nroche Exp $
  * Project: MediaTeX
  * Module : cache
  *
@@ -25,22 +25,19 @@
 #ifndef MDTX_SERVER_CACHE_H
 #define MDTX_SERVER_CACHE_H 1
 
-#include "../memory/confTree.h"
-#include "threads.h"
+#include "mediatex-types.h"
+#include "server/mediatex-server.h"
 
 /* API */
 
-char* getAbsCachePath(Collection* coll, char* path);
-char* getAbsRecordPath(Collection* coll, Record* record);
-int callAccess(char* path);
-int makeDir(char* base, char* path, mode_t mode);
-int removeDir(char* base, char* path);
-int extractCp(char* source, char* target);
+char* getAbsoluteCachePath(Collection* coll, char* path);
+char* getFinalSupplyInPath(char* path);
+char* getFinalSupplyOutPath(char* path);
+char* getAbsoluteRecordPath(Collection* coll, Record* record);
 
 int quickScan(Collection* collection);
 int quickScanAll(void);
 int cacheAlloc(Record** record, Collection* coll, Archive* archive);
-int uploadFinaleArchive(RecordTree* recordTree, Connexion* connexion);
 
 #endif /* MDTX_SERVER_CACHE_H */
 
