@@ -1,5 +1,5 @@
 /*=======================================================================
- * Version: $Id: cgiSrv.h,v 1.3 2015/06/03 14:03:55 nroche Exp $
+ * Version: $Id: cgiSrv.h,v 1.5 2015/08/19 01:09:10 nroche Exp $
  * Project: MediaTeX
  * Module : cgi-server
  *
@@ -25,13 +25,11 @@
 #ifndef MDTX_SERVER_CGI_H
 #define MDTX_SERVER_CGI_H 1
 
-#include "../memory/recordTree.h"
-#include "threads.h"
+#include "mediatex-types.h"
 
 /* API */
 
-int cgiServer(RecordTree* demands, Connexion* connexion);
-
+int cgiServer(Connexion* connexion);
 
 #endif /* MDTX_SERVER_CGI_H */
 
