@@ -1,7 +1,7 @@
 /*=======================================================================
- * Version: $Id: extract.h,v 1.3 2015/06/03 14:03:56 nroche Exp $
+ * Version: $Id: extract.h,v 1.5 2015/08/23 23:39:17 nroche Exp $
  * Project: MediaTeX
- * Module : server/extract
+ * Module : extract
  *
  * Manage local cache extraction
 
@@ -25,19 +25,21 @@
 #ifndef MDTX_SERVER_EXTRACT_H
 #define MDTX_SERVER_EXTRACT_H 1
 
-#include "../memory/confTree.h"
-#include "../memory/recordTree.h"
+#include "mediatex-types.h"
 
 /* API */
 
-
-typedef enum {X_MAIN, X_CGI, X_STEP} ExtractType;
+typedef enum {
+  X_MAIN, // do scp extraction if locally needed
+  X_CGI,  // no scp extraction
+  X_STEP  // force scp extraction on gateway if remotely needed
+} ExtractType;
 
 typedef struct ExtractData {
 
   Collection* coll;
-  ExtractType context; // UNDEF for global extraction
-  RG* toKeeps;  // Archive*
+  ExtractType context; // manage scp rule
+  RG* toKeeps;         // Archive*
   int found;
   Archive* target;
 
