@@ -1,7 +1,7 @@
 /*=======================================================================
- * Version: $Id: have.h,v 1.3 2015/06/03 14:03:56 nroche Exp $
+ * Version: $Id: have.h,v 1.5 2015/08/19 01:09:10 nroche Exp $
  * Project: MediaTeX
- * Module : server/have
+ * Module : have
  *
  * Manage extraction from removable device
 
@@ -25,12 +25,11 @@
 #ifndef MDTX_SERVER_HAVE_H
 #define MDTX_SERVER_HAVE_H 1
 
-#include "../memory/recordTree.h"
-#include "threads.h"
+#include "mediatex-types.h"
 
 /* API */
 
-int extractFinaleArchives(RecordTree* recordTree, Connexion* connexion);
+int extractFinaleArchives(Connexion* connexion);
 
 #endif /* MDTX_SERVER_HAVE_H */
 
