@@ -1,7 +1,7 @@
 /*=======================================================================
- * Version: $Id: notify.c,v 1.3 2015/06/03 14:03:56 nroche Exp $
+ * Version: $Id: notify.c,v 1.19 2015/10/04 14:22:27 nroche Exp $
  * Project: MediaTeX
- * Module : server/notify
+ * Module : notify
 
  * Send cache index to other servers 
 
@@ -22,24 +22,8 @@
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  =======================================================================*/
 
-#include "../mediatex.h"
-#include "../misc/log.h"
-#include "../misc/md5sum.h"
-#include "../misc/address.h"
-#include "../memory/cacheTree.h"
-#include "../parser/serverFile.tab.h"
-#include "../parser/confFile.tab.h"
-#include "../common/connect.h"
-#include "../common/extractScore.h"
-#include "../common/openClose.h"
-#include "cache.h"
-#include "notify.h"
-
-#ifndef utMAIN
-#include <sys/socket.h> //
-#include <netinet/in.h> // inet_ntoa
-#include <arpa/inet.h>  //
-#endif
+#include "mediatex-config.h"
+#include "server/mediatex-server.h"
 
 int notifyArchive(NotifyData* data, Archive* archive);
 
@@ -52,13 +36,14 @@ int notifyArchive(NotifyData* data, Archive* archive);
  * Output     : int *found = TRUE if notifyed
  *              FALSE on error
  =======================================================================*/
-int notifyContainer(NotifyData* data, Container* container)
+int 
+notifyContainer(NotifyData* data, Container* container)
 {
   int rc = FALSE;
   Archive* archive = 0;
   RGIT* curr = 0;
 
-  logEmit(LOG_DEBUG, "notify a container %s/%s:%lli", 
+  logMain(LOG_DEBUG, "notify a container %s/%s:%lli", 
 	  strEType(container->type), container->parent->hash,
 	  (long long int)container->parent->size);
 
@@ -69,7 +54,7 @@ int notifyContainer(NotifyData* data, Container* container)
   data->found = TRUE;
 
   // we notify all parents (only one for TGZ, several for CAT...)
-  while((archive = rgNext_r(container->parents, &curr))) {
+  while ((archive = rgNext_r(container->parents, &curr))) {
     if (!notifyArchive(data, archive)) goto error;
   }
 
@@ -77,7 +62,7 @@ int notifyContainer(NotifyData* data, Container* container)
   rc = TRUE;
  error:
   if (!rc) {
-    logEmit(LOG_ERR, "%s", "notifyContainer fails");
+    logMain(LOG_ERR, "notifyContainer fails");
   }
   return rc;
 } 
@@ -91,35 +76,31 @@ int notifyContainer(NotifyData* data, Container* container)
  * Output     : int *found = TRUE if notifyed
  *              FALSE on error
  =======================================================================*/
-int notifyArchive(NotifyData* data, Archive* archive)
+int 
+notifyArchive(NotifyData* data, Archive* archive)
 {
   int rc = FALSE;
   FromAsso* asso = 0;
   RGIT* curr = 0;
 
-  logEmit(LOG_DEBUG, "notify an archive: %s:%lli", 
+  logMain(LOG_DEBUG, "notify an archive: %s:%lli", 
 	  archive->hash, archive->size);
 
   data->found = FALSE;
   checkCollection(data->coll);
-
-  // No good, as it may be a nat client...
-  /* // stop if available from network */
-  /* if (archive->remoteSupplies->nbItems > 0) { */
-  /*   data->found = TRUE; */
-  /*   goto end; */
-  /* } */
   
   // look for a matching local supply
   if (archive->state >= AVAILABLE) {
     data->found = TRUE;
-    if (!keepArchive(data->coll, archive, REMOTE_DEMAND)) goto error;
+    logMain(LOG_INFO, "found a local supply to notify: %s:%lli", 
+	    archive->hash, archive->size);
     if (!rgInsert(data->toNotify, archive->localSupply)) goto error;
     goto end;
   }
 
-  // continue searching as we stop at the first container already there
-  while(!data->found && (asso = rgNext_r(archive->fromContainers, &curr))) {
+  // continue searching deeper if needed
+  while (!data->found && 
+	(asso = rgNext_r(archive->fromContainers, &curr))) {
     if (!notifyContainer(data, asso->container)) goto error;
   }
 
@@ -127,14 +108,14 @@ int notifyArchive(NotifyData* data, Archive* archive)
   rc = TRUE;
  error:
   if (!rc) {
-    logEmit(LOG_ERR, "%s", "notifyArchive fails");
+    logMain(LOG_ERR, "notifyArchive fails");
   }
   return rc;
 } 
 
 /*=======================================================================
- * Function   : getWantedArchives
- * Description: copy all wanted archives into a ring
+ * Function   : getWantedRemoteArchives
+ * Description: copy all remotely wanted archives into a ring
  * Synopsis   : RG* getWantedArchives(Collection* coll)
  * Input      : Collection* coll
  * Output     : a ring of arhives, 0 o error
@@ -150,16 +131,19 @@ getWantedRemoteArchives(Collection* coll)
   RGIT* curr2 = 0;
 
   checkCollection(coll);
-  logEmit(LOG_DEBUG, "%s", "getWantedArchives");
+  logMain(LOG_DEBUG, "getWantedRemoteArchives");
 
   if (!(ring = createRing())) goto error;
 
-  while((archive = rgNext_r(coll->cacheTree->archives, &curr))) {
+  while ((archive = rgNext_r(coll->cacheTree->archives, &curr))) {
     if (archive->state < WANTED) continue; // no remote demand
 
     // look for a remote demand
-    while((record = rgNext_r(archive->demands, &curr2))) {
+    while ((record = rgNext_r(archive->demands, &curr2))) {
       if (getRecordType(record) != REMOTE_DEMAND) continue;
+
+      logMain(LOG_DEBUG, "working on remote demand: %s:%lli",
+	      archive->hash, archive->size);
       if (!rgInsert(ring, archive)) goto error;
       break;
     }
@@ -168,23 +152,25 @@ getWantedRemoteArchives(Collection* coll)
   rc = ring;
  error:
   if (!rc) {
-    logEmit(LOG_ERR, "%s", "getWantedRemoteArchives fails");
+    logMain(LOG_ERR, "getWantedRemoteArchives fails");
     destroyOnlyRing(ring);
   }
   return rc;
 } 
 
 /*=======================================================================
- * Function   : 
- * Description: 
- * Synopsis   : 
- * Input      : 
+ * Function   : addFinalDemands
+ * Description: Add final demands to the message to send
+ * Synopsis   : int addFinalDemands(NotifyData* data)
+ * Input      : NotifyData* data
  * Output     : TRUE on success
  =======================================================================*/
-int addFinalDemands(NotifyData* data)
+int 
+addFinalDemands(NotifyData* data)
 {
   int rc = FALSE;
   Collection* coll = 0;
+  Server* localhost = 0;
   Archive* archive = 0;
   Record* record = 0;
   Record* demand = 0;
@@ -194,31 +180,55 @@ int addFinalDemands(NotifyData* data)
 
   coll = data->coll;
   checkCollection(coll);
-  logEmit(LOG_DEBUG, "%s", "addFinalDemands");
+  logMain(LOG_DEBUG, "addFinalDemands");
 
-  while((archive = rgNext_r(coll->cacheTree->archives, &curr)) 
-	!= 0) {
+  if (!(localhost = getLocalHost(coll))) goto error;
+
+  while ((archive = rgNext_r(coll->cacheTree->archives, &curr))) {
     if (archive->state != WANTED) continue;
-    while((record = rgNext_r(archive->demands, &curr2)) != 0) {
-      
-      // final demand: add it
-      if (getRecordType(record) == FINALE_DEMAND) {
+    
+    // add final demand
+    curr2 = 0;
+    while ((record = rgNext_r(archive->demands, &curr2))) {
+      if (getRecordType(record) == FINAL_DEMAND) {
 
+	logMain(LOG_INFO, "found a final demand to notify: %s:%lli",
+		archive->hash, archive->size);
 	if (!(extra = createString("!wanted"))) goto error;
-	if (!(demand = newRecord(coll->localhost, archive, 
-				 DEMAND, extra))) goto error;
+	if (!(demand = newRecord(coll->localhost, archive, DEMAND, extra))) 
+	  goto error;
 	extra = 0;
 	if (!rgInsert(data->toNotify, demand)) goto error;
 	demand = 0;
 	break;
       }
     }
-  }
 
+    // if localhost is a gateway...
+    if (isEmptyRing(coll->localhost->gateways)) continue;
+
+    // ...relay NAT client's final demand too (as our)
+    curr2 = 0;
+    while ((record = rgNext_r(archive->demands, &curr2))) {
+      if (getRecordType(record) == REMOTE_DEMAND &&
+	rgShareItems(localhost->gateways, record->server->networks)) {
+
+	logMain(LOG_INFO, "found a remote demand to manage: %s:%lli",
+		record->archive->hash, record->archive->size);
+	if (!(extra = createString("!wanted"))) goto error;
+	if (!(demand = newRecord(coll->localhost, record->archive, DEMAND, extra))) 
+	  goto error;
+	extra = 0;
+	if (!rgInsert(data->toNotify, demand)) goto error;
+	demand = 0;
+      }
+    }
+  }
+ 
   rc = TRUE;
  error:
   if (!rc) {
-    logEmit(LOG_ERR, "%s", "addFinalDemands fails");
+    logMain(LOG_ERR, "addFinalDemands fails");
   }
   return rc;
 } 
@@ -229,10 +239,9 @@ int addFinalDemands(NotifyData* data)
  * Synopsis   : int addBadTopLocalSupplies(NotifyData* data)
  * Input      : NotifyData* data
  * Output     : TRUE on success
-
- * TODO       : check minGeoDup and nb REMOTE_SUPPLY
  =======================================================================*/
-int addBadTopLocalSupplies(NotifyData* data)
+int 
+addBadTopLocalSupplies(NotifyData* data)
 {
   int rc = FALSE;
   Collection* coll = 0;
@@ -241,70 +250,72 @@ int addBadTopLocalSupplies(NotifyData* data)
 
   coll = data->coll;
   checkCollection(coll);
-  logEmit(LOG_DEBUG, "%s", "addBadTopLocalSupplies");
+  logMain(LOG_DEBUG, "addBadTopLocalSupplies");
 
-  // add local iso (or other top containers) if it own a bad score
-  while((archive = rgNext_r(coll->cacheTree->archives, &curr)) 
-	!= 0) {
+  // add local top containers having a bad score
+  while ((archive = rgNext_r(coll->cacheTree->archives, &curr))) {
     if (archive->state < AVAILABLE) continue;
-    if (archive->fromContainers->nbItems != 0) continue;
-    if (archive->extractScore > 10) 
+    if (archive->extractScore > coll->serverTree->scoreParam.maxScore /2) 
       continue;
+    if (archive->fromContainers->nbItems > 0) continue;
 
-    /* check minGeoDup and nb REMOTE_SUPPLY
-       if (archive->extractScore <
-       coll->serverTree->scoreParam.badScore && ...) continue
-    */
+    /* maybe check minGeoDup and nb REMOTE_SUPPLY too in future */
 
-    if (!keepArchive(data->coll, archive, REMOTE_DEMAND)) goto error;
+    logMain(LOG_INFO, 
+	    "found a bad score's local top container to notify: %s:%lli",
+	    archive->hash, archive->size);
     if (!rgInsert(data->toNotify, archive->localSupply)) goto error;
   }
 
   rc = TRUE;
  error:
   if (!rc) {
-    logEmit(LOG_ERR, "%s", "addBadTopLocalSupplies fails");
+    logMain(LOG_ERR, "addBadTopLocalSupplies fails");
   }
   return rc;
 } 
 
 /*=======================================================================
- * Function   : extractArchives
- * Description: Try to extract all the archives one by one
- * Synopsis   : int extractRemoteArchives(Collection* coll)
+ * Function   : buildNotifyRings
+ * Description: build records to send (local supplies + local demands)
+ * Synopsis   : RG* buildNotifyRings(Collection* coll, RG* records)
  * Input      : Collection* coll
+ *              RG* records: the record's ring to push into
  * Output     : TRUE on success
  =======================================================================*/
-RG* buildNotifyRings(Collection* coll, RG* records)
+int
+buildNotifyRings(Collection* coll, RG* records)
 {
-  RG* rc = 0;
+  int rc = FALSE;
   RG* archives = 0;
   Archive* archive = 0;
   RGIT* curr = 0;
   NotifyData data;
 
   checkCollection(coll);
-  logEmit(LOG_DEBUG, "buildNotifyRings %s collection", coll->label);
+  logMain(LOG_DEBUG, "buildNotifyRings %s collection", coll->label);
   data.coll = coll;
   data.toNotify = records;
+
+  // work on archive wanted by remote servers
   if (!(archives = getWantedRemoteArchives(coll))) goto error;
 
-  // for each cache entry, add local-supplies
-  while((archive = rgNext_r(archives, &curr)) != 0) {
+  // for each of them, try to add local-supplies
+  while ((archive = rgNext_r(archives, &curr))) {
     if (!notifyArchive(&data, archive)) goto error;
   }
 
-  // add final demands
+  // next, add final demands (on localserver)
   if (!addFinalDemands(&data)) goto error;
 
-  // add top archives with bad score
+  // and, add top archives with bad score
   if (!computeExtractScore(data.coll)) goto error;
   if (!addBadTopLocalSupplies(&data)) goto error;
 
-  rc = data.toNotify;
+  rc = TRUE;
  error:
   if (!rc) {
-    logEmit(LOG_ERR, "%s", "buildNotifyRings fails");
+    logMain(LOG_ERR, "buildNotifyRings fails");
   }
   destroyOnlyRing(archives);
   return rc;
@@ -322,8 +333,9 @@ RG* buildNotifyRings(Collection* coll, RG* records)
  *              Server* origin = overriding caller (when Nat)
  * Output     : TRUE on success
  =======================================================================*/
-int sendRemoteNotifyServer(Server* server, RecordTree* recordTree, 
-			   Server* origin)
+int 
+sendRemoteNotifyServer(Server* server, RecordTree* recordTree, 
+		       Server* origin)
 {
   int rc = FALSE;
   Collection* coll = 0;
@@ -334,34 +346,27 @@ int sendRemoteNotifyServer(Server* server, RecordTree* recordTree,
   if (recordTree == 0) goto error;
   coll = recordTree->collection;
 
-  logEmit(LOG_DEBUG, "sendRemoteNotifyServer for %s/%s:%i",
+  logMain(LOG_DEBUG, "sendRemoteNotifyServer for %s/%s:%i",
  	  coll->label, server->host, server->mdtxPort);
   
-  if (!env.dryRun) {
-    // get a socket to the server
-    if ((socket = connectServer(server)) == -1) {
-      logEmit(LOG_NOTICE, "cannot connect %s", server->host);
-      goto end;
-    }
+  // get a socket to the server
+  if ((socket = connectServer(server)) == -1) {
+    logMain(LOG_NOTICE, "cannot connect %s", server->host);
+    goto end;
   }
     
   // send the archive tree
-  if (origin != 0) serverFP = origin->fingerPrint; // masquerade
-  if (env.dryRun) {
-    serializeRecordTree(recordTree, 0, serverFP);
-  }
-  else {
-    if (!upgradeServer(socket, recordTree, serverFP)) goto error;
-  }
-
-  logEmit(LOG_NOTICE, "%s:%i notified", server->host, server->mdtxPort);
+  if (origin) serverFP = origin->fingerPrint; // masquerade
+  if (!upgradeServer(socket, recordTree, serverFP)) goto error;
+  
+  logMain(LOG_NOTICE, "%s:%i notified", server->host, server->mdtxPort);
  end:
   rc = TRUE;
  error:
   if (!rc) {
-    logEmit(LOG_ERR, "%s", "sendRemoteNotifyServer fails");
+    logMain(LOG_ERR, "sendRemoteNotifyServer fails");
   }
-  if (socket != -1) close(socket);
+  if (!env.dryRun && socket != -1) close(socket);
   return rc;
 }
 
@@ -372,7 +377,8 @@ int sendRemoteNotifyServer(Server* server, RecordTree* recordTree,
  * Input      : Collection* coll: collection to notify
  * Output     : TRUE on success
  =======================================================================*/
-int sendRemoteNotify(Collection* coll)
+int 
+sendRemoteNotify(Collection* coll)
 {
   int rc = FALSE;
   Server* localhost = 0;
@@ -381,7 +387,7 @@ int sendRemoteNotify(Collection* coll)
   Record* record = 0;
   RGIT* curr = 0;
 
-  logEmit(LOG_DEBUG, "sendRemoteNotify for %s collections", 
+  logMain(LOG_DEBUG, "sendRemoteNotify for %s collections", 
 	  coll->label);
 
   if (!(recordTree = createRecordTree())) goto error;
@@ -393,14 +399,14 @@ int sendRemoteNotify(Collection* coll)
   if (!(localhost = getLocalHost(coll))) goto error2;
   if (!lockCacheRead(coll)) goto error2;
 
-  // build records to send (local-supplies + local-demands)
+  // build records to send (local supplies + local demands)
   if (!buildNotifyRings(coll, recordTree->records)) goto error3;
 
   // note: we may send an empty ring in order to tell we no more look 
   // for any record
 
   // for all servers sharing the collection
-  while((target=rgNext_r(coll->serverTree->servers, &curr))) {
+  while ((target=rgNext_r(coll->serverTree->servers, &curr))) {
     if (target->isLocalhost) continue;
 
     // skip server not directly connected to us
@@ -415,8 +421,8 @@ int sendRemoteNotify(Collection* coll)
 
   // free local demands
   curr = 0;
-  while((record = rgNext_r(recordTree->records, &curr)) != 0) {
-    if (getRecordType(record) == LOCALE_DEMAND) {
+  while ((record = rgNext_r(recordTree->records, &curr))) {
+    if (getRecordType(record) == LOCAL_DEMAND) {
       destroyRecord(record);
       curr->it = 0;
     }
@@ -426,7 +432,7 @@ int sendRemoteNotify(Collection* coll)
   if (!releaseCollection(coll, SERV|EXTR|CACH)) goto error;
  error:
   if (!rc) {
-    logEmit(LOG_ERR, "sendRemoteNotify %s collection fails", 
+    logMain(LOG_ERR, "sendRemoteNotify %s collection fails", 
 	    coll->label);
   }
   recordTree->records = destroyOnlyRing(recordTree->records);
@@ -439,12 +445,10 @@ int sendRemoteNotify(Collection* coll)
  * Description: Receive a remote server notification
  * Synopsis   : int acceptRemoteNotify(RecordTree* tree,
  *                                                 Connexion* connexion)
- * Input      : RecordTree* tree = the remote cache index
- *              Connexion* connexion = gives the remote IP address
- * Output     : N/A
- * Note       : STILL A LOT TO DO HERE
+ * Input      : Connexion* connexion = gives the remote IP address
+ * Output     : TRUE on success
  =======================================================================*/
-int acceptRemoteNotify(RecordTree* tree, Connexion* connexion)
+int acceptRemoteNotify(Connexion* connexion)
 {
   int rc = FALSE;
   RG* records = 0;
@@ -455,22 +459,25 @@ int acceptRemoteNotify(RecordTree* tree, Connexion* connexion)
   Server* localhost = 0;
   RGIT* curr = 0;
 
-  coll = tree->collection;
+  static char status[][8] = {
+    "240 ok"
+  };
+
+  logMain(LOG_DEBUG, "acceptRemoteNotify");
+  coll = connexion->message->collection;
   source = connexion->server;
   checkCollection(coll);
   checkServer(source);
-  logEmit(LOG_DEBUG, "%s", "acceptRemoteNotify");
 
-  if (!loadCollection(tree->collection, CACH)) goto error;
-
-  if (!(localhost = getLocalHost(coll))) goto error2; 
+  if (!loadCollection(coll, CACH)) goto error;
+  if (!(localhost = getLocalHost(coll))) goto error2;
   
   // first: if localhost is a gateway...
   if (!isEmptyRing(coll->localhost->gateways)) {
     curr = 0;
 
-    // ...forward "same" message to our Nat clients
-    while((target=rgNext_r(coll->serverTree->servers, &curr))) {
+    // ...forward the message to the Nat clients
+    while ((target=rgNext_r(coll->serverTree->servers, &curr))) {
 
       // skip server already connected to the source
       if (rgShareItems(source->networks, target->networks)) continue;
@@ -478,179 +485,45 @@ int acceptRemoteNotify(RecordTree* tree, Connexion* connexion)
       // skip server if not on our gateway networks
       if (!rgShareItems(localhost->gateways, target->networks)) continue;
 
-      logEmit(LOG_NOTICE, "forward message to %s:%i nat client",
+      logMain(LOG_NOTICE, "forward message to %s:%i nat client",
 	      target->host, target->mdtxPort);
-      if (!sendRemoteNotifyServer(target, tree, source)) goto error2;
+      if (!sendRemoteNotifyServer(target, connexion->message, source)) 
+	goto error2;
     }
   }
 
   // secondly: update our cache
   if (!lockCacheRead(coll)) goto error2;
 
-  // del all records we have from the calling server
+  // del all records we previously get from the calling server
   curr = 0;
   records = coll->cacheTree->recordTree->records;
-  while((record = rgNext_r(records, &curr)) != 0) {  
+  while ((record = rgNext_r(records, &curr))) {  
     if (record->server != source) continue;
     if (!delCacheEntry(coll, record)) goto error3;
   }
 		
-  // add calling server's records
-  rgRewind(tree->records);
-  while ((record = rgNext(tree->records)) != 0) {
+  // add new fresh records provided by the calling server
+  while ((record = rgHead(connexion->message->records))) {
+    // record remains into the cache
     if (!addCacheEntry(coll, record)) goto error3;
-    tree->records->curr->it = 0; // consume the record from the tree
+
+    rgRemove(connexion->message->records);
   }
   
+  sprintf(connexion->status, "%s", status[0]);
   rc = TRUE;
  error3:
     if (!unLockCache(coll)) rc = FALSE;
  error2:
-  if (!releaseCollection(tree->collection, CACH|SERV)) rc = FALSE;
+  if (!releaseCollection(coll, CACH)) rc = FALSE;
  error:
   if (!rc) {
-    logEmit(LOG_DEBUG, "%s", "acceptRemoteNotify fails");
+    logMain(LOG_DEBUG, "acceptRemoteNotify fails");
   }
   return rc;
 }
 
-/************************************************************************/
-
-#ifdef utMAIN
-#include "../misc/command.h"
-#include "../misc/address.h"
-#include "../common/openClose.h"
-#include "utFunc.h"
-GLOBAL_STRUCT_DEF;
-int running = TRUE;
-
-/*=======================================================================
- * Function   : usage
- * Description: Print the usage.
- * Synopsis   : static void usage(char* programName)
- * Input      : programName = the name of the program; usually argv[0].
- * Output     : N/A
- =======================================================================*/
-static void 
-usage(char* programName)
-{
-  mdtxUsage(programName);
-
-  mdtxOptions();
-  //fprintf(stderr, "  ---\n");
-  return;
-}
-
-
-/*=======================================================================
- * Function   : main 
- * Author     : Nicolas ROCHE
- * modif      : 2012/05/01
- * Description: Unit test for cache module.
- * Synopsis   : ./utcache
- * Input      : N/A
- * Output     : N/A
-
- * TODO       : unit test for the receive case
- =======================================================================*/
-int 
-main(int argc, char** argv)
-{
-  char inputRep[256] = ".";
-  Collection* coll = 0;
-  Archive* archive = 0;
-  Server* server = 0;
-  Record* record = 0;
-  char* extra = 0;
-  // ---
-  int rc = 0;
-  int cOption = EOF;
-  char* programName = *argv;
-  char* options = MDTX_SHORT_OPTIONS"d:";
-  struct option longOptions[] = {
-    MDTX_LONG_OPTIONS,
-    {"input-rep", required_argument, 0, 'd'},
-    {0, 0, 0, 0}
-  };
-
-  // import mdtx environment
-  getEnv(&env);
-
-  // parse the command line
-  while((cOption = getopt_long(argc, argv, options, longOptions, 0)) 
-	!= EOF) {
-    switch(cOption) {
-      
-    case 'd':
-      if(optarg == 0 || *optarg == (char)0) {
-	fprintf(stderr, 
-		"%s: nil or empty argument for the input repository\n",
-		programName);
-	rc = EINVAL;
-	break;
-      }
-      strncpy(inputRep, optarg, strlen(optarg)+1);
-      break; 
-
-      GET_MDTX_OPTIONS; // generic options
-    }
-    if (rc) goto optError;
-  }
-
-  // export mdtx environment
-  if (!setEnv(programName, &env)) goto optError;
-
-  /************************************************************************/
-  if (!(coll = mdtxGetCollection("coll1"))) goto error;
-  if (!getLocalHost(coll)) goto error;
-  utLog("%s", "Clean the cache:", 0);
-  if (!utCleanCaches()) goto error;
-
-  utLog("%s", "add a demands and local supplies:", 0);
-  
-  // remote demand
-  if (!(archive = 
-	addArchive(coll, "022a34b2f9b893fba5774237e1aa80ea", 24075))) 
-    goto error;
-  if (!(server = addServer(coll, "7af51aceb06864e690fa6a9e00000001")))
-    goto error;
-  if (!(extra = createString("!wanted"))) goto error;
-  if (!(record = addRecord(coll, server, archive, DEMAND, extra)))
-    goto error;
-  if (!addCacheEntry(coll, record)) goto error;
-  
-  // local demand
-  if (!(extra = createString("test@test"))) goto error;
-  if (!(record = addRecord(coll, coll->localhost, archive, DEMAND, extra)))
-    goto error;
-  if (!addCacheEntry(coll, record)) goto error;
-  if (!utCopyFileOnCache(coll, inputRep, "logoP1.cat")) goto error;
-  if (!utCopyFileOnCache(coll, inputRep, "logo.tgz")) goto error;
-  if (!quickScan(coll)) goto error;
-  utLog("%s", "we have :", coll);
-  
-  utLog("%s", "here we send", 0);
-  if (!sendRemoteNotify(coll)) goto error;
-  
-  //utLog("%s", "here we receive", 0);
-  // ... need to copy the ring and clean the cache
-  //if (!acceptRemoteNotify(diff, LOCALHOST)) goto error;
-
-  utLog("%s", "Clean the cache:", 0);
-  if (!utCleanCaches()) goto error;
-  /************************************************************************/
-
-  rc = TRUE;
- error:
-  freeConfiguration();
-  ENDINGS;
-  rc=!rc;
- optError:
-  exit(rc);
-}
-
-#endif // utMAIN
-
 /* Local Variables: */
 /* mode: c */
 /* mode: font-lock */
