@@ -1,7 +1,7 @@
 /*=======================================================================
- * Version: $Id: threads.c,v 1.3 2015/06/03 14:03:56 nroche Exp $
+ * Version: $Id: threads.c,v 1.13 2015/10/11 01:03:54 nroche Exp $
  * Project: MediaTeX
- * Module : server/threads
+ * Module : threads
 
  * Handle sockets and signals
 
@@ -22,21 +22,10 @@
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  =======================================================================*/
 
-#include "../mediatex.h"
-#include "../misc/log.h"
-#include "../misc/tcp.h"
-#include "../misc/signals.h"
-#include "../misc/shm.h"
-#include "../memory/confTree.h"
-#include "../common/register.h"
-#include "threads.h"
-
-#include <pthread.h>
-#include <netinet/in.h> // for inet_ntoa
-#include <arpa/inet.h>  // for inet_ntoa
+#include "mediatex-config.h"
+#include "server/mediatex-server.h"
 
 // global variables
-extern sigset_t signalsToManage;
 int hold = FALSE;
 
 static int isMutexInitialized = FALSE;
@@ -59,7 +48,7 @@ initMutex()
 
   if (!isMutexInitialized) {
     if ((rc = pthread_mutex_init(&jobsMutex, (pthread_mutexattr_t*)0))) {
-      logEmit(LOG_INFO, "pthread_mutex_init: %s", strerror(rc));
+      logMain(LOG_INFO, "pthread_mutex_init: %s", strerror(rc));
       rc = FALSE;
       goto error;
     }
@@ -82,14 +71,14 @@ initThreadParamaters(pthread_attr_t *attr)
 {
   int rc = 0;
     
-  if((rc = pthread_attr_init(attr)) != 0) {
-    logEmit(LOG_ERR, "Create thread attributes: %d (%s)",
+  if((rc = pthread_attr_init(attr))) {
+    logMain(LOG_ERR, "Create thread attributes: %d (%s)",
 	    rc, strerror(rc));
     goto error;
   }
   
   if((rc = pthread_attr_setdetachstate(attr, PTHREAD_CREATE_DETACHED))) {
-    logEmit(LOG_ERR, "fails to set thread detach attr: %d (%s)",
+    logMain(LOG_ERR, "fails to set thread detach attr: %d (%s)",
 	    rc, strerror(rc));
     goto error;
   }
@@ -121,29 +110,38 @@ sigManager(void* arg)
   int try = 5;
   struct sockaddr_in address;
   int port = 0;
-  
+  sigset_t mask;
+
   (void) arg;
-  
+
   if (!initMutex()) goto error;
 
+  // signal we are looking for:
+  if (sigemptyset(&mask)) goto error;
+  if (sigaddset(&mask, SIGHUP)) goto error;
+  if (sigaddset(&mask, SIGUSR1)) goto error;
+  if (sigaddset(&mask, SIGTERM)) goto error;
+  if (sigaddset(&mask, SIGSEGV)) goto error;
+  if (sigaddset(&mask, SIGINT)) goto error;
+
   while (env.running) {
     sigNumber = -1;
-    if ((sigNumber = sigwaitinfo(&signalsToManage, 0)) == -1) {
+    if ((sigNumber = sigwaitinfo(&mask, 0)) == -1) {
       if (errno == EINTR) continue; // so as to manage debugging with gdb
-      logEmit(LOG_ERR, "sigwait fails: %s", strerror(errno));
+      logMain(LOG_ERR, "sigwait fails: %s", strerror(errno));
       goto error;
     }
     
     switch (sigNumber) {
 
     case SIGSEGV:
-      logEmit(LOG_ERR, "%s", "segfault (SIGSEGV)");
+      logMain(LOG_ERR, "segfault (SIGSEGV)");
       reEnableALL();
       kill(getpid(), SIGSEGV);
       goto error;
       break;
     case SIGINT:
-      logEmit(LOG_ERR, "%s", "stopped by user (SIGINT)");
+      logMain(LOG_ERR, "stopped by user (SIGINT)");
       reEnableALL();
       kill(getpid(), SIGINT);
       goto error;
@@ -152,7 +150,7 @@ sigManager(void* arg)
     case SIGHUP:
       // wait until no more job are running
       hold = TRUE;
-      logEmit(LOG_NOTICE, "%s", "accepting signal HUP");
+      logMain(LOG_NOTICE, "accepting signal HUP");
     retry1:
       while (taskSocketNumber > 0 || taskSignalNumber > 0)
 	usleep(100000);
@@ -165,9 +163,9 @@ sigManager(void* arg)
 
       if (!hupManager()) exit(1); // force exit if reload fails;
       pthread_mutex_unlock(&jobsMutex);
-#ifndef utMAIN
-      memoryStatus(LOG_NOTICE);
-#endif
+      if (!env.noRegression) {
+	memoryStatus(LOG_NOTICE, __FILE__, __LINE__);
+      }
       hold = FALSE;
       continue;
 
@@ -176,7 +174,7 @@ sigManager(void* arg)
 
       // wait until no more job are running
       hold = TRUE;
-      logEmit(LOG_NOTICE, "%s", "accepting signal TERM");
+      logMain(LOG_NOTICE, "accepting signal TERM");
     retry2:
       while (taskSocketNumber > 0 || taskSignalNumber > 0)
 	usleep(100000);
@@ -202,23 +200,19 @@ sigManager(void* arg)
       rc=rc&& connectTcpSocket(&address);
       if (!rc) exit(3); // force exit if socket fails
 
-#ifdef utMAIN
     case SIGUSR1:
-      logEmit(LOG_NOTICE, "%s", "accepting signal USR1");    
+      logMain(LOG_NOTICE, "accepting signal USR1");    
       break;
-#endif
 
     default:
-      logEmit(LOG_INFO, "receive signal %i", sigNumber);
-#ifdef utMAIN
+      logMain(LOG_INFO, "receive unexpected signal %i", sigNumber);
       continue;
-#endif
     }
 
     // wait for a dedicated thread allocation
     while (taskSignalNumber+1 > MAX_TASK_SIGNAL_THREAD) {
       if (!env.running) goto error;
-      logEmit(LOG_WARNING, "%s", "pending USR1 signal");
+      logMain(LOG_WARNING, "pending USR1 signal");
       sleep(20);
     };
 
@@ -229,7 +223,7 @@ sigManager(void* arg)
     // create dedicated thread for signal query
     while ((rc = pthread_create(&signalTaskThread, &taskAttr,
   				signalJob, 0))) {
-      logEmit(LOG_ERR, "pthread_create fails: %s", strerror(rc));
+      logMain(LOG_ERR, "pthread_create fails: %s", strerror(rc));
       if (rc == EAGAIN && try--) {
   	usleep(100000);
   	continue;
@@ -255,9 +249,10 @@ void signalJobEnds()
   pthread_mutex_lock(&jobsMutex);
   taskSignalNumber--;
   pthread_mutex_unlock(&jobsMutex);
-#ifndef utMAIN
-  memoryStatus(LOG_NOTICE);
-#endif
+
+  if (!env.noRegression) {
+    memoryStatus(LOG_INFO, __FILE__, __LINE__);
+  }
 }
 
 
@@ -282,7 +277,7 @@ serverManager(int sock, struct sockaddr_in* address_accepted)
 
   // connexion informations 
   if (!(connexion = (Connexion*)malloc(sizeof(Connexion)))) {
-    logEmit(LOG_ERR, "malloc cannot create connexion objet: %s", 
+    logMain(LOG_ERR, "malloc cannot create connexion objet: %s", 
 	    strerror(errno));
     goto error;
   }
@@ -297,7 +292,7 @@ serverManager(int sock, struct sockaddr_in* address_accepted)
  retry:
   while (hold || taskSocketNumber+1 > MAX_TASK_SOCKET_THREAD) {
     if (!env.running) goto end;
-    logEmit(LOG_WARNING, "pending connexion from %s:%u (%s)",
+    logMain(LOG_WARNING, "pending connexion from %s:%u (%s)",
 	    inet_ntoa(address_accepted->sin_addr),
 	    port, connexion->host);
     sleep(2);
@@ -312,14 +307,14 @@ serverManager(int sock, struct sockaddr_in* address_accepted)
   ++taskSocketNumber;
   pthread_mutex_unlock(&jobsMutex);
 
-  logEmit(LOG_INFO, "accepting connexion from %s:%u (%s)",
+  logMain(LOG_INFO, "accepting connexion from %s:%u (%s)",
 	  inet_ntoa(address_accepted->sin_addr),
 	  port, connexion->host);
   
   // create dedicated thread for socket query
   while ((rc = pthread_create(&socketTaskThread, &taskAttr, 
 			      socketJob, (void *)connexion))) {
-    logEmit(LOG_ERR, "pthread_create fails: %s", strerror(rc));
+    logMain(LOG_ERR, "pthread_create fails: %s", strerror(rc));
     if (rc == EAGAIN && try--) {
       usleep(100000);
       continue;
@@ -331,7 +326,7 @@ serverManager(int sock, struct sockaddr_in* address_accepted)
     goto error;
   }
 
-  // thread consume the connexion variables
+  // thread had consumed the connexion variables
   connexion = 0;
   sock = 0;
  end:
@@ -347,19 +342,27 @@ serverManager(int sock, struct sockaddr_in* address_accepted)
 
 /*=======================================================================
  * Function   : socketJobEnds
- * Description: Function to be called by finishing socket job
+ * Description: Function to be called by threads having finish socket job
  * Synopsis   : int socketJobEnds()
  * Input      : N/A
  * Output     : TRUE on success
  =======================================================================*/
-void socketJobEnds()
+void socketJobEnds(Connexion* connexion)
 {
   pthread_mutex_lock(&jobsMutex);
   taskSocketNumber--;
   pthread_mutex_unlock(&jobsMutex);
-#ifndef utMAIN
-  memoryStatus(LOG_NOTICE);
-#endif
+
+  // connexion variable is managed the calling thread
+  if (connexion) {
+    if (connexion->sock) close(connexion->sock);
+    if (connexion->host) free(connexion->host);
+    free(connexion);
+  }
+
+  if (!env.noRegression) {
+    memoryStatus(LOG_INFO, __FILE__, __LINE__);
+  }
 }
 
 
@@ -386,224 +389,122 @@ mainLoop()
 
   // convert port into char*
   if (sprintf(service, "%i", getConfiguration()->mdtxPort) < 0) {
-    logEmit(LOG_ERR, "cannot convert %i port number into service", 
+    logMain(LOG_ERR, "cannot convert %i port number into service", 
 	    getConfiguration()->mdtxPort);
     goto error;
   }
   
   // build the listenning socket for both remote and local connection
   if (!buildSocketAddress(&address, 0, "tcp", service)) {
-    logEmit(LOG_ERR, "%s", "error while building socket address");
+    logMain(LOG_ERR, "error while building socket address");
     goto error;
   }
   
   // main loop (listen to socket)
-  logEmit(LOG_NOTICE, "Daemon (%i) started", getpid());
+  logMain(LOG_NOTICE, "Daemon (%i) started", getpid());
   if (!acceptTcpSocket(&address, serverManager)) goto error;
   
   rc = TRUE;
  error:
   env.running = FALSE;
   if (!kill(getpid(), SIGTERM) == -1) {
-    logEmit(LOG_ERR, "killing signal handler failed: %s", errno);
+    logMain(LOG_ERR, "killing signal handler failed: %s", errno);
     rc = FALSE;
   }
   if (!mdtxShmFree()) rc = FALSE;
   if (thread && (err = pthread_join(thread, 0))) {
-    logEmit(LOG_ERR, "pthread_join fails: %s", strerror(err));
+    logMain(LOG_ERR, "pthread_join fails: %s", strerror(err));
     goto error;
   }
   pthread_attr_destroy(&taskAttr);
   return rc;
 }
 
-/************************************************************************/
-
-#ifdef utMAIN
-#include "../misc/command.h"
-GLOBAL_STRUCT_DEF;
-
-/*=======================================================================
- * Function   : termManager
- * Description: Callback function for SIGTERM
- * Synopsis   : void termManager()
- * Input      : N/A
- * Output     : N/A
- =======================================================================*/
-int
-termManager()
-{
-  logEmit(LOG_NOTICE, "%s", "daemon exiting");
-  return TRUE;
-}
-
-/*=======================================================================
- * Function   : hupManager
- * Description: Callback function for SIGHUP
- * Synopsis   : void hupManager()
- * Input      : N/A
- * Output     : N/A
- =======================================================================*/
-int
-hupManager()
-{
-  logEmit(LOG_NOTICE, "%s", "daemon wake-up");
-  return TRUE;
-}
-
 
 /*=======================================================================
- * Function   : signalJob
- * Description: thread callback function for signals
- * Synopsis   : void* signalJob(void* arg)
- * Input      : void* arg = not used
- * Output     : (void*)TRUE on success
+ * Function   : checkMessage
+ * Description: Common operation on message
+ * Synopsis   : int checkMessage(Connexion* con)
+ * Input      : Connexion* con
+ * Output     : set con->tree
+ *              set con->server
+ *              TRUE on succes
  =======================================================================*/
-void* 
-signalJob(void* arg)
+int checkMessage(Connexion* con)
 {
-  Configuration* conf = 0;
-  int me = 0;
-  long int rc = FALSE;
-  ShmParam param;
+  int rc = FALSE;
+  Collection* coll = 0;
+  Server* server = 0;
+  Record* record = 0;
+  RGIT* curr = 0;
 
-  (void)arg;
-  if (!(conf = getConfiguration())) goto error;
-  me = taskSignalNumber;
-  
-  if (!shmRead(conf->confFile, MDTX_SHM_BUFF_SIZE,
-  	       mdtxShmRead, (void*)&param))
-    goto error;
-
-  logEmit(LOG_INFO, "in  shm: (%s)", param.buf);  
-
-  if (strcmp(param.buf, "0000")) {
-    usleep(50000);
-    logEmit(LOG_NOTICE, "doing job %i for signal", me);
-    usleep(50000);
-    logEmit(LOG_NOTICE, "finish job %i for signal", me);
-    usleep(50000);
-    strcpy(param.buf, "0000");
-    rc = shmWrite(conf->confFile, MDTX_SHM_BUFF_SIZE,
-    		  mdtxShmCopy, (void*)&param);
-  }
-
-  logEmit(LOG_INFO, "out shm: (%s)", param.buf);  
-  rc = TRUE;
- error:
-  signalJobEnds();
-  return (void*)rc;
-}
-
-
-/*=======================================================================
- * Function   : socketJob
- * Description: thread callback function for sockets
- * Synopsis   : void* socketJob(void* arg)
- * Input      : void* arg = Connexion*: the connection data struct
- * Output     : N/A
- =======================================================================*/
-void* socketJob(void* arg)
-{
-  int me = 0;
-  long int rc = FALSE;
-  Connexion* connexion = 0;
-
-  me = taskSocketNumber;
-  connexion = (Connexion*)arg;
-
-  close(connexion->sock);
-  usleep(50000);
-  logEmit(LOG_NOTICE, "doing job %i for %s", me, connexion->host);
-  usleep(50000);
-  logEmit(LOG_NOTICE, "finish job %i for %s", me, connexion->host);
-  usleep(50000); 
-
-  rc = TRUE;
-  if (connexion) {
-    if (connexion->host) free(connexion->host);
-    free(connexion);
-  }
-  socketJobEnds();
-  return (void*)rc;
-}
-
-/*=======================================================================
- * Function   : usage
- * Description: Print the usage.
- * Synopsis   : static void usage(char* programName)
- * Input      : programName = the name of the program; usually argv[0].
- * Output     : N/A
- =======================================================================*/
-static void 
-usage(char* programName)
-{
-  mdtxUsage(programName);
-
-  mdtxOptions();
-  //fprintf(stderr, "  ---\n");
-  return;
-}
-
-
-/*=======================================================================
- * Function   : main 
- * Author     : 2011/03/05
- * modif      : 2012/05/01
- * Description: Unit test for threads module.
- * Synopsis   : ./utthreads
- * Input      : N/A
- * Output     : N/A
- =======================================================================*/
-int 
-main(int argc, char** argv)
-{
-  // ---
-  int rc = 0;
-  int cOption = EOF;
-  char* programName = *argv;
-  char* options = MDTX_SHORT_OPTIONS;
-  struct option longOptions[] = {
-    MDTX_LONG_OPTIONS,
-    {0, 0, 0, 0}
+  static char status[][64] = {
+   "302 message without collection",
+   "303 message from server '%s' not registered into %s collection",
+   "304 message contains a record not related to author %s but %s",
+   "401 fails to read message",
+   "402 fails to load %s collection's serverTree",
+   "403 fails to get localhost"
   };
 
-  // import mdtx environment
-  getEnv(&env);
+  logMain(LOG_DEBUG, "checkMessage");
+  sprintf(con->status, "%s", status[3]);
+  con->server = 0;
 
-  // parse the command line
-  while((cOption = getopt_long(argc, argv, options, longOptions, 0)) 
-	!= EOF) {
-    switch(cOption) {
-      
-      GET_MDTX_OPTIONS; // generic options
-    }
-    if (rc) goto optError;
+  logRecordTree(LOG_MAIN, LOG_NOTICE, con->message, 
+		con->message->fingerPrint);
+
+  if (!(coll = con->message->collection)) {
+    sprintf(con->status, "%s", status[0]);
+    goto error;
   }
 
-  // export mdtx environment
-  /*
-    in ut, 3 telnet without sleep =>
-    > [err threads.c] pthread_create fails: Resource temporarily unavailable
-    > [err threads.c] pthread_create fails: Resource temporarily unavailable
-  */
-  if (!setEnv(programName, &env)) goto optError;
+  if (!loadCollection(coll, SERV)) {
+    sprintf(con->status, status[4], coll->label);
+    goto error;
+  }
 
-  /************************************************************************/
-  if (!mainLoop()) goto error;
-  /************************************************************************/
- 
+  // minimal upgrade
+  if (!getLocalHost(coll)) {
+    sprintf(con->status, "%s", status[5]);
+    goto error2;
+  }
+  
+  // match server from fingerprint in message header
+  // (may be masqueraded by a Nat server)
+  while ((server = rgNext_r(coll->serverTree->servers, &curr))) {
+    if (!(strncmp(con->message->fingerPrint, server->fingerPrint, 
+		  MAX_SIZE_MD5))) break;
+  }
+  if (server == 0) {
+    sprintf(con->status, status[1], 
+	    con->message->fingerPrint, coll->label);
+    goto error2;
+  }
+
+  // check all records are related to the message's author
+  if (!isEmptyRing(con->message->records)) {
+    curr = 0;
+    while ((record = rgNext_r(con->message->records, &curr))) {
+      if (server != record->server) {
+	sprintf(con->status, status[2], 
+		con->message->fingerPrint, record->server->fingerPrint);
+	goto error2;
+      }
+    }
+  }
+    
+  con->server = server;
   rc = TRUE;
+ error2:
+  if (!releaseCollection(coll, SERV)) rc = FALSE;
  error:
-  freeConfiguration();
-  ENDINGS;
-  rc=!rc;
- optError:
-  exit(rc);
+  if (!rc) {
+    logMain(LOG_ERR, "checkMessage fails");
+  }
+  return rc;
 }
 
-#endif // utMAIN
-
 /* Local Variables: */
 /* mode: c */
 /* mode: font-lock */
