@@ -1,7 +1,7 @@
 /*=======================================================================
- * Version: $Id: threads.h,v 1.3 2015/06/03 14:03:56 nroche Exp $
+ * Version: $Id: threads.h,v 1.6 2015/08/19 01:09:10 nroche Exp $
  * Project: MediaTeX
- * Module : server/threads
+ * Module : threads
  *
  * Handle sockets and signals
 
@@ -32,6 +32,8 @@ typedef struct Connexion {
   // no use to record port here as incoming port is random
   char* host;
   Server* server;
+  char status[576];
+  RecordTree* message;
 } Connexion;
 
 // callback functions requiered
@@ -42,11 +44,14 @@ extern void* socketJob(void* arg);
 
 // to be called by Job callbacks when finishing
 void signalJobEnds();
-void socketJobEnds();
+void socketJobEnds(Connexion* connexion);
 
 // main thread
 int mainLoop();
 
+// common fonction call to parse messages
+int checkMessage(Connexion* con);
+
 #endif /* _MDTX_SERVER_THREADS_H */
 
 /* Local Variables: */
