@@ -23,10 +23,6 @@
  =======================================================================*/
 
 #include "mediatex.h"
-#include "misc/log.h"
-#include "misc/command.h"
-#include "memory/confTree.h"
-#include "common/openClose.h"
 #include "client/commonHtml.h"
 #include "client/catalogHtml.h"
 
@@ -1054,11 +1050,10 @@ main(int argc, char** argv)
   if (!releaseCollection(coll, SERV|CTLG|EXTR)) goto error;
   /************************************************************************/
 
-  freeConfiguration();
   rc = TRUE;
  error:
-  logEmit(LOG_INFO, "** exit on %s **", rc?"success":"error");
-  DefaultLog = logClose(DefaultLog);
+  freeConfiguration();
+  ENDINGS;
   rc=!rc;
  optError:
   exit(rc);
